#include "monty.h"
#include "fusion_p.h"

template<typename T> struct _checked_ptr_1 
{
  T * ptr;
  size_t sz;
  _checked_ptr_1<T>(T * ptr, size_t sz) : ptr(ptr), sz(sz) {} 
  T & operator[](ptrdiff_t i) { assert(i >= 0 && i < sz); return ptr[i]; } 
  const T & operator[](ptrdiff_t i) const { assert(i >= 0 && i < sz); return ptr[i]; } 
  void update(T * ptr_, size_t sz_) { ptr = ptr_; sz = sz_; }
};

template<typename T> struct _checked_ptr_2
{
  T * ptr; 
  size_t sz0, sz1; 
  _checked_ptr_2<T>(T * ptr, size_t sz0, size_t sz1) : ptr(ptr), sz0(sz0),sz1(sz1) {} 
  T & operator()(ptrdiff_t i0, ptrdiff_t i1) { assert(i0 >= 0 && i0 < sz0 && i1 >= 0 && i1 < sz1); return ptr[i0 * sz1 + i1]; } 
  const T & operator()(ptrdiff_t i0, ptrdiff_t i1) const { assert(i0 >= 0 && i0 < sz0 && i1 >= 0 && i1 < sz1); return ptr[i0 * sz1 + i1]; } 
  void update(T * ptr_, size_t sz0_, size_t sz1_) { ptr = ptr_; sz0 = sz0_; sz1 = sz1_; }
};

// See http://www.cplusplus.com/articles/DE18T05o/
//                 A      && ( (       B      && B1 && B2      ) || (      C      &&   C1 &&   C2  ) )
// A a and b a have different signs
// B, B1, B2 a and b are both non-negative, r is less than both a and b
// C, C1, C2 a and b are both negative, r is greater than both a and b

struct InternalNumericOverflow {};

template<typename T> 
static inline T checked_add(T a, T b, bool & overflow) {
  int r = a+b;
  overflow = ((a ^ b) >= 0) && ( (( (a & b) >= 0) && r < a && r < b) || ( ((a & b) < 0) && a < r && b < r) );
  return r;
}

template<typename T>
static inline T safe_add_(T a, T b) {
  bool overflow; 
  T r = checked_add(a,b,overflow);
  if (overflow)
    throw InternalNumericOverflow();
  else
    return r;
}

static inline           int safe_add(int a, int b) { return safe_add_<long long int>(a,b); }
static inline long long int safe_add(long long int a, long long int b) { return safe_add_<long long int>(a,b); }
static inline long long int safe_add(int a, long long int b) { return safe_add_<long long int>(a,b); }
static inline long long int safe_add(long long int a, int b) { return safe_add_<long long int>(a,b); }

template<typename T>
static inline T checked_mul(T a, T b, bool & overflow) {
  T r = a * b;
  overflow = b != 0 && (((a ^ b) >= 0 && a > std::numeric_limits<T>::max() / b) || ((a ^ b) < 0 && a < std::numeric_limits<T>::min() / b));
  return r;
}

template<typename T>
static inline T safe_mul_(T a, T b) {
  bool overflow; 
  T r = checked_mul(a,b,overflow);
  if (overflow)
    throw InternalNumericOverflow();
  else
    return r;
}

static inline           int safe_mul(int a, int b) { return safe_mul_<long long int>(a,b); }
static inline long long int safe_mul(long long int a, long long int b) { return safe_mul_<long long int>(a,b); }
static inline long long int safe_mul(int a, long long int b) { return safe_mul_<long long int>(a,b); }
static inline long long int safe_mul(long long int a, int b) { return safe_mul_<long long int>(a,b); }

std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::StatusKey val){switch (val){case StatusKey::Unknown: os << "StatusKey::Unknown"; break;case StatusKey::Basic: os << "StatusKey::Basic"; break;case StatusKey::SuperBasic: os << "StatusKey::SuperBasic"; break;case StatusKey::OnBound: os << "StatusKey::OnBound"; break;case StatusKey::Infinity: os << "StatusKey::Infinity"; break;default: os << "StatusKey.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::SolutionType val){switch (val){case SolutionType::Default: os << "SolutionType::Default"; break;case SolutionType::Basic: os << "SolutionType::Basic"; break;case SolutionType::Interior: os << "SolutionType::Interior"; break;case SolutionType::Integer: os << "SolutionType::Integer"; break;default: os << "SolutionType.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::ProblemStatus val){switch (val){case ProblemStatus::Unknown: os << "ProblemStatus::Unknown"; break;case ProblemStatus::PrimalAndDualFeasible: os << "ProblemStatus::PrimalAndDualFeasible"; break;case ProblemStatus::PrimalFeasible: os << "ProblemStatus::PrimalFeasible"; break;case ProblemStatus::DualFeasible: os << "ProblemStatus::DualFeasible"; break;case ProblemStatus::PrimalInfeasible: os << "ProblemStatus::PrimalInfeasible"; break;case ProblemStatus::DualInfeasible: os << "ProblemStatus::DualInfeasible"; break;case ProblemStatus::PrimalAndDualInfeasible: os << "ProblemStatus::PrimalAndDualInfeasible"; break;case ProblemStatus::IllPosed: os << "ProblemStatus::IllPosed"; break;case ProblemStatus::PrimalInfeasibleOrUnbounded: os << "ProblemStatus::PrimalInfeasibleOrUnbounded"; break;default: os << "ProblemStatus.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::AccSolutionStatus val){switch (val){case AccSolutionStatus::Anything: os << "AccSolutionStatus::Anything"; break;case AccSolutionStatus::Optimal: os << "AccSolutionStatus::Optimal"; break;case AccSolutionStatus::Feasible: os << "AccSolutionStatus::Feasible"; break;case AccSolutionStatus::Certificate: os << "AccSolutionStatus::Certificate"; break;default: os << "AccSolutionStatus.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::SolutionStatus val){switch (val){case SolutionStatus::Undefined: os << "SolutionStatus::Undefined"; break;case SolutionStatus::Unknown: os << "SolutionStatus::Unknown"; break;case SolutionStatus::Optimal: os << "SolutionStatus::Optimal"; break;case SolutionStatus::Feasible: os << "SolutionStatus::Feasible"; break;case SolutionStatus::Certificate: os << "SolutionStatus::Certificate"; break;case SolutionStatus::IllposedCert: os << "SolutionStatus::IllposedCert"; break;default: os << "SolutionStatus.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::ObjectiveSense val){switch (val){case ObjectiveSense::Undefined: os << "ObjectiveSense::Undefined"; break;case ObjectiveSense::Minimize: os << "ObjectiveSense::Minimize"; break;case ObjectiveSense::Maximize: os << "ObjectiveSense::Maximize"; break;default: os << "ObjectiveSense.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::QConeKey val){switch (val){case QConeKey::InQCone: os << "QConeKey::InQCone"; break;case QConeKey::InRotatedQCone: os << "QConeKey::InRotatedQCone"; break;case QConeKey::InPExpCone: os << "QConeKey::InPExpCone"; break;case QConeKey::InPPowCone: os << "QConeKey::InPPowCone"; break;case QConeKey::InDExpCone: os << "QConeKey::InDExpCone"; break;case QConeKey::InDPowCone: os << "QConeKey::InDPowCone"; break;default: os << "QConeKey.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::PSDKey val){switch (val){case PSDKey::IsSymPSD: os << "PSDKey::IsSymPSD"; break;case PSDKey::IsTrilPSD: os << "PSDKey::IsTrilPSD"; break;default: os << "PSDKey.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::RelationKey val){switch (val){case RelationKey::EqualsTo: os << "RelationKey::EqualsTo"; break;case RelationKey::LessThan: os << "RelationKey::LessThan"; break;case RelationKey::GreaterThan: os << "RelationKey::GreaterThan"; break;case RelationKey::IsFree: os << "RelationKey::IsFree"; break;case RelationKey::InRange: os << "RelationKey::InRange"; break;default: os << "RelationKey.<invalid>"; break;}return os;}mosek::fusion::Sort::Sort(mosek::fusion::p_Sort *_impl) : _impl(_impl) { /*std::cout << "Sort() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Sort::~Sort() { delete _impl; _impl = nullptr; }mosek::fusion::p_Sort::p_Sort  (::mosek::fusion::Sort * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::Sort::argTransposeSort  ( std::shared_ptr< monty::ndarray< long long,1 > > _151,    std::shared_ptr< monty::ndarray< long long,1 > > _152,    int _153,    int _154,    int _155,    std::shared_ptr< monty::ndarray< long long,1 > > _156) { mosek::fusion::p_Sort::argTransposeSort(_151,_152,_153,_154,_155,_156); }void mosek::fusion::p_Sort::argTransposeSort(std::shared_ptr< monty::ndarray< long long,1 > > _151,std::shared_ptr< monty::ndarray< long long,1 > > _152,int _153,int _154,int _155,std::shared_ptr< monty::ndarray< long long,1 > > _156){
  _checked_ptr_1<long long> _ptr__151(_151 ? _151->raw() : nullptr, _151 ? _151->size(0) : 0);
  _checked_ptr_1<long long> _ptr__152(_152 ? _152->raw() : nullptr, _152 ? _152->size(0) : 0);
  _checked_ptr_1<long long> _ptr__156(_156 ? _156->raw() : nullptr, _156 ? _156->size(0) : 0);
  int _6702 = (int)0;
  int _6703 = safe_add( safe_mul( _153,_155 ),(int)1 );
  for (int _157 = _6702; _157 < _6703; ++_157)
  {
    {
      _ptr__152[_157] = (int)0;
    }
  }
  int _6704 = (int)0;
  int _6705 = (int)((_156)->size(0));
  for (int _158 = _6704; _158 < _6705; ++_158)
  {
    {
      ++ _ptr__152[safe_add( safe_add( safe_mul( (_ptr__156[_ptr__151[_158]] / safe_mul( _154,_155 )),_155 ),(_ptr__156[_ptr__151[_158]] % _155) ),(int)1 )];
    }
  }
  int _6706 = (int)0;
  int _6707 = safe_mul( _153,_155 );
  for (int _159 = _6706; _159 < _6707; ++_159)
  {
    {
      _ptr__152[safe_add( _159,(int)1 )] = safe_add( _ptr__152[safe_add( _159,(int)1 )],_ptr__152[_159] );
    }
  }
  std::vector<long long> _6708;
  for (int _161 = (int)0, _6709 = (int)((_151)->size(0)); _161 < _6709 ; ++_161)
  {
    _6708.push_back(_ptr__151[_161]);
  }
  auto _6710 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_6708.size()),_6708.begin(),_6708.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _160 = _6710;
  _checked_ptr_1<long long> _ptr__160(_160 ? _160->raw() : nullptr,_160 ? _160->size(0) : 0);
  long long _6711 = (long long)0;
  long long _6712 = (long long)((_156)->size(0));
  for (long long _162 = _6711; _162 < _6712; ++_162)
  {
    {
      long long _163 = safe_add( safe_mul( (_ptr__156[_ptr__160[_162]] / safe_mul( _154,_155 )),_155 ),(_ptr__156[_ptr__160[_162]] % _155) );
      _ptr__151[_ptr__152[_163]] = _ptr__160[_162];
      ++ _ptr__152[_163];
    }
  }
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _164,    std::shared_ptr< monty::ndarray< long long,1 > > _165) { mosek::fusion::p_Sort::argsort(_164,_165); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _164,std::shared_ptr< monty::ndarray< long long,1 > > _165){
  _checked_ptr_1<long long> _ptr__164(_164 ? _164->raw() : nullptr, _164 ? _164->size(0) : 0);
  _checked_ptr_1<long long> _ptr__165(_165 ? _165->raw() : nullptr, _165 ? _165->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_164,_165,(long long)((int)0),(long long)((int)((_164)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _166,    std::shared_ptr< monty::ndarray< int,1 > > _167) { mosek::fusion::p_Sort::argsort(_166,_167); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _166,std::shared_ptr< monty::ndarray< int,1 > > _167){
  _checked_ptr_1<long long> _ptr__166(_166 ? _166->raw() : nullptr, _166 ? _166->size(0) : 0);
  _checked_ptr_1<int> _ptr__167(_167 ? _167->raw() : nullptr, _167 ? _167->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_166,_167,(long long)((int)0),(long long)((int)((_166)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _168,    std::shared_ptr< monty::ndarray< long long,1 > > _169,    std::shared_ptr< monty::ndarray< long long,1 > > _170) { mosek::fusion::p_Sort::argsort(_168,_169,_170); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _168,std::shared_ptr< monty::ndarray< long long,1 > > _169,std::shared_ptr< monty::ndarray< long long,1 > > _170){
  _checked_ptr_1<long long> _ptr__168(_168 ? _168->raw() : nullptr, _168 ? _168->size(0) : 0);
  _checked_ptr_1<long long> _ptr__169(_169 ? _169->raw() : nullptr, _169 ? _169->size(0) : 0);
  _checked_ptr_1<long long> _ptr__170(_170 ? _170->raw() : nullptr, _170 ? _170->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_168,_169,_170,(long long)((int)0),(long long)((int)((_168)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _171,    std::shared_ptr< monty::ndarray< int,1 > > _172,    std::shared_ptr< monty::ndarray< int,1 > > _173) { mosek::fusion::p_Sort::argsort(_171,_172,_173); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _171,std::shared_ptr< monty::ndarray< int,1 > > _172,std::shared_ptr< monty::ndarray< int,1 > > _173){
  _checked_ptr_1<long long> _ptr__171(_171 ? _171->raw() : nullptr, _171 ? _171->size(0) : 0);
  _checked_ptr_1<int> _ptr__172(_172 ? _172->raw() : nullptr, _172 ? _172->size(0) : 0);
  _checked_ptr_1<int> _ptr__173(_173 ? _173->raw() : nullptr, _173 ? _173->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_171,_172,_173,(long long)((int)0),(long long)((int)((_171)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _174,    std::shared_ptr< monty::ndarray< long long,1 > > _175,    long long _176,    long long _177) { mosek::fusion::p_Sort::argsort(_174,_175,_176,_177); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _174,std::shared_ptr< monty::ndarray< long long,1 > > _175,long long _176,long long _177){
  _checked_ptr_1<long long> _ptr__174(_174 ? _174->raw() : nullptr, _174 ? _174->size(0) : 0);
  _checked_ptr_1<long long> _ptr__175(_175 ? _175->raw() : nullptr, _175 ? _175->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_174,_175,_176,_177,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _178,    std::shared_ptr< monty::ndarray< int,1 > > _179,    long long _180,    long long _181) { mosek::fusion::p_Sort::argsort(_178,_179,_180,_181); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _178,std::shared_ptr< monty::ndarray< int,1 > > _179,long long _180,long long _181){
  _checked_ptr_1<long long> _ptr__178(_178 ? _178->raw() : nullptr, _178 ? _178->size(0) : 0);
  _checked_ptr_1<int> _ptr__179(_179 ? _179->raw() : nullptr, _179 ? _179->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_178,_179,_180,_181,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _182,    std::shared_ptr< monty::ndarray< long long,1 > > _183,    std::shared_ptr< monty::ndarray< long long,1 > > _184,    long long _185,    long long _186) { mosek::fusion::p_Sort::argsort(_182,_183,_184,_185,_186); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _182,std::shared_ptr< monty::ndarray< long long,1 > > _183,std::shared_ptr< monty::ndarray< long long,1 > > _184,long long _185,long long _186){
  _checked_ptr_1<long long> _ptr__182(_182 ? _182->raw() : nullptr, _182 ? _182->size(0) : 0);
  _checked_ptr_1<long long> _ptr__183(_183 ? _183->raw() : nullptr, _183 ? _183->size(0) : 0);
  _checked_ptr_1<long long> _ptr__184(_184 ? _184->raw() : nullptr, _184 ? _184->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_182,_183,_184,_185,_186,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _187,    std::shared_ptr< monty::ndarray< int,1 > > _188,    std::shared_ptr< monty::ndarray< int,1 > > _189,    long long _190,    long long _191) { mosek::fusion::p_Sort::argsort(_187,_188,_189,_190,_191); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _187,std::shared_ptr< monty::ndarray< int,1 > > _188,std::shared_ptr< monty::ndarray< int,1 > > _189,long long _190,long long _191){
  _checked_ptr_1<long long> _ptr__187(_187 ? _187->raw() : nullptr, _187 ? _187->size(0) : 0);
  _checked_ptr_1<int> _ptr__188(_188 ? _188->raw() : nullptr, _188 ? _188->size(0) : 0);
  _checked_ptr_1<int> _ptr__189(_189 ? _189->raw() : nullptr, _189 ? _189->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_187,_188,_189,_190,_191,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _192,    std::shared_ptr< monty::ndarray< long long,1 > > _193,    long long _194,    long long _195,    bool _196) { mosek::fusion::p_Sort::argsort(_192,_193,_194,_195,_196); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _192,std::shared_ptr< monty::ndarray< long long,1 > > _193,long long _194,long long _195,bool _196){
  _checked_ptr_1<long long> _ptr__192(_192 ? _192->raw() : nullptr, _192 ? _192->size(0) : 0);
  _checked_ptr_1<long long> _ptr__193(_193 ? _193->raw() : nullptr, _193 ? _193->size(0) : 0);
  if (((!_196) || ((_195 - _194) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_192,_193,_194,_195);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_192,_193,_194,_195,_196)))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _197 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)4)));
      _checked_ptr_1<long long> _ptr__197(_197 ? _197->raw() : nullptr,_197 ? _197->size(0) : 0);
      int _198 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_192,_193,nullptr,_194,_195,_197);
      if (((_ptr__197[(int)1] - _ptr__197[(int)0]) < safe_mul( _198,(_195 - _194) )))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_192,_193,_194,_195,_ptr__197[(int)0],_ptr__197[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_192,_193,_194,_195);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _199,    std::shared_ptr< monty::ndarray< int,1 > > _200,    long long _201,    long long _202,    bool _203) { mosek::fusion::p_Sort::argsort(_199,_200,_201,_202,_203); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _199,std::shared_ptr< monty::ndarray< int,1 > > _200,long long _201,long long _202,bool _203){
  _checked_ptr_1<long long> _ptr__199(_199 ? _199->raw() : nullptr, _199 ? _199->size(0) : 0);
  _checked_ptr_1<int> _ptr__200(_200 ? _200->raw() : nullptr, _200 ? _200->size(0) : 0);
  if (((!_203) || ((_202 - _201) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_199,_200,_201,_202);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_199,_200,_201,_202,_203)))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _204 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)4)));
      _checked_ptr_1<int> _ptr__204(_204 ? _204->raw() : nullptr,_204 ? _204->size(0) : 0);
      int _205 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_199,_200,nullptr,_201,_202,_204);
      if (((_ptr__204[(int)1] - _ptr__204[(int)0]) < safe_mul( _205,(_202 - _201) )))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_199,_200,_201,_202,_ptr__204[(int)0],_ptr__204[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_199,_200,_201,_202);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _206,    std::shared_ptr< monty::ndarray< long long,1 > > _207,    std::shared_ptr< monty::ndarray< long long,1 > > _208,    long long _209,    long long _210,    bool _211) { mosek::fusion::p_Sort::argsort(_206,_207,_208,_209,_210,_211); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _206,std::shared_ptr< monty::ndarray< long long,1 > > _207,std::shared_ptr< monty::ndarray< long long,1 > > _208,long long _209,long long _210,bool _211){
  _checked_ptr_1<long long> _ptr__206(_206 ? _206->raw() : nullptr, _206 ? _206->size(0) : 0);
  _checked_ptr_1<long long> _ptr__207(_207 ? _207->raw() : nullptr, _207 ? _207->size(0) : 0);
  _checked_ptr_1<long long> _ptr__208(_208 ? _208->raw() : nullptr, _208 ? _208->size(0) : 0);
  if (((!_211) || ((_210 - _209) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_206,_207,_208,_209,_210);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_206,_207,_208,_209,_210,_211)))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _212 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)4)));
      _checked_ptr_1<long long> _ptr__212(_212 ? _212->raw() : nullptr,_212 ? _212->size(0) : 0);
      int _213 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_206,_207,_208,_209,_210,_212);
      if ((((_ptr__212[(int)1] - _ptr__212[(int)0]) < safe_mul( _213,(_210 - _209) )) && ((_ptr__212[(int)3] - _ptr__212[(int)2]) < safe_mul( _213,(_210 - _209) ))))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_206,_208,_209,_210,_ptr__212[(int)2],_ptr__212[(int)3]);
          ::mosek::fusion::p_Sort::argbucketsort(_206,_207,_209,_210,_ptr__212[(int)0],_ptr__212[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_206,_207,_208,_209,_210);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _214,    std::shared_ptr< monty::ndarray< int,1 > > _215,    std::shared_ptr< monty::ndarray< int,1 > > _216,    long long _217,    long long _218,    bool _219) { mosek::fusion::p_Sort::argsort(_214,_215,_216,_217,_218,_219); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _214,std::shared_ptr< monty::ndarray< int,1 > > _215,std::shared_ptr< monty::ndarray< int,1 > > _216,long long _217,long long _218,bool _219){
  _checked_ptr_1<long long> _ptr__214(_214 ? _214->raw() : nullptr, _214 ? _214->size(0) : 0);
  _checked_ptr_1<int> _ptr__215(_215 ? _215->raw() : nullptr, _215 ? _215->size(0) : 0);
  _checked_ptr_1<int> _ptr__216(_216 ? _216->raw() : nullptr, _216 ? _216->size(0) : 0);
  if (((!_219) || ((_218 - _217) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_214,_215,_216,_217,_218);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_214,_215,_216,_217,_218,_219)))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _220 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)4)));
      _checked_ptr_1<int> _ptr__220(_220 ? _220->raw() : nullptr,_220 ? _220->size(0) : 0);
      int _221 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_214,_215,_216,_217,_218,_220);
      if ((((_ptr__220[(int)1] - _ptr__220[(int)0]) < safe_mul( _221,(_218 - _217) )) && ((_ptr__220[(int)3] - _ptr__220[(int)2]) < safe_mul( _221,(_218 - _217) ))))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_214,_216,_217,_218,_ptr__220[(int)2],_ptr__220[(int)3]);
          ::mosek::fusion::p_Sort::argbucketsort(_214,_215,_217,_218,_ptr__220[(int)0],_ptr__220[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_214,_215,_216,_217,_218);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argbucketsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _222,    std::shared_ptr< monty::ndarray< long long,1 > > _223,    long long _224,    long long _225,    long long _226,    long long _227) { mosek::fusion::p_Sort::argbucketsort(_222,_223,_224,_225,_226,_227); }void mosek::fusion::p_Sort::argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _222,std::shared_ptr< monty::ndarray< long long,1 > > _223,long long _224,long long _225,long long _226,long long _227){
  _checked_ptr_1<long long> _ptr__222(_222 ? _222->raw() : nullptr, _222 ? _222->size(0) : 0);
  _checked_ptr_1<long long> _ptr__223(_223 ? _223->raw() : nullptr, _223 ? _223->size(0) : 0);
  ::mosek::fusion::Utils::Tools::bucketsort(_222,_224,_225,_223,_226,_227);
}
void mosek::fusion::Sort::argbucketsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _228,    std::shared_ptr< monty::ndarray< int,1 > > _229,    long long _230,    long long _231,    int _232,    int _233) { mosek::fusion::p_Sort::argbucketsort(_228,_229,_230,_231,_232,_233); }void mosek::fusion::p_Sort::argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _228,std::shared_ptr< monty::ndarray< int,1 > > _229,long long _230,long long _231,int _232,int _233){
  _checked_ptr_1<long long> _ptr__228(_228 ? _228->raw() : nullptr, _228 ? _228->size(0) : 0);
  _checked_ptr_1<int> _ptr__229(_229 ? _229->raw() : nullptr, _229 ? _229->size(0) : 0);
  ::mosek::fusion::Utils::Tools::bucketsort(_228,_230,_231,_229,_232,_233);
}
void mosek::fusion::Sort::getminmax  ( std::shared_ptr< monty::ndarray< long long,1 > > _234,    std::shared_ptr< monty::ndarray< long long,1 > > _235,    std::shared_ptr< monty::ndarray< long long,1 > > _236,    long long _237,    long long _238,    std::shared_ptr< monty::ndarray< long long,1 > > _239) { mosek::fusion::p_Sort::getminmax(_234,_235,_236,_237,_238,_239); }void mosek::fusion::p_Sort::getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _234,std::shared_ptr< monty::ndarray< long long,1 > > _235,std::shared_ptr< monty::ndarray< long long,1 > > _236,long long _237,long long _238,std::shared_ptr< monty::ndarray< long long,1 > > _239){
  _checked_ptr_1<long long> _ptr__234(_234 ? _234->raw() : nullptr, _234 ? _234->size(0) : 0);
  _checked_ptr_1<long long> _ptr__235(_235 ? _235->raw() : nullptr, _235 ? _235->size(0) : 0);
  _checked_ptr_1<long long> _ptr__236(_236 ? _236->raw() : nullptr, _236 ? _236->size(0) : 0);
  _checked_ptr_1<long long> _ptr__239(_239 ? _239->raw() : nullptr, _239 ? _239->size(0) : 0);
  _ptr__239[(int)0] = _ptr__235[_ptr__234[_237]];
  _ptr__239[(int)1] = _ptr__235[_ptr__234[_237]];
  long long _6713 = safe_add( _237,(int)1 );
  long long _6714 = _238;
  for (long long _240 = _6713; _240 < _6714; ++_240)
  {
    {
      if ((_ptr__239[(int)0] > _ptr__235[_ptr__234[_240]]))
      {
        {
          _ptr__239[(int)0] = _ptr__235[_ptr__234[_240]];
        }
      }
      {}
      if ((_ptr__239[(int)1] < _ptr__235[_ptr__234[_240]]))
      {
        {
          _ptr__239[(int)1] = _ptr__235[_ptr__234[_240]];
        }
      }
      {}
    }
  }
  if ((NULL != _236.get()))
  {
    {
      _ptr__239[(int)2] = _ptr__236[_ptr__234[_237]];
      _ptr__239[(int)3] = _ptr__236[_ptr__234[_237]];
      long long _6715 = safe_add( _237,(int)1 );
      long long _6716 = _238;
      for (long long _241 = _6715; _241 < _6716; ++_241)
      {
        {
          if ((_ptr__239[(int)2] > _ptr__236[_ptr__234[_241]]))
          {
            {
              _ptr__239[(int)2] = _ptr__236[_ptr__234[_241]];
            }
          }
          {}
          if ((_ptr__239[(int)3] < _ptr__236[_ptr__234[_241]]))
          {
            {
              _ptr__239[(int)3] = _ptr__236[_ptr__234[_241]];
            }
          }
          {}
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::getminmax  ( std::shared_ptr< monty::ndarray< long long,1 > > _242,    std::shared_ptr< monty::ndarray< int,1 > > _243,    std::shared_ptr< monty::ndarray< int,1 > > _244,    long long _245,    long long _246,    std::shared_ptr< monty::ndarray< int,1 > > _247) { mosek::fusion::p_Sort::getminmax(_242,_243,_244,_245,_246,_247); }void mosek::fusion::p_Sort::getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _242,std::shared_ptr< monty::ndarray< int,1 > > _243,std::shared_ptr< monty::ndarray< int,1 > > _244,long long _245,long long _246,std::shared_ptr< monty::ndarray< int,1 > > _247){
  _checked_ptr_1<long long> _ptr__242(_242 ? _242->raw() : nullptr, _242 ? _242->size(0) : 0);
  _checked_ptr_1<int> _ptr__243(_243 ? _243->raw() : nullptr, _243 ? _243->size(0) : 0);
  _checked_ptr_1<int> _ptr__244(_244 ? _244->raw() : nullptr, _244 ? _244->size(0) : 0);
  _checked_ptr_1<int> _ptr__247(_247 ? _247->raw() : nullptr, _247 ? _247->size(0) : 0);
  _ptr__247[(int)0] = _ptr__243[_ptr__242[_245]];
  _ptr__247[(int)1] = _ptr__243[_ptr__242[_245]];
  long long _6717 = safe_add( _245,(int)1 );
  long long _6718 = _246;
  for (long long _248 = _6717; _248 < _6718; ++_248)
  {
    {
      if ((_ptr__247[(int)0] > _ptr__243[_ptr__242[_248]]))
      {
        {
          _ptr__247[(int)0] = _ptr__243[_ptr__242[_248]];
        }
      }
      {}
      if ((_ptr__247[(int)1] < _ptr__243[_ptr__242[_248]]))
      {
        {
          _ptr__247[(int)1] = _ptr__243[_ptr__242[_248]];
        }
      }
      {}
    }
  }
  if ((NULL != _244.get()))
  {
    {
      _ptr__247[(int)2] = _ptr__244[_ptr__242[_245]];
      _ptr__247[(int)3] = _ptr__244[_ptr__242[_245]];
      long long _6719 = safe_add( _245,(int)1 );
      long long _6720 = _246;
      for (long long _249 = _6719; _249 < _6720; ++_249)
      {
        {
          if ((_ptr__247[(int)2] > _ptr__244[_ptr__242[_249]]))
          {
            {
              _ptr__247[(int)2] = _ptr__244[_ptr__242[_249]];
            }
          }
          {}
          if ((_ptr__247[(int)3] < _ptr__244[_ptr__242[_249]]))
          {
            {
              _ptr__247[(int)3] = _ptr__244[_ptr__242[_249]];
            }
          }
          {}
        }
      }
    }
  }
  {}
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _250,    std::shared_ptr< monty::ndarray< long long,1 > > _251,    long long _252,    long long _253,    bool _254) { return mosek::fusion::p_Sort::issorted(_250,_251,_252,_253,_254); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _250,std::shared_ptr< monty::ndarray< long long,1 > > _251,long long _252,long long _253,bool _254){
  _checked_ptr_1<long long> _ptr__250(_250 ? _250->raw() : nullptr, _250 ? _250->size(0) : 0);
  _checked_ptr_1<long long> _ptr__251(_251 ? _251->raw() : nullptr, _251 ? _251->size(0) : 0);
  long long _6721 = _252;
  long long _6722 = (_253 - (int)1);
  for (long long _255 = _6721; _255 < _6722; ++_255)
  {
    {
      if ((_ptr__251[_ptr__250[_255]] > _ptr__251[_ptr__250[safe_add( _255,(int)1 )]]))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _256,    std::shared_ptr< monty::ndarray< int,1 > > _257,    long long _258,    long long _259,    bool _260) { return mosek::fusion::p_Sort::issorted(_256,_257,_258,_259,_260); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _256,std::shared_ptr< monty::ndarray< int,1 > > _257,long long _258,long long _259,bool _260){
  _checked_ptr_1<long long> _ptr__256(_256 ? _256->raw() : nullptr, _256 ? _256->size(0) : 0);
  _checked_ptr_1<int> _ptr__257(_257 ? _257->raw() : nullptr, _257 ? _257->size(0) : 0);
  long long _6723 = _258;
  long long _6724 = (_259 - (int)1);
  for (long long _261 = _6723; _261 < _6724; ++_261)
  {
    {
      if ((_ptr__257[_ptr__256[_261]] > _ptr__257[_ptr__256[safe_add( _261,(int)1 )]]))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _262,    std::shared_ptr< monty::ndarray< long long,1 > > _263,    std::shared_ptr< monty::ndarray< long long,1 > > _264,    long long _265,    long long _266,    bool _267) { return mosek::fusion::p_Sort::issorted(_262,_263,_264,_265,_266,_267); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _262,std::shared_ptr< monty::ndarray< long long,1 > > _263,std::shared_ptr< monty::ndarray< long long,1 > > _264,long long _265,long long _266,bool _267){
  _checked_ptr_1<long long> _ptr__262(_262 ? _262->raw() : nullptr, _262 ? _262->size(0) : 0);
  _checked_ptr_1<long long> _ptr__263(_263 ? _263->raw() : nullptr, _263 ? _263->size(0) : 0);
  _checked_ptr_1<long long> _ptr__264(_264 ? _264->raw() : nullptr, _264 ? _264->size(0) : 0);
  long long _6725 = _265;
  long long _6726 = (_266 - (int)1);
  for (long long _268 = _6725; _268 < _6726; ++_268)
  {
    {
      if (((_ptr__263[_ptr__262[_268]] > _ptr__263[_ptr__262[safe_add( _268,(int)1 )]]) || ((_ptr__263[_ptr__262[safe_add( _268,(int)1 )]] == _ptr__263[_ptr__262[_268]]) && (_ptr__264[_ptr__262[_268]] > _ptr__264[_ptr__262[safe_add( _268,(int)1 )]]))))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _269,    std::shared_ptr< monty::ndarray< int,1 > > _270,    std::shared_ptr< monty::ndarray< int,1 > > _271,    long long _272,    long long _273,    bool _274) { return mosek::fusion::p_Sort::issorted(_269,_270,_271,_272,_273,_274); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _269,std::shared_ptr< monty::ndarray< int,1 > > _270,std::shared_ptr< monty::ndarray< int,1 > > _271,long long _272,long long _273,bool _274){
  _checked_ptr_1<long long> _ptr__269(_269 ? _269->raw() : nullptr, _269 ? _269->size(0) : 0);
  _checked_ptr_1<int> _ptr__270(_270 ? _270->raw() : nullptr, _270 ? _270->size(0) : 0);
  _checked_ptr_1<int> _ptr__271(_271 ? _271->raw() : nullptr, _271 ? _271->size(0) : 0);
  long long _6727 = _272;
  long long _6728 = (_273 - (int)1);
  for (long long _275 = _6727; _275 < _6728; ++_275)
  {
    {
      if (((_ptr__270[_ptr__269[_275]] > _ptr__270[_ptr__269[safe_add( _275,(int)1 )]]) || ((_ptr__270[_ptr__269[_275]] == _ptr__270[_ptr__269[safe_add( _275,(int)1 )]]) && (_ptr__271[_ptr__269[_275]] > _ptr__271[_ptr__269[safe_add( _275,(int)1 )]]))))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
void mosek::fusion::p_Sort::destroy(){}void mosek::fusion::Sort::destroy() { mosek::fusion::p_Sort::_get_impl(this)->destroy(); }mosek::fusion::IndexCounter::IndexCounter(mosek::fusion::p_IndexCounter *_impl) : _impl(_impl) { /*std::cout << "IndexCounter() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::IndexCounter::~IndexCounter() { delete _impl; _impl = nullptr; }mosek::fusion::p_IndexCounter::p_IndexCounter  (::mosek::fusion::IndexCounter * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::IndexCounter::t mosek::fusion::p_IndexCounter::_new_IndexCounter  (std::shared_ptr< monty::ndarray< int,1 > > _276){ return new mosek::fusion::IndexCounter(_276); }mosek::fusion::IndexCounter::IndexCounter  (std::shared_ptr< monty::ndarray< int,1 > > _276) :    IndexCounter(new mosek::fusion::p_IndexCounter(this)){ mosek::fusion::p_IndexCounter::_get_impl(this)->_initialize(_276); }void mosek::fusion::p_IndexCounter::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _276){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__276(_276 ? _276->raw() : nullptr, _276 ? _276->size(0) : 0);
    n = (int)((_276)->size(0));
    ii = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(n)));
    st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
    start = (long long)0;
    strides = ::mosek::fusion::p_Set::strides(_276);
    std::vector<int> _6729;
    for (int _277 = (int)0, _6730 = (int)((_276)->size(0)); _277 < _6730 ; ++_277)
    {
      _6729.push_back(_ptr__276[_277]);
    }
    auto _6731 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6729.size()),_6729.begin(),_6729.end()));
    dims = _6731;
  }
}mosek::fusion::IndexCounter::t mosek::fusion::p_IndexCounter::_new_IndexCounter  (long long _278,    std::shared_ptr< monty::ndarray< int,1 > > _279,    std::shared_ptr< monty::ndarray< int,1 > > _280){ return new mosek::fusion::IndexCounter(_278,_279,_280); }mosek::fusion::IndexCounter::IndexCounter  (long long _278,    std::shared_ptr< monty::ndarray< int,1 > > _279,    std::shared_ptr< monty::ndarray< int,1 > > _280) :    IndexCounter(new mosek::fusion::p_IndexCounter(this)){ mosek::fusion::p_IndexCounter::_get_impl(this)->_initialize(_278,_279,_280); }void mosek::fusion::p_IndexCounter::_initialize  (long long _278,    std::shared_ptr< monty::ndarray< int,1 > > _279,    std::shared_ptr< monty::ndarray< int,1 > > _280){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__279(_279 ? _279->raw() : nullptr, _279 ? _279->size(0) : 0);
    _checked_ptr_1<int> _ptr__280(_280 ? _280->raw() : nullptr, _280 ? _280->size(0) : 0);
    int _281 = (int)((_280)->size(0));
    n = (int)((_279)->size(0));
    ii = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(n)));
    st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
    int _6732 = (int)0;
    int _6733 = n;
    for (int _282 = _6732; _282 < _6733; ++_282)
    {
      {
        ((*st)(_282)) = _278;
      }
    }
    strides = ::mosek::fusion::p_Set::strides(_280);
    dims = _279;
    start = _278;
  }
}mosek::fusion::IndexCounter::t mosek::fusion::p_IndexCounter::_new_IndexCounter  (long long _283,    std::shared_ptr< monty::ndarray< int,1 > > _284,    std::shared_ptr< monty::ndarray< long long,1 > > _285){ return new mosek::fusion::IndexCounter(_283,_284,_285); }mosek::fusion::IndexCounter::IndexCounter  (long long _283,    std::shared_ptr< monty::ndarray< int,1 > > _284,    std::shared_ptr< monty::ndarray< long long,1 > > _285) :    IndexCounter(new mosek::fusion::p_IndexCounter(this)){ mosek::fusion::p_IndexCounter::_get_impl(this)->_initialize(_283,_284,_285); }void mosek::fusion::p_IndexCounter::_initialize  (long long _283,    std::shared_ptr< monty::ndarray< int,1 > > _284,    std::shared_ptr< monty::ndarray< long long,1 > > _285){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__284(_284 ? _284->raw() : nullptr, _284 ? _284->size(0) : 0);
    _checked_ptr_1<long long> _ptr__285(_285 ? _285->raw() : nullptr, _285 ? _285->size(0) : 0);
    n = (int)((_284)->size(0));
    ii = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(n)));
    st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
    int _6734 = (int)0;
    int _6735 = n;
    for (int _286 = _6734; _286 < _6735; ++_286)
    {
      {
        ((*st)(_286)) = _283;
      }
    }
    strides = _285;
    dims = _284;
    start = _283;
  }
}bool mosek::fusion::IndexCounter :: atEnd() { return mosek::fusion::p_IndexCounter::_get_impl(this)->atEnd(); }bool mosek::fusion::p_IndexCounter::atEnd(){
  return (((*ii)((n - (int)1))) >= ((*dims)((n - (int)1))));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::IndexCounter :: getIndex() { return mosek::fusion::p_IndexCounter::_get_impl(this)->getIndex(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_IndexCounter::getIndex(){
  return ii;
}
long long mosek::fusion::IndexCounter :: next() { return mosek::fusion::p_IndexCounter::_get_impl(this)->next(); }long long mosek::fusion::p_IndexCounter::next(){
  long long _287 = _pubthis->get();
  _pubthis->inc();
  return _287;
}
long long mosek::fusion::IndexCounter :: get() { return mosek::fusion::p_IndexCounter::_get_impl(this)->get(); }long long mosek::fusion::p_IndexCounter::get(){
  return ((*st)((int)0));
}
void mosek::fusion::IndexCounter :: inc() { mosek::fusion::p_IndexCounter::_get_impl(this)->inc(); }void mosek::fusion::p_IndexCounter::inc(){
  ++ ((*ii)((int)0));
  ((*st)((int)0)) = safe_add( ((*st)((int)0)),((*strides)((n - (int)1))) );
  int _288;
  {
    _288 = (int)0;
    for(;((_288 < (n - (int)1)) && (((*ii)(_288)) == ((*dims)(((n - _288) - (int)1)))));++ _288)
    {
      {
        ((*ii)(_288)) = (int)0;
        ++ ((*ii)(safe_add( _288,(int)1 )));
        ((*st)(safe_add( _288,(int)1 ))) = safe_add( ((*st)(safe_add( _288,(int)1 ))),((*strides)(((n - _288) - (int)2))) );
      }
    }
  }
  int _6736 = (int)0;
  int _6737 = _288;
  for (int _289 = _6736; _289 < _6737; ++_289)
  {
    {
      ((*st)(_289)) = ((*st)(_288));
    }
  }
}
void mosek::fusion::IndexCounter :: reset() { mosek::fusion::p_IndexCounter::_get_impl(this)->reset(); }void mosek::fusion::p_IndexCounter::reset(){
  st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
  int _6738 = (int)0;
  int _6739 = n;
  for (int _290 = _6738; _290 < _6739; ++_290)
  {
    {
      ((*st)(_290)) = start;
    }
  }
}
void mosek::fusion::p_IndexCounter::destroy(){dims.reset();strides.reset();st.reset();ii.reset();}void mosek::fusion::IndexCounter::destroy() { mosek::fusion::p_IndexCounter::_get_impl(this)->destroy(); }mosek::fusion::CommonTools::CommonTools(mosek::fusion::p_CommonTools *_impl) : _impl(_impl) { /*std::cout << "CommonTools() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::CommonTools::~CommonTools() { delete _impl; _impl = nullptr; }mosek::fusion::p_CommonTools::p_CommonTools  (::mosek::fusion::CommonTools * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::CommonTools::resize  ( std::shared_ptr< monty::ndarray< long long,1 > > _291,    int _292) { return mosek::fusion::p_CommonTools::resize(_291,_292); }std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_CommonTools::resize(std::shared_ptr< monty::ndarray< long long,1 > > _291,int _292){
  _checked_ptr_1<long long> _ptr__291(_291 ? _291->raw() : nullptr, _291 ? _291->size(0) : 0);
  if ((_292 == (int)((_291)->size(0))))
  {
    {
      return _291;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _293 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_292)));
      _checked_ptr_1<long long> _ptr__293(_293 ? _293->raw() : nullptr,_293 ? _293->size(0) : 0);
      if ((_292 > (int)((_291)->size(0))))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_291,(int)0,_293,(int)0,(int)((_291)->size(0)));
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_291,(int)0,_293,(int)0,_292);
        }
      }
      return _293;
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::CommonTools::resize  ( std::shared_ptr< monty::ndarray< int,1 > > _294,    int _295) { return mosek::fusion::p_CommonTools::resize(_294,_295); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_CommonTools::resize(std::shared_ptr< monty::ndarray< int,1 > > _294,int _295){
  _checked_ptr_1<int> _ptr__294(_294 ? _294->raw() : nullptr, _294 ? _294->size(0) : 0);
  if ((_295 == (int)((_294)->size(0))))
  {
    {
      return _294;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _296 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_295)));
      _checked_ptr_1<int> _ptr__296(_296 ? _296->raw() : nullptr,_296 ? _296->size(0) : 0);
      if ((_295 > (int)((_294)->size(0))))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_294,(int)0,_296,(int)0,(int)((_294)->size(0)));
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_294,(int)0,_296,(int)0,_295);
        }
      }
      return _296;
    }
  }
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::CommonTools::resize  ( std::shared_ptr< monty::ndarray< double,1 > > _297,    int _298) { return mosek::fusion::p_CommonTools::resize(_297,_298); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_CommonTools::resize(std::shared_ptr< monty::ndarray< double,1 > > _297,int _298){
  _checked_ptr_1<double> _ptr__297(_297 ? _297->raw() : nullptr, _297 ? _297->size(0) : 0);
  if ((_298 == (int)((_297)->size(0))))
  {
    {
      return _297;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _299 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_298)));
      _checked_ptr_1<double> _ptr__299(_299 ? _299->raw() : nullptr,_299 ? _299->size(0) : 0);
      if ((_298 > (int)((_297)->size(0))))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_297,(int)0,_299,(int)0,(int)((_297)->size(0)));
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_297,(int)0,_299,(int)0,_298);
        }
      }
      return _299;
    }
  }
}
int mosek::fusion::CommonTools::binarySearch  ( std::shared_ptr< monty::ndarray< int,1 > > _300,    int _301) { return mosek::fusion::p_CommonTools::binarySearch(_300,_301); }int mosek::fusion::p_CommonTools::binarySearch(std::shared_ptr< monty::ndarray< int,1 > > _300,int _301){
  _checked_ptr_1<int> _ptr__300(_300 ? _300->raw() : nullptr, _300 ? _300->size(0) : 0);
  int _302 = (int)0;
  int _303 = (int)((_300)->size(0));
  if ((_ptr__300[_302] == _301))
  {
    {
      return _302;
    }
  }
  else if((_ptr__300[(_303 - (int)1)] == _301))
  {
    {
      return (_303 - (int)1);
    }
  }
  {}
  while ( (_302 < (_303 - (int)1)) )
  {
    {
      int _304 = ((_303 - _302) / (int)2);
      if ((_301 < _ptr__300[_304]))
      {
        {
          _302 = safe_add( _304,(int)1 );
        }
      }
      else if((_301 > _ptr__300[_304]))
      {
        {
          _303 = _304;
        }
      }
      else
      {
        {
          return _304;
        }
      }
    }
  }
  return (-(int)1);
}
int mosek::fusion::CommonTools::binarySearch  ( std::shared_ptr< monty::ndarray< long long,1 > > _305,    long long _306) { return mosek::fusion::p_CommonTools::binarySearch(_305,_306); }int mosek::fusion::p_CommonTools::binarySearch(std::shared_ptr< monty::ndarray< long long,1 > > _305,long long _306){
  _checked_ptr_1<long long> _ptr__305(_305 ? _305->raw() : nullptr, _305 ? _305->size(0) : 0);
  int _307 = ::mosek::fusion::p_CommonTools::binarySearchL(_305,_306);
  if (((_307 < (int)((_305)->size(0))) && (_ptr__305[_307] == _306)))
  {
    {
      return _307;
    }
  }
  else
  {
    {
      return (-(int)1);
    }
  }
}
int mosek::fusion::CommonTools::binarySearchR  ( std::shared_ptr< monty::ndarray< long long,1 > > _308,    long long _309) { return mosek::fusion::p_CommonTools::binarySearchR(_308,_309); }int mosek::fusion::p_CommonTools::binarySearchR(std::shared_ptr< monty::ndarray< long long,1 > > _308,long long _309){
  _checked_ptr_1<long long> _ptr__308(_308 ? _308->raw() : nullptr, _308 ? _308->size(0) : 0);
  int _310 = (int)0;
  int _311 = (int)((_308)->size(0));
  if ((_ptr__308[_310] > _309))
  {
    {
      return _310;
    }
  }
  {}
  while ( (_310 < (_311 - (int)1)) )
  {
    {
      int _312 = (safe_add( _311,_310 ) / (int)2);
      if ((_309 >= _ptr__308[_312]))
      {
        {
          _310 = _312;
        }
      }
      else
      {
        {
          _311 = _312;
        }
      }
    }
  }
  return _311;
}
int mosek::fusion::CommonTools::binarySearchL  ( std::shared_ptr< monty::ndarray< long long,1 > > _313,    long long _314) { return mosek::fusion::p_CommonTools::binarySearchL(_313,_314); }int mosek::fusion::p_CommonTools::binarySearchL(std::shared_ptr< monty::ndarray< long long,1 > > _313,long long _314){
  _checked_ptr_1<long long> _ptr__313(_313 ? _313->raw() : nullptr, _313 ? _313->size(0) : 0);
  int _315 = (int)0;
  int _316 = (int)((_313)->size(0));
  if ((_314 <= _ptr__313[_315]))
  {
    {
      return _315;
    }
  }
  {}
  while ( (_315 < (_316 - (int)1)) )
  {
    {
      int _317 = (safe_add( _316,_315 ) / (int)2);
      if ((_ptr__313[_317] < _314))
      {
        {
          _315 = _317;
        }
      }
      else
      {
        {
          _316 = _317;
        }
      }
    }
  }
  return _316;
}
void mosek::fusion::CommonTools::ndIncr  ( std::shared_ptr< monty::ndarray< int,1 > > _318,    std::shared_ptr< monty::ndarray< int,1 > > _319,    std::shared_ptr< monty::ndarray< int,1 > > _320) { mosek::fusion::p_CommonTools::ndIncr(_318,_319,_320); }void mosek::fusion::p_CommonTools::ndIncr(std::shared_ptr< monty::ndarray< int,1 > > _318,std::shared_ptr< monty::ndarray< int,1 > > _319,std::shared_ptr< monty::ndarray< int,1 > > _320){
  _checked_ptr_1<int> _ptr__318(_318 ? _318->raw() : nullptr, _318 ? _318->size(0) : 0);
  _checked_ptr_1<int> _ptr__319(_319 ? _319->raw() : nullptr, _319 ? _319->size(0) : 0);
  _checked_ptr_1<int> _ptr__320(_320 ? _320->raw() : nullptr, _320 ? _320->size(0) : 0);
  int _321 = ((int)((_318)->size(0)) - (int)1);
  ++ _ptr__318[_321];
  while ( ((_321 > (int)0) && (_ptr__318[_321] >= _ptr__320[_321])) )
  {
    {
      _ptr__318[_321] = _ptr__319[_321];
      ++ _ptr__318[(_321 - (int)1)];
    }
  }
}
void mosek::fusion::CommonTools::transposeTriplets  ( std::shared_ptr< monty::ndarray< int,1 > > _322,    std::shared_ptr< monty::ndarray< int,1 > > _323,    std::shared_ptr< monty::ndarray< double,1 > > _324,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _325,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _326,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _327,    long long _328,    int _329,    int _330) { mosek::fusion::p_CommonTools::transposeTriplets(_322,_323,_324,_325,_326,_327,_328,_329,_330); }void mosek::fusion::p_CommonTools::transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _322,std::shared_ptr< monty::ndarray< int,1 > > _323,std::shared_ptr< monty::ndarray< double,1 > > _324,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _325,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _326,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _327,long long _328,int _329,int _330){
  _checked_ptr_1<int> _ptr__322(_322 ? _322->raw() : nullptr, _322 ? _322->size(0) : 0);
  _checked_ptr_1<int> _ptr__323(_323 ? _323->raw() : nullptr, _323 ? _323->size(0) : 0);
  _checked_ptr_1<double> _ptr__324(_324 ? _324->raw() : nullptr, _324 ? _324->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _331 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _329,(int)2 ))));
  _checked_ptr_1<long long> _ptr__331(_331 ? _331->raw() : nullptr,_331 ? _331->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _332 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _330,(int)2 ))));
  _checked_ptr_1<long long> _ptr__332(_332 ? _332->raw() : nullptr,_332 ? _332->size(0) : 0);
  {
    long long _333 = (long long)0;
    for(;(_333 < _328);++ _333)
    {
      {
        _ptr__332[safe_add( _ptr__323[_333],(int)2 )] = safe_add( _ptr__332[safe_add( _ptr__323[_333],(int)2 )],(int)1 );
        _ptr__331[safe_add( _ptr__322[_333],(int)2 )] = safe_add( _ptr__331[safe_add( _ptr__322[_333],(int)2 )],(int)1 );
      }
    }
  }
  {
    int _334 = (int)1;
    for(;(_334 < _329);++ _334)
    {
      {
        _ptr__331[safe_add( _334,(int)1 )] = safe_add( _ptr__331[safe_add( _334,(int)1 )],_ptr__331[_334] );
      }
    }
  }
  {
    int _335 = (int)1;
    for(;(_335 < _330);++ _335)
    {
      {
        _ptr__332[safe_add( _335,(int)1 )] = safe_add( _ptr__332[safe_add( _335,(int)1 )],_ptr__332[_335] );
      }
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _336 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_328)));
  _checked_ptr_1<long long> _ptr__336(_336 ? _336->raw() : nullptr,_336 ? _336->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _337 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_328)));
  _checked_ptr_1<long long> _ptr__337(_337 ? _337->raw() : nullptr,_337 ? _337->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _338 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_328)));
  _checked_ptr_1<double> _ptr__338(_338 ? _338->raw() : nullptr,_338 ? _338->size(0) : 0);
  int _6740 = (int)0;
  int _6741 = _329;
  for (int _339 = _6740; _339 < _6741; ++_339)
  {
    {
      {
        long long _340 = _ptr__331[_339];
        for(;(_340 < _ptr__331[safe_add( _339,(int)1 )]);++ _340)
        {
          {
            int _341 = _ptr__323[_340];
            long long _342 = _ptr__332[_341];
            _ptr__336[_342] = _339;
            _ptr__337[_342] = _341;
            _ptr__338[_342] = _ptr__324[_340];
            _ptr__332[_341] = safe_add( _342,(int)1 );
          }
        }
      }
    }
  }
  ((*_325)((int)0)) = _337;
  ((*_326)((int)0)) = _336;
  ((*_327)((int)0)) = _338;
}
void mosek::fusion::CommonTools::transposeTriplets  ( std::shared_ptr< monty::ndarray< int,1 > > _343,    std::shared_ptr< monty::ndarray< int,1 > > _344,    std::shared_ptr< monty::ndarray< double,1 > > _345,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _346,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _347,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _348,    long long _349,    int _350,    int _351) { mosek::fusion::p_CommonTools::transposeTriplets(_343,_344,_345,_346,_347,_348,_349,_350,_351); }void mosek::fusion::p_CommonTools::transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _343,std::shared_ptr< monty::ndarray< int,1 > > _344,std::shared_ptr< monty::ndarray< double,1 > > _345,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _346,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _347,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _348,long long _349,int _350,int _351){
  _checked_ptr_1<int> _ptr__343(_343 ? _343->raw() : nullptr, _343 ? _343->size(0) : 0);
  _checked_ptr_1<int> _ptr__344(_344 ? _344->raw() : nullptr, _344 ? _344->size(0) : 0);
  _checked_ptr_1<double> _ptr__345(_345 ? _345->raw() : nullptr, _345 ? _345->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _352 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _350,(int)2 ))));
  _checked_ptr_1<long long> _ptr__352(_352 ? _352->raw() : nullptr,_352 ? _352->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _353 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _351,(int)2 ))));
  _checked_ptr_1<long long> _ptr__353(_353 ? _353->raw() : nullptr,_353 ? _353->size(0) : 0);
  {
    long long _354 = (long long)0;
    for(;(_354 < _349);++ _354)
    {
      {
        _ptr__353[safe_add( _ptr__344[_354],(int)2 )] = safe_add( _ptr__353[safe_add( _ptr__344[_354],(int)2 )],(int)1 );
        _ptr__352[safe_add( _ptr__343[_354],(int)2 )] = safe_add( _ptr__352[safe_add( _ptr__343[_354],(int)2 )],(int)1 );
      }
    }
  }
  {
    int _355 = (int)1;
    for(;(_355 < _350);++ _355)
    {
      {
        _ptr__352[safe_add( _355,(int)1 )] = safe_add( _ptr__352[safe_add( _355,(int)1 )],_ptr__352[_355] );
      }
    }
  }
  {
    int _356 = (int)1;
    for(;(_356 < _351);++ _356)
    {
      {
        _ptr__353[safe_add( _356,(int)1 )] = safe_add( _ptr__353[safe_add( _356,(int)1 )],_ptr__353[_356] );
      }
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _357 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_349)));
  _checked_ptr_1<int> _ptr__357(_357 ? _357->raw() : nullptr,_357 ? _357->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _358 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_349)));
  _checked_ptr_1<int> _ptr__358(_358 ? _358->raw() : nullptr,_358 ? _358->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _359 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_349)));
  _checked_ptr_1<double> _ptr__359(_359 ? _359->raw() : nullptr,_359 ? _359->size(0) : 0);
  {
    int _360 = (int)0;
    for(;(_360 < _350);++ _360)
    {
      {
        long long _6742 = _ptr__352[_360];
        long long _6743 = _ptr__352[safe_add( _360,(int)1 )];
        for (long long _361 = _6742; _361 < _6743; ++_361)
        {
          {
            int _362 = _ptr__344[_361];
            long long _363 = _ptr__353[_362];
            _ptr__357[_363] = _360;
            _ptr__358[_363] = _362;
            _ptr__359[_363] = _ptr__345[_361];
            _ptr__353[_362] = safe_add( _363,(int)1 );
          }
        }
      }
    }
  }
  ((*_346)((int)0)) = _358;
  ((*_347)((int)0)) = _357;
  ((*_348)((int)0)) = _359;
}
void mosek::fusion::CommonTools::tripletSort  ( std::shared_ptr< monty::ndarray< int,1 > > _364,    std::shared_ptr< monty::ndarray< int,1 > > _365,    std::shared_ptr< monty::ndarray< double,1 > > _366,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _367,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _368,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _369,    long long _370,    int _371,    int _372) { mosek::fusion::p_CommonTools::tripletSort(_364,_365,_366,_367,_368,_369,_370,_371,_372); }void mosek::fusion::p_CommonTools::tripletSort(std::shared_ptr< monty::ndarray< int,1 > > _364,std::shared_ptr< monty::ndarray< int,1 > > _365,std::shared_ptr< monty::ndarray< double,1 > > _366,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _367,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _368,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _369,long long _370,int _371,int _372){
  _checked_ptr_1<int> _ptr__364(_364 ? _364->raw() : nullptr, _364 ? _364->size(0) : 0);
  _checked_ptr_1<int> _ptr__365(_365 ? _365->raw() : nullptr, _365 ? _365->size(0) : 0);
  _checked_ptr_1<double> _ptr__366(_366 ? _366->raw() : nullptr, _366 ? _366->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _373 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_370)));
  _checked_ptr_1<int> _ptr__373(_373 ? _373->raw() : nullptr,_373 ? _373->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _374 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _372,(int)2 ))));
  _checked_ptr_1<long long> _ptr__374(_374 ? _374->raw() : nullptr,_374 ? _374->size(0) : 0);
  long long _6744 = (long long)0;
  long long _6745 = _370;
  for (long long _375 = _6744; _375 < _6745; ++_375)
  {
    {
      _ptr__374[safe_add( _ptr__365[_375],(int)2 )] = safe_add( _ptr__374[safe_add( _ptr__365[_375],(int)2 )],(int)1 );
    }
  }
  int _6746 = (int)1;
  int _6747 = _372;
  for (int _376 = _6746; _376 < _6747; ++_376)
  {
    {
      _ptr__374[safe_add( _376,(int)1 )] = safe_add( _ptr__374[safe_add( _376,(int)1 )],_ptr__374[_376] );
    }
  }
  int _6748 = (int)0;
  int _6749 = (int)_370;
  for (int _377 = _6748; _377 < _6749; ++_377)
  {
    {
      int _378 = _ptr__365[_377];
      _ptr__373[_ptr__374[safe_add( _378,(int)1 )]] = _377;
      _ptr__374[safe_add( _378,(int)1 )] = safe_add( _ptr__374[safe_add( _378,(int)1 )],(int)1 );
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _379 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _371,(int)2 ))));
  _checked_ptr_1<long long> _ptr__379(_379 ? _379->raw() : nullptr,_379 ? _379->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _380 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_370)));
  _checked_ptr_1<int> _ptr__380(_380 ? _380->raw() : nullptr,_380 ? _380->size(0) : 0);
  {
    int _381 = (int)0;
    for(;(_381 < _370);++ _381)
    {
      {
        _ptr__379[safe_add( _ptr__364[_381],(int)2 )] = safe_add( _ptr__379[safe_add( _ptr__364[_381],(int)2 )],(int)1 );
      }
    }
  }
  {
    int _382 = (int)1;
    for(;(_382 < _371);++ _382)
    {
      {
        _ptr__379[safe_add( _382,(int)1 )] = safe_add( _ptr__379[safe_add( _382,(int)1 )],_ptr__379[_382] );
      }
    }
  }
  {
    int _383 = (int)0;
    for(;(_383 < _372);++ _383)
    {
      {
        {
          long long _384 = _ptr__374[_383];
          for(;(_384 < _ptr__374[safe_add( _383,(int)1 )]);++ _384)
          {
            {
              int _385 = _ptr__364[_ptr__373[_384]];
              _ptr__380[_ptr__379[safe_add( _385,(int)1 )]] = _ptr__373[_384];
              _ptr__379[safe_add( _385,(int)1 )] = safe_add( _ptr__379[safe_add( _385,(int)1 )],(int)1 );
            }
          }
        }
      }
    }
  }
  int _386 = (int)1;
  {
    int _387 = _ptr__364[_ptr__380[(int)0]];
    int _388 = _ptr__365[_ptr__380[(int)0]];
    {
      int _389 = (int)1;
      for(;(_389 < _370);++ _389)
      {
        {
          int _390 = _ptr__380[_389];
          if (((_387 != _ptr__364[_390]) || (_388 != _ptr__365[_390])))
          {
            {
              _387 = _ptr__364[_390];
              _388 = _ptr__365[_390];
              ++ _386;
            }
          }
          {}
        }
      }
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _391 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_386)));
  _checked_ptr_1<int> _ptr__391(_391 ? _391->raw() : nullptr,_391 ? _391->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _392 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_386)));
  _checked_ptr_1<int> _ptr__392(_392 ? _392->raw() : nullptr,_392 ? _392->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _393 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_386)));
  _checked_ptr_1<double> _ptr__393(_393 ? _393->raw() : nullptr,_393 ? _393->size(0) : 0);
  {
    int _394 = _ptr__380[(int)0];
    _ptr__391[(int)0] = _ptr__364[_394];
    _ptr__392[(int)0] = _ptr__365[_394];
    _ptr__393[(int)0] = _ptr__366[_394];
  }
  int _395 = (int)1;
  int _6750 = (int)1;
  long long _6751 = _370;
  for (long long _396 = _6750; _396 < _6751; ++_396)
  {
    {
      int _397 = _ptr__380[_396];
      if (((_ptr__391[(_395 - (int)1)] == _ptr__364[_397]) && (_ptr__392[(_395 - (int)1)] == _ptr__365[_397])))
      {
        {
          _ptr__393[(_395 - (int)1)] = (_ptr__393[(_395 - (int)1)] + _ptr__366[_397]);
        }
      }
      else
      {
        {
          _ptr__391[_395] = _ptr__364[_397];
          _ptr__392[_395] = _ptr__365[_397];
          _ptr__393[_395] = _ptr__366[_397];
          ++ _395;
        }
      }
    }
  }
  ((*_367)((int)0)) = _391;
  ((*_368)((int)0)) = _392;
  ((*_369)((int)0)) = _393;
}
void mosek::fusion::CommonTools::argMSort  ( std::shared_ptr< monty::ndarray< int,1 > > _398,    std::shared_ptr< monty::ndarray< int,1 > > _399) { mosek::fusion::p_CommonTools::argMSort(_398,_399); }void mosek::fusion::p_CommonTools::argMSort(std::shared_ptr< monty::ndarray< int,1 > > _398,std::shared_ptr< monty::ndarray< int,1 > > _399){
  _checked_ptr_1<int> _ptr__398(_398 ? _398->raw() : nullptr, _398 ? _398->size(0) : 0);
  _checked_ptr_1<int> _ptr__399(_399 ? _399->raw() : nullptr, _399 ? _399->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _400 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_398)->size(0)))));
  _checked_ptr_1<int> _ptr__400(_400 ? _400->raw() : nullptr,_400 ? _400->size(0) : 0);
  bool _401 = false;
  {
    int _402 = (int)1;
    for(;(_402 < (int)((_398)->size(0)));_402 *= (int)2)
    {
      {
        _401 = (!_401);
        int _6752 = (int)0;
        int _6753 = (int)((_398)->size(0));
        int _6754 = safe_mul( _402,(int)2 );
        for (int _403 = _6752; _403 < _6753; _403 += _6754)
        {
          {
            if (_401)
            {
              {
                ::mosek::fusion::p_CommonTools::mergeInto(_398,_400,_399,_403,safe_add( _403,_402 ),safe_add( _403,safe_mul( (int)2,_402 ) ));
              }
            }
            else
            {
              {
                ::mosek::fusion::p_CommonTools::mergeInto(_400,_398,_399,_403,safe_add( _403,_402 ),safe_add( _403,safe_mul( (int)2,_402 ) ));
              }
            }
          }
        }
      }
    }
  }
  if (_401)
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(_400,(int)0,_398,(int)0,(int)((_398)->size(0)));
    }
  }
  {}
}
void mosek::fusion::p_CommonTools::mergeInto(std::shared_ptr< monty::ndarray< int,1 > > _404,std::shared_ptr< monty::ndarray< int,1 > > _405,std::shared_ptr< monty::ndarray< int,1 > > _406,int _407,int _408,int _409){
  _checked_ptr_1<int> _ptr__404(_404 ? _404->raw() : nullptr, _404 ? _404->size(0) : 0);
  _checked_ptr_1<int> _ptr__405(_405 ? _405->raw() : nullptr, _405 ? _405->size(0) : 0);
  _checked_ptr_1<int> _ptr__406(_406 ? _406->raw() : nullptr, _406 ? _406->size(0) : 0);
  int _6755;
  bool _6756 = (_409 > (int)((_404)->size(0)));
  if (_6756)
  {
    _6755 = (int)((_404)->size(0));
  }
  else
  {
    _6755 = _409;
  }
  int _410 = _6755;
  int _6757;
  bool _6758 = (_408 > _410);
  if (_6758)
  {
    _6757 = _410;
  }
  else
  {
    _6757 = _408;
  }
  int _411 = _6757;
  if ((_411 == _410))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(_404,_407,_405,_407,(_411 - _407));
    }
  }
  else
  {
    {
      int _412 = _407;
      int _413 = _411;
      int _414;
      {
        _414 = _407;
        for(;((_412 < _411) && (_413 < _410));++ _414)
        {
          {
            if ((_ptr__406[_ptr__404[_412]] < _ptr__406[_ptr__404[_413]]))
            {
              {
                _ptr__405[_414] = _ptr__404[_412];
                ++ _412;
              }
            }
            else
            {
              {
                _ptr__405[_414] = _ptr__404[_413];
                ++ _413;
              }
            }
          }
        }
      }
      while ( (_412 < _411) )
      {
        {
          _ptr__405[_414] = _ptr__404[_412];
          ++ _412;
          ++ _414;
        }
      }
      while ( (_413 < _410) )
      {
        {
          _ptr__405[_414] = _ptr__404[_413];
          ++ _413;
          ++ _414;
        }
      }
    }
  }
}
void mosek::fusion::CommonTools::argQsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _415,    std::shared_ptr< monty::ndarray< long long,1 > > _416,    std::shared_ptr< monty::ndarray< long long,1 > > _417,    long long _418,    long long _419) { mosek::fusion::p_CommonTools::argQsort(_415,_416,_417,_418,_419); }void mosek::fusion::p_CommonTools::argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _415,std::shared_ptr< monty::ndarray< long long,1 > > _416,std::shared_ptr< monty::ndarray< long long,1 > > _417,long long _418,long long _419){
  _checked_ptr_1<long long> _ptr__415(_415 ? _415->raw() : nullptr, _415 ? _415->size(0) : 0);
  _checked_ptr_1<long long> _ptr__416(_416 ? _416->raw() : nullptr, _416 ? _416->size(0) : 0);
  _checked_ptr_1<long long> _ptr__417(_417 ? _417->raw() : nullptr, _417 ? _417->size(0) : 0);
  if ((NULL == _417.get()))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_415,_416,_418,_419);
    }
  }
  else
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_415,_416,_417,_418,_419);
    }
  }
}
void mosek::fusion::CommonTools::argQsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _420,    std::shared_ptr< monty::ndarray< int,1 > > _421,    std::shared_ptr< monty::ndarray< int,1 > > _422,    long long _423,    long long _424) { mosek::fusion::p_CommonTools::argQsort(_420,_421,_422,_423,_424); }void mosek::fusion::p_CommonTools::argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _420,std::shared_ptr< monty::ndarray< int,1 > > _421,std::shared_ptr< monty::ndarray< int,1 > > _422,long long _423,long long _424){
  _checked_ptr_1<long long> _ptr__420(_420 ? _420->raw() : nullptr, _420 ? _420->size(0) : 0);
  _checked_ptr_1<int> _ptr__421(_421 ? _421->raw() : nullptr, _421 ? _421->size(0) : 0);
  _checked_ptr_1<int> _ptr__422(_422 ? _422->raw() : nullptr, _422 ? _422->size(0) : 0);
  if ((NULL == _422.get()))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_420,_421,_423,_424);
    }
  }
  else
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_420,_421,_422,_423,_424);
    }
  }
}
void mosek::fusion::p_CommonTools::destroy(){}void mosek::fusion::CommonTools::destroy() { mosek::fusion::p_CommonTools::_get_impl(this)->destroy(); }mosek::fusion::SolutionStruct::SolutionStruct(mosek::fusion::p_SolutionStruct *_impl) : _impl(_impl) { /*std::cout << "SolutionStruct() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SolutionStruct::~SolutionStruct() { delete _impl; _impl = nullptr; }mosek::fusion::p_SolutionStruct::p_SolutionStruct  (::mosek::fusion::SolutionStruct * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_yx() { return _impl->yx; }
void mosek::fusion::SolutionStruct::set_yx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->yx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_snx() { return _impl->snx; }
void mosek::fusion::SolutionStruct::set_snx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->snx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_sux() { return _impl->sux; }
void mosek::fusion::SolutionStruct::set_sux(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->sux = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_slx() { return _impl->slx; }
void mosek::fusion::SolutionStruct::set_slx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->slx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_bars() { return _impl->bars; }
void mosek::fusion::SolutionStruct::set_bars(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bars = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_barx() { return _impl->barx; }
void mosek::fusion::SolutionStruct::set_barx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->barx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_y() { return _impl->y; }
void mosek::fusion::SolutionStruct::set_y(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->y = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_suc() { return _impl->suc; }
void mosek::fusion::SolutionStruct::set_suc(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->suc = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_slc() { return _impl->slc; }
void mosek::fusion::SolutionStruct::set_slc(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->slc = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_xx() { return _impl->xx; }
void mosek::fusion::SolutionStruct::set_xx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->xx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_xc() { return _impl->xc; }
void mosek::fusion::SolutionStruct::set_xc(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->xc = _val; }
double mosek::fusion::SolutionStruct::get_dobj() { return _impl->dobj; }
void mosek::fusion::SolutionStruct::set_dobj(double _val) { _impl->dobj = _val; }
double mosek::fusion::SolutionStruct::get_pobj() { return _impl->pobj; }
void mosek::fusion::SolutionStruct::set_pobj(double _val) { _impl->pobj = _val; }
mosek::fusion::ProblemStatus mosek::fusion::SolutionStruct::get_probstatus() { return _impl->probstatus; }
void mosek::fusion::SolutionStruct::set_probstatus(mosek::fusion::ProblemStatus _val) { _impl->probstatus = _val; }
mosek::fusion::SolutionStatus mosek::fusion::SolutionStruct::get_dstatus() { return _impl->dstatus; }
void mosek::fusion::SolutionStruct::set_dstatus(mosek::fusion::SolutionStatus _val) { _impl->dstatus = _val; }
mosek::fusion::SolutionStatus mosek::fusion::SolutionStruct::get_pstatus() { return _impl->pstatus; }
void mosek::fusion::SolutionStruct::set_pstatus(mosek::fusion::SolutionStatus _val) { _impl->pstatus = _val; }
int mosek::fusion::SolutionStruct::get_sol_numbarvar() { return _impl->sol_numbarvar; }
void mosek::fusion::SolutionStruct::set_sol_numbarvar(int _val) { _impl->sol_numbarvar = _val; }
int mosek::fusion::SolutionStruct::get_sol_numcone() { return _impl->sol_numcone; }
void mosek::fusion::SolutionStruct::set_sol_numcone(int _val) { _impl->sol_numcone = _val; }
int mosek::fusion::SolutionStruct::get_sol_numvar() { return _impl->sol_numvar; }
void mosek::fusion::SolutionStruct::set_sol_numvar(int _val) { _impl->sol_numvar = _val; }
int mosek::fusion::SolutionStruct::get_sol_numcon() { return _impl->sol_numcon; }
void mosek::fusion::SolutionStruct::set_sol_numcon(int _val) { _impl->sol_numcon = _val; }
mosek::fusion::SolutionStruct::t mosek::fusion::p_SolutionStruct::_new_SolutionStruct  (int _425,    int _426,    int _427,    int _428){ return new mosek::fusion::SolutionStruct(_425,_426,_427,_428); }mosek::fusion::SolutionStruct::SolutionStruct  (int _425,    int _426,    int _427,    int _428) :    SolutionStruct(new mosek::fusion::p_SolutionStruct(this)){ mosek::fusion::p_SolutionStruct::_get_impl(this)->_initialize(_425,_426,_427,_428); }void mosek::fusion::p_SolutionStruct::_initialize  (int _425,    int _426,    int _427,    int _428){monty::rc_reserve __reserve_this(_pubthis);   {
    pobj = 0.0;
    dobj = 0.0;
    pstatus = ::mosek::fusion::SolutionStatus::Unknown;
    dstatus = ::mosek::fusion::SolutionStatus::Unknown;
    probstatus = ::mosek::fusion::ProblemStatus::Unknown;
    sol_numvar = _425;
    sol_numcon = _426;
    sol_numcone = _427;
    sol_numbarvar = _428;
    slx = nullptr;
    sux = nullptr;
    xx = nullptr;
    yx = nullptr;
    slc = nullptr;
    suc = nullptr;
    y = nullptr;
    xc = nullptr;
    snx = nullptr;
    barx = nullptr;
    bars = nullptr;
    if ((_425 > (int)0))
    {
      {
        slx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
        sux = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
        xx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
        yx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
      }
    }
    {}
    if ((_428 > (int)0))
    {
      {
        barx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_428)));
        bars = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_428)));
      }
    }
    {}
    if ((_426 > (int)0))
    {
      {
        slc = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_426)));
        suc = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_426)));
        y = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_426)));
        xc = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_426)));
      }
    }
    {}
    if ((_427 > (int)0))
    {
      {
        snx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
      }
    }
    {}
  }
}mosek::fusion::SolutionStruct::t mosek::fusion::p_SolutionStruct::_new_SolutionStruct  (monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429){ return new mosek::fusion::SolutionStruct(_429); }mosek::fusion::SolutionStruct::SolutionStruct  (monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429) :    SolutionStruct(new mosek::fusion::p_SolutionStruct(this)){ mosek::fusion::p_SolutionStruct::_get_impl(this)->_initialize(_429); }void mosek::fusion::p_SolutionStruct::_initialize  (monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429){monty::rc_reserve __reserve_this(_pubthis);   {
    sol_numcon = mosek::fusion::p_SolutionStruct::_get_impl(_429)->sol_numcon;
    sol_numvar = mosek::fusion::p_SolutionStruct::_get_impl(_429)->sol_numvar;
    sol_numcone = mosek::fusion::p_SolutionStruct::_get_impl(_429)->sol_numcone;
    sol_numbarvar = mosek::fusion::p_SolutionStruct::_get_impl(_429)->sol_numbarvar;
    pstatus = mosek::fusion::p_SolutionStruct::_get_impl(_429)->pstatus;
    dstatus = mosek::fusion::p_SolutionStruct::_get_impl(_429)->dstatus;
    probstatus = mosek::fusion::p_SolutionStruct::_get_impl(_429)->probstatus;
    pobj = mosek::fusion::p_SolutionStruct::_get_impl(_429)->pobj;
    dobj = mosek::fusion::p_SolutionStruct::_get_impl(_429)->dobj;
    std::shared_ptr< monty::ndarray< double,1 > > _6759;
    bool _6760 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->xc.get());
    if (_6760)
    {
      _6759 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->xc);
    }
    else
    {
      _6759 = nullptr;
    }
    xc = _6759;
    std::shared_ptr< monty::ndarray< double,1 > > _6761;
    bool _6762 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->xx.get());
    if (_6762)
    {
      _6761 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->xx);
    }
    else
    {
      _6761 = nullptr;
    }
    xx = _6761;
    std::shared_ptr< monty::ndarray< double,1 > > _6763;
    bool _6764 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->yx.get());
    if (_6764)
    {
      _6763 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->yx);
    }
    else
    {
      _6763 = nullptr;
    }
    yx = _6763;
    std::shared_ptr< monty::ndarray< double,1 > > _6765;
    bool _6766 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->slc.get());
    if (_6766)
    {
      _6765 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->slx);
    }
    else
    {
      _6765 = nullptr;
    }
    slc = _6765;
    std::shared_ptr< monty::ndarray< double,1 > > _6767;
    bool _6768 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->suc.get());
    if (_6768)
    {
      _6767 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->sux);
    }
    else
    {
      _6767 = nullptr;
    }
    suc = _6767;
    std::shared_ptr< monty::ndarray< double,1 > > _6769;
    bool _6770 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->y.get());
    if (_6770)
    {
      _6769 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->y);
    }
    else
    {
      _6769 = nullptr;
    }
    y = _6769;
    barx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->barx);
    bars = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->bars);
    std::shared_ptr< monty::ndarray< double,1 > > _6771;
    bool _6772 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->slx.get());
    if (_6772)
    {
      _6771 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->slx);
    }
    else
    {
      _6771 = nullptr;
    }
    slx = _6771;
    std::shared_ptr< monty::ndarray< double,1 > > _6773;
    bool _6774 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->sux.get());
    if (_6774)
    {
      _6773 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->sux);
    }
    else
    {
      _6773 = nullptr;
    }
    sux = _6773;
    std::shared_ptr< monty::ndarray< double,1 > > _6775;
    bool _6776 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->snx.get());
    if (_6776)
    {
      _6775 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->snx);
    }
    else
    {
      _6775 = nullptr;
    }
    snx = _6775;
  }
}monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::SolutionStruct :: __mosek_2fusion_2SolutionStruct__clone() { return mosek::fusion::p_SolutionStruct::_get_impl(this)->__mosek_2fusion_2SolutionStruct__clone(); }monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::SolutionStruct::clone() { return __mosek_2fusion_2SolutionStruct__clone(); }
monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::p_SolutionStruct::__mosek_2fusion_2SolutionStruct__clone(){
  return ::mosek::fusion::p_SolutionStruct::_new_SolutionStruct(::mosek::fusion::SolutionStruct::t(_pubthis));
}
void mosek::fusion::SolutionStruct :: resize(int _430,int _431,int _432,int _433) { mosek::fusion::p_SolutionStruct::_get_impl(this)->resize(_430,_431,_432,_433); }void mosek::fusion::p_SolutionStruct::resize(int _430,int _431,int _432,int _433){
  if ((_433 < (int)0))
  {
    {
    }
  }
  else if((_433 <= sol_numbarvar))
  {
    {
      sol_numbarvar = _433;
    }
  }
  else if((_433 <= (int)((barx)->size(0))))
  {
    {
    }
  }
  else
  {
    {
      int _434;
      if ((safe_mul( sol_numbarvar,(int)2 ) > safe_add( _433,(int)100 )))
      {
        {
          _434 = safe_mul( sol_numbarvar,(int)2 );
        }
      }
      else
      {
        {
          _434 = safe_add( _433,(int)100 );
        }
      }
      barx = ::mosek::fusion::p_CommonTools::resize(barx,_434);
      bars = ::mosek::fusion::p_CommonTools::resize(bars,_434);
      sol_numbarvar = _434;
    }
  }
  if ((_430 < (int)0))
  {
    {
    }
  }
  else if((_430 <= sol_numvar))
  {
    {
      sol_numvar = _430;
    }
  }
  else if((_430 <= (int)((xx)->size(0))))
  {
    {
      int _6777 = sol_numvar;
      int _6778 = _430;
      for (int _435 = _6777; _435 < _6778; ++_435)
      {
        {
          ((*slx)(_435)) = 0.0;
          ((*sux)(_435)) = 0.0;
          ((*xx)(_435)) = 0.0;
          ((*yx)(_435)) = 0.0;
        }
      }
      sol_numvar = _430;
    }
  }
  else
  {
    {
      int _436;
      if ((safe_mul( sol_numvar,(int)2 ) > safe_add( _430,(int)100 )))
      {
        {
          _436 = safe_mul( sol_numvar,(int)2 );
        }
      }
      else
      {
        {
          _436 = safe_add( _430,(int)100 );
        }
      }
      std::shared_ptr< monty::ndarray< double,1 > > _437 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_436)));
      _checked_ptr_1<double> _ptr__437(_437 ? _437->raw() : nullptr,_437 ? _437->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(slx,(int)0,_437,(int)0,(int)((slx)->size(0)));
      slx = _437;
      std::shared_ptr< monty::ndarray< double,1 > > _438 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_436)));
      _checked_ptr_1<double> _ptr__438(_438 ? _438->raw() : nullptr,_438 ? _438->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(sux,(int)0,_438,(int)0,(int)((sux)->size(0)));
      sux = _438;
      std::shared_ptr< monty::ndarray< double,1 > > _439 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_436)));
      _checked_ptr_1<double> _ptr__439(_439 ? _439->raw() : nullptr,_439 ? _439->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(xx,(int)0,_439,(int)0,(int)((xx)->size(0)));
      xx = _439;
      std::shared_ptr< monty::ndarray< double,1 > > _440 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_436)));
      _checked_ptr_1<double> _ptr__440(_440 ? _440->raw() : nullptr,_440 ? _440->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(yx,(int)0,_440,(int)0,(int)((yx)->size(0)));
      yx = _440;
      {
        int _441 = sol_numvar;
        for(;(_441 < _430);++ _441)
        {
          {
            ((*slx)(_441)) = 0.0;
            ((*sux)(_441)) = 0.0;
            ((*xx)(_441)) = 0.0;
          }
        }
      }
      sol_numvar = _430;
    }
  }
  if ((_431 < (int)0))
  {
    {
    }
  }
  else if((_431 <= sol_numcon))
  {
    {
      sol_numcon = _431;
    }
  }
  else if((_431 <= (int)((xx)->size(0))))
  {
    {
      int _6779 = sol_numcon;
      int _6780 = _431;
      for (int _442 = _6779; _442 < _6780; ++_442)
      {
        {
          ((*slc)(_442)) = 0.0;
          ((*suc)(_442)) = 0.0;
          ((*xc)(_442)) = 0.0;
          ((*y)(_442)) = 0.0;
        }
      }
      sol_numcon = _431;
    }
  }
  else
  {
    {
      int _443;
      if ((safe_mul( sol_numcon,(int)2 ) > safe_add( _431,(int)100 )))
      {
        {
          _443 = safe_mul( sol_numcon,(int)2 );
        }
      }
      else
      {
        {
          _443 = safe_add( _431,(int)100 );
        }
      }
      std::shared_ptr< monty::ndarray< double,1 > > _444 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_443)));
      _checked_ptr_1<double> _ptr__444(_444 ? _444->raw() : nullptr,_444 ? _444->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(slc,(int)0,_444,(int)0,(int)((slc)->size(0)));
      slc = _444;
      std::shared_ptr< monty::ndarray< double,1 > > _445 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_443)));
      _checked_ptr_1<double> _ptr__445(_445 ? _445->raw() : nullptr,_445 ? _445->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(suc,(int)0,_445,(int)0,(int)((suc)->size(0)));
      suc = _445;
      std::shared_ptr< monty::ndarray< double,1 > > _446 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_443)));
      _checked_ptr_1<double> _ptr__446(_446 ? _446->raw() : nullptr,_446 ? _446->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(xc,(int)0,_446,(int)0,(int)((xc)->size(0)));
      xc = _446;
      std::shared_ptr< monty::ndarray< double,1 > > _447 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_443)));
      _checked_ptr_1<double> _ptr__447(_447 ? _447->raw() : nullptr,_447 ? _447->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(y,(int)0,_447,(int)0,(int)((y)->size(0)));
      y = _447;
      int _6781 = sol_numcon;
      int _6782 = _431;
      for (int _448 = _6781; _448 < _6782; ++_448)
      {
        {
          ((*slc)(_448)) = 0.0;
          ((*suc)(_448)) = 0.0;
          ((*xc)(_448)) = 0.0;
          ((*y)(_448)) = 0.0;
        }
      }
      sol_numcon = _431;
    }
  }
  if ((_432 < (int)0))
  {
    {
    }
  }
  else if((_432 <= sol_numcone))
  {
    {
      sol_numcone = _432;
    }
  }
  else if((_432 <= (int)((xx)->size(0))))
  {
    {
      int _6783 = sol_numcone;
      int _6784 = _432;
      for (int _449 = _6783; _449 < _6784; ++_449)
      {
        {
          ((*snx)(_449)) = 0.0;
        }
      }
      sol_numcone = _432;
    }
  }
  else
  {
    {
      int _450;
      if ((safe_mul( sol_numcone,(int)2 ) > safe_add( _432,(int)100 )))
      {
        {
          _450 = safe_mul( sol_numcone,(int)2 );
        }
      }
      else
      {
        {
          _450 = safe_add( _432,(int)100 );
        }
      }
      std::shared_ptr< monty::ndarray< double,1 > > _451 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_450)));
      _checked_ptr_1<double> _ptr__451(_451 ? _451->raw() : nullptr,_451 ? _451->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(snx,(int)0,_451,(int)0,(int)((snx)->size(0)));
      snx = _451;
      {
        int _452 = sol_numcone;
        for(;(_452 < _432);++ _452)
        {
          {
            ((*snx)(_452)) = 0.0;
          }
        }
      }
      sol_numcone = _432;
    }
  }
}
bool mosek::fusion::SolutionStruct :: isDualAcceptable(mosek::fusion::AccSolutionStatus _453) { return mosek::fusion::p_SolutionStruct::_get_impl(this)->isDualAcceptable(_453); }bool mosek::fusion::p_SolutionStruct::isDualAcceptable(mosek::fusion::AccSolutionStatus _453){
  return isAcceptable(dstatus,_453);
}
bool mosek::fusion::SolutionStruct :: isPrimalAcceptable(mosek::fusion::AccSolutionStatus _454) { return mosek::fusion::p_SolutionStruct::_get_impl(this)->isPrimalAcceptable(_454); }bool mosek::fusion::p_SolutionStruct::isPrimalAcceptable(mosek::fusion::AccSolutionStatus _454){
  return isAcceptable(pstatus,_454);
}
bool mosek::fusion::p_SolutionStruct::isAcceptable(mosek::fusion::SolutionStatus _455,mosek::fusion::AccSolutionStatus _456){
  if ((_456 == ::mosek::fusion::AccSolutionStatus::Anything))
  {
    {
      return true;
    }
  }
  else if((_456 == ::mosek::fusion::AccSolutionStatus::Optimal))
  {
    {
      return (_455 == ::mosek::fusion::SolutionStatus::Optimal);
    }
  }
  else if((_456 == ::mosek::fusion::AccSolutionStatus::Feasible))
  {
    {
      return ((_455 == ::mosek::fusion::SolutionStatus::Optimal) || (_455 == ::mosek::fusion::SolutionStatus::Feasible));
    }
  }
  else if((_456 == ::mosek::fusion::AccSolutionStatus::Certificate))
  {
    {
      return (_455 == ::mosek::fusion::SolutionStatus::Certificate);
    }
  }
  {}
  return false;
}
void mosek::fusion::p_SolutionStruct::destroy(){yx.reset();snx.reset();sux.reset();slx.reset();bars.reset();barx.reset();y.reset();suc.reset();slc.reset();xx.reset();xc.reset();}void mosek::fusion::SolutionStruct::destroy() { mosek::fusion::p_SolutionStruct::_get_impl(this)->destroy(); }mosek::fusion::ConNZStruct::ConNZStruct(mosek::fusion::p_ConNZStruct *_impl) : _impl(_impl) { /*std::cout << "ConNZStruct() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ConNZStruct::~ConNZStruct() { delete _impl; _impl = nullptr; }mosek::fusion::p_ConNZStruct::p_ConNZStruct  (::mosek::fusion::ConNZStruct * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_barmidx() { return _impl->barmidx; }
void mosek::fusion::ConNZStruct::set_barmidx(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barmidx = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_barsubj() { return _impl->barsubj; }
void mosek::fusion::ConNZStruct::set_barsubj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubj = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_barsubi() { return _impl->barsubi; }
void mosek::fusion::ConNZStruct::set_barsubi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubi = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConNZStruct::get_bfix() { return _impl->bfix; }
void mosek::fusion::ConNZStruct::set_bfix(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bfix = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConNZStruct::get_cof() { return _impl->cof; }
void mosek::fusion::ConNZStruct::set_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->cof = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_subj() { return _impl->subj; }
void mosek::fusion::ConNZStruct::set_subj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->subj = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::ConNZStruct::get_ptrb() { return _impl->ptrb; }
void mosek::fusion::ConNZStruct::set_ptrb(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->ptrb = _val; }
mosek::fusion::ConNZStruct::t mosek::fusion::p_ConNZStruct::_new_ConNZStruct  (std::shared_ptr< monty::ndarray< long long,1 > > _457,    std::shared_ptr< monty::ndarray< int,1 > > _458,    std::shared_ptr< monty::ndarray< double,1 > > _459,    std::shared_ptr< monty::ndarray< double,1 > > _460,    std::shared_ptr< monty::ndarray< int,1 > > _461,    std::shared_ptr< monty::ndarray< int,1 > > _462,    std::shared_ptr< monty::ndarray< int,1 > > _463){ return new mosek::fusion::ConNZStruct(_457,_458,_459,_460,_461,_462,_463); }mosek::fusion::ConNZStruct::ConNZStruct  (std::shared_ptr< monty::ndarray< long long,1 > > _457,    std::shared_ptr< monty::ndarray< int,1 > > _458,    std::shared_ptr< monty::ndarray< double,1 > > _459,    std::shared_ptr< monty::ndarray< double,1 > > _460,    std::shared_ptr< monty::ndarray< int,1 > > _461,    std::shared_ptr< monty::ndarray< int,1 > > _462,    std::shared_ptr< monty::ndarray< int,1 > > _463) :    ConNZStruct(new mosek::fusion::p_ConNZStruct(this)){ mosek::fusion::p_ConNZStruct::_get_impl(this)->_initialize(_457,_458,_459,_460,_461,_462,_463); }void mosek::fusion::p_ConNZStruct::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _457,    std::shared_ptr< monty::ndarray< int,1 > > _458,    std::shared_ptr< monty::ndarray< double,1 > > _459,    std::shared_ptr< monty::ndarray< double,1 > > _460,    std::shared_ptr< monty::ndarray< int,1 > > _461,    std::shared_ptr< monty::ndarray< int,1 > > _462,    std::shared_ptr< monty::ndarray< int,1 > > _463){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__457(_457 ? _457->raw() : nullptr, _457 ? _457->size(0) : 0);
    _checked_ptr_1<int> _ptr__458(_458 ? _458->raw() : nullptr, _458 ? _458->size(0) : 0);
    _checked_ptr_1<double> _ptr__459(_459 ? _459->raw() : nullptr, _459 ? _459->size(0) : 0);
    _checked_ptr_1<double> _ptr__460(_460 ? _460->raw() : nullptr, _460 ? _460->size(0) : 0);
    _checked_ptr_1<int> _ptr__461(_461 ? _461->raw() : nullptr, _461 ? _461->size(0) : 0);
    _checked_ptr_1<int> _ptr__462(_462 ? _462->raw() : nullptr, _462 ? _462->size(0) : 0);
    _checked_ptr_1<int> _ptr__463(_463 ? _463->raw() : nullptr, _463 ? _463->size(0) : 0);
    ptrb = _457;
    subj = _458;
    cof = _459;
    bfix = _460;
    barsubi = _461;
    barsubj = _462;
    barmidx = _463;
  }
}void mosek::fusion::p_ConNZStruct::destroy(){barmidx.reset();barsubj.reset();barsubi.reset();bfix.reset();cof.reset();subj.reset();ptrb.reset();}void mosek::fusion::ConNZStruct::destroy() { mosek::fusion::p_ConNZStruct::_get_impl(this)->destroy(); }mosek::fusion::Model::Model(mosek::fusion::p_Model *_impl) : mosek::fusion::BaseModel(_impl) { /*std::cout << "Model()" << this << std::endl; */ }mosek::fusion::Model::~Model() {  /* std::cout << "~Model()" << this << std::endl << std::flush; */ }mosek::fusion::p_Model::p_Model  (::mosek::fusion::Model * _pubthis) :     mosek::fusion::p_BaseModel(_pubthis),    _pubthis(_pubthis){}mosek::fusion::Model::t mosek::fusion::p_Model::_new_Model  (monty::rc_ptr< ::mosek::fusion::Model > _464){ return new mosek::fusion::Model(_464); }mosek::fusion::Model::Model  (monty::rc_ptr< ::mosek::fusion::Model > _464) :    Model(new mosek::fusion::p_Model(this)){ mosek::fusion::p_Model::_get_impl(this)->_initialize(_464); }void mosek::fusion::p_Model::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _464){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseModel::_initialize(_464);
    monty::rc_ptr< ::mosek::fusion::Model > _465 = ::mosek::fusion::Model::t(_pubthis);
    model_name = mosek::fusion::p_Model::_get_impl(_464)->model_name;
    acceptable_sol = mosek::fusion::p_Model::_get_impl(_464)->acceptable_sol;
    solutionptr = mosek::fusion::p_Model::_get_impl(_464)->solutionptr;
    natvarmap_blockid = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natvarmap_blockid);
    natvarmap_idx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natvarmap_idx);
    natvarmap_type = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natvarmap_type);
    natvarmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks(mosek::fusion::p_Model::_get_impl(_464)->natvarmap);
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelVariable >> _6785;
    for (int _466 = (int)0, _6786 = (int)((mosek::fusion::p_Model::_get_impl(_464)->vars)->size(0)); _466 < _6786 ; ++_466)
    {
      monty::rc_ptr< ::mosek::fusion::ModelVariable > _6787;
      bool _6788 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_464)->vars)(_466)).get());
      if (_6788)
      {
        _6787 = mosek::fusion::p_ModelVariable::_get_impl(((*mosek::fusion::p_Model::_get_impl(_464)->vars)(_466)).get())->__mosek_2fusion_2ModelVariable__clone(_465);
      }
      else
      {
        _6787 = nullptr;
      }
      _6785.push_back(_6787);
    }
    auto _6789 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_6785.size()),_6785.begin(),_6785.end()));
    vars = _6789;
    natconemap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks(mosek::fusion::p_Model::_get_impl(_464)->natconemap);
    natconemap_dim = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconemap_dim);
    natbarvar_numbarvarelm = mosek::fusion::p_Model::_get_impl(_464)->natbarvar_numbarvarelm;
    natbarvar_ptr = ::mosek::fusion::Utils::Tools::arraycopy(natbarvar_ptr);
    natbarvar_i = ::mosek::fusion::Utils::Tools::arraycopy(natbarvar_i);
    natbarvar_j = ::mosek::fusion::Utils::Tools::arraycopy(natbarvar_j);
    natbarvar_idx = ::mosek::fusion::Utils::Tools::arraycopy(natbarvar_idx);
    natbarvarmap_nblock = mosek::fusion::p_Model::_get_impl(_464)->natbarvarmap_nblock;
    natbarvar_dim = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natbarvar_dim);
    natbarvarmap_num = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natbarvarmap_num);
    natbarvarmap_ptr = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natbarvarmap_ptr);
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelVariable >> _6790;
    for (int _467 = (int)0, _6791 = (int)((mosek::fusion::p_Model::_get_impl(_464)->barvars)->size(0)); _467 < _6791 ; ++_467)
    {
      monty::rc_ptr< ::mosek::fusion::ModelVariable > _6792;
      bool _6793 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_464)->barvars)(_467)).get());
      if (_6793)
      {
        _6792 = mosek::fusion::p_ModelVariable::_get_impl(((*mosek::fusion::p_Model::_get_impl(_464)->barvars)(_467)).get())->__mosek_2fusion_2ModelVariable__clone(_465);
      }
      else
      {
        _6792 = nullptr;
      }
      _6790.push_back(_6792);
    }
    auto _6794 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_6790.size()),_6790.begin(),_6790.end()));
    barvars = _6794;
    var_map = mosek::fusion::p_Model::_get_impl(_464)->var_map->__mosek_2fusion_2Utils_2StringIntMap__clone();
    natconmap_blockid = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_blockid);
    natconmap_slackidx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_slackidx);
    natconmap_idx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_idx);
    natconmap_type = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_type);
    natconmap_efix = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_efix);
    natconmap_lb = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_lb);
    natconmap_ub = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_ub);
    natconmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks(mosek::fusion::p_Model::_get_impl(_464)->natconmap);
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelConstraint >> _6795;
    for (int _468 = (int)0, _6796 = (int)((mosek::fusion::p_Model::_get_impl(_464)->cons)->size(0)); _468 < _6796 ; ++_468)
    {
      monty::rc_ptr< ::mosek::fusion::ModelConstraint > _6797;
      bool _6798 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_464)->cons)(_468)).get());
      if (_6798)
      {
        _6797 = mosek::fusion::p_ModelConstraint::_get_impl(((*mosek::fusion::p_Model::_get_impl(_464)->cons)(_468)).get())->__mosek_2fusion_2ModelConstraint__clone(_465);
      }
      else
      {
        _6797 = nullptr;
      }
      _6795.push_back(_6797);
    }
    auto _6799 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 >(monty::shape(_6795.size()),_6795.begin(),_6795.end()));
    cons = _6799;
    con_map = mosek::fusion::p_Model::_get_impl(_464)->con_map->__mosek_2fusion_2Utils_2StringIntMap__clone();
    initsol_xx = nullptr;
    initsol_xx_flag = nullptr;
    bfixidx = mosek::fusion::p_Model::_get_impl(_464)->bfixidx;
    rs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    ws = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    xs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  }
}mosek::fusion::Model::t mosek::fusion::p_Model::_new_Model  (const std::string &  _469){ return new mosek::fusion::Model(_469); }mosek::fusion::Model::Model  (const std::string &  _469) :    Model(new mosek::fusion::p_Model(this)){ mosek::fusion::p_Model::_get_impl(this)->_initialize(_469); }void mosek::fusion::p_Model::_initialize  (const std::string &  _469){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseModel::_initialize(_469,std::string (""));
    model_name = _469;
    acceptable_sol = ::mosek::fusion::AccSolutionStatus::Optimal;
    solutionptr = ::mosek::fusion::SolutionType::Default;
    natvarmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks();
    natvarmap_blockid = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natvarmap_idx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natvarmap_type = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelVariable >> _6800;
    for (int _470 = (int)0, _6801 = (int)1024; _470 < _6801 ; ++_470)
    {
      _6800.push_back(nullptr);
    }
    auto _6802 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_6800.size()),_6800.begin(),_6800.end()));
    vars = _6802;
    natconemap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks();
    natconemap_dim = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    barvars = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape((int)0)));
    natbarvar_ptr = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0)));
    natbarvar_numbarvarelm = (int)0;
    natbarvar_i = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvar_j = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvar_idx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvarmap_nblock = (int)0;
    natbarvar_dim = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvarmap_num = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvarmap_ptr = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)});
    barvars = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape((int)0)));
    var_map = ::mosek::fusion::Utils::p_StringIntMap::_new_StringIntMap();
    initsol_xx = nullptr;
    initsol_xx_flag = nullptr;
    natconmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks();
    natconmap_blockid = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_slackidx = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)1024)));
    natconmap_idx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_type = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_efix = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)1024)));
    natconmap_lb = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)1024)));
    natconmap_ub = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)1024)));
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelConstraint >> _6803;
    for (int _471 = (int)0, _6804 = (int)1024; _471 < _6804 ; ++_471)
    {
      _6803.push_back(nullptr);
    }
    auto _6805 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 >(monty::shape(_6803.size()),_6803.begin(),_6803.end()));
    cons = _6805;
    con_map = ::mosek::fusion::Utils::p_StringIntMap::_new_StringIntMap();
    bfixidx = natvarmap_alloc((int)1);
    task_var_putboundlist_fx(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(bfixidx)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}));
    task_var_name(bfixidx,std::string ("1.0"));
    rs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    ws = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    xs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  }
}mosek::fusion::Model::t mosek::fusion::p_Model::_new_Model  (){ return new mosek::fusion::Model(); }mosek::fusion::Model::Model  () :    Model(new mosek::fusion::p_Model(this)){ mosek::fusion::p_Model::_get_impl(this)->_initialize(); }void mosek::fusion::p_Model::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Model::_initialize(std::string (""));
  }
}monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_Model::__mosek_2fusion_2Model__formstConstr(monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _472,std::shared_ptr< monty::ndarray< int,1 > > _473,std::shared_ptr< monty::ndarray< int,1 > > _474){
  _checked_ptr_1<int> _ptr__473(_473 ? _473->raw() : nullptr, _473 ? _473->size(0) : 0);
  _checked_ptr_1<int> _ptr__474(_474 ? _474->raw() : nullptr, _474 ? _474->size(0) : 0);
  return _472;
}
void mosek::fusion::p_Model::connames(std::shared_ptr< monty::ndarray< int,1 > > _475,const std::string & _476,std::shared_ptr< monty::ndarray< int,1 > > _477,std::shared_ptr< monty::ndarray< long long,1 > > _478){
  _checked_ptr_1<int> _ptr__475(_475 ? _475->raw() : nullptr, _475 ? _475->size(0) : 0);
  _checked_ptr_1<int> _ptr__477(_477 ? _477->raw() : nullptr, _477 ? _477->size(0) : 0);
  _checked_ptr_1<long long> _ptr__478(_478 ? _478->raw() : nullptr, _478 ? _478->size(0) : 0);
  task_format_con_names(_475,_476,_477,_478);
}
void mosek::fusion::p_Model::varnames(std::shared_ptr< monty::ndarray< int,1 > > _479,const std::string & _480,std::shared_ptr< monty::ndarray< int,1 > > _481,std::shared_ptr< monty::ndarray< long long,1 > > _482){
  _checked_ptr_1<int> _ptr__479(_479 ? _479->raw() : nullptr, _479 ? _479->size(0) : 0);
  _checked_ptr_1<int> _ptr__481(_481 ? _481->raw() : nullptr, _481 ? _481->size(0) : 0);
  _checked_ptr_1<long long> _ptr__482(_482 ? _482->raw() : nullptr, _482 ? _482->size(0) : 0);
  task_format_var_names(_479,_480,_481,_482);
}
void mosek::fusion::p_Model::varname(int _483,const std::string & _484){
  task_var_name(_483,_484);
}
void mosek::fusion::p_Model::natbarvarmap_get(int _485,std::shared_ptr< monty::ndarray< int,1 > > _486){
  _checked_ptr_1<int> _ptr__486(_486 ? _486->raw() : nullptr, _486 ? _486->size(0) : 0);
  int _487 = ((*natbarvarmap_ptr)(_485));
  int _488 = ((*natbarvarmap_num)(_485));
  int _6806 = (int)0;
  int _6807 = _488;
  for (int _489 = _6806; _489 < _6807; ++_489)
  {
    {
      _ptr__486[_489] = safe_add( _487,_489 );
    }
  }
}
void mosek::fusion::p_Model::natbarvar_get(int _490,std::shared_ptr< monty::ndarray< long long,1 > > _491){
  _checked_ptr_1<long long> _ptr__491(_491 ? _491->raw() : nullptr, _491 ? _491->size(0) : 0);
  int _492 = ((*natbarvarmap_ptr)(_490));
  int _493 = ((*natbarvarmap_num)(_490));
  int _494 = ((*natbarvar_dim)(((*natbarvarmap_ptr)(_490))));
  int _495 = (safe_mul( safe_mul( _493,_494 ),safe_add( _494,(int)1 ) ) / (int)2);
  long long _496 = ((*natbarvar_ptr)(_492));
  int _6808 = (int)0;
  int _6809 = _495;
  for (int _497 = _6808; _497 < _6809; ++_497)
  {
    {
      _ptr__491[_497] = safe_add( _496,_497 );
    }
  }
}
int mosek::fusion::p_Model::natbarvarmap_alloc(int _498,int _499){
  int _500 = (int)((natbarvar_idx)->size(0));
  int _501 = task_numbarvar();
  int _502 = (safe_mul( _499,safe_add( _499,(int)1 ) ) / (int)2);
  int _503 = safe_mul( _498,_502 );
  if ((safe_add( natbarvar_numbarvarelm,_503 ) >= _500))
  {
    {
      if ((_503 < _500))
      {
        {
          _503 = _500;
        }
      }
      {}
      natbarvar_idx = ::mosek::fusion::p_CommonTools::resize(natbarvar_idx,safe_add( _500,_503 ));
      natbarvar_i = ::mosek::fusion::p_CommonTools::resize(natbarvar_i,safe_add( _500,_503 ));
      natbarvar_j = ::mosek::fusion::p_CommonTools::resize(natbarvar_j,safe_add( _500,_503 ));
    }
  }
  {}
  if ((safe_add( natbarvarmap_nblock,(int)1 ) >= (int)((natbarvarmap_num)->size(0))))
  {
    {
      int _6810;
      bool _6811 = ((int)((natbarvarmap_num)->size(0)) > (int)0);
      if (_6811)
      {
        _6810 = safe_mul( (int)((natbarvarmap_num)->size(0)),(int)2 );
      }
      else
      {
        _6810 = (int)32;
      }
      int _504 = _6810;
      natbarvarmap_num = ::mosek::fusion::p_CommonTools::resize(natbarvarmap_num,_504);
      natbarvarmap_ptr = ::mosek::fusion::p_CommonTools::resize(natbarvarmap_ptr,safe_add( _504,(int)1 ));
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > _505 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_504)));
      int _6812 = (int)0;
      int _6813 = (int)((barvars)->size(0));
      for (int _506 = _6812; _506 < _6813; ++_506)
      {
        {
          ((*_505)(_506)) = ((*barvars)(_506));
        }
      }
      barvars = _505;
    }
  }
  {}
  if ((safe_add( _501,_498 ) > (int)((natbarvar_dim)->size(0))))
  {
    {
      int _6814;
      bool _6815 = (safe_add( _501,_498 ) < safe_mul( (int)((natbarvar_dim)->size(0)),(int)2 ));
      if (_6815)
      {
        _6814 = safe_mul( (int)((natbarvar_dim)->size(0)),(int)2 );
      }
      else
      {
        _6814 = safe_add( _501,_498 );
      }
      int _507 = _6814;
      natbarvar_dim = ::mosek::fusion::p_CommonTools::resize(natbarvar_dim,_507);
    }
  }
  {}
  if ((safe_add( _501,_498 ) >= (int)((natbarvar_ptr)->size(0))))
  {
    {
      int _6816;
      bool _6817 = (_498 > (int)((natbarvar_ptr)->size(0)));
      if (_6817)
      {
        _6816 = _498;
      }
      else
      {
        _6816 = (int)((natbarvar_ptr)->size(0));
      }
      int _508 = _6816;
      natbarvar_ptr = ::mosek::fusion::p_CommonTools::resize(natbarvar_ptr,safe_add( safe_add( (int)((natbarvar_ptr)->size(0)),_508 ),(int)1 ));
    }
  }
  {}
  int _6818 = (int)0;
  int _6819 = _498;
  for (int _509 = _6818; _509 < _6819; ++_509)
  {
    {
      ((*natbarvar_dim)(safe_add( _501,_509 ))) = _499;
    }
  }
  ((*natbarvarmap_num)(natbarvarmap_nblock)) = _498;
  ((*natbarvarmap_ptr)(safe_add( natbarvarmap_nblock,(int)1 ))) = safe_add( ((*natbarvarmap_ptr)(natbarvarmap_nblock)),_498 );
  int _510 = task_append_barvar(_499,_498);
  int _511 = ((*natbarvarmap_ptr)(natbarvarmap_nblock));
  {
    long long _512 = ((*natbarvar_ptr)(_501));
    int _6820 = (int)0;
    int _6821 = _499;
    for (int _513 = _6820; _513 < _6821; ++_513)
    {
      {
        int _6822 = _513;
        int _6823 = _499;
        for (int _514 = _6822; _514 < _6823; ++_514)
        {
          {
            int _6824 = (int)0;
            int _6825 = _498;
            for (int _515 = _6824; _515 < _6825; ++_515)
            {
              {
                ((*natbarvar_idx)(safe_add( _512,safe_mul( _515,_502 ) ))) = safe_add( _511,_515 );
                ((*natbarvar_i)(safe_add( _512,safe_mul( _515,_502 ) ))) = _514;
                ((*natbarvar_j)(safe_add( _512,safe_mul( _515,_502 ) ))) = _513;
              }
            }
            ++ _512;
          }
        }
      }
    }
    int _6826 = (int)0;
    int _6827 = _498;
    for (int _516 = _6826; _516 < _6827; ++_516)
    {
      {
        ((*natbarvar_ptr)(safe_add( safe_add( _511,_516 ),(int)1 ))) = safe_add( ((*natbarvar_ptr)(safe_add( _511,_516 ))),_502 );
      }
    }
  }
  natbarvarmap_nblock += (int)1;
  natbarvar_numbarvarelm += safe_mul( _498,_502 );
  return (natbarvarmap_nblock - (int)1);
}
int mosek::fusion::p_Model::natvarmap_alloc(int _517){
  int _518 = natvarmap->alloc(_517);
  int _519 = safe_add( natvarmap->maxidx(_518),(int)1 );
  int _520 = natvarmap->capacity();
  int _521 = natvarmap->numblocks();
  if (((int)((natvarmap_idx)->size(0)) < _520))
  {
    {
      int _522 = (int)((natvarmap_idx)->size(0));
      natvarmap_idx = ::mosek::fusion::p_CommonTools::resize(natvarmap_idx,_520);
      int _6828 = _522;
      int _6829 = _520;
      for (int _523 = _6828; _523 < _6829; ++_523)
      {
        {
          ((*natvarmap_idx)(_523)) = (-(int)1);
        }
      }
      natvarmap_blockid = ::mosek::fusion::p_CommonTools::resize(natvarmap_blockid,_520);
    }
  }
  {}
  if (((int)((vars)->size(0)) < _521))
  {
    {
      natvarmap_type = ::mosek::fusion::p_CommonTools::resize(natvarmap_type,_521);
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > _524 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_521)));
      int _6830 = (int)0;
      int _6831 = (int)((vars)->size(0));
      for (int _525 = _6830; _525 < _6831; ++_525)
      {
        {
          ((*_524)(_525)) = ((*vars)(_525));
        }
      }
      int _6832 = (int)((vars)->size(0));
      int _6833 = (int)((_524)->size(0));
      for (int _526 = _6832; _526 < _6833; ++_526)
      {
        {
          ((*_524)(_526)) = nullptr;
        }
      }
      vars = _524;
    }
  }
  {}
  if ((task_numvar() < _519))
  {
    {
      task_append_var((_519 - task_numvar()));
    }
  }
  {}
  return _518;
}
int mosek::fusion::p_Model::natconmap_alloc(int _527){
  int _528 = natconmap->alloc(_527);
  int _529 = safe_add( natconmap->maxidx(_528),(int)1 );
  int _530 = natconmap->capacity();
  int _531 = natconmap->numblocks();
  if (((int)((natconmap_idx)->size(0)) < _530))
  {
    {
      int _532 = (int)((natconmap_idx)->size(0));
      natconmap_idx = ::mosek::fusion::p_CommonTools::resize(natconmap_idx,_530);
      int _6834 = _532;
      int _6835 = _530;
      for (int _533 = _6834; _533 < _6835; ++_533)
      {
        {
          ((*natconmap_idx)(_533)) = (-(int)1);
        }
      }
      natconmap_efix = ::mosek::fusion::p_CommonTools::resize(natconmap_efix,_530);
      natconmap_lb = ::mosek::fusion::p_CommonTools::resize(natconmap_lb,_530);
      natconmap_ub = ::mosek::fusion::p_CommonTools::resize(natconmap_ub,_530);
      natconmap_blockid = ::mosek::fusion::p_CommonTools::resize(natconmap_blockid,_530);
      natconmap_slackidx = ::mosek::fusion::p_CommonTools::resize(natconmap_slackidx,_530);
    }
  }
  {}
  if (((int)((cons)->size(0)) < _531))
  {
    {
      natconmap_type = ::mosek::fusion::p_CommonTools::resize(natconmap_type,_531);
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > > _534 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 >(monty::shape(_531)));
      int _6836 = (int)0;
      int _6837 = (int)((cons)->size(0));
      for (int _535 = _6836; _535 < _6837; ++_535)
      {
        {
          ((*_534)(_535)) = ((*cons)(_535));
        }
      }
      int _6838 = (int)((cons)->size(0));
      int _6839 = _531;
      for (int _536 = _6838; _536 < _6839; ++_536)
      {
        {
          ((*_534)(_536)) = nullptr;
        }
      }
      cons = _534;
    }
  }
  {}
  if ((_529 > task_numcon()))
  {
    {
      task_append_con((_529 - task_numcon()));
    }
  }
  {}
  return _528;
}
int mosek::fusion::p_Model::natconemap_alloc(int _537){
  int _538 = natconemap->alloc(_537);
  int _539 = safe_add( natconemap->maxidx(_538),(int)1 );
  if ((_539 > task_numcone()))
  {
    {
      task_append_zerocones((_539 - task_numcone()));
    }
  }
  {}
  natconemap_dim = ::mosek::fusion::p_CommonTools::resize(natconemap_dim,natconemap->numblocks());
  return _538;
}
void mosek::fusion::p_Model::make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _540){
  _checked_ptr_1<long long> _ptr__540(_540 ? _540->raw() : nullptr, _540 ? _540->size(0) : 0);
  int _541 = (int)0;
  int _6840 = (int)0;
  int _6841 = (int)((_540)->size(0));
  for (int _542 = _6840; _542 < _6841; ++_542)
  {
    {
      if ((_ptr__540[_542] > (int)0))
      {
        {
          ++ _541;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _543 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_541)));
  _checked_ptr_1<int> _ptr__543(_543 ? _543->raw() : nullptr,_543 ? _543->size(0) : 0);
  int _544 = (int)0;
  int _6842 = (int)0;
  int _6843 = (int)((_540)->size(0));
  for (int _545 = _6842; _545 < _6843; ++_545)
  {
    {
      if ((_ptr__540[_545] > (int)0))
      {
        {
          _ptr__543[_544] = (int)(_ptr__540[_545] - (int)1);
          ++ _544;
        }
      }
      {}
    }
  }
  task_var_putcontlist(_543);
}
void mosek::fusion::p_Model::make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _546){
  _checked_ptr_1<long long> _ptr__546(_546 ? _546->raw() : nullptr, _546 ? _546->size(0) : 0);
  int _547 = (int)0;
  int _6844 = (int)0;
  int _6845 = (int)((_546)->size(0));
  for (int _548 = _6844; _548 < _6845; ++_548)
  {
    {
      if ((_ptr__546[_548] > (int)0))
      {
        {
          ++ _547;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _549 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_547)));
  _checked_ptr_1<int> _ptr__549(_549 ? _549->raw() : nullptr,_549 ? _549->size(0) : 0);
  int _550 = (int)0;
  int _6846 = (int)0;
  int _6847 = (int)((_546)->size(0));
  for (int _551 = _6846; _551 < _6847; ++_551)
  {
    {
      if ((_ptr__546[_551] > (int)0))
      {
        {
          _ptr__549[_550] = (int)(_ptr__546[_551] - (int)1);
          ++ _550;
        }
      }
      {}
    }
  }
  task_var_putintlist(_549);
}
void mosek::fusion::Model::putlicensewait  ( bool _552) { mosek::fusion::p_Model::putlicensewait(_552); }void mosek::fusion::p_Model::putlicensewait(bool _552){
  ::mosek::fusion::p_BaseModel::env_putlicensewait(_552);
}
void mosek::fusion::Model::putlicensepath  ( const std::string & _553) { mosek::fusion::p_Model::putlicensepath(_553); }void mosek::fusion::p_Model::putlicensepath(const std::string & _553){
  ::mosek::fusion::p_BaseModel::env_putlicensepath(_553);
}
void mosek::fusion::Model::putlicensecode  ( std::shared_ptr< monty::ndarray< int,1 > > _554) { mosek::fusion::p_Model::putlicensecode(_554); }void mosek::fusion::p_Model::putlicensecode(std::shared_ptr< monty::ndarray< int,1 > > _554){
  _checked_ptr_1<int> _ptr__554(_554 ? _554->raw() : nullptr, _554 ? _554->size(0) : 0);
  ::mosek::fusion::p_BaseModel::env_putlicensecode(_554);
}
void mosek::fusion::Model :: dispose() { mosek::fusion::p_Model::_get_impl(this)->dispose(); }void mosek::fusion::p_Model::dispose(){
  int _6848 = (int)0;
  int _6849 = (int)((vars)->size(0));
  for (int _555 = _6848; _555 < _6849; ++_555)
  {
    {
      ((*vars)(_555)) = nullptr;
    }
  }
  int _6850 = (int)0;
  int _6851 = (int)((cons)->size(0));
  for (int _556 = _6850; _556 < _6851; ++_556)
  {
    {
      ((*cons)(_556)) = nullptr;
    }
  }
  ::mosek::fusion::p_BaseModel::dispose();
}
void mosek::fusion::p_Model::nativeVarToStr(int _557,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _558){
  if (((_557 < (int)0) || ((_557 >= (int)((natvarmap_idx)->size(0))) || (((*natvarmap_idx)(_557)) < (int)0))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Native variable index is invalid"));
    }
  }
  {}
  ((*vars)(((*natvarmap_blockid)(_557))))->elementName((long long)(((*natvarmap_idx)(_557))),_558);
}
MSKtask_t mosek::fusion::Model :: __mosek_2fusion_2Model__getTask() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getTask(); }MSKtask_t mosek::fusion::Model::getTask() { return __mosek_2fusion_2Model__getTask(); }
MSKtask_t mosek::fusion::p_Model::__mosek_2fusion_2Model__getTask(){
  return __mosek_2fusion_2BaseModel__task_get();
}
void mosek::fusion::Model :: getConstraintValues(bool _559,std::shared_ptr< monty::ndarray< int,1 > > _560,std::shared_ptr< monty::ndarray< double,1 > > _561,int _562) { mosek::fusion::p_Model::_get_impl(this)->getConstraintValues(_559,_560,_561,_562); }void mosek::fusion::p_Model::getConstraintValues(bool _559,std::shared_ptr< monty::ndarray< int,1 > > _560,std::shared_ptr< monty::ndarray< double,1 > > _561,int _562){
  _checked_ptr_1<int> _ptr__560(_560 ? _560->raw() : nullptr, _560 ? _560->size(0) : 0);
  _checked_ptr_1<double> _ptr__561(_561 ? _561->raw() : nullptr, _561 ? _561->size(0) : 0);
  int _563 = (int)((_560)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _6852;
  bool _6853 = _559;
  if (_6853)
  {
    _6852 = getSolution_xx(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6852 = getSolution_yx(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _564 = _6852;
  _checked_ptr_1<double> _ptr__564(_564 ? _564->raw() : nullptr,_564 ? _564->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6854;
  bool _6855 = _559;
  if (_6855)
  {
    _6854 = getSolution_barx(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6854 = getSolution_bars(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _565 = _6854;
  _checked_ptr_1<double> _ptr__565(_565 ? _565->raw() : nullptr,_565 ? _565->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6856;
  bool _6857 = _559;
  if (_6857)
  {
    _6856 = getSolution_xc(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6856 = getSolution_y(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _566 = _6856;
  _checked_ptr_1<double> _ptr__566(_566 ? _566->raw() : nullptr,_566 ? _566->size(0) : 0);
  int _6858 = (int)0;
  int _6859 = _563;
  for (int _567 = _6858; _567 < _6859; ++_567)
  {
    {
      long long _568 = ((*natconmap_slackidx)(_ptr__560[_567]));
      if ((_568 < (int)0))
      {
        {
          long long _569 = (-safe_add( _568,(int)1 ));
          _ptr__561[safe_add( _562,_567 )] = _ptr__565[_569];
        }
      }
      else if((_568 > (int)0))
      {
        {
          _ptr__561[safe_add( _562,_567 )] = _ptr__564[(_568 - (int)1)];
        }
      }
      else
      {
        {
          _ptr__561[safe_add( _562,_567 )] = _ptr__566[_ptr__560[_567]];
        }
      }
    }
  }
}
void mosek::fusion::Model :: getVariableDuals(bool _570,std::shared_ptr< monty::ndarray< long long,1 > > _571,std::shared_ptr< monty::ndarray< double,1 > > _572,int _573) { mosek::fusion::p_Model::_get_impl(this)->getVariableDuals(_570,_571,_572,_573); }void mosek::fusion::p_Model::getVariableDuals(bool _570,std::shared_ptr< monty::ndarray< long long,1 > > _571,std::shared_ptr< monty::ndarray< double,1 > > _572,int _573){
  _checked_ptr_1<long long> _ptr__571(_571 ? _571->raw() : nullptr, _571 ? _571->size(0) : 0);
  _checked_ptr_1<double> _ptr__572(_572 ? _572->raw() : nullptr, _572 ? _572->size(0) : 0);
  int _574 = (int)((_571)->size(0));
  if (_570)
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _575 = getSolution_slx(::mosek::fusion::SolutionType::Default);
      _checked_ptr_1<double> _ptr__575(_575 ? _575->raw() : nullptr,_575 ? _575->size(0) : 0);
      int _6860 = (int)0;
      int _6861 = _574;
      for (int _576 = _6860; _576 < _6861; ++_576)
      {
        {
          if ((_ptr__571[_576] > (int)0))
          {
            {
              _ptr__572[safe_add( _573,_576 )] = _ptr__575[(_ptr__571[_576] - (int)1)];
            }
          }
          else
          {
            {
              _ptr__572[safe_add( _573,_576 )] = (int)0;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _577 = getSolution_sux(::mosek::fusion::SolutionType::Default);
      _checked_ptr_1<double> _ptr__577(_577 ? _577->raw() : nullptr,_577 ? _577->size(0) : 0);
      int _6862 = (int)0;
      int _6863 = _574;
      for (int _578 = _6862; _578 < _6863; ++_578)
      {
        {
          if ((_ptr__571[_578] > (int)0))
          {
            {
              _ptr__572[safe_add( _573,_578 )] = (-_ptr__577[(_ptr__571[_578] - (int)1)]);
            }
          }
          else
          {
            {
              _ptr__572[safe_add( _573,_578 )] = (int)0;
            }
          }
        }
      }
    }
  }
}
void mosek::fusion::Model :: getVariableValues(bool _579,std::shared_ptr< monty::ndarray< long long,1 > > _580,std::shared_ptr< monty::ndarray< double,1 > > _581,int _582) { mosek::fusion::p_Model::_get_impl(this)->getVariableValues(_579,_580,_581,_582); }void mosek::fusion::p_Model::getVariableValues(bool _579,std::shared_ptr< monty::ndarray< long long,1 > > _580,std::shared_ptr< monty::ndarray< double,1 > > _581,int _582){
  _checked_ptr_1<long long> _ptr__580(_580 ? _580->raw() : nullptr, _580 ? _580->size(0) : 0);
  _checked_ptr_1<double> _ptr__581(_581 ? _581->raw() : nullptr, _581 ? _581->size(0) : 0);
  int _583 = (int)((_580)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _6864;
  bool _6865 = _579;
  if (_6865)
  {
    _6864 = getSolution_xx(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6864 = getSolution_yx(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _584 = _6864;
  _checked_ptr_1<double> _ptr__584(_584 ? _584->raw() : nullptr,_584 ? _584->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6866;
  bool _6867 = (natbarvar_numbarvarelm > (int)0);
  if (_6867)
  {
    std::shared_ptr< monty::ndarray< double,1 > > _6868;
    bool _6869 = _579;
    if (_6869)
    {
      _6868 = getSolution_barx(::mosek::fusion::SolutionType::Default);
    }
    else
    {
      _6868 = getSolution_bars(::mosek::fusion::SolutionType::Default);
    }
    _6866 = _6868;
  }
  else
  {
    _6866 = nullptr;
  }
  std::shared_ptr< monty::ndarray< double,1 > > _585 = _6866;
  _checked_ptr_1<double> _ptr__585(_585 ? _585->raw() : nullptr,_585 ? _585->size(0) : 0);
  int _6870 = (int)0;
  int _6871 = _583;
  for (int _586 = _6870; _586 < _6871; ++_586)
  {
    {
      if ((_ptr__580[_586] > (int)0))
      {
        {
          _ptr__581[safe_add( _582,_586 )] = _ptr__584[(_ptr__580[_586] - (int)1)];
        }
      }
      else if((_ptr__580[_586] < (int)0))
      {
        {
          long long _587 = (-safe_add( _ptr__580[_586],(int)1 ));
          _ptr__581[safe_add( _582,_586 )] = _ptr__585[_587];
        }
      }
      else
      {
        {
          _ptr__581[safe_add( _582,_586 )] = (int)0;
        }
      }
    }
  }
}
void mosek::fusion::Model :: setVariableValues(bool _588,std::shared_ptr< monty::ndarray< long long,1 > > _589,std::shared_ptr< monty::ndarray< double,1 > > _590) { mosek::fusion::p_Model::_get_impl(this)->setVariableValues(_588,_589,_590); }void mosek::fusion::p_Model::setVariableValues(bool _588,std::shared_ptr< monty::ndarray< long long,1 > > _589,std::shared_ptr< monty::ndarray< double,1 > > _590){
  _checked_ptr_1<long long> _ptr__589(_589 ? _589->raw() : nullptr, _589 ? _589->size(0) : 0);
  _checked_ptr_1<double> _ptr__590(_590 ? _590->raw() : nullptr, _590 ? _590->size(0) : 0);
  if (_588)
  {
    {
      int _591 = (int)0;
      int _6872 = (int)0;
      int _6873 = (int)((_589)->size(0));
      for (int _592 = _6872; _592 < _6873; ++_592)
      {
        {
          if ((_ptr__589[_592] >= (int)0))
          {
            {
              ++ _591;
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _593 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_591)));
      _checked_ptr_1<int> _ptr__593(_593 ? _593->raw() : nullptr,_593 ? _593->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _6874;
      bool _6875 = (_591 == (int)((_589)->size(0)));
      if (_6875)
      {
        _6874 = _590;
      }
      else
      {
        _6874 = _590;
      }
      std::shared_ptr< monty::ndarray< double,1 > > _594 = _6874;
      _checked_ptr_1<double> _ptr__594(_594 ? _594->raw() : nullptr,_594 ? _594->size(0) : 0);
      int _595 = (int)0;
      int _6876 = (int)0;
      int _6877 = (int)((_589)->size(0));
      for (int _596 = _6876; _596 < _6877; ++_596)
      {
        {
          if ((_ptr__589[_596] > (int)0))
          {
            {
              _ptr__593[_595] = (int)(_ptr__589[_596] - (int)1);
              ++ _595;
            }
          }
          {}
        }
      }
      setSolution_xx(_593,_594);
    }
  }
  else
  {
    {
    }
  }
}
void mosek::fusion::Model :: flushNames() { mosek::fusion::p_Model::_get_impl(this)->flushNames(); }void mosek::fusion::p_Model::flushNames(){
  int _6878 = (int)0;
  int _6879 = (int)((vars)->size(0));
  for (int _597 = _6878; _597 < _6879; ++_597)
  {
    {
      if ((NULL != ((*vars)(_597)).get()))
      {
        {
          mosek::fusion::p_ModelVariable::_get_impl(((*vars)(_597)).get())->flushNames();
        }
      }
      {}
    }
  }
  int _6880 = (int)0;
  int _6881 = (int)((barvars)->size(0));
  for (int _598 = _6880; _598 < _6881; ++_598)
  {
    {
      if ((NULL != ((*barvars)(_598)).get()))
      {
        {
          mosek::fusion::p_ModelVariable::_get_impl(((*barvars)(_598)).get())->flushNames();
        }
      }
      {}
    }
  }
  int _6882 = (int)0;
  int _6883 = (int)((cons)->size(0));
  for (int _599 = _6882; _599 < _6883; ++_599)
  {
    {
      if ((NULL != ((*cons)(_599)).get()))
      {
        {
          mosek::fusion::p_ModelConstraint::_get_impl(((*cons)(_599)).get())->flushNames();
        }
      }
      {}
    }
  }
}
void mosek::fusion::Model :: writeTask(const std::string & _600) { mosek::fusion::p_Model::_get_impl(this)->writeTask(_600); }void mosek::fusion::p_Model::writeTask(const std::string & _600){
  _pubthis->flushNames();
  task_write(_600);
}
long long mosek::fusion::Model :: getSolverLIntInfo(const std::string & _601) { return mosek::fusion::p_Model::_get_impl(this)->getSolverLIntInfo(_601); }long long mosek::fusion::p_Model::getSolverLIntInfo(const std::string & _601){
  return task_get_liinf(_601);
}
int mosek::fusion::Model :: getSolverIntInfo(const std::string & _602) { return mosek::fusion::p_Model::_get_impl(this)->getSolverIntInfo(_602); }int mosek::fusion::p_Model::getSolverIntInfo(const std::string & _602){
  return task_get_iinf(_602);
}
double mosek::fusion::Model :: getSolverDoubleInfo(const std::string & _603) { return mosek::fusion::p_Model::_get_impl(this)->getSolverDoubleInfo(_603); }double mosek::fusion::p_Model::getSolverDoubleInfo(const std::string & _603){
  return task_get_dinf(_603);
}
void mosek::fusion::Model :: setCallbackHandler(mosek::cbhandler_t _604) { mosek::fusion::p_Model::_get_impl(this)->setCallbackHandler(_604); }void mosek::fusion::p_Model::setCallbackHandler(mosek::cbhandler_t _604){
  task_setCallbackHandler(_604);
}
void mosek::fusion::Model :: setDataCallbackHandler(mosek::datacbhandler_t _605) { mosek::fusion::p_Model::_get_impl(this)->setDataCallbackHandler(_605); }void mosek::fusion::p_Model::setDataCallbackHandler(mosek::datacbhandler_t _605){
  task_setDataCallbackHandler(_605);
}
void mosek::fusion::Model :: setLogHandler(mosek::msghandler_t _606) { mosek::fusion::p_Model::_get_impl(this)->setLogHandler(_606); }void mosek::fusion::p_Model::setLogHandler(mosek::msghandler_t _606){
  task_setLogHandler(_606);
}
void mosek::fusion::Model :: setSolverParam(const std::string & _607,double _608) { mosek::fusion::p_Model::_get_impl(this)->setSolverParam(_607,_608); }void mosek::fusion::p_Model::setSolverParam(const std::string & _607,double _608){
  ::mosek::fusion::p_Parameters::setParameter(::mosek::fusion::Model::t(_pubthis),_607,_608);
}
void mosek::fusion::Model :: setSolverParam(const std::string & _609,int _610) { mosek::fusion::p_Model::_get_impl(this)->setSolverParam(_609,_610); }void mosek::fusion::p_Model::setSolverParam(const std::string & _609,int _610){
  ::mosek::fusion::p_Parameters::setParameter(::mosek::fusion::Model::t(_pubthis),_609,_610);
}
void mosek::fusion::Model :: setSolverParam(const std::string & _611,const std::string & _612) { mosek::fusion::p_Model::_get_impl(this)->setSolverParam(_611,_612); }void mosek::fusion::p_Model::setSolverParam(const std::string & _611,const std::string & _612){
  ::mosek::fusion::p_Parameters::setParameter(::mosek::fusion::Model::t(_pubthis),_611,_612);
}
void mosek::fusion::Model :: breakSolver() { mosek::fusion::p_Model::_get_impl(this)->breakSolver(); }void mosek::fusion::p_Model::breakSolver(){
  task_break_solve();
}
void mosek::fusion::Model :: solve() { mosek::fusion::p_Model::_get_impl(this)->solve(); }void mosek::fusion::p_Model::solve(){
  flush_initsol(::mosek::fusion::SolutionType::Interior);
  flush_initsol(::mosek::fusion::SolutionType::Integer);
  flush_initsol(::mosek::fusion::SolutionType::Basic);
  task_solve();
}
void mosek::fusion::Model :: flushSolutions() { mosek::fusion::p_Model::_get_impl(this)->flushSolutions(); }void mosek::fusion::p_Model::flushSolutions(){
  flush_initsol(::mosek::fusion::SolutionType::Interior);
  flush_initsol(::mosek::fusion::SolutionType::Integer);
  flush_initsol(::mosek::fusion::SolutionType::Basic);
}
void mosek::fusion::p_Model::flush_initsol(mosek::fusion::SolutionType _613){
  if ((NULL != initsol_xx.get()))
  {
    {
      int _614 = task_numvar();
      std::shared_ptr< monty::ndarray< double,1 > > _615 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_614)));
      _checked_ptr_1<double> _ptr__615(_615 ? _615->raw() : nullptr,_615 ? _615->size(0) : 0);
      try
      {
        {
          monty::rc_ptr< ::mosek::fusion::SolutionStruct > _617 = __mosek_2fusion_2Model__get_sol_cache(_613,true);
          if ((NULL != mosek::fusion::p_SolutionStruct::_get_impl(_617)->xx.get()))
          {
            {
              int _6884;
              bool _6885 = ((int)((mosek::fusion::p_SolutionStruct::_get_impl(_617)->xx)->size(0)) <= _614);
              if (_6885)
              {
                _6884 = (int)((mosek::fusion::p_SolutionStruct::_get_impl(_617)->xx)->size(0));
              }
              else
              {
                _6884 = _614;
              }
              ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_617)->xx,(int)0,_615,(int)0,_6884);
            }
          }
          {}
        }
      }
      catch (mosek::fusion::SolutionError _616)
      {
        {
        }
      }
      int _6886;
      bool _6887 = ((int)((initsol_xx)->size(0)) <= _614);
      if (_6887)
      {
        _6886 = (int)((initsol_xx)->size(0));
      }
      else
      {
        _6886 = _614;
      }
      int _618 = _6886;
      int _6888 = (int)0;
      int _6889 = _618;
      for (int _619 = _6888; _619 < _6889; ++_619)
      {
        {
          if (((*initsol_xx_flag)(_619)))
          {
            {
              _ptr__615[_619] = ((*initsol_xx)(_619));
            }
          }
          {}
        }
      }
      task_putxx_slice(_613,(int)0,_614,_615);
    }
  }
  {}
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getDualSolutionStatus() { return mosek::fusion::p_Model::_get_impl(this)->getDualSolutionStatus(); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getDualSolutionStatus(){
  return _pubthis->getDualSolutionStatus(solutionptr);
}
mosek::fusion::ProblemStatus mosek::fusion::Model :: getProblemStatus() { return mosek::fusion::p_Model::_get_impl(this)->getProblemStatus(); }mosek::fusion::ProblemStatus mosek::fusion::p_Model::getProblemStatus(){
  return _pubthis->getProblemStatus(solutionptr);
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getPrimalSolutionStatus() { return mosek::fusion::p_Model::_get_impl(this)->getPrimalSolutionStatus(); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getPrimalSolutionStatus(){
  return _pubthis->getPrimalSolutionStatus(solutionptr);
}
double mosek::fusion::Model :: dualObjValue() { return mosek::fusion::p_Model::_get_impl(this)->dualObjValue(); }double mosek::fusion::p_Model::dualObjValue(){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(::mosek::fusion::SolutionType::Default,false))->dobj;
}
double mosek::fusion::Model :: primalObjValue() { return mosek::fusion::p_Model::_get_impl(this)->primalObjValue(); }double mosek::fusion::p_Model::primalObjValue(){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(::mosek::fusion::SolutionType::Default,true))->pobj;
}
monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::p_Model::__mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _620,bool _621,bool _622){
  monty::rc_ptr< ::mosek::fusion::SolutionStruct > _623 = nullptr;
  mosek::fusion::SolutionType _624 = _620;
  if ((_624 == ::mosek::fusion::SolutionType::Default))
  {
    {
      _624 = solutionptr;
    }
  }
  {}
  if ((_624 == ::mosek::fusion::SolutionType::Default))
  {
    {
      if ((NULL != sol_itg.get()))
      {
        {
          _623 = sol_itg;
        }
      }
      else if((NULL != sol_bas.get()))
      {
        {
          _623 = sol_bas;
        }
      }
      else
      {
        {
          _623 = sol_itr;
        }
      }
    }
  }
  else if((_624 == ::mosek::fusion::SolutionType::Interior))
  {
    {
      _623 = sol_itr;
    }
  }
  else if((_624 == ::mosek::fusion::SolutionType::Basic))
  {
    {
      _623 = sol_bas;
    }
  }
  else if((_624 == ::mosek::fusion::SolutionType::Integer))
  {
    {
      _623 = sol_itg;
    }
  }
  {}
  if ((NULL == _623.get()))
  {
    {
      throw ::mosek::fusion::SolutionError(std::string ("Solution not available"));
    }
  }
  else
  {
    {
      if ((_622 || ((_621 && _623->isPrimalAcceptable(acceptable_sol)) || ((!_621) && _623->isDualAcceptable(acceptable_sol)))))
      {
        {
          return _623;
        }
      }
      else
      {
        {
          monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _625 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
          mosek::fusion::SolutionStatus _626 = mosek::fusion::p_SolutionStruct::_get_impl(_623)->pstatus;
          mosek::fusion::ProblemStatus _627 = mosek::fusion::p_SolutionStruct::_get_impl(_623)->probstatus;
          if ((!_621))
          {
            {
              _626 = mosek::fusion::p_SolutionStruct::_get_impl(_623)->dstatus;
            }
          }
          {}
          _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Solution status is "));
          if ((_626 == ::mosek::fusion::SolutionStatus::Undefined))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Undefined"));
            }
          }
          else if((_626 == ::mosek::fusion::SolutionStatus::Unknown))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Unknown"));
            }
          }
          else if((_626 == ::mosek::fusion::SolutionStatus::Optimal))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Optimal"));
            }
          }
          else if((_626 == ::mosek::fusion::SolutionStatus::Feasible))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Feasible"));
            }
          }
          else if((_626 == ::mosek::fusion::SolutionStatus::Certificate))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Certificate"));
            }
          }
          else if((_626 == ::mosek::fusion::SolutionStatus::IllposedCert))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("IllposedCert"));
            }
          }
          {}
          _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" but at least "));
          if ((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Anything))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Anything"));
            }
          }
          else if((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Optimal))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Optimal"));
            }
          }
          else if((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Feasible))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Feasible"));
            }
          }
          else if((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Certificate))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Certificate"));
            }
          }
          {}
          _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" is expected. Reason: Accessing "));
          if ((_623 == sol_itr))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("interior-point solution"));
            }
          }
          else if((_623 == sol_bas))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("basic solution"));
            }
          }
          else if((_623 == sol_itg))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("integer solution"));
            }
          }
          {}
          _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" whose problem status is "));
          if ((_627 == ::mosek::fusion::ProblemStatus::Unknown))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Unknown"));
            }
          }
          else if((_627 == ::mosek::fusion::ProblemStatus::PrimalAndDualFeasible))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PrimalAndDualFeasible"));
            }
          }
          else if((_627 == ::mosek::fusion::ProblemStatus::PrimalFeasible))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PrimalFeasible"));
            }
          }
          else if((_627 == ::mosek::fusion::ProblemStatus::DualFeasible))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("DualFeasible"));
            }
          }
          else if((_627 == ::mosek::fusion::ProblemStatus::PrimalInfeasible))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PrimalInfeasible"));
            }
          }
          else if((_627 == ::mosek::fusion::ProblemStatus::DualInfeasible))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("DualInfeasible"));
            }
          }
          else if((_627 == ::mosek::fusion::ProblemStatus::PrimalAndDualInfeasible))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PrimalAndDualInfeasible"));
            }
          }
          else if((_627 == ::mosek::fusion::ProblemStatus::IllPosed))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("IllPosed"));
            }
          }
          else if((_627 == ::mosek::fusion::ProblemStatus::PrimalInfeasibleOrUnbounded))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PrimalInfeasibleOrUnbounded"));
            }
          }
          {}
          _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("."));
          throw ::mosek::fusion::SolutionError(_625->toString());
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::p_Model::__mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _628,bool _629){
  return __mosek_2fusion_2Model__get_sol_cache(_628,_629,false);
}
void mosek::fusion::p_Model::setSolution_xx(std::shared_ptr< monty::ndarray< int,1 > > _630,std::shared_ptr< monty::ndarray< double,1 > > _631){
  _checked_ptr_1<int> _ptr__630(_630 ? _630->raw() : nullptr, _630 ? _630->size(0) : 0);
  _checked_ptr_1<double> _ptr__631(_631 ? _631->raw() : nullptr, _631 ? _631->size(0) : 0);
  ensure_initsol_xx();
  int _6890 = (int)0;
  int _6891 = (int)((_630)->size(0));
  for (int _632 = _6890; _632 < _6891; ++_632)
  {
    {
      ((*initsol_xx)(_ptr__630[_632])) = _ptr__631[_632];
      ((*initsol_xx_flag)(_ptr__630[_632])) = true;
    }
  }
}
void mosek::fusion::p_Model::ensure_initsol_xx(){
  int _633 = (int)((natvarmap_idx)->size(0));
  if ((NULL == initsol_xx.get()))
  {
    {
      initsol_xx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_633)));
      std::vector<bool> _6892;
      for (int _634 = (int)0, _6893 = _633; _634 < _6893 ; ++_634)
      {
        _6892.push_back(false);
      }
      auto _6894 = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape(_6892.size()),_6892.begin(),_6892.end()));
      initsol_xx_flag = _6894;
    }
  }
  else if(((int)((initsol_xx)->size(0)) < _633))
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _635 = initsol_xx;
      _checked_ptr_1<double> _ptr__635(_635 ? _635->raw() : nullptr,_635 ? _635->size(0) : 0);
      std::shared_ptr< monty::ndarray< bool,1 > > _636 = initsol_xx_flag;
      initsol_xx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_633)));
      initsol_xx_flag = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape(_633)));
      ::mosek::fusion::Utils::Tools::arraycopy(_635,(int)0,initsol_xx,(int)0,_633);
      int _6895 = (int)0;
      int _6896 = _633;
      for (int _637 = _6895; _637 < _6896; ++_637)
      {
        {
          ((*initsol_xx_flag)(_637)) = ((*_636)(_637));
        }
      }
    }
  }
  {}
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_bars(mosek::fusion::SolutionType _638){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_638,false))->bars;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_barx(mosek::fusion::SolutionType _639){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_639,false))->barx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_y(mosek::fusion::SolutionType _640){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_640,false))->y;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_xc(mosek::fusion::SolutionType _641){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_641,true))->xc;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_snx(mosek::fusion::SolutionType _642){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_642,false))->snx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_suc(mosek::fusion::SolutionType _643){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_643,false))->suc;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_slc(mosek::fusion::SolutionType _644){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_644,false))->slc;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_sux(mosek::fusion::SolutionType _645){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_645,false))->sux;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_slx(mosek::fusion::SolutionType _646){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_646,false))->slx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_yx(mosek::fusion::SolutionType _647){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_647,true))->yx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_xx(mosek::fusion::SolutionType _648){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_648,true))->xx;
}
void mosek::fusion::Model :: selectedSolution(mosek::fusion::SolutionType _649) { mosek::fusion::p_Model::_get_impl(this)->selectedSolution(_649); }void mosek::fusion::p_Model::selectedSolution(mosek::fusion::SolutionType _649){
  solutionptr = _649;
}
mosek::fusion::AccSolutionStatus mosek::fusion::Model :: getAcceptedSolutionStatus() { return mosek::fusion::p_Model::_get_impl(this)->getAcceptedSolutionStatus(); }mosek::fusion::AccSolutionStatus mosek::fusion::p_Model::getAcceptedSolutionStatus(){
  return acceptable_sol;
}
void mosek::fusion::Model :: acceptedSolutionStatus(mosek::fusion::AccSolutionStatus _650) { mosek::fusion::p_Model::_get_impl(this)->acceptedSolutionStatus(_650); }void mosek::fusion::p_Model::acceptedSolutionStatus(mosek::fusion::AccSolutionStatus _650){
  acceptable_sol = _650;
}
mosek::fusion::ProblemStatus mosek::fusion::Model :: getProblemStatus(mosek::fusion::SolutionType _651) { return mosek::fusion::p_Model::_get_impl(this)->getProblemStatus(_651); }mosek::fusion::ProblemStatus mosek::fusion::p_Model::getProblemStatus(mosek::fusion::SolutionType _651){
  monty::rc_ptr< ::mosek::fusion::SolutionStruct > _652 = nullptr;
  if ((_651 == ::mosek::fusion::SolutionType::Default))
  {
    {
      if ((NULL != sol_itg.get()))
      {
        {
          _652 = sol_itg;
        }
      }
      else if((NULL != sol_bas.get()))
      {
        {
          _652 = sol_bas;
        }
      }
      else
      {
        {
          _652 = sol_itr;
        }
      }
    }
  }
  else if((_651 == ::mosek::fusion::SolutionType::Interior))
  {
    {
      _652 = sol_itr;
    }
  }
  else if((_651 == ::mosek::fusion::SolutionType::Basic))
  {
    {
      _652 = sol_bas;
    }
  }
  else if((_651 == ::mosek::fusion::SolutionType::Integer))
  {
    {
      _652 = sol_itg;
    }
  }
  {}
  if ((NULL == _652.get()))
  {
    {
      return ::mosek::fusion::ProblemStatus::Unknown;
    }
  }
  else
  {
    {
      return mosek::fusion::p_SolutionStruct::_get_impl(_652)->probstatus;
    }
  }
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getDualSolutionStatus(mosek::fusion::SolutionType _653) { return mosek::fusion::p_Model::_get_impl(this)->getDualSolutionStatus(_653); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getDualSolutionStatus(mosek::fusion::SolutionType _653){
  return getSolutionStatus(_653,false);
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getPrimalSolutionStatus(mosek::fusion::SolutionType _654) { return mosek::fusion::p_Model::_get_impl(this)->getPrimalSolutionStatus(_654); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getPrimalSolutionStatus(mosek::fusion::SolutionType _654){
  return getSolutionStatus(_654,true);
}
mosek::fusion::SolutionStatus mosek::fusion::p_Model::getSolutionStatus(mosek::fusion::SolutionType _655,bool _656){
  try
  {
    {
      monty::rc_ptr< ::mosek::fusion::SolutionStruct > _658 = __mosek_2fusion_2Model__get_sol_cache(_655,_656,true);
      if (_656)
      {
        {
          return mosek::fusion::p_SolutionStruct::_get_impl(_658)->pstatus;
        }
      }
      else
      {
        {
          return mosek::fusion::p_SolutionStruct::_get_impl(_658)->dstatus;
        }
      }
    }
  }
  catch (mosek::fusion::SolutionError _657)
  {
    {
      return ::mosek::fusion::SolutionStatus::Undefined;
    }
  }
}
void mosek::fusion::p_Model::update(std::shared_ptr< monty::ndarray< int,1 > > _659,monty::rc_ptr< ::mosek::fusion::Expression > _660){
  _checked_ptr_1<int> _ptr__659(_659 ? _659->raw() : nullptr, _659 ? _659->size(0) : 0);
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_660)).as<::mosek::fusion::Expression>())->eval(ws,rs,xs);
  int _661 = ws->popi32();
  int _662 = ws->popi32(_661);
  int _663 = ws->popi32();
  int _664 = ws->popi32();
  bool _665 = ((int)0 != ws->popi32());
  int _666 = ws->popi32(safe_add( _663,(int)1 ));
  int _6897;
  bool _6898 = _665;
  if (_6898)
  {
    _6897 = ws->popi64(_663);
  }
  else
  {
    _6897 = (int)0;
  }
  int _667 = _6897;
  int _668 = ws->popi64(_664);
  int _669 = ws->popf64(_663);
  int _670 = ws->popf64(_664);
  std::shared_ptr< monty::ndarray< int,1 > > _671 = mosek::fusion::p_WorkStack::_get_impl(ws)->i32;
  _checked_ptr_1<int> _ptr__671(_671 ? _671->raw() : nullptr,_671 ? _671->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _672 = mosek::fusion::p_WorkStack::_get_impl(ws)->i64;
  _checked_ptr_1<long long> _ptr__672(_672 ? _672->raw() : nullptr,_672 ? _672->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _673 = mosek::fusion::p_WorkStack::_get_impl(ws)->f64;
  _checked_ptr_1<double> _ptr__673(_673 ? _673->raw() : nullptr,_673 ? _673->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _674 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _663,(int)1 ))));
  _checked_ptr_1<long long> _ptr__674(_674 ? _674->raw() : nullptr,_674 ? _674->size(0) : 0);
  int _6899 = (int)0;
  int _6900 = _663;
  for (int _675 = _6899; _675 < _6900; ++_675)
  {
    {
      int _6901 = _ptr__671[safe_add( _666,_675 )];
      int _6902 = _ptr__671[safe_add( safe_add( _666,_675 ),(int)1 )];
      for (int _676 = _6901; _676 < _6902; ++_676)
      {
        {
          if ((_ptr__672[safe_add( _668,_676 )] > (int)0))
          {
            {
              ++ _ptr__674[safe_add( _675,(int)1 )];
            }
          }
          {}
        }
      }
    }
  }
  int _6903 = (int)0;
  int _6904 = _663;
  for (int _677 = _6903; _677 < _6904; ++_677)
  {
    {
      _ptr__674[safe_add( _677,(int)1 )] += _ptr__674[_677];
    }
  }
  long long _678 = _ptr__674[_663];
  std::shared_ptr< monty::ndarray< int,1 > > _679 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_678)));
  _checked_ptr_1<int> _ptr__679(_679 ? _679->raw() : nullptr,_679 ? _679->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _680 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_678)));
  _checked_ptr_1<double> _ptr__680(_680 ? _680->raw() : nullptr,_680 ? _680->size(0) : 0);
  int _681 = (int)0;
  int _6905 = (int)0;
  int _6906 = _663;
  for (int _682 = _6905; _682 < _6906; ++_682)
  {
    {
      int _6907 = _ptr__671[safe_add( _666,_682 )];
      int _6908 = _ptr__671[safe_add( safe_add( _666,_682 ),(int)1 )];
      for (int _683 = _6907; _683 < _6908; ++_683)
      {
        {
          if ((_ptr__672[safe_add( _668,_683 )] > (int)0))
          {
            {
              _ptr__679[_681] = (int)(_ptr__672[safe_add( _668,_683 )] - (int)1);
              _ptr__680[_681] = _ptr__673[safe_add( _670,_683 )];
              ++ _681;
            }
          }
          {}
        }
      }
    }
  }
  task_putarowlist(_659,_674,_679,_680);
  std::vector<int> _6909;
  for (int _684 = (int)0, _6910 = _663; _684 < _6910 ; ++_684)
  {
    _6909.push_back(bfixidx);
  }
  auto _6911 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6909.size()),_6909.begin(),_6909.end()));
  std::vector<double> _6912;
  for (int _685 = (int)0, _6913 = _663; _685 < _6913 ; ++_685)
  {
    _6912.push_back(_ptr__673[safe_add( _669,_685 )]);
  }
  auto _6914 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6912.size()),_6912.begin(),_6912.end()));
  task_putaijlist(_659,_6911,_6914,(long long)(_663));
  int _686 = (int)0;
  int _6915 = (int)0;
  int _6916 = _663;
  for (int _687 = _6915; _687 < _6916; ++_687)
  {
    {
      if ((((*natconmap_slackidx)(_ptr__659[_687])) > (int)0))
      {
        {
          ++ _686;
        }
      }
      {}
    }
  }
  if ((_686 > (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _688 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_686)));
      _checked_ptr_1<int> _ptr__688(_688 ? _688->raw() : nullptr,_688 ? _688->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _689 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_686)));
      _checked_ptr_1<int> _ptr__689(_689 ? _689->raw() : nullptr,_689 ? _689->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _690 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_686)));
      _checked_ptr_1<double> _ptr__690(_690 ? _690->raw() : nullptr,_690 ? _690->size(0) : 0);
      int _691 = (int)0;
      int _6917 = (int)0;
      int _6918 = _663;
      for (int _692 = _6917; _692 < _6918; ++_692)
      {
        {
          if ((((*natconmap_slackidx)(_ptr__659[_692])) > (int)0))
          {
            {
              _ptr__688[_691] = _ptr__659[_692];
              _ptr__689[_691] = (int)(((*natconmap_slackidx)(_ptr__659[_692])) - (int)1);
              _ptr__690[_691] = (-1.0);
              ++ _691;
            }
          }
          {}
        }
      }
      task_putaijlist(_688,_689,_690,(long long)(_686));
    }
  }
  {}
}
void mosek::fusion::p_Model::update(std::shared_ptr< monty::ndarray< int,1 > > _693,monty::rc_ptr< ::mosek::fusion::Expression > _694,std::shared_ptr< monty::ndarray< int,1 > > _695,bool _696){
  _checked_ptr_1<int> _ptr__693(_693 ? _693->raw() : nullptr, _693 ? _693->size(0) : 0);
  _checked_ptr_1<int> _ptr__695(_695 ? _695->raw() : nullptr, _695 ? _695->size(0) : 0);
  int _697 = safe_mul( (int)((_693)->size(0)),(int)((_695)->size(0)) );
  std::shared_ptr< monty::ndarray< double,1 > > _698 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_697)));
  _checked_ptr_1<double> _ptr__698(_698 ? _698->raw() : nullptr,_698 ? _698->size(0) : 0);
  std::vector<int> _6919;
  for (int _700 = (int)0, _6920 = (int)((_693)->size(0)); _700 < _6920 ; ++_700)
  {
    for (int _701 = (int)0, _6921 = (int)((_695)->size(0)); _701 < _6921 ; ++_701)
    {
      _6919.push_back(_ptr__693[_700]);
    }
  }
  auto _6922 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6919.size()),_6919.begin(),_6919.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _699 = _6922;
  _checked_ptr_1<int> _ptr__699(_699 ? _699->raw() : nullptr,_699 ? _699->size(0) : 0);
  std::vector<int> _6923;
  for (int _703 = (int)0, _6924 = (int)((_693)->size(0)); _703 < _6924 ; ++_703)
  {
    for (int _704 = (int)0, _6925 = (int)((_695)->size(0)); _704 < _6925 ; ++_704)
    {
      _6923.push_back(_ptr__695[_704]);
    }
  }
  auto _6926 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6923.size()),_6923.begin(),_6923.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _702 = _6926;
  _checked_ptr_1<int> _ptr__702(_702 ? _702->raw() : nullptr,_702 ? _702->size(0) : 0);
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_694)).as<::mosek::fusion::Expression>())->eval(ws,rs,xs);
  int _705 = ws->popi32();
  int _706 = ws->popi32(_705);
  int _707 = ws->popi32();
  int _708 = ws->popi32();
  bool _709 = ((int)0 != ws->popi32());
  int _710 = ws->popi32(safe_add( _707,(int)1 ));
  int _6927;
  bool _6928 = _709;
  if (_6928)
  {
    _6927 = ws->popi64(_707);
  }
  else
  {
    _6927 = (int)0;
  }
  int _711 = _6927;
  int _712 = ws->popi64(_708);
  int _713 = ws->popf64(_707);
  int _714 = ws->popf64(_708);
  std::shared_ptr< monty::ndarray< int,1 > > _715 = mosek::fusion::p_WorkStack::_get_impl(ws)->i32;
  _checked_ptr_1<int> _ptr__715(_715 ? _715->raw() : nullptr,_715 ? _715->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _716 = mosek::fusion::p_WorkStack::_get_impl(ws)->i64;
  _checked_ptr_1<long long> _ptr__716(_716 ? _716->raw() : nullptr,_716 ? _716->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _717 = mosek::fusion::p_WorkStack::_get_impl(ws)->f64;
  _checked_ptr_1<double> _ptr__717(_717 ? _717->raw() : nullptr,_717 ? _717->size(0) : 0);
  int _718 = (int)0;
  int _6929 = (int)0;
  int _6930 = _707;
  for (int _719 = _6929; _719 < _6930; ++_719)
  {
    {
      int _720 = _ptr__715[safe_add( _710,_719 )];
      int _721 = _ptr__715[safe_add( safe_add( _710,_719 ),(int)1 )];
      int _722 = _720;
      int _723 = (int)0;
      while ( ((_723 < (int)((_695)->size(0))) && (_722 < _721)) )
      {
        {
          if ((_ptr__695[_723] < (_ptr__716[safe_add( _712,_722 )] - (int)1)))
          {
            {
              ++ _723;
            }
          }
          else if((_ptr__695[_723] > (_ptr__716[safe_add( _712,_722 )] - (int)1)))
          {
            {
              ++ _722;
            }
          }
          else
          {
            {
              _ptr__698[safe_add( _718,_723 )] = _ptr__717[safe_add( _714,_722 )];
              ++ _723;
              ++ _722;
            }
          }
        }
      }
      _718 += (int)((_695)->size(0));
    }
  }
  task_putaijlist(_699,_702,_698,(long long)(_697));
  if (_696)
  {
    {
      std::vector<int> _6931;
      for (int _724 = (int)0, _6932 = _707; _724 < _6932 ; ++_724)
      {
        _6931.push_back(bfixidx);
      }
      auto _6933 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6931.size()),_6931.begin(),_6931.end()));
      std::vector<double> _6934;
      for (int _725 = (int)0, _6935 = _707; _725 < _6935 ; ++_725)
      {
        _6934.push_back(_ptr__717[safe_add( _713,_725 )]);
      }
      auto _6936 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6934.size()),_6934.begin(),_6934.end()));
      task_putaijlist(_693,_6933,_6936,(long long)(_707));
    }
  }
  {}
}
void mosek::fusion::Model :: updateObjective(monty::rc_ptr< ::mosek::fusion::Expression > _726,monty::rc_ptr< ::mosek::fusion::Variable > _727) { mosek::fusion::p_Model::_get_impl(this)->updateObjective(_726,_727); }void mosek::fusion::p_Model::updateObjective(monty::rc_ptr< ::mosek::fusion::Expression > _726,monty::rc_ptr< ::mosek::fusion::Variable > _727){
  if ((_726->getSize() != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid expression size for objective"));
    }
  }
  {}
  int _728 = _727->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _729 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_728)));
  _checked_ptr_1<long long> _ptr__729(_729 ? _729->raw() : nullptr,_729 ? _729->size(0) : 0);
  if ((_728 < _727->getSize()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _730 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_728)));
      _checked_ptr_1<long long> _ptr__730(_730 ? _730->raw() : nullptr,_730 ? _730->size(0) : 0);
      _727->inst((int)0,_730,(int)0,_729);
    }
  }
  else
  {
    {
      _727->inst((int)0,_729);
    }
  }
  int _6937 = (int)0;
  int _6938 = _728;
  for (int _731 = _6937; _731 < _6938; ++_731)
  {
    {
      if ((_ptr__729[_731] < (int)0))
      {
        {
          throw ::mosek::fusion::UnimplementedError(std::string ("Updating semidefinite terms is currently not possible"));
        }
      }
      {}
    }
  }
  bool _732 = true;
  int _6939 = (int)0;
  int _6940 = (_728 - (int)1);
  for (int _733 = _6939; _733 < _6940; ++_733)
  {
    {
      _732 = (_732 && (_ptr__729[_733] < _ptr__729[(_733 - (int)1)]));
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _734 = nullptr;
  _checked_ptr_1<int> _ptr__734(_734 ? _734->raw() : nullptr,_734 ? _734->size(0) : 0);
  if (_732)
  {
    {
      std::vector<int> _6941;
      for (int _735 = (int)0, _6942 = _728; _735 < _6942 ; ++_735)
      {
        _6941.push_back((int)(_ptr__729[_735] - (int)1));
      }
      auto _6943 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6941.size()),_6941.begin(),_6941.end()));
      _734 = _6943;
      _ptr__734.update(_734 ? _734->raw() : nullptr, _734 ? _734->size(0) : 0);
    }
  }
  else
  {
    {
      std::vector<long long> _6944;
      for (int _737 = (-(int)1), _6945 = _728; _737 < _6945 ; ++_737)
      {
        _6944.push_back(_737);
      }
      auto _6946 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_6944.size()),_6944.begin(),_6944.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _736 = _6946;
      _checked_ptr_1<long long> _ptr__736(_736 ? _736->raw() : nullptr,_736 ? _736->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_736,_729,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_728));
      std::vector<int> _6947;
      for (int _738 = (int)0, _6948 = _728; _738 < _6948 ; ++_738)
      {
        _6947.push_back((int)(_ptr__729[_ptr__736[_738]] - (int)1));
      }
      auto _6949 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6947.size()),_6947.begin(),_6947.end()));
      _734 = _6949;
      _ptr__734.update(_734 ? _734->raw() : nullptr, _734 ? _734->size(0) : 0);
    }
  }
  int _739 = (int)((_734)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _740 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_739)));
  _checked_ptr_1<double> _ptr__740(_740 ? _740->raw() : nullptr,_740 ? _740->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _741 = _734;
  _checked_ptr_1<int> _ptr__741(_741 ? _741->raw() : nullptr,_741 ? _741->size(0) : 0);
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_726)).as<::mosek::fusion::Expression>())->eval(ws,rs,xs);
  int _742 = ws->popi32();
  int _743 = ws->popi32(_742);
  int _744 = ws->popi32();
  int _745 = ws->popi32();
  bool _746 = ((int)0 != ws->popi32());
  int _747 = ws->popi32(safe_add( _744,(int)1 ));
  int _6950;
  bool _6951 = _746;
  if (_6951)
  {
    _6950 = ws->popi64(_744);
  }
  else
  {
    _6950 = (int)0;
  }
  int _748 = _6950;
  int _749 = ws->popi64(_745);
  int _750 = ws->popf64(_744);
  int _751 = ws->popf64(_745);
  std::shared_ptr< monty::ndarray< int,1 > > _752 = mosek::fusion::p_WorkStack::_get_impl(ws)->i32;
  _checked_ptr_1<int> _ptr__752(_752 ? _752->raw() : nullptr,_752 ? _752->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _753 = mosek::fusion::p_WorkStack::_get_impl(ws)->i64;
  _checked_ptr_1<long long> _ptr__753(_753 ? _753->raw() : nullptr,_753 ? _753->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _754 = mosek::fusion::p_WorkStack::_get_impl(ws)->f64;
  _checked_ptr_1<double> _ptr__754(_754 ? _754->raw() : nullptr,_754 ? _754->size(0) : 0);
  int _755 = (int)0;
  int _6952 = (int)0;
  int _6953 = _744;
  for (int _756 = _6952; _756 < _6953; ++_756)
  {
    {
      int _757 = _ptr__752[safe_add( _747,_756 )];
      int _758 = _ptr__752[safe_add( safe_add( _747,_756 ),(int)1 )];
      int _759 = _757;
      int _760 = (int)0;
      while ( ((_760 < (int)((_734)->size(0))) && (_759 < _758)) )
      {
        {
          if ((_ptr__734[_760] < (_ptr__753[safe_add( _749,_759 )] - (int)1)))
          {
            {
              ++ _760;
            }
          }
          else if((_ptr__734[_760] > (_ptr__753[safe_add( _749,_759 )] - (int)1)))
          {
            {
              ++ _759;
            }
          }
          else
          {
            {
              _ptr__740[safe_add( _755,_760 )] = _ptr__754[safe_add( _751,_759 )];
              ++ _760;
              ++ _759;
            }
          }
        }
      }
      _755 += (int)((_734)->size(0));
    }
  }
  task_putclist(_741,_740);
}
void mosek::fusion::p_Model::objective_(const std::string & _761,mosek::fusion::ObjectiveSense _762,monty::rc_ptr< ::mosek::fusion::Expression > _763){
  task_putobjectivename(_761);
  monty::rc_ptr< ::mosek::fusion::WorkStack > _764 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  monty::rc_ptr< ::mosek::fusion::WorkStack > _765 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_763)).as<::mosek::fusion::Expression>())->eval(_764,_765,xs);
  std::shared_ptr< monty::ndarray< int,1 > > _766 = mosek::fusion::p_WorkStack::_get_impl(_764)->i32;
  _checked_ptr_1<int> _ptr__766(_766 ? _766->raw() : nullptr,_766 ? _766->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _767 = mosek::fusion::p_WorkStack::_get_impl(_764)->i64;
  _checked_ptr_1<long long> _ptr__767(_767 ? _767->raw() : nullptr,_767 ? _767->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _768 = mosek::fusion::p_WorkStack::_get_impl(_764)->f64;
  _checked_ptr_1<double> _ptr__768(_768 ? _768->raw() : nullptr,_768 ? _768->size(0) : 0);
  int _769 = _764->popi32();
  int _770 = (int)1;
  int _6954 = (int)0;
  int _6955 = _769;
  for (int _771 = _6954; _771 < _6955; ++_771)
  {
    {
      _769 *= _764->popi32();
    }
  }
  if ((_770 != (int)1))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid expression size for objective"));
    }
  }
  {}
  int _772 = _764->popi32();
  if ((_772 != (int)1))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid expression for objective"));
    }
  }
  {}
  int _773 = _764->popi32();
  bool _774 = (_764->popi32() != (int)0);
  int _775 = _764->popi32(safe_add( _772,(int)1 ));
  int _776 = _764->popi64(_773);
  int _777 = _764->popf64(_772);
  int _778 = _764->popf64(_773);
  int _779 = (int)0;
  int _780 = (int)0;
  int _6956 = (int)0;
  int _6957 = _773;
  for (int _781 = _6956; _781 < _6957; ++_781)
  {
    {
      if ((_ptr__767[safe_add( _776,_781 )] < (int)0))
      {
        {
          ++ _780;
        }
      }
      else if((_ptr__767[safe_add( _776,_781 )] > (int)0))
      {
        {
          ++ _779;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _782 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_779)));
  _checked_ptr_1<int> _ptr__782(_782 ? _782->raw() : nullptr,_782 ? _782->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _783 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_779)));
  _checked_ptr_1<double> _ptr__783(_783 ? _783->raw() : nullptr,_783 ? _783->size(0) : 0);
  {
    int _784 = (int)0;
    int _6958 = (int)0;
    int _6959 = _773;
    for (int _785 = _6958; _785 < _6959; ++_785)
    {
      {
        if ((_ptr__767[safe_add( _776,_785 )] > (int)0))
        {
          {
            _ptr__782[_784] = (int)(_ptr__767[safe_add( _776,_785 )] - (int)1);
            _ptr__783[_784] = _ptr__768[safe_add( _778,_785 )];
            ++ _784;
          }
        }
        {}
      }
    }
  }
  task_putobjective((_762 == ::mosek::fusion::ObjectiveSense::Maximize),_782,_783,_ptr__768[_777]);
  if ((_780 > (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _786 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_780)));
      _checked_ptr_1<int> _ptr__786(_786 ? _786->raw() : nullptr,_786 ? _786->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _787 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_780)));
      _checked_ptr_1<int> _ptr__787(_787 ? _787->raw() : nullptr,_787 ? _787->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _788 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_780)));
      _checked_ptr_1<int> _ptr__788(_788 ? _788->raw() : nullptr,_788 ? _788->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _789 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_780)));
      _checked_ptr_1<double> _ptr__789(_789 ? _789->raw() : nullptr,_789 ? _789->size(0) : 0);
      int _6960 = (int)0;
      int _6961 = _780;
      for (int _790 = _6960; _790 < _6961; ++_790)
      {
        {
          long long _791 = (-safe_add( _ptr__767[safe_add( _776,_790 )],(int)1 ));
          _ptr__786[_790] = ((*natbarvar_idx)(_791));
          _ptr__787[_790] = ((*natbarvar_i)(_791));
          _ptr__788[_790] = ((*natbarvar_j)(_791));
          double _6962;
          bool _6963 = (_ptr__787[_790] == _ptr__788[_790]);
          if (_6963)
          {
            _6962 = _ptr__768[safe_add( _778,_790 )];
          }
          else
          {
            _6962 = (0.5 * _ptr__768[safe_add( _778,_790 )]);
          }
          _ptr__789[_790] = _6962;
        }
      }
      task_putbarc(_786,_787,_788,_789);
    }
  }
  {}
}
void mosek::fusion::Model :: objective(double _792) { mosek::fusion::p_Model::_get_impl(this)->objective(_792); }void mosek::fusion::p_Model::objective(double _792){
  objective_(std::string (""),::mosek::fusion::ObjectiveSense::Minimize,::mosek::fusion::p_Expr::constTerm(_792));
}
void mosek::fusion::Model :: objective(mosek::fusion::ObjectiveSense _793,double _794) { mosek::fusion::p_Model::_get_impl(this)->objective(_793,_794); }void mosek::fusion::p_Model::objective(mosek::fusion::ObjectiveSense _793,double _794){
  objective_(std::string (""),_793,::mosek::fusion::p_Expr::constTerm(_794));
}
void mosek::fusion::Model :: objective(mosek::fusion::ObjectiveSense _795,monty::rc_ptr< ::mosek::fusion::Expression > _796) { mosek::fusion::p_Model::_get_impl(this)->objective(_795,_796); }void mosek::fusion::p_Model::objective(mosek::fusion::ObjectiveSense _795,monty::rc_ptr< ::mosek::fusion::Expression > _796){
  objective_(std::string (""),_795,_796);
}
void mosek::fusion::Model :: objective(const std::string & _797,double _798) { mosek::fusion::p_Model::_get_impl(this)->objective(_797,_798); }void mosek::fusion::p_Model::objective(const std::string & _797,double _798){
  objective_(_797,::mosek::fusion::ObjectiveSense::Minimize,::mosek::fusion::p_Expr::constTerm(_798));
}
void mosek::fusion::Model :: objective(const std::string & _799,mosek::fusion::ObjectiveSense _800,double _801) { mosek::fusion::p_Model::_get_impl(this)->objective(_799,_800,_801); }void mosek::fusion::p_Model::objective(const std::string & _799,mosek::fusion::ObjectiveSense _800,double _801){
  objective_(_799,_800,::mosek::fusion::p_Expr::constTerm(_801));
}
void mosek::fusion::Model :: objective(const std::string & _802,mosek::fusion::ObjectiveSense _803,monty::rc_ptr< ::mosek::fusion::Expression > _804) { mosek::fusion::p_Model::_get_impl(this)->objective(_802,_803,_804); }void mosek::fusion::p_Model::objective(const std::string & _802,mosek::fusion::ObjectiveSense _803,monty::rc_ptr< ::mosek::fusion::Expression > _804){
  objective_(_802,_803,_804);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _805,monty::rc_ptr< ::mosek::fusion::ConeDomain > _806) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_805,_806); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _805,monty::rc_ptr< ::mosek::fusion::ConeDomain > _806) { return __mosek_2fusion_2Model__constraint(_805,_806); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _805,monty::rc_ptr< ::mosek::fusion::ConeDomain > _806){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_805,_806);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _807,monty::rc_ptr< ::mosek::fusion::Expression > _808,monty::rc_ptr< ::mosek::fusion::ConeDomain > _809) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_807,_808,_809); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _807,monty::rc_ptr< ::mosek::fusion::Expression > _808,monty::rc_ptr< ::mosek::fusion::ConeDomain > _809) { return __mosek_2fusion_2Model__constraint(_807,_808,_809); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _807,monty::rc_ptr< ::mosek::fusion::Expression > _808,monty::rc_ptr< ::mosek::fusion::ConeDomain > _809){
  return __mosek_2fusion_2Model__constraint_(_807,_808,_809);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _810,monty::rc_ptr< ::mosek::fusion::RangeDomain > _811) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_810,_811); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _810,monty::rc_ptr< ::mosek::fusion::RangeDomain > _811) { return __mosek_2fusion_2Model__constraint(_810,_811); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _810,monty::rc_ptr< ::mosek::fusion::RangeDomain > _811){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_810,_811);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _812,monty::rc_ptr< ::mosek::fusion::Expression > _813,monty::rc_ptr< ::mosek::fusion::RangeDomain > _814) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_812,_813,_814); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _812,monty::rc_ptr< ::mosek::fusion::Expression > _813,monty::rc_ptr< ::mosek::fusion::RangeDomain > _814) { return __mosek_2fusion_2Model__constraint(_812,_813,_814); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _812,monty::rc_ptr< ::mosek::fusion::Expression > _813,monty::rc_ptr< ::mosek::fusion::RangeDomain > _814){
  return __mosek_2fusion_2Model__constraint_(_812,_813,_814);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _815,monty::rc_ptr< ::mosek::fusion::LinearDomain > _816) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_815,_816); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _815,monty::rc_ptr< ::mosek::fusion::LinearDomain > _816) { return __mosek_2fusion_2Model__constraint(_815,_816); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _815,monty::rc_ptr< ::mosek::fusion::LinearDomain > _816){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_815,_816);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _817,monty::rc_ptr< ::mosek::fusion::Expression > _818,monty::rc_ptr< ::mosek::fusion::LinearDomain > _819) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_817,_818,_819); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _817,monty::rc_ptr< ::mosek::fusion::Expression > _818,monty::rc_ptr< ::mosek::fusion::LinearDomain > _819) { return __mosek_2fusion_2Model__constraint(_817,_818,_819); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _817,monty::rc_ptr< ::mosek::fusion::Expression > _818,monty::rc_ptr< ::mosek::fusion::LinearDomain > _819){
  return __mosek_2fusion_2Model__constraint_(_817,_818,_819);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _820,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _821) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_820,_821); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _820,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _821) { return __mosek_2fusion_2Model__constraint(_820,_821); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _820,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _821){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_820,_821);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _822,monty::rc_ptr< ::mosek::fusion::Expression > _823,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _824) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_822,_823,_824); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _822,monty::rc_ptr< ::mosek::fusion::Expression > _823,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _824) { return __mosek_2fusion_2Model__constraint(_822,_823,_824); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _822,monty::rc_ptr< ::mosek::fusion::Expression > _823,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _824){
  return __mosek_2fusion_2Model__constraint_(_822,_823,_824);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _825,monty::rc_ptr< ::mosek::fusion::PSDDomain > _826) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_825,_826); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _825,monty::rc_ptr< ::mosek::fusion::PSDDomain > _826) { return __mosek_2fusion_2Model__constraint(_825,_826); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _825,monty::rc_ptr< ::mosek::fusion::PSDDomain > _826){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_825,_826);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _827,monty::rc_ptr< ::mosek::fusion::Expression > _828,monty::rc_ptr< ::mosek::fusion::PSDDomain > _829) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_827,_828,_829); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _827,monty::rc_ptr< ::mosek::fusion::Expression > _828,monty::rc_ptr< ::mosek::fusion::PSDDomain > _829) { return __mosek_2fusion_2Model__constraint(_827,_828,_829); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _827,monty::rc_ptr< ::mosek::fusion::Expression > _828,monty::rc_ptr< ::mosek::fusion::PSDDomain > _829){
  return __mosek_2fusion_2Model__constraint_(_827,_828,_829);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _830) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_830); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _830) { return __mosek_2fusion_2Model__variable(_830); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _830){
  return __mosek_2fusion_2Model__variable_(std::string (""),mosek::fusion::p_LinPSDDomain::_get_impl(_830)->shape,_830);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _831,int _832,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _833) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_831,_832,_833); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _831,int _832,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _833) { return __mosek_2fusion_2Model__variable(_831,_832,_833); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _831,int _832,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _833){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_831),(int)(_831),(int)(_832)}),_833);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _834,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _835) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_834,_835); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _834,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _835) { return __mosek_2fusion_2Model__variable(_834,_835); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _834,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _835){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_834),(int)(_834)}),_835);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _836,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _837) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_836,_837); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _836,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _837) { return __mosek_2fusion_2Model__variable(_836,_837); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _836,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _837){
  return __mosek_2fusion_2Model__variable_(_836,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_837);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _838,int _839,int _840,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _841) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_838,_839,_840,_841); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _838,int _839,int _840,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _841) { return __mosek_2fusion_2Model__variable(_838,_839,_840,_841); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _838,int _839,int _840,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _841){
  return __mosek_2fusion_2Model__variable_(_838,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_839),(int)(_839),(int)(_840)}),_841);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _842,int _843,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _844) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_842,_843,_844); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _842,int _843,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _844) { return __mosek_2fusion_2Model__variable(_842,_843,_844); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _842,int _843,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _844){
  return __mosek_2fusion_2Model__variable_(_842,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_843),(int)(_843)}),_844);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _845,std::shared_ptr< monty::ndarray< int,1 > > _846,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _847) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_845,_846,_847); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _845,std::shared_ptr< monty::ndarray< int,1 > > _846,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _847) { return __mosek_2fusion_2Model__variable(_845,_846,_847); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _845,std::shared_ptr< monty::ndarray< int,1 > > _846,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _847){
  _checked_ptr_1<int> _ptr__846(_846 ? _846->raw() : nullptr, _846 ? _846->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_845,_846,_847);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _848) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_848); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _848) { return __mosek_2fusion_2Model__variable(_848); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _848){
  return (__mosek_2fusion_2Model__variable_(std::string (""),mosek::fusion::p_PSDDomain::_get_impl(_848)->shape,_848)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _849,int _850,monty::rc_ptr< ::mosek::fusion::PSDDomain > _851) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_849,_850,_851); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _849,int _850,monty::rc_ptr< ::mosek::fusion::PSDDomain > _851) { return __mosek_2fusion_2Model__variable(_849,_850,_851); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _849,int _850,monty::rc_ptr< ::mosek::fusion::PSDDomain > _851){
  return (__mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_849),(int)(_849),(int)(_850)}),_851)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _852,monty::rc_ptr< ::mosek::fusion::PSDDomain > _853) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_852,_853); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _852,monty::rc_ptr< ::mosek::fusion::PSDDomain > _853) { return __mosek_2fusion_2Model__variable(_852,_853); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _852,monty::rc_ptr< ::mosek::fusion::PSDDomain > _853){
  return (__mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_852),(int)(_852)}),_853)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _854,monty::rc_ptr< ::mosek::fusion::PSDDomain > _855) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_854,_855); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _854,monty::rc_ptr< ::mosek::fusion::PSDDomain > _855) { return __mosek_2fusion_2Model__variable(_854,_855); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _854,monty::rc_ptr< ::mosek::fusion::PSDDomain > _855){
  return (__mosek_2fusion_2Model__variable_(_854,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_855)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _856,int _857,int _858,monty::rc_ptr< ::mosek::fusion::PSDDomain > _859) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_856,_857,_858,_859); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _856,int _857,int _858,monty::rc_ptr< ::mosek::fusion::PSDDomain > _859) { return __mosek_2fusion_2Model__variable(_856,_857,_858,_859); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _856,int _857,int _858,monty::rc_ptr< ::mosek::fusion::PSDDomain > _859){
  return (__mosek_2fusion_2Model__variable_(_856,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_857),(int)(_857),(int)(_858)}),_859)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _860,int _861,monty::rc_ptr< ::mosek::fusion::PSDDomain > _862) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_860,_861,_862); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _860,int _861,monty::rc_ptr< ::mosek::fusion::PSDDomain > _862) { return __mosek_2fusion_2Model__variable(_860,_861,_862); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _860,int _861,monty::rc_ptr< ::mosek::fusion::PSDDomain > _862){
  return (__mosek_2fusion_2Model__variable_(_860,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_861),(int)(_861)}),_862)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _863,std::shared_ptr< monty::ndarray< int,1 > > _864,monty::rc_ptr< ::mosek::fusion::PSDDomain > _865) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_863,_864,_865); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _863,std::shared_ptr< monty::ndarray< int,1 > > _864,monty::rc_ptr< ::mosek::fusion::PSDDomain > _865) { return __mosek_2fusion_2Model__variable(_863,_864,_865); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _863,std::shared_ptr< monty::ndarray< int,1 > > _864,monty::rc_ptr< ::mosek::fusion::PSDDomain > _865){
  _checked_ptr_1<int> _ptr__864(_864 ? _864->raw() : nullptr, _864 ? _864->size(0) : 0);
  return (__mosek_2fusion_2Model__variable_(_863,_864,_865)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _866) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_866); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _866) { return __mosek_2fusion_2Model__variable(_866); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _866){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_866);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _867) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_867); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _867) { return __mosek_2fusion_2Model__variable(_867); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _867){
  return __mosek_2fusion_2Model__ranged_variable(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_867);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _868) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_868); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _868) { return __mosek_2fusion_2Model__variable(_868); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _868){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_868);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _869,monty::rc_ptr< ::mosek::fusion::ConeDomain > _870) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_869,_870); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _869,monty::rc_ptr< ::mosek::fusion::ConeDomain > _870) { return __mosek_2fusion_2Model__variable(_869,_870); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _869,monty::rc_ptr< ::mosek::fusion::ConeDomain > _870){
  _checked_ptr_1<int> _ptr__869(_869 ? _869->raw() : nullptr, _869 ? _869->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(std::string (""),_869,_870);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _871,monty::rc_ptr< ::mosek::fusion::RangeDomain > _872) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_871,_872); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _871,monty::rc_ptr< ::mosek::fusion::RangeDomain > _872) { return __mosek_2fusion_2Model__variable(_871,_872); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _871,monty::rc_ptr< ::mosek::fusion::RangeDomain > _872){
  _checked_ptr_1<int> _ptr__871(_871 ? _871->raw() : nullptr, _871 ? _871->size(0) : 0);
  return __mosek_2fusion_2Model__ranged_variable(std::string (""),_871,_872);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _873,monty::rc_ptr< ::mosek::fusion::LinearDomain > _874) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_873,_874); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _873,monty::rc_ptr< ::mosek::fusion::LinearDomain > _874) { return __mosek_2fusion_2Model__variable(_873,_874); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _873,monty::rc_ptr< ::mosek::fusion::LinearDomain > _874){
  _checked_ptr_1<int> _ptr__873(_873 ? _873->raw() : nullptr, _873 ? _873->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(std::string (""),_873,_874);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _875) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_875); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _875) { return __mosek_2fusion_2Model__variable(_875); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _875){
  _checked_ptr_1<int> _ptr__875(_875 ? _875->raw() : nullptr, _875 ? _875->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(std::string (""),_875,::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _876,monty::rc_ptr< ::mosek::fusion::ConeDomain > _877) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_876,_877); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _876,monty::rc_ptr< ::mosek::fusion::ConeDomain > _877) { return __mosek_2fusion_2Model__variable(_876,_877); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _876,monty::rc_ptr< ::mosek::fusion::ConeDomain > _877){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_876)}),_877);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _878,monty::rc_ptr< ::mosek::fusion::RangeDomain > _879) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_878,_879); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _878,monty::rc_ptr< ::mosek::fusion::RangeDomain > _879) { return __mosek_2fusion_2Model__variable(_878,_879); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _878,monty::rc_ptr< ::mosek::fusion::RangeDomain > _879){
  return __mosek_2fusion_2Model__ranged_variable(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_878)}),_879);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _880,monty::rc_ptr< ::mosek::fusion::LinearDomain > _881) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_880,_881); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _880,monty::rc_ptr< ::mosek::fusion::LinearDomain > _881) { return __mosek_2fusion_2Model__variable(_880,_881); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _880,monty::rc_ptr< ::mosek::fusion::LinearDomain > _881){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_880)}),_881);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _882) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_882); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _882) { return __mosek_2fusion_2Model__variable(_882); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _882){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_882)}),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable() { return __mosek_2fusion_2Model__variable(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _883,monty::rc_ptr< ::mosek::fusion::ConeDomain > _884) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_883,_884); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _883,monty::rc_ptr< ::mosek::fusion::ConeDomain > _884) { return __mosek_2fusion_2Model__variable(_883,_884); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _883,monty::rc_ptr< ::mosek::fusion::ConeDomain > _884){
  return __mosek_2fusion_2Model__variable_(_883,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_884);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _885,monty::rc_ptr< ::mosek::fusion::RangeDomain > _886) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_885,_886); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _885,monty::rc_ptr< ::mosek::fusion::RangeDomain > _886) { return __mosek_2fusion_2Model__variable(_885,_886); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _885,monty::rc_ptr< ::mosek::fusion::RangeDomain > _886){
  return __mosek_2fusion_2Model__ranged_variable(_885,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_886);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _887,monty::rc_ptr< ::mosek::fusion::LinearDomain > _888) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_887,_888); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _887,monty::rc_ptr< ::mosek::fusion::LinearDomain > _888) { return __mosek_2fusion_2Model__variable(_887,_888); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _887,monty::rc_ptr< ::mosek::fusion::LinearDomain > _888){
  return __mosek_2fusion_2Model__variable_(_887,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_888);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _889,std::shared_ptr< monty::ndarray< int,1 > > _890,monty::rc_ptr< ::mosek::fusion::ConeDomain > _891) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_889,_890,_891); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _889,std::shared_ptr< monty::ndarray< int,1 > > _890,monty::rc_ptr< ::mosek::fusion::ConeDomain > _891) { return __mosek_2fusion_2Model__variable(_889,_890,_891); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _889,std::shared_ptr< monty::ndarray< int,1 > > _890,monty::rc_ptr< ::mosek::fusion::ConeDomain > _891){
  _checked_ptr_1<int> _ptr__890(_890 ? _890->raw() : nullptr, _890 ? _890->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_889,_890,_891);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _892,std::shared_ptr< monty::ndarray< int,1 > > _893,monty::rc_ptr< ::mosek::fusion::RangeDomain > _894) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_892,_893,_894); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _892,std::shared_ptr< monty::ndarray< int,1 > > _893,monty::rc_ptr< ::mosek::fusion::RangeDomain > _894) { return __mosek_2fusion_2Model__variable(_892,_893,_894); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _892,std::shared_ptr< monty::ndarray< int,1 > > _893,monty::rc_ptr< ::mosek::fusion::RangeDomain > _894){
  _checked_ptr_1<int> _ptr__893(_893 ? _893->raw() : nullptr, _893 ? _893->size(0) : 0);
  return __mosek_2fusion_2Model__ranged_variable(_892,_893,_894);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _895,std::shared_ptr< monty::ndarray< int,1 > > _896,monty::rc_ptr< ::mosek::fusion::LinearDomain > _897) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_895,_896,_897); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _895,std::shared_ptr< monty::ndarray< int,1 > > _896,monty::rc_ptr< ::mosek::fusion::LinearDomain > _897) { return __mosek_2fusion_2Model__variable(_895,_896,_897); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _895,std::shared_ptr< monty::ndarray< int,1 > > _896,monty::rc_ptr< ::mosek::fusion::LinearDomain > _897){
  _checked_ptr_1<int> _ptr__896(_896 ? _896->raw() : nullptr, _896 ? _896->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_895,_896,_897);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _898,std::shared_ptr< monty::ndarray< int,1 > > _899) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_898,_899); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _898,std::shared_ptr< monty::ndarray< int,1 > > _899) { return __mosek_2fusion_2Model__variable(_898,_899); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _898,std::shared_ptr< monty::ndarray< int,1 > > _899){
  _checked_ptr_1<int> _ptr__899(_899 ? _899->raw() : nullptr, _899 ? _899->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_898,_899,::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _900,int _901,monty::rc_ptr< ::mosek::fusion::ConeDomain > _902) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_900,_901,_902); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _900,int _901,monty::rc_ptr< ::mosek::fusion::ConeDomain > _902) { return __mosek_2fusion_2Model__variable(_900,_901,_902); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _900,int _901,monty::rc_ptr< ::mosek::fusion::ConeDomain > _902){
  return __mosek_2fusion_2Model__variable_(_900,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_901)}),_902);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _903,int _904,monty::rc_ptr< ::mosek::fusion::RangeDomain > _905) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_903,_904,_905); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _903,int _904,monty::rc_ptr< ::mosek::fusion::RangeDomain > _905) { return __mosek_2fusion_2Model__variable(_903,_904,_905); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _903,int _904,monty::rc_ptr< ::mosek::fusion::RangeDomain > _905){
  return __mosek_2fusion_2Model__ranged_variable(_903,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_904)}),_905);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _906,int _907,monty::rc_ptr< ::mosek::fusion::LinearDomain > _908) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_906,_907,_908); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _906,int _907,monty::rc_ptr< ::mosek::fusion::LinearDomain > _908) { return __mosek_2fusion_2Model__variable(_906,_907,_908); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _906,int _907,monty::rc_ptr< ::mosek::fusion::LinearDomain > _908){
  return __mosek_2fusion_2Model__variable_(_906,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_907)}),_908);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _909,int _910) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_909,_910); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _909,int _910) { return __mosek_2fusion_2Model__variable(_909,_910); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _909,int _910){
  return __mosek_2fusion_2Model__variable_(_909,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_910)}),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _911) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_911); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _911) { return __mosek_2fusion_2Model__variable(_911); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _911){
  return __mosek_2fusion_2Model__variable_(_911,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__ranged_variable(const std::string & _912,std::shared_ptr< monty::ndarray< int,1 > > _913,monty::rc_ptr< ::mosek::fusion::RangeDomain > _914){
  _checked_ptr_1<int> _ptr__913(_913 ? _913->raw() : nullptr, _913 ? _913->size(0) : 0);
  if ((((int)((_912).size()) > (int)0) && hasVariable(_912)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_912)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _6964;
  bool _6965 = (NULL != _913.get());
  if (_6965)
  {
    _6964 = _913;
  }
  else
  {
    _6964 = mosek::fusion::p_RangeDomain::_get_impl(_914)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _915 = _6964;
  _checked_ptr_1<int> _ptr__915(_915 ? _915->raw() : nullptr,_915 ? _915->size(0) : 0);
  if (((NULL != mosek::fusion::p_RangeDomain::_get_impl(_914)->shape.get()) && (!::mosek::fusion::p_Set::match(mosek::fusion::p_RangeDomain::_get_impl(_914)->shape,_915))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  {}
  if ((NULL == _915.get()))
  {
    {
      _915 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
      _ptr__915.update(_915 ? _915->raw() : nullptr, _915 ? _915->size(0) : 0);
    }
  }
  {}
  int _916 = (int)((_915)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _917 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_916)));
  _checked_ptr_1<int> _ptr__917(_917 ? _917->raw() : nullptr,_917 ? _917->size(0) : 0);
  if ((_916 > (int)0))
  {
    {
      _ptr__917[(_916 - (int)1)] = (int)1;
      int _6966 = (int)1;
      int _6967 = _916;
      for (int _918 = _6966; _918 < _6967; ++_918)
      {
        {
          _ptr__917[((_916 - _918) - (int)1)] = safe_mul( _ptr__917[(_916 - _918)],_ptr__915[(_916 - _918)] );
        }
      }
    }
  }
  {}
  int _919 = (int)1;
  int _6968 = (int)0;
  int _6969 = (int)((_915)->size(0));
  for (int _920 = _6968; _920 < _6969; ++_920)
  {
    {
      _919 *= _ptr__915[_920];
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _921 = nullptr;
  _checked_ptr_1<long long> _ptr__921(_921 ? _921->raw() : nullptr,_921 ? _921->size(0) : 0);
  if ((NULL != _921.get()))
  {
    {
      if (((int)((mosek::fusion::p_RangeDomain::_get_impl(_914)->sparsity)->size(1)) != _916))
      {
        {
          throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
        }
      }
      {}
      _921 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((mosek::fusion::p_RangeDomain::_get_impl(_914)->sparsity)->size(0)))));
      _ptr__921.update(_921 ? _921->raw() : nullptr, _921 ? _921->size(0) : 0);
      int _6970 = (int)0;
      int _6971 = (int)((mosek::fusion::p_RangeDomain::_get_impl(_914)->sparsity)->size(0));
      for (int _922 = _6970; _922 < _6971; ++_922)
      {
        {
          int _6972 = (int)0;
          int _6973 = (int)((mosek::fusion::p_RangeDomain::_get_impl(_914)->sparsity)->size(1));
          for (int _923 = _6972; _923 < _6973; ++_923)
          {
            {
              if (((((*mosek::fusion::p_RangeDomain::_get_impl(_914)->sparsity)(_922,_923)) < (int)0) || (((*mosek::fusion::p_RangeDomain::_get_impl(_914)->sparsity)(_922,_923)) >= _ptr__915[_923])))
              {
                {
                  throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
                }
              }
              {}
            }
          }
          long long _924 = (int)0;
          int _6974 = (int)0;
          int _6975 = (int)((mosek::fusion::p_RangeDomain::_get_impl(_914)->sparsity)->size(1));
          for (int _925 = _6974; _925 < _6975; ++_925)
          {
            {
              _924 += safe_mul( _ptr__917[_925],((*mosek::fusion::p_RangeDomain::_get_impl(_914)->sparsity)(_922,_925)) );
            }
          }
          _ptr__921[_922] = _924;
        }
      }
    }
  }
  {}
  int _6976;
  bool _6977 = (NULL != _921.get());
  if (_6977)
  {
    _6976 = (int)((_921)->size(0));
  }
  else
  {
    _6976 = _919;
  }
  int _926 = _6976;
  std::shared_ptr< monty::ndarray< double,1 > > _927;
  _checked_ptr_1<double> _ptr__927(_927 ? _927->raw() : nullptr,_927 ? _927->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _928;
  _checked_ptr_1<double> _ptr__928(_928 ? _928->raw() : nullptr,_928 ? _928->size(0) : 0);
  if (mosek::fusion::p_RangeDomain::_get_impl(_914)->scalable)
  {
    {
      std::vector<double> _6978;
      for (int _929 = (int)0, _6979 = _926; _929 < _6979 ; ++_929)
      {
        _6978.push_back(((*mosek::fusion::p_RangeDomain::_get_impl(_914)->lb)((int)0)));
      }
      auto _6980 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6978.size()),_6978.begin(),_6978.end()));
      _927 = _6980;
      _ptr__927.update(_927 ? _927->raw() : nullptr, _927 ? _927->size(0) : 0);
      std::vector<double> _6981;
      for (int _930 = (int)0, _6982 = _926; _930 < _6982 ; ++_930)
      {
        _6981.push_back(((*mosek::fusion::p_RangeDomain::_get_impl(_914)->ub)((int)0)));
      }
      auto _6983 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6981.size()),_6981.begin(),_6981.end()));
      _928 = _6983;
      _ptr__928.update(_928 ? _928->raw() : nullptr, _928 ? _928->size(0) : 0);
    }
  }
  else
  {
    {
      _927 = mosek::fusion::p_RangeDomain::_get_impl(_914)->lb;
      _ptr__927.update(_927 ? _927->raw() : nullptr, _927 ? _927->size(0) : 0);
      _928 = mosek::fusion::p_RangeDomain::_get_impl(_914)->ub;
      _ptr__928.update(_928 ? _928->raw() : nullptr, _928 ? _928->size(0) : 0);
    }
  }
  int _931 = natvarmap_alloc(_926);
  std::shared_ptr< monty::ndarray< int,1 > > _932 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natvarmap->blocksize(_931))));
  _checked_ptr_1<int> _ptr__932(_932 ? _932->raw() : nullptr,_932 ? _932->size(0) : 0);
  natvarmap->get(_931,_932,(int)0);
  int _6984 = (int)0;
  int _6985 = _926;
  for (int _933 = _6984; _933 < _6985; ++_933)
  {
    {
      ((*natvarmap_idx)(_ptr__932[_933])) = _931;
    }
  }
  task_var_putboundlist_ra(_932,_927,_928);
  monty::rc_ptr< ::mosek::fusion::RangedVariable > _934 = ::mosek::fusion::p_RangedVariable::_new_RangedVariable(::mosek::fusion::Model::t(_pubthis),_912,(long long)(_931),_915,_921,_932);
  if (mosek::fusion::p_RangeDomain::_get_impl(_914)->cardinal_flag)
  {
    {
      task_var_putintlist(_932);
    }
  }
  {}
  ((*vars)(_931)) = (_934).as<::mosek::fusion::ModelVariable>();
  if (((int)((_912).size()) > (int)0))
  {
    {
      var_map->setItem(_912,_931);
    }
  }
  {}
  return (_934).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _935,std::shared_ptr< monty::ndarray< int,1 > > _936,monty::rc_ptr< ::mosek::fusion::ConeDomain > _937){
  _checked_ptr_1<int> _ptr__936(_936 ? _936->raw() : nullptr, _936 ? _936->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _6986;
  bool _6987 = (NULL != _936.get());
  if (_6987)
  {
    _6986 = _936;
  }
  else
  {
    _6986 = mosek::fusion::p_ConeDomain::_get_impl(_937)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _938 = _6986;
  _checked_ptr_1<int> _ptr__938(_938 ? _938->raw() : nullptr,_938 ? _938->size(0) : 0);
  if ((((int)((_935).size()) > (int)0) && hasVariable(_935)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_935)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if ((NULL == _938.get()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Missing shape"));
    }
  }
  else if(((NULL != mosek::fusion::p_ConeDomain::_get_impl(_937)->shape.get()) && (!::mosek::fusion::p_Set::match(_938,mosek::fusion::p_ConeDomain::_get_impl(_937)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  else if((_937->getAxis() >= (int)((_938)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid cone dimension"));
    }
  }
  {}
  int _6988;
  bool _6989 = (NULL != mosek::fusion::p_ConeDomain::_get_impl(_937)->shape.get());
  if (_6989)
  {
    _6988 = _937->getAxis();
  }
  else
  {
    _6988 = ((int)((_938)->size(0)) - (int)1);
  }
  int _939 = _6988;
  int _940 = _ptr__938[_939];
  int _941 = (int)((_938)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _942 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_941)));
  _checked_ptr_1<int> _ptr__942(_942 ? _942->raw() : nullptr,_942 ? _942->size(0) : 0);
  _ptr__942[(_941 - (int)1)] = (int)1;
  int _6990 = (int)1;
  int _6991 = _941;
  for (int _943 = _6990; _943 < _6991; ++_943)
  {
    {
      _ptr__942[((_941 - _943) - (int)1)] = safe_mul( _ptr__942[(_941 - _943)],_ptr__938[(_941 - _943)] );
    }
  }
  int _944 = _ptr__938[(int)0];
  int _6992 = (int)1;
  int _6993 = (int)((_938)->size(0));
  for (int _945 = _6992; _945 < _6993; ++_945)
  {
    {
      _944 *= _ptr__938[_945];
    }
  }
  int _946 = (int)1;
  int _6994 = (int)0;
  int _6995 = _939;
  for (int _947 = _6994; _947 < _6995; ++_947)
  {
    {
      _946 *= _ptr__938[_947];
    }
  }
  int _948 = (int)1;
  int _6996 = safe_add( _939,(int)1 );
  int _6997 = _941;
  for (int _949 = _6996; _949 < _6997; ++_949)
  {
    {
      _948 *= _ptr__938[_949];
    }
  }
  int _950 = safe_mul( _946,_948 );
  if ((((mosek::fusion::p_ConeDomain::_get_impl(_937)->key == ::mosek::fusion::QConeKey::InQCone) && (_940 < (int)2)) || (((mosek::fusion::p_ConeDomain::_get_impl(_937)->key == ::mosek::fusion::QConeKey::InRotatedQCone) && (_940 < (int)3)) || (((mosek::fusion::p_ConeDomain::_get_impl(_937)->key == ::mosek::fusion::QConeKey::InPExpCone) && (_940 != (int)3)) || (((mosek::fusion::p_ConeDomain::_get_impl(_937)->key == ::mosek::fusion::QConeKey::InPPowCone) && (_940 < (int)2)) || (((mosek::fusion::p_ConeDomain::_get_impl(_937)->key == ::mosek::fusion::QConeKey::InDExpCone) && (_940 != (int)3)) || ((mosek::fusion::p_ConeDomain::_get_impl(_937)->key == ::mosek::fusion::QConeKey::InDPowCone) && (_940 < (int)2))))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid size for cone"));
    }
  }
  {}
  int _951 = natvarmap_alloc(_944);
  int _952 = natconemap_alloc(_950);
  ((*natvarmap_type)(_951)) = safe_add( _952,(int)6 );
  std::shared_ptr< monty::ndarray< int,1 > > _953 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natvarmap->blocksize(_951))));
  _checked_ptr_1<int> _ptr__953(_953 ? _953->raw() : nullptr,_953 ? _953->size(0) : 0);
  natvarmap->get(_951,_953,(int)0);
  int _6998 = (int)0;
  int _6999 = _944;
  for (int _954 = _6998; _954 < _6999; ++_954)
  {
    {
      ((*natvarmap_idx)(_ptr__953[_954])) = _951;
    }
  }
  task_var_putboundlist_fr(_953);
  if (mosek::fusion::p_ConeDomain::_get_impl(_937)->int_flag)
  {
    {
      task_var_putintlist(_953);
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _955 = _953;
  _checked_ptr_1<int> _ptr__955(_955 ? _955->raw() : nullptr,_955 ? _955->size(0) : 0);
  if ((_939 < ((int)((_938)->size(0)) - (int)1)))
  {
    {
      _955 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_953)->size(0)))));
      _ptr__955.update(_955 ? _955->raw() : nullptr, _955 ? _955->size(0) : 0);
      int _956 = (int)0;
      int _7000 = (int)0;
      int _7001 = _946;
      for (int _957 = _7000; _957 < _7001; ++_957)
      {
        {
          int _7002 = (int)0;
          int _7003 = _948;
          for (int _958 = _7002; _958 < _7003; ++_958)
          {
            {
              int _7004 = (int)0;
              int _7005 = _940;
              for (int _959 = _7004; _959 < _7005; ++_959)
              {
                {
                  _ptr__955[_956] = _ptr__953[safe_add( safe_mul( safe_add( safe_mul( _957,_940 ),_959 ),_948 ),_958 )];
                  ++ _956;
                }
              }
            }
          }
        }
      }
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _960 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_950)));
  _checked_ptr_1<int> _ptr__960(_960 ? _960->raw() : nullptr,_960 ? _960->size(0) : 0);
  natconemap->get(_952,_960,(int)0);
  ((*natconemap_dim)(_952)) = _940;
  if ((mosek::fusion::p_ConeDomain::_get_impl(_937)->key == ::mosek::fusion::QConeKey::InQCone))
  {
    {
      task_put_quadcones(_960,_940,_950,_955);
    }
  }
  else
  {
    {
      if ((mosek::fusion::p_ConeDomain::_get_impl(_937)->key == ::mosek::fusion::QConeKey::InRotatedQCone))
      {
        {
          task_put_rquadcones(_960,_940,_950,_955);
        }
      }
      else
      {
        {
          if ((mosek::fusion::p_ConeDomain::_get_impl(_937)->key == ::mosek::fusion::QConeKey::InPExpCone))
          {
            {
              task_put_pexpcones(_960,_940,_950,_955);
            }
          }
          else
          {
            {
              if ((mosek::fusion::p_ConeDomain::_get_impl(_937)->key == ::mosek::fusion::QConeKey::InPPowCone))
              {
                {
                  std::vector<double> _7006;
                  for (int _961 = (int)0, _7007 = _950; _961 < _7007 ; ++_961)
                  {
                    _7006.push_back(mosek::fusion::p_ConeDomain::_get_impl(_937)->alpha);
                  }
                  auto _7008 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7006.size()),_7006.begin(),_7006.end()));
                  task_put_ppowcones(_960,_940,_950,_955,_7008);
                }
              }
              else
              {
                {
                  if ((mosek::fusion::p_ConeDomain::_get_impl(_937)->key == ::mosek::fusion::QConeKey::InDExpCone))
                  {
                    {
                      task_put_dexpcones(_960,_940,_950,_955);
                    }
                  }
                  else
                  {
                    {
                      if ((mosek::fusion::p_ConeDomain::_get_impl(_937)->key == ::mosek::fusion::QConeKey::InDPowCone))
                      {
                        {
                          std::vector<double> _7009;
                          for (int _962 = (int)0, _7010 = _950; _962 < _7010 ; ++_962)
                          {
                            _7009.push_back(mosek::fusion::p_ConeDomain::_get_impl(_937)->alpha);
                          }
                          auto _7011 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7009.size()),_7009.begin(),_7009.end()));
                          task_put_dpowcones(_960,_940,_950,_955,_7011);
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  int _7012 = (int)0;
  int _7013 = (int)((_960)->size(0));
  for (int _963 = _7012; _963 < _7013; ++_963)
  {
    {
      task_cone_name(_ptr__960[_963],::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__960[_963])->toString());
    }
  }
  monty::rc_ptr< ::mosek::fusion::ConicVariable > _964 = ::mosek::fusion::p_ConicVariable::_new_ConicVariable(::mosek::fusion::Model::t(_pubthis),_935,_951,_938,_953);
  ((*vars)(_951)) = (_964).as<::mosek::fusion::ModelVariable>();
  if (((int)((_935).size()) > (int)0))
  {
    {
      var_map->setItem(_935,_951);
    }
  }
  {}
  return (_964).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _965,std::shared_ptr< monty::ndarray< int,1 > > _966,monty::rc_ptr< ::mosek::fusion::LinearDomain > _967){
  _checked_ptr_1<int> _ptr__966(_966 ? _966->raw() : nullptr, _966 ? _966->size(0) : 0);
  if ((((int)((_965).size()) > (int)0) && hasVariable(_965)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_965)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _7014;
  bool _7015 = (NULL != _966.get());
  if (_7015)
  {
    _7014 = _966;
  }
  else
  {
    _7014 = mosek::fusion::p_LinearDomain::_get_impl(_967)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _968 = _7014;
  _checked_ptr_1<int> _ptr__968(_968 ? _968->raw() : nullptr,_968 ? _968->size(0) : 0);
  if (((NULL != mosek::fusion::p_LinearDomain::_get_impl(_967)->shape.get()) && (!::mosek::fusion::p_Set::match(mosek::fusion::p_LinearDomain::_get_impl(_967)->shape,_968))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  {}
  if ((NULL == _968.get()))
  {
    {
      _968 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
      _ptr__968.update(_968 ? _968->raw() : nullptr, _968 ? _968->size(0) : 0);
    }
  }
  {}
  int _969 = (int)((_968)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _970 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_969)));
  _checked_ptr_1<int> _ptr__970(_970 ? _970->raw() : nullptr,_970 ? _970->size(0) : 0);
  if ((_969 > (int)0))
  {
    {
      _ptr__970[(_969 - (int)1)] = (int)1;
      int _7016 = (int)1;
      int _7017 = _969;
      for (int _971 = _7016; _971 < _7017; ++_971)
      {
        {
          _ptr__970[((_969 - _971) - (int)1)] = safe_mul( _ptr__970[(_969 - _971)],_ptr__968[(_969 - _971)] );
        }
      }
    }
  }
  {}
  int _972 = (int)1;
  int _7018 = (int)0;
  int _7019 = (int)((_968)->size(0));
  for (int _973 = _7018; _973 < _7019; ++_973)
  {
    {
      _972 *= _ptr__968[_973];
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _974 = nullptr;
  _checked_ptr_1<long long> _ptr__974(_974 ? _974->raw() : nullptr,_974 ? _974->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _975 = nullptr;
  _checked_ptr_1<int> _ptr__975(_975 ? _975->raw() : nullptr,_975 ? _975->size(0) : 0);
  if (mosek::fusion::p_LinearDomain::_get_impl(_967)->empty)
  {
    {
      _974 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0)));
      _ptr__974.update(_974 ? _974->raw() : nullptr, _974 ? _974->size(0) : 0);
    }
  }
  else if((NULL != mosek::fusion::p_LinearDomain::_get_impl(_967)->sparsity.get()))
  {
    {
      if (((int)((mosek::fusion::p_LinearDomain::_get_impl(_967)->sparsity)->size(1)) != _969))
      {
        {
          throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
        }
      }
      {}
      int _976 = (int)((mosek::fusion::p_LinearDomain::_get_impl(_967)->sparsity)->size(0));
      _974 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_976)));
      _ptr__974.update(_974 ? _974->raw() : nullptr, _974 ? _974->size(0) : 0);
      {
        bool _977 = false;
        std::shared_ptr< monty::ndarray< int,2 > > _978 = mosek::fusion::p_LinearDomain::_get_impl(_967)->sparsity;
        int _7020 = (int)0;
        int _7021 = _976;
        for (int _979 = _7020; _979 < _7021; ++_979)
        {
          {
            int _7022 = (int)0;
            int _7023 = (int)((_978)->size(1));
            for (int _980 = _7022; _980 < _7023; ++_980)
            {
              {
                _977 = (_977 || ((((*_978)(_979,_980)) < (int)0) || (((*_978)(_979,_980)) >= _ptr__968[_980])));
              }
            }
            if ((!_977))
            {
              {
                long long _981 = (int)0;
                int _7024 = (int)0;
                int _7025 = (int)((_978)->size(1));
                for (int _982 = _7024; _982 < _7025; ++_982)
                {
                  {
                    _981 += safe_mul( _ptr__970[_982],((*_978)(_979,_982)) );
                  }
                }
                _ptr__974[_979] = _981;
              }
            }
            {}
          }
        }
        if (_977)
        {
          {
            throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is out of bounds"));
          }
        }
        {}
      }
      std::shared_ptr< monty::ndarray< int,2 > > _983 = mosek::fusion::p_LinearDomain::_get_impl(_967)->sparsity;
      int _984 = (int)0;
      int _7026 = (int)0;
      int _7027 = _969;
      for (int _985 = _7026; _985 < _7027; ++_985)
      {
        {
          if ((_984 < _ptr__968[_985]))
          {
            {
              _984 = _ptr__968[_985];
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _986 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_976)));
      _checked_ptr_1<int> _ptr__986(_986 ? _986->raw() : nullptr,_986 ? _986->size(0) : 0);
      int _7028 = (int)0;
      int _7029 = _976;
      for (int _987 = _7028; _987 < _7029; ++_987)
      {
        {
          _ptr__986[_987] = _987;
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _988 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_976)));
      _checked_ptr_1<int> _ptr__988(_988 ? _988->raw() : nullptr,_988 ? _988->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _989 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _984,(int)1 ))));
      _checked_ptr_1<int> _ptr__989(_989 ? _989->raw() : nullptr,_989 ? _989->size(0) : 0);
      int _7030 = (int)0;
      int _7031 = _969;
      for (int _990 = _7030; _990 < _7031; ++_990)
      {
        {
          {
            int _991 = ((_969 - _990) - (int)1);
            int _7032 = (int)0;
            int _7033 = safe_add( _ptr__968[_991],(int)1 );
            for (int _992 = _7032; _992 < _7033; ++_992)
            {
              {
                _ptr__989[_992] = (int)0;
              }
            }
            int _7034 = (int)0;
            int _7035 = _976;
            for (int _993 = _7034; _993 < _7035; ++_993)
            {
              {
                ++ _ptr__989[safe_add( ((*_983)(_993,_991)),(int)1 )];
              }
            }
            int _7036 = (int)0;
            int _7037 = _ptr__968[_991];
            for (int _994 = _7036; _994 < _7037; ++_994)
            {
              {
                _ptr__989[safe_add( _994,(int)1 )] += _ptr__989[_994];
              }
            }
            int _7038 = (int)0;
            int _7039 = _976;
            for (int _995 = _7038; _995 < _7039; ++_995)
            {
              {
                int _996 = _ptr__986[_995];
                _ptr__988[_ptr__989[((*_983)(_996,_991))]] = _996;
                ++ _ptr__989[((*_983)(_996,_991))];
              }
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _997 = _986;
          _checked_ptr_1<int> _ptr__997(_997 ? _997->raw() : nullptr,_997 ? _997->size(0) : 0);
          _986 = _988;
          _ptr__986.update(_986 ? _986->raw() : nullptr, _986 ? _986->size(0) : 0);
          _988 = _997;
          _ptr__988.update(_988 ? _988->raw() : nullptr, _988 ? _988->size(0) : 0);
        }
      }
      int _7040 = (int)0;
      int _7041 = _976;
      for (int _998 = _7040; _998 < _7041; ++_998)
      {
        {
          int _999 = _ptr__986[_998];
          long long _1000 = (int)0;
          int _7042 = (int)0;
          int _7043 = _969;
          for (int _1001 = _7042; _1001 < _7043; ++_1001)
          {
            {
              _1000 += safe_mul( _ptr__970[_1001],((*_983)(_999,_1001)) );
            }
          }
          _ptr__974[_998] = _1000;
        }
      }
    }
  }
  {}
  int _7044;
  bool _7045 = (NULL != _974.get());
  if (_7045)
  {
    _7044 = (int)((_974)->size(0));
  }
  else
  {
    _7044 = _972;
  }
  int _1002 = _7044;
  std::shared_ptr< monty::ndarray< double,1 > > _1003 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1002)));
  _checked_ptr_1<double> _ptr__1003(_1003 ? _1003->raw() : nullptr,_1003 ? _1003->size(0) : 0);
  if ((NULL != mosek::fusion::p_LinearDomain::_get_impl(_967)->bnd.get()))
  {
    {
      if (((int)((mosek::fusion::p_LinearDomain::_get_impl(_967)->bnd)->size(0)) == (int)1))
      {
        {
          int _7046 = (int)0;
          int _7047 = _1002;
          for (int _1004 = _7046; _1004 < _7047; ++_1004)
          {
            {
              _ptr__1003[_1004] = ((*mosek::fusion::p_LinearDomain::_get_impl(_967)->bnd)((int)0));
            }
          }
        }
      }
      else if(((int)((mosek::fusion::p_LinearDomain::_get_impl(_967)->bnd)->size(0)) == _1002))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinearDomain::_get_impl(_967)->bnd,(int)0,_1003,(int)0,_1002);
        }
      }
      else
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid right hand side shape in domain"));
        }
      }
    }
  }
  {}
  int _1005 = natvarmap_alloc(_1002);
  std::shared_ptr< monty::ndarray< int,1 > > _1006 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natvarmap->blocksize(_1005))));
  _checked_ptr_1<int> _ptr__1006(_1006 ? _1006->raw() : nullptr,_1006 ? _1006->size(0) : 0);
  natvarmap->get(_1005,_1006,(int)0);
  int _7048 = (int)0;
  int _7049 = _1002;
  for (int _1007 = _7048; _1007 < _7049; ++_1007)
  {
    {
      ((*natvarmap_idx)(_ptr__1006[_1007])) = _1005;
    }
  }
  if ((mosek::fusion::p_LinearDomain::_get_impl(_967)->key == ::mosek::fusion::RelationKey::IsFree))
  {
    {
      task_var_putboundlist_fr(_1006);
      ((*natvarmap_type)(_1005)) = (int)1;
    }
  }
  {}
  if ((mosek::fusion::p_LinearDomain::_get_impl(_967)->key == ::mosek::fusion::RelationKey::LessThan))
  {
    {
      task_var_putboundlist_up(_1006,_1003);
      ((*natvarmap_type)(_1005)) = (int)3;
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_967)->key == ::mosek::fusion::RelationKey::GreaterThan))
  {
    {
      task_var_putboundlist_lo(_1006,_1003);
      ((*natvarmap_type)(_1005)) = (int)2;
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_967)->key == ::mosek::fusion::RelationKey::EqualsTo))
  {
    {
      task_var_putboundlist_fx(_1006,_1003);
      ((*natvarmap_type)(_1005)) = (int)5;
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::LinearVariable > _1008 = ::mosek::fusion::p_LinearVariable::_new_LinearVariable(::mosek::fusion::Model::t(_pubthis),_965,(long long)(_1005),_968,_974,_1006);
  if (mosek::fusion::p_LinearDomain::_get_impl(_967)->cardinal_flag)
  {
    {
      task_var_putintlist(_1006);
    }
  }
  {}
  ((*vars)(_1005)) = (_1008).as<::mosek::fusion::ModelVariable>();
  if (((int)((_965).size()) > (int)0))
  {
    {
      var_map->setItem(_965,_1005);
    }
  }
  {}
  return (_1008).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _1009,std::shared_ptr< monty::ndarray< int,1 > > _1010,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1011){
  _checked_ptr_1<int> _ptr__1010(_1010 ? _1010->raw() : nullptr, _1010 ? _1010->size(0) : 0);
  if ((((int)((_1009).size()) > (int)0) && hasVariable(_1009)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1009)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _7050;
  bool _7051 = (NULL != _1010.get());
  if (_7051)
  {
    _7050 = _1010;
  }
  else
  {
    _7050 = mosek::fusion::p_LinPSDDomain::_get_impl(_1011)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1012 = _7050;
  _checked_ptr_1<int> _ptr__1012(_1012 ? _1012->raw() : nullptr,_1012 ? _1012->size(0) : 0);
  if ((NULL == _1012.get()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Missing shape for variable"));
    }
  }
  else if((!::mosek::fusion::p_Set::match(mosek::fusion::p_LinPSDDomain::_get_impl(_1011)->shape,_1012)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  {}
  int _1013 = (int)((_1012)->size(0));
  int _1014 = mosek::fusion::p_LinPSDDomain::_get_impl(_1011)->conedim;
  if (((_1014 < (int)0) || (_1014 >= _1013)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid cone direction dimension"));
    }
  }
  {}
  int _1015 = _ptr__1012[_1014];
  int _1016 = (int)((::mosek::fusion::Utils::Tools::sqrt((double)(safe_add( (int)1,safe_mul( (int)8,_1015 ) ))) - (int)1) / (int)2);
  if (((safe_mul( _1016,safe_add( _1016,(int)1 ) ) / (int)2) != _1015))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid size for semidefinite variable"));
    }
  }
  {}
  int _1017 = (int)1;
  int _1018 = _ptr__1012[_1014];
  int _1019 = (int)1;
  int _7052 = (int)0;
  int _7053 = _1014;
  for (int _1020 = _7052; _1020 < _7053; ++_1020)
  {
    {
      _1019 *= _ptr__1012[_1020];
    }
  }
  int _7054 = safe_add( _1014,(int)1 );
  int _7055 = _1013;
  for (int _1021 = _7054; _1021 < _7055; ++_1021)
  {
    {
      _1017 *= _ptr__1012[_1021];
    }
  }
  int _1022 = safe_mul( _1019,_1017 );
  int _1023 = safe_mul( _1022,_1015 );
  int _1024 = natbarvarmap_alloc(_1022,_1016);
  std::shared_ptr< monty::ndarray< int,1 > > _1025 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1023)));
  _checked_ptr_1<int> _ptr__1025(_1025 ? _1025->raw() : nullptr,_1025 ? _1025->size(0) : 0);
  natbarvarmap_get(_1024,_1025);
  std::shared_ptr< monty::ndarray< long long,1 > > _1026 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1022,_1018 ))));
  _checked_ptr_1<long long> _ptr__1026(_1026 ? _1026->raw() : nullptr,_1026 ? _1026->size(0) : 0);
  {
    int _1027 = (int)0;
    int _7056 = (int)0;
    int _7057 = _1019;
    for (int _1028 = _7056; _1028 < _7057; ++_1028)
    {
      {
        int _7058 = (int)0;
        int _7059 = _1018;
        for (int _1029 = _7058; _1029 < _7059; ++_1029)
        {
          {
            int _7060 = (int)0;
            int _7061 = safe_add( _1029,(int)1 );
            for (int _1030 = _7060; _1030 < _7061; ++_1030)
            {
              {
                int _7062 = (int)0;
                int _7063 = _1017;
                for (int _1031 = _7062; _1031 < _7063; ++_1031)
                {
                  {
                    _ptr__1026[_1027] = safe_add( ((*natbarvar_ptr)(safe_add( safe_mul( _1028,_1017 ),_1031 ))),safe_add( (safe_mul( _1029,((safe_mul( (int)2,_1016 ) - _1029) - (int)1) ) / (int)2),_1030 ) );
                    ++ _1027;
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1032 = ::mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable(::mosek::fusion::Model::t(_pubthis),_1009,_1024,_1012,_1014,_1026);
  ((*barvars)(_1024)) = (_1032).as<::mosek::fusion::ModelVariable>();
  if (((int)((_1009).size()) > (int)0))
  {
    {
      var_map->setItem(_1009,(-safe_add( _1024,(int)1 )));
    }
  }
  {}
  return (_1032).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::SymmetricVariable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _1033,std::shared_ptr< monty::ndarray< int,1 > > _1034,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1035){
  _checked_ptr_1<int> _ptr__1034(_1034 ? _1034->raw() : nullptr, _1034 ? _1034->size(0) : 0);
  if ((((int)((_1033).size()) > (int)0) && hasVariable(_1033)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1033)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _1036 = _1034;
  _checked_ptr_1<int> _ptr__1036(_1036 ? _1036->raw() : nullptr,_1036 ? _1036->size(0) : 0);
  if ((NULL == _1036.get()))
  {
    {
      _1036 = mosek::fusion::p_PSDDomain::_get_impl(_1035)->shape;
      _ptr__1036.update(_1036 ? _1036->raw() : nullptr, _1036 ? _1036->size(0) : 0);
    }
  }
  {}
  if ((NULL == _1036.get()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Missing shape for variable"));
    }
  }
  {}
  int _1037 = mosek::fusion::p_PSDDomain::_get_impl(_1035)->conedim1;
  int _1038 = mosek::fusion::p_PSDDomain::_get_impl(_1035)->conedim2;
  int _1039 = (int)((_1036)->size(0));
  int _1040 = _ptr__1036[_1037];
  if ((_1037 > _1038))
  {
    {
      int _1041 = _1037;
      _1037 = _1038;
      _1038 = _1041;
    }
  }
  {}
  if (((_1037 == _1038) || ((_1037 < (int)0) || (_1038 >= _1039))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid cone order dimensions for semidefinite variables"));
    }
  }
  {}
  if ((_ptr__1036[_1037] != _ptr__1036[_1038]))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape in cone order dimensions"));
    }
  }
  {}
  int _1042 = (int)1;
  int _7064 = (int)0;
  int _7065 = _1037;
  for (int _1043 = _7064; _1043 < _7065; ++_1043)
  {
    {
      _1042 *= _ptr__1036[_1043];
    }
  }
  int _7066 = safe_add( _1037,(int)1 );
  int _7067 = _1038;
  for (int _1044 = _7066; _1044 < _7067; ++_1044)
  {
    {
      _1042 *= _ptr__1036[_1044];
    }
  }
  int _7068 = safe_add( _1038,(int)1 );
  int _7069 = _1039;
  for (int _1045 = _7068; _1045 < _7069; ++_1045)
  {
    {
      _1042 *= _ptr__1036[_1045];
    }
  }
  int _1046 = (safe_mul( safe_mul( _1042,_1040 ),safe_add( _1040,(int)1 ) ) / (int)2);
  int _1047 = natbarvarmap_alloc(_1042,_1040);
  std::shared_ptr< monty::ndarray< long long,1 > > _1048 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1046)));
  _checked_ptr_1<long long> _ptr__1048(_1048 ? _1048->raw() : nullptr,_1048 ? _1048->size(0) : 0);
  natbarvar_get(_1047,_1048);
  monty::rc_ptr< ::mosek::fusion::PSDVariable > _1049 = ::mosek::fusion::p_PSDVariable::_new_PSDVariable(::mosek::fusion::Model::t(_pubthis),_1033,_1047,_1036,mosek::fusion::p_PSDDomain::_get_impl(_1035)->conedim1,mosek::fusion::p_PSDDomain::_get_impl(_1035)->conedim2,_1048);
  ((*barvars)(_1047)) = (_1049).as<::mosek::fusion::ModelVariable>();
  if (((int)((_1033).size()) > (int)0))
  {
    {
      var_map->setItem(_1033,(-safe_add( _1047,(int)1 )));
    }
  }
  {}
  return (_1049).as<::mosek::fusion::SymmetricVariable>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1050,monty::rc_ptr< ::mosek::fusion::Expression > _1051,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1052){
  if ((((int)((_1050).size()) > (int)0) && hasConstraint(_1050)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1050)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if (mosek::fusion::p_RangeDomain::_get_impl(_1052)->cardinal_flag)
  {
    {
      throw ::mosek::fusion::DomainError(std::string ("Integer domain not allowed in a constraint"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1053 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1051)).as<::mosek::fusion::Expression>());
  _1053->eval(rs,ws,xs);
  rs->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _1054 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1054(_1054 ? _1054->raw() : nullptr,_1054 ? _1054->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1055 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1055(_1055 ? _1055->raw() : nullptr,_1055 ? _1055->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1056 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1056(_1056 ? _1056->raw() : nullptr,_1056 ? _1056->size(0) : 0);
  int _1057 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1058 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1059 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1060 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  bool _1061 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1062 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1063 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1064 = mosek::fusion::p_WorkStack::_get_impl(rs)->bfix_base;
  int _1065 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  if ((NULL != mosek::fusion::p_RangeDomain::_get_impl(_1052)->shape.get()))
  {
    {
      if (((int)((mosek::fusion::p_RangeDomain::_get_impl(_1052)->shape)->size(0)) != _1057))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
        }
      }
      else
      {
        {
          int _7070 = (int)0;
          int _7071 = _1057;
          for (int _1066 = _7070; _1066 < _7071; ++_1066)
          {
            {
              if ((((*mosek::fusion::p_RangeDomain::_get_impl(_1052)->shape)(_1066)) != _ptr__1054[safe_add( _1058,_1066 )]))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
                }
              }
              {}
            }
          }
        }
      }
    }
  }
  {}
  int _1067 = (int)1;
  int _7072 = (int)0;
  int _7073 = _1057;
  for (int _1068 = _7072; _1068 < _7073; ++_1068)
  {
    {
      _1067 *= _ptr__1054[safe_add( _1058,_1068 )];
    }
  }
  int _1069 = natconmap_alloc(_1067);
  std::shared_ptr< monty::ndarray< int,1 > > _1070 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1067)));
  _checked_ptr_1<int> _ptr__1070(_1070 ? _1070->raw() : nullptr,_1070 ? _1070->size(0) : 0);
  natconmap->get(_1069,_1070,(int)0);
  int _7074 = (int)0;
  int _7075 = _1067;
  for (int _1071 = _7074; _1071 < _7075; ++_1071)
  {
    {
      ((*natconmap_idx)(_ptr__1070[_1071])) = _1069;
      ((*natconmap_slackidx)(_ptr__1070[_1071])) = (int)0;
    }
  }
  ((*natconmap_type)(_1069)) = (int)4;
  putarows(_1070,rs,_1059,_1060,_1062,_1063,_1065);
  std::vector<int> _7076;
  for (int _1072 = (int)0, _7077 = _1059; _1072 < _7077 ; ++_1072)
  {
    _7076.push_back(bfixidx);
  }
  auto _7078 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7076.size()),_7076.begin(),_7076.end()));
  std::vector<double> _7079;
  for (int _1073 = (int)0, _7080 = _1059; _1073 < _7080 ; ++_1073)
  {
    _7079.push_back(_ptr__1056[safe_add( _1064,_1073 )]);
  }
  auto _7081 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7079.size()),_7079.begin(),_7079.end()));
  task_putaijlist(_1070,_7078,_7081,(long long)(_1059));
  std::shared_ptr< monty::ndarray< double,1 > > _1074 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1067)));
  _checked_ptr_1<double> _ptr__1074(_1074 ? _1074->raw() : nullptr,_1074 ? _1074->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1075 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1067)));
  _checked_ptr_1<double> _ptr__1075(_1075 ? _1075->raw() : nullptr,_1075 ? _1075->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1076 = natconmap_efix;
  _checked_ptr_1<double> _ptr__1076(_1076 ? _1076->raw() : nullptr,_1076 ? _1076->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1077 = mosek::fusion::p_RangeDomain::_get_impl(_1052)->lb;
  _checked_ptr_1<double> _ptr__1077(_1077 ? _1077->raw() : nullptr,_1077 ? _1077->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1078 = mosek::fusion::p_RangeDomain::_get_impl(_1052)->ub;
  _checked_ptr_1<double> _ptr__1078(_1078 ? _1078->raw() : nullptr,_1078 ? _1078->size(0) : 0);
  bool _1079 = mosek::fusion::p_RangeDomain::_get_impl(_1052)->empty;
  bool _1080 = mosek::fusion::p_RangeDomain::_get_impl(_1052)->scalable;
  std::shared_ptr< monty::ndarray< int,2 > > _1081 = mosek::fusion::p_RangeDomain::_get_impl(_1052)->sparsity;
  {
    int _7082 = (int)0;
    int _7083 = _1059;
    for (int _1082 = _7082; _1082 < _7083; ++_1082)
    {
      {
        _ptr__1076[_ptr__1070[_1082]] = _ptr__1056[safe_add( _1064,_1082 )];
      }
    }
    if (_1080)
    {
      {
        int _7084 = (int)0;
        int _7085 = _1067;
        for (int _1083 = _7084; _1083 < _7085; ++_1083)
        {
          {
            _ptr__1074[_1083] = _ptr__1077[(int)0];
            _ptr__1075[_1083] = _ptr__1078[(int)0];
          }
        }
      }
    }
    else if(_1079)
    {
      {
      }
    }
    else if((NULL != _1081.get()))
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _1084 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1057)));
        _checked_ptr_1<int> _ptr__1084(_1084 ? _1084->raw() : nullptr,_1084 ? _1084->size(0) : 0);
        _ptr__1084[(_1057 - (int)1)] = (int)1;
        int _7086 = (int)1;
        int _7087 = _1057;
        for (int _1085 = _7086; _1085 < _7087; ++_1085)
        {
          {
            _ptr__1084[((_1057 - _1085) - (int)1)] = safe_mul( _ptr__1084[(_1057 - _1085)],_ptr__1054[(safe_add( _1058,_1057 ) - _1085)] );
          }
        }
        int _7088 = (int)0;
        int _7089 = (int)((_1077)->size(0));
        for (int _1086 = _7088; _1086 < _7089; ++_1086)
        {
          {
            int _1087 = (int)0;
            int _7090 = (int)0;
            int _7091 = _1057;
            for (int _1088 = _7090; _1088 < _7091; ++_1088)
            {
              {
                _1087 += safe_mul( _ptr__1084[_1088],((*_1081)(_1086,_1088)) );
              }
            }
            _ptr__1074[_1087] = _ptr__1077[_1086];
            _ptr__1075[_1087] = _ptr__1078[_1086];
          }
        }
      }
    }
    else
    {
      {
        int _7092 = (int)0;
        int _7093 = _1067;
        for (int _1089 = _7092; _1089 < _7093; ++_1089)
        {
          {
            _ptr__1074[_1089] = _ptr__1077[_1089];
            _ptr__1075[_1089] = _ptr__1078[_1089];
          }
        }
      }
    }
  }
  task_con_putboundlist_ra(_1070,_1074,_1075);
  std::vector<int> _7094;
  for (int _1091 = (int)0, _7095 = _1057; _1091 < _7095 ; ++_1091)
  {
    _7094.push_back(_ptr__1054[safe_add( _1058,_1091 )]);
  }
  auto _7096 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7094.size()),_7094.begin(),_7094.end()));
  monty::rc_ptr< ::mosek::fusion::RangedConstraint > _1090 = ::mosek::fusion::p_RangedConstraint::_new_RangedConstraint(::mosek::fusion::Model::t(_pubthis),_1050,_7096,_1070);
  ((*cons)(_1069)) = (_1090).as<::mosek::fusion::ModelConstraint>();
  if (((int)((_1050).size()) > (int)0))
  {
    {
      con_map->setItem(_1050,_1069);
    }
  }
  {}
  return (_1090).as<::mosek::fusion::Constraint>();
}
void mosek::fusion::p_Model::update_bfix(std::shared_ptr< monty::ndarray< int,1 > > _1092,std::shared_ptr< monty::ndarray< double,1 > > _1093){
  _checked_ptr_1<int> _ptr__1092(_1092 ? _1092->raw() : nullptr, _1092 ? _1092->size(0) : 0);
  _checked_ptr_1<double> _ptr__1093(_1093 ? _1093->raw() : nullptr, _1093 ? _1093->size(0) : 0);
  std::vector<int> _7097;
  for (int _1094 = (int)0, _7098 = (int)((_1092)->size(0)); _1094 < _7098 ; ++_1094)
  {
    _7097.push_back((int)0);
  }
  auto _7099 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7097.size()),_7097.begin(),_7097.end()));
  task_putaijlist(_1092,_7099,_1093,(long long)((int)((_1092)->size(0))));
}
void mosek::fusion::p_Model::putarows(std::shared_ptr< monty::ndarray< int,1 > > _1095,monty::rc_ptr< ::mosek::fusion::WorkStack > _1096,int _1097,int _1098,int _1099,int _1100,int _1101){
  _checked_ptr_1<int> _ptr__1095(_1095 ? _1095->raw() : nullptr, _1095 ? _1095->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1102 = mosek::fusion::p_WorkStack::_get_impl(_1096)->i32;
  _checked_ptr_1<int> _ptr__1102(_1102 ? _1102->raw() : nullptr,_1102 ? _1102->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1103 = mosek::fusion::p_WorkStack::_get_impl(_1096)->i64;
  _checked_ptr_1<long long> _ptr__1103(_1103 ? _1103->raw() : nullptr,_1103 ? _1103->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1104 = mosek::fusion::p_WorkStack::_get_impl(_1096)->f64;
  _checked_ptr_1<double> _ptr__1104(_1104 ? _1104->raw() : nullptr,_1104 ? _1104->size(0) : 0);
  int _1105 = (int)0;
  int _1106 = (int)0;
  int _1107 = (int)0;
  int _7100 = (int)0;
  int _7101 = _1097;
  for (int _1108 = _7100; _1108 < _7101; ++_1108)
  {
    {
      int _1109 = _ptr__1102[safe_add( _1099,_1108 )];
      int _1110 = _ptr__1102[safe_add( safe_add( _1099,_1108 ),(int)1 )];
      int _1111 = _1109;
      while ( ((_1111 < _1110) && (_ptr__1103[safe_add( _1100,_1111 )] < (int)0)) )
      {
        {
          int _1112 = ((*natbarvar_idx)((-safe_add( _ptr__1103[safe_add( _1100,_1111 )],(int)1 ))));
          int _1113 = _1111;
          ++ _1111;
          while ( ((_1111 < _1110) && ((_ptr__1103[safe_add( _1100,_1111 )] < (int)0) && (_1112 == ((*natbarvar_idx)((-safe_add( _ptr__1103[safe_add( _1100,_1111 )],(int)1 ))))))) )
          {
            {
              ++ _1111;
            }
          }
          ++ _1106;
        }
      }
      _1107 += (_1111 - _1109);
      _1105 += (_1110 - _1111);
    }
  }
  int _1114 = (int)((_1095)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _1115 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _1114,(int)1 ))));
  _checked_ptr_1<long long> _ptr__1115(_1115 ? _1115->raw() : nullptr,_1115 ? _1115->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1116 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1105)));
  _checked_ptr_1<int> _ptr__1116(_1116 ? _1116->raw() : nullptr,_1116 ? _1116->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1117 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1105)));
  _checked_ptr_1<double> _ptr__1117(_1117 ? _1117->raw() : nullptr,_1117 ? _1117->size(0) : 0);
  {
    int _1118 = (int)0;
    int _7102 = (int)0;
    int _7103 = _1097;
    for (int _1119 = _7102; _1119 < _7103; ++_1119)
    {
      {
        int _1120 = (int)0;
        int _7104 = _ptr__1102[safe_add( _1099,_1119 )];
        int _7105 = _ptr__1102[safe_add( safe_add( _1099,_1119 ),(int)1 )];
        for (int _1121 = _7104; _1121 < _7105; ++_1121)
        {
          {
            if ((_ptr__1103[safe_add( _1100,_1121 )] > (int)0))
            {
              {
                _ptr__1116[safe_add( _1118,_1120 )] = (int)(_ptr__1103[safe_add( _1100,_1121 )] - (int)1);
                _ptr__1117[safe_add( _1118,_1120 )] = _ptr__1104[safe_add( _1101,_1121 )];
                ++ _1120;
              }
            }
            {}
          }
        }
        _ptr__1115[safe_add( _1119,(int)1 )] = safe_add( _ptr__1115[_1119],_1120 );
        _1118 += _1120;
      }
    }
  }
  task_putarowlist(_1095,_1115,_1116,_1117);
  if ((_1106 > (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _1122 = _1095;
      _checked_ptr_1<int> _ptr__1122(_1122 ? _1122->raw() : nullptr,_1122 ? _1122->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1123 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _1114,(int)1 ))));
      _checked_ptr_1<long long> _ptr__1123(_1123 ? _1123->raw() : nullptr,_1123 ? _1123->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1124 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1106)));
      _checked_ptr_1<int> _ptr__1124(_1124 ? _1124->raw() : nullptr,_1124 ? _1124->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1125 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1106)));
      _checked_ptr_1<int> _ptr__1125(_1125 ? _1125->raw() : nullptr,_1125 ? _1125->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1126 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1106)));
      _checked_ptr_1<long long> _ptr__1126(_1126 ? _1126->raw() : nullptr,_1126 ? _1126->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1127 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1107)));
      _checked_ptr_1<int> _ptr__1127(_1127 ? _1127->raw() : nullptr,_1127 ? _1127->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1128 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1107)));
      _checked_ptr_1<int> _ptr__1128(_1128 ? _1128->raw() : nullptr,_1128 ? _1128->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _1129 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1107)));
      _checked_ptr_1<double> _ptr__1129(_1129 ? _1129->raw() : nullptr,_1129 ? _1129->size(0) : 0);
      int _1130 = (int)0;
      int _1131 = (int)0;
      int _7106 = (int)0;
      int _7107 = _1114;
      for (int _1132 = _7106; _1132 < _7107; ++_1132)
      {
        {
          int _1133 = _ptr__1102[safe_add( _1099,_1132 )];
          int _1134 = _ptr__1102[safe_add( safe_add( _1099,_1132 ),(int)1 )];
          while ( ((_1133 < _1134) && (_ptr__1103[safe_add( _1100,_1133 )] < (int)0)) )
          {
            {
              int _1135 = _1133;
              int _1136 = ((*natbarvar_idx)((-safe_add( _ptr__1103[safe_add( _1100,_1133 )],(int)1 ))));
              while ( ((_1133 < _1134) && ((_ptr__1103[safe_add( _1100,_1133 )] < (int)0) && (((*natbarvar_idx)((-safe_add( _ptr__1103[safe_add( _1100,_1133 )],(int)1 )))) == _1136))) )
              {
                {
                  _ptr__1127[_1131] = ((*natbarvar_i)((-safe_add( _ptr__1103[safe_add( _1100,_1133 )],(int)1 ))));
                  _ptr__1128[_1131] = ((*natbarvar_j)((-safe_add( _ptr__1103[safe_add( _1100,_1133 )],(int)1 ))));
                  if ((_ptr__1127[_1131] == _ptr__1128[_1131]))
                  {
                    {
                      _ptr__1129[_1131] = _ptr__1104[safe_add( _1101,_1133 )];
                    }
                  }
                  else
                  {
                    {
                      _ptr__1129[_1131] = (0.5 * _ptr__1104[safe_add( _1101,_1133 )]);
                    }
                  }
                  ++ _1131;
                  ++ _1133;
                }
              }
              _ptr__1124[_1130] = _1136;
              _ptr__1125[_1130] = ((*natbarvar_dim)(_1136));
              _ptr__1126[_1130] = (_1133 - _1135);
              ++ _1130;
            }
          }
          _1133 = _1134;
          _ptr__1123[safe_add( _1132,(int)1 )] = _1130;
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1137 = task_appendsymmatlist(_1125,_1126,_1127,_1128,_1129);
      _checked_ptr_1<long long> _ptr__1137(_1137 ? _1137->raw() : nullptr,_1137 ? _1137->size(0) : 0);
      task_putbararowlist(_1122,_1123,_1124,_1137);
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1138,monty::rc_ptr< ::mosek::fusion::Expression > _1139,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1140){
  std::shared_ptr< monty::ndarray< int,1 > > _1141 = _1139->getShape();
  _checked_ptr_1<int> _ptr__1141(_1141 ? _1141->raw() : nullptr,_1141 ? _1141->size(0) : 0);
  if (((NULL != mosek::fusion::p_PSDDomain::_get_impl(_1140)->shape.get()) && (!::mosek::fusion::p_Set::match(_1141,mosek::fusion::p_PSDDomain::_get_impl(_1140)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  bool _1142;
  int _1143;
  int _1144;
  if (mosek::fusion::p_PSDDomain::_get_impl(_1140)->axisIsSet)
  {
    {
      _1142 = (mosek::fusion::p_PSDDomain::_get_impl(_1140)->conedim1 < mosek::fusion::p_PSDDomain::_get_impl(_1140)->conedim2);
      int _7108;
      bool _7109 = _1142;
      if (_7109)
      {
        _7108 = mosek::fusion::p_PSDDomain::_get_impl(_1140)->conedim1;
      }
      else
      {
        _7108 = mosek::fusion::p_PSDDomain::_get_impl(_1140)->conedim2;
      }
      _1144 = _7108;
      int _7110;
      bool _7111 = _1142;
      if (_7111)
      {
        _7110 = mosek::fusion::p_PSDDomain::_get_impl(_1140)->conedim2;
      }
      else
      {
        _7110 = mosek::fusion::p_PSDDomain::_get_impl(_1140)->conedim1;
      }
      _1143 = _7110;
    }
  }
  else
  {
    {
      _1142 = true;
      _1144 = ((int)((_1141)->size(0)) - (int)2);
      _1143 = ((int)((_1141)->size(0)) - (int)1);
    }
  }
  if (((_1143 >= (int)((_1141)->size(0))) || (_ptr__1141[_1144] != _ptr__1141[_1143])))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Expression > _7112;
  bool _7113 = (mosek::fusion::p_PSDDomain::_get_impl(_1140)->key == ::mosek::fusion::PSDKey::IsSymPSD);
  if (_7113)
  {
    _7112 = ::mosek::fusion::p_ExprSymmetrize::_new_ExprSymmetrize(_1144,_1143,_1139).as<::mosek::fusion::Expression>();
  }
  else
  {
    _7112 = _1139;
  }
  monty::rc_ptr< ::mosek::fusion::ExprCompress > _1145 = ::mosek::fusion::p_ExprCompress::_new_ExprCompress((::mosek::fusion::p_ExprDenseTril::_new_ExprDenseTril(_1144,_1143,_7112)).as<::mosek::fusion::Expression>());
  _1145->eval(rs,ws,xs);
  std::shared_ptr< monty::ndarray< int,1 > > _1146 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1146(_1146 ? _1146->raw() : nullptr,_1146 ? _1146->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1147 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1147(_1147 ? _1147->raw() : nullptr,_1147 ? _1147->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1148 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1148(_1148 ? _1148->raw() : nullptr,_1148 ? _1148->size(0) : 0);
  int _1149 = rs->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _1150 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1149)));
  _checked_ptr_1<int> _ptr__1150(_1150 ? _1150->raw() : nullptr,_1150 ? _1150->size(0) : 0);
  rs->popi32(_1149,_1150,(int)0);
  int _1151 = rs->popi32();
  int _1152 = rs->popi32();
  bool _1153 = (rs->popi32() != (int)0);
  int _1154 = rs->popi32(safe_add( _1151,(int)1 ));
  int _7114;
  bool _7115 = _1153;
  if (_7115)
  {
    _7114 = rs->popi64(_1151);
  }
  else
  {
    _7114 = (-(int)99999);
  }
  int _1155 = _7114;
  int _1156 = rs->popi64(_1152);
  int _1157 = rs->popf64(_1151);
  int _1158 = rs->popf64(_1152);
  int _1159 = _ptr__1150[_1143];
  int _1160 = (safe_mul( _1159,safe_add( _1159,(int)1 ) ) / (int)2);
  int _7116 = (int)0;
  int _7117 = _1149;
  for (int _1161 = _7116; _1161 < _7117; ++_1161)
  {
    {
      if (((_1161 != _1144) && (_1161 != _1143)))
      {
        {
          _1160 *= _ptr__1150[_1161];
        }
      }
      {}
    }
  }
  int _1162 = natconmap_alloc(_1160);
  std::shared_ptr< monty::ndarray< int,1 > > _1163 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1160)));
  _checked_ptr_1<int> _ptr__1163(_1163 ? _1163->raw() : nullptr,_1163 ? _1163->size(0) : 0);
  natconmap->get(_1162,_1163,(int)0);
  putarows(_1163,rs,_1151,_1152,_1154,_1156,_1158);
  std::vector<int> _7118;
  for (int _1164 = (int)0, _7119 = _1151; _1164 < _7119 ; ++_1164)
  {
    _7118.push_back(bfixidx);
  }
  auto _7120 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7118.size()),_7118.begin(),_7118.end()));
  std::vector<double> _7121;
  for (int _1165 = (int)0, _7122 = _1151; _1165 < _7122 ; ++_1165)
  {
    _7121.push_back(_ptr__1148[safe_add( _1157,_1165 )]);
  }
  auto _7123 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7121.size()),_7121.begin(),_7121.end()));
  task_putaijlist(_1163,_7120,_7123,(long long)(_1151));
  std::shared_ptr< monty::ndarray< int,1 > > _1166 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1)});
  _checked_ptr_1<int> _ptr__1166(_1166 ? _1166->raw() : nullptr,_1166 ? _1166->size(0) : 0);
  int _7124 = (int)0;
  int _7125 = _1144;
  for (int _1167 = _7124; _1167 < _7125; ++_1167)
  {
    {
      _ptr__1166[(int)0] *= _ptr__1150[_1167];
    }
  }
  _ptr__1166[(int)1] = _ptr__1150[_1144];
  int _7126 = safe_add( _1144,(int)1 );
  int _7127 = _1143;
  for (int _1168 = _7126; _1168 < _7127; ++_1168)
  {
    {
      _ptr__1166[(int)2] *= _ptr__1150[_1168];
    }
  }
  _ptr__1166[(int)3] = _ptr__1150[_1143];
  int _7128 = safe_add( _1143,(int)1 );
  int _7129 = _1149;
  for (int _1169 = _7128; _1169 < _7129; ++_1169)
  {
    {
      _ptr__1166[(int)4] *= _ptr__1150[_1169];
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1170 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)5)));
  _checked_ptr_1<int> _ptr__1170(_1170 ? _1170->raw() : nullptr,_1170 ? _1170->size(0) : 0);
  _ptr__1170[(int)4] = (int)1;
  int _7130 = (int)1;
  int _7131 = (int)5;
  for (int _1171 = _7130; _1171 < _7131; ++_1171)
  {
    {
      _ptr__1170[(((int)5 - _1171) - (int)1)] = safe_mul( _ptr__1170[((int)5 - _1171)],_ptr__1166[((int)5 - _1171)] );
    }
  }
  std::shared_ptr< monty::ndarray< double,1 > > _1172 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1160)));
  _checked_ptr_1<double> _ptr__1172(_1172 ? _1172->raw() : nullptr,_1172 ? _1172->size(0) : 0);
  if ((_1155 < (int)0))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Unexpected case!"));
    }
  }
  else
  {
    {
      int _7132 = (int)0;
      int _7133 = _1151;
      for (int _1173 = _7132; _1173 < _7133; ++_1173)
      {
        {
          ((*natconmap_efix)(_ptr__1163[_1173])) = _ptr__1148[safe_add( _1157,_1173 )];
          ((*natconmap_lb)(_ptr__1163[_1173])) = (int)0;
          ((*natconmap_ub)(_ptr__1163[_1173])) = (int)0;
          _ptr__1172[_1173] = 0.0;
        }
      }
    }
  }
  task_con_putboundlist_fx(_1163,_1172);
  int _1174 = safe_mul( safe_mul( _ptr__1166[(int)0],_ptr__1166[(int)2] ),_ptr__1166[(int)4] );
  int _1175 = _ptr__1166[(int)1];
  int _1176 = natbarvarmap_alloc(_1174,_1175);
  std::shared_ptr< monty::ndarray< int,1 > > _1177 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1174)));
  _checked_ptr_1<int> _ptr__1177(_1177 ? _1177->raw() : nullptr,_1177 ? _1177->size(0) : 0);
  natbarvarmap_get(_1176,_1177);
  std::vector<int> _7134;
  for (int _1179 = (int)0, _7135 = (safe_mul( _1175,safe_add( _1175,(int)1 ) ) / (int)2); _1179 < _7135 ; ++_1179)
  {
    _7134.push_back(_1175);
  }
  auto _7136 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7134.size()),_7134.begin(),_7134.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1178 = _7136;
  _checked_ptr_1<int> _ptr__1178(_1178 ? _1178->raw() : nullptr,_1178 ? _1178->size(0) : 0);
  std::vector<long long> _7137;
  for (int _1181 = (int)0, _7138 = (safe_mul( _1175,safe_add( _1175,(int)1 ) ) / (int)2); _1181 < _7138 ; ++_1181)
  {
    _7137.push_back((int)1);
  }
  auto _7139 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7137.size()),_7137.begin(),_7137.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _1180 = _7139;
  _checked_ptr_1<long long> _ptr__1180(_1180 ? _1180->raw() : nullptr,_1180 ? _1180->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1182 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((safe_mul( _1175,safe_add( _1175,(int)1 ) ) / (int)2))));
  _checked_ptr_1<int> _ptr__1182(_1182 ? _1182->raw() : nullptr,_1182 ? _1182->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1183 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((safe_mul( _1175,safe_add( _1175,(int)1 ) ) / (int)2))));
  _checked_ptr_1<int> _ptr__1183(_1183 ? _1183->raw() : nullptr,_1183 ? _1183->size(0) : 0);
  std::vector<double> _7140;
  for (int _1185 = (int)0, _7141 = (safe_mul( _1175,safe_add( _1175,(int)1 ) ) / (int)2); _1185 < _7141 ; ++_1185)
  {
    _7140.push_back((-0.5));
  }
  auto _7142 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7140.size()),_7140.begin(),_7140.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1184 = _7142;
  _checked_ptr_1<double> _ptr__1184(_1184 ? _1184->raw() : nullptr,_1184 ? _1184->size(0) : 0);
  int _7143 = (int)1;
  int _7144 = safe_add( _1175,(int)1 );
  for (int _1186 = _7143; _1186 < _7144; ++_1186)
  {
    {
      _ptr__1184[((safe_mul( _1186,safe_add( _1186,(int)1 ) ) / (int)2) - (int)1)] = (-1.0);
    }
  }
  {
    int _1187 = (int)0;
    int _7145 = (int)0;
    int _7146 = _1175;
    for (int _1188 = _7145; _1188 < _7146; ++_1188)
    {
      {
        int _7147 = (int)0;
        int _7148 = safe_add( _1188,(int)1 );
        for (int _1189 = _7147; _1189 < _7148; ++_1189)
        {
          {
            _ptr__1182[_1187] = _1188;
            _ptr__1183[_1187] = _1189;
            ++ _1187;
          }
        }
      }
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1190 = task_appendsymmatlist(_1178,_1180,_1182,_1183,_1184);
  _checked_ptr_1<long long> _ptr__1190(_1190 ? _1190->raw() : nullptr,_1190 ? _1190->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1191 = _1163;
  _checked_ptr_1<int> _ptr__1191(_1191 ? _1191->raw() : nullptr,_1191 ? _1191->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1192 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1160)));
  _checked_ptr_1<int> _ptr__1192(_1192 ? _1192->raw() : nullptr,_1192 ? _1192->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1193 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1160)));
  _checked_ptr_1<long long> _ptr__1193(_1193 ? _1193->raw() : nullptr,_1193 ? _1193->size(0) : 0);
  {
    int _1194 = (int)0;
    if (_1142)
    {
      {
        int _7149 = (int)0;
        int _7150 = _ptr__1166[(int)0];
        for (int _1195 = _7149; _1195 < _7150; ++_1195)
        {
          {
            int _7151 = (int)0;
            int _7152 = _ptr__1166[(int)1];
            for (int _1196 = _7151; _1196 < _7152; ++_1196)
            {
              {
                int _7153 = (int)0;
                int _7154 = _ptr__1166[(int)2];
                for (int _1197 = _7153; _1197 < _7154; ++_1197)
                {
                  {
                    int _7155 = (int)0;
                    int _7156 = safe_add( _1196,(int)1 );
                    for (int _1198 = _7155; _1198 < _7156; ++_1198)
                    {
                      {
                        int _7157 = (int)0;
                        int _7158 = _ptr__1166[(int)4];
                        for (int _1199 = _7157; _1199 < _7158; ++_1199)
                        {
                          {
                            _ptr__1193[_1194] = _ptr__1190[safe_add( (safe_mul( _1196,safe_add( _1196,(int)1 ) ) / (int)2),_1198 )];
                            _ptr__1192[_1194] = _ptr__1177[safe_add( safe_mul( safe_add( safe_mul( _1195,_ptr__1166[(int)2] ),_1197 ),_ptr__1166[(int)4] ),_1199 )];
                            ((*natconmap_slackidx)(_ptr__1163[_1194])) = safe_add( safe_add( ((*natbarvar_ptr)(_ptr__1192[_1194])),(safe_mul( _1198,((safe_mul( (int)2,_ptr__1166[(int)1] ) - _1198) - (int)1) ) / (int)2) ),_1196 );
                            ++ _1194;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        int _7159 = (int)0;
        int _7160 = _ptr__1166[(int)0];
        for (int _1200 = _7159; _1200 < _7160; ++_1200)
        {
          {
            int _7161 = (int)0;
            int _7162 = _ptr__1166[(int)1];
            for (int _1201 = _7161; _1201 < _7162; ++_1201)
            {
              {
                int _7163 = (int)0;
                int _7164 = _ptr__1166[(int)2];
                for (int _1202 = _7163; _1202 < _7164; ++_1202)
                {
                  {
                    int _7165 = _1201;
                    int _7166 = _ptr__1166[(int)1];
                    for (int _1203 = _7165; _1203 < _7166; ++_1203)
                    {
                      {
                        int _7167 = (int)0;
                        int _7168 = _ptr__1166[(int)4];
                        for (int _1204 = _7167; _1204 < _7168; ++_1204)
                        {
                          {
                            _ptr__1193[_1194] = _ptr__1190[safe_add( (safe_mul( _1203,safe_add( _1203,(int)1 ) ) / (int)2),_1201 )];
                            _ptr__1192[_1194] = _ptr__1177[safe_add( safe_mul( safe_add( safe_mul( _1200,_ptr__1166[(int)2] ),_1202 ),_ptr__1166[(int)4] ),_1204 )];
                            ((*natconmap_slackidx)(_ptr__1163[_1194])) = safe_add( safe_add( ((*natbarvar_ptr)(_ptr__1192[_1194])),(safe_mul( _1201,((safe_mul( (int)2,_ptr__1166[(int)1] ) - _1201) - (int)1) ) / (int)2) ),_1203 );
                            ++ _1194;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  task_putbaraijlist(_1191,_1192,_1193);
  ((*natconmap_type)(_1162)) = (-safe_add( _1176,(int)1 ));
  std::vector<long long> _7169;
  for (int _1206 = (int)0, _7170 = _1160; _1206 < _7170 ; ++_1206)
  {
    _7169.push_back(((*natconmap_slackidx)(_ptr__1163[_1206])));
  }
  auto _7171 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7169.size()),_7169.begin(),_7169.end()));
  monty::rc_ptr< ::mosek::fusion::PSDConstraint > _1205 = ::mosek::fusion::p_PSDConstraint::_new_PSDConstraint(::mosek::fusion::Model::t(_pubthis),_1138,_1162,_1150,_1144,_1143,_7171,_1163);
  ((*cons)(_1162)) = (_1205).as<::mosek::fusion::ModelConstraint>();
  if (((int)((_1138).size()) > (int)0))
  {
    {
      con_map->setItem(_1138,_1162);
    }
  }
  {}
  return (_1205).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1207,monty::rc_ptr< ::mosek::fusion::Expression > _1208,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1209){
  if ((((int)((_1207).size()) > (int)0) && hasConstraint(_1207)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1207)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if ((((int)((_1207).size()) > (int)0) && hasConstraint(_1207)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1207)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1210 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1208)).as<::mosek::fusion::Expression>());
  _1210->eval(rs,ws,xs);
  std::shared_ptr< monty::ndarray< int,1 > > _1211 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1211(_1211 ? _1211->raw() : nullptr,_1211 ? _1211->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1212 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1212(_1212 ? _1212->raw() : nullptr,_1212 ? _1212->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1213 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1213(_1213 ? _1213->raw() : nullptr,_1213 ? _1213->size(0) : 0);
  int _1214 = rs->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _1215 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1214)));
  _checked_ptr_1<int> _ptr__1215(_1215 ? _1215->raw() : nullptr,_1215 ? _1215->size(0) : 0);
  rs->popi32(_1214,_1215,(int)0);
  int _1216 = rs->popi32();
  int _1217 = rs->popi32();
  bool _1218 = (rs->popi32() != (int)0);
  int _1219 = rs->popi32(safe_add( _1216,(int)1 ));
  int _1220 = rs->popi64(_1217);
  int _1221 = rs->popf64(_1216);
  int _1222 = rs->popf64(_1217);
  if (((NULL != mosek::fusion::p_LinPSDDomain::_get_impl(_1209)->shape.get()) && (!::mosek::fusion::p_Set::match(_1215,mosek::fusion::p_LinPSDDomain::_get_impl(_1209)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  int _1223 = (int)1;
  int _7172 = (int)0;
  int _7173 = _1214;
  for (int _1224 = _7172; _1224 < _7173; ++_1224)
  {
    {
      _1223 *= _ptr__1215[_1224];
    }
  }
  int _1225 = mosek::fusion::p_LinPSDDomain::_get_impl(_1209)->conedim;
  int _1226 = _ptr__1215[_1225];
  int _1227 = (int)((::mosek::fusion::Utils::Tools::sqrt((double)(safe_add( (int)1,safe_mul( (int)8,_1226 ) ))) - (int)1) / (int)2);
  if (((safe_mul( _1227,safe_add( _1227,(int)1 ) ) / (int)2) != _1226))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid size for semidefinite variable"));
    }
  }
  {}
  int _1228 = (int)1;
  int _7174 = (int)0;
  int _7175 = _1225;
  for (int _1229 = _7174; _1229 < _7175; ++_1229)
  {
    {
      _1228 *= _ptr__1215[_1229];
    }
  }
  int _1230 = (int)1;
  int _7176 = safe_add( _1225,(int)1 );
  int _7177 = _1214;
  for (int _1231 = _7176; _1231 < _7177; ++_1231)
  {
    {
      _1230 *= _ptr__1215[_1231];
    }
  }
  int _1232 = safe_mul( _1228,_1230 );
  int _1233 = natconmap_alloc(_1223);
  std::shared_ptr< monty::ndarray< int,1 > > _1234 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1223)));
  _checked_ptr_1<int> _ptr__1234(_1234 ? _1234->raw() : nullptr,_1234 ? _1234->size(0) : 0);
  natconmap->get(_1233,_1234,(int)0);
  putarows(_1234,rs,_1216,_1217,_1219,_1220,_1222);
  std::vector<int> _7178;
  for (int _1235 = (int)0, _7179 = _1216; _1235 < _7179 ; ++_1235)
  {
    _7178.push_back(bfixidx);
  }
  auto _7180 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7178.size()),_7178.begin(),_7178.end()));
  std::vector<double> _7181;
  for (int _1236 = (int)0, _7182 = _1216; _1236 < _7182 ; ++_1236)
  {
    _7181.push_back(_ptr__1213[safe_add( _1221,_1236 )]);
  }
  auto _7183 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7181.size()),_7181.begin(),_7181.end()));
  task_putaijlist(_1234,_7180,_7183,(long long)(_1216));
  int _1237 = natbarvarmap_alloc(_1232,_1227);
  std::shared_ptr< monty::ndarray< int,1 > > _1238 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1232)));
  _checked_ptr_1<int> _ptr__1238(_1238 ? _1238->raw() : nullptr,_1238 ? _1238->size(0) : 0);
  natbarvarmap_get(_1237,_1238);
  ((*barvars)(_1237)) = nullptr;
  int _1239 = safe_mul( safe_mul( _1226,_1228 ),_1230 );
  std::vector<int> _7184;
  for (int _1241 = (int)0, _7185 = _1226; _1241 < _7185 ; ++_1241)
  {
    _7184.push_back(_1241);
  }
  auto _7186 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7184.size()),_7184.begin(),_7184.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1240 = _7186;
  _checked_ptr_1<int> _ptr__1240(_1240 ? _1240->raw() : nullptr,_1240 ? _1240->size(0) : 0);
  std::vector<long long> _7187;
  for (int _1243 = (int)0, _7188 = _1226; _1243 < _7188 ; ++_1243)
  {
    _7187.push_back((int)1);
  }
  auto _7189 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7187.size()),_7187.begin(),_7187.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _1242 = _7189;
  _checked_ptr_1<long long> _ptr__1242(_1242 ? _1242->raw() : nullptr,_1242 ? _1242->size(0) : 0);
  std::vector<double> _7190;
  for (int _1245 = (int)0, _7191 = _1226; _1245 < _7191 ; ++_1245)
  {
    _7190.push_back((-0.5));
  }
  auto _7192 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7190.size()),_7190.begin(),_7190.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1244 = _7192;
  _checked_ptr_1<double> _ptr__1244(_1244 ? _1244->raw() : nullptr,_1244 ? _1244->size(0) : 0);
  int _7193 = (int)1;
  int _7194 = safe_add( _1226,(int)1 );
  for (int _1246 = _7193; _1246 < _7194; ++_1246)
  {
    {
      _ptr__1244[((safe_mul( _1246,safe_add( _1246,(int)1 ) ) / (int)2) - (int)1)] = (-1.0);
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1247 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1226)));
  _checked_ptr_1<int> _ptr__1247(_1247 ? _1247->raw() : nullptr,_1247 ? _1247->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1248 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1226)));
  _checked_ptr_1<int> _ptr__1248(_1248 ? _1248->raw() : nullptr,_1248 ? _1248->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1249 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1239)));
  _checked_ptr_1<int> _ptr__1249(_1249 ? _1249->raw() : nullptr,_1249 ? _1249->size(0) : 0);
  {
    int _1250 = (int)0;
    int _7195 = (int)0;
    int _7196 = _1228;
    for (int _1251 = _7195; _1251 < _7196; ++_1251)
    {
      {
        int _7197 = (int)0;
        int _7198 = _1227;
        for (int _1252 = _7197; _1252 < _7198; ++_1252)
        {
          {
            int _7199 = (int)0;
            int _7200 = safe_add( _1252,(int)1 );
            for (int _1253 = _7199; _1253 < _7200; ++_1253)
            {
              {
                int _7201 = (int)0;
                int _7202 = _1230;
                for (int _1254 = _7201; _1254 < _7202; ++_1254)
                {
                  {
                    _ptr__1249[_1250] = safe_add( safe_mul( _1251,_1230 ),_1254 );
                    _ptr__1247[_1250] = _1252;
                    _ptr__1248[_1250] = _1253;
                    ++ _1250;
                  }
                }
              }
            }
          }
        }
      }
    }
    ((*natconmap_type)(_1233)) = (-safe_add( _1237,(int)1 ));
    int _7203 = (int)0;
    int _7204 = _1223;
    for (int _1255 = _7203; _1255 < _7204; ++_1255)
    {
      {
        ((*natconmap_blockid)(_ptr__1234[_1255])) = _1233;
        ((*natconmap_idx)(_ptr__1234[_1255])) = _1255;
        ((*natconmap_efix)(_ptr__1234[_1255])) = _ptr__1213[safe_add( _1221,_1255 )];
        ((*natconmap_lb)(_ptr__1234[_1255])) = (int)0;
        ((*natconmap_ub)(_ptr__1234[_1255])) = (int)0;
      }
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1256 = task_appendsymmatlist(_1240,_1242,_1247,_1248,_1244);
  _checked_ptr_1<long long> _ptr__1256(_1256 ? _1256->raw() : nullptr,_1256 ? _1256->size(0) : 0);
  task_putbaraijlist(_1234,_1249,_1256);
  std::vector<double> _7205;
  for (int _1258 = (int)0, _7206 = _1223; _1258 < _7206 ; ++_1258)
  {
    _7205.push_back(0.0);
  }
  auto _7207 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7205.size()),_7205.begin(),_7205.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1257 = _7207;
  _checked_ptr_1<double> _ptr__1257(_1257 ? _1257->raw() : nullptr,_1257 ? _1257->size(0) : 0);
  task_con_putboundlist_fx(_1234,_1257);
  std::vector<long long> _7208;
  for (int _1260 = (int)0, _7209 = _1223; _1260 < _7209 ; ++_1260)
  {
    _7208.push_back(((*natconmap_slackidx)(_ptr__1234[_1260])));
  }
  auto _7210 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7208.size()),_7208.begin(),_7208.end()));
  monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _1259 = ::mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint(::mosek::fusion::Model::t(_pubthis),_1207,_1233,_1215,_1225,_1234,_7210);
  ((*cons)(_1233)) = (_1259).as<::mosek::fusion::ModelConstraint>();
  if (((int)((_1207).size()) > (int)0))
  {
    {
      con_map->setItem(_1207,_1233);
    }
  }
  {}
  return (_1259).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1261,monty::rc_ptr< ::mosek::fusion::Expression > _1262,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1263){
  if ((((int)((_1261).size()) > (int)0) && hasConstraint(_1261)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1261)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if ((((int)((_1261).size()) > (int)0) && hasConstraint(_1261)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1261)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if (mosek::fusion::p_ConeDomain::_get_impl(_1263)->int_flag)
  {
    {
      throw ::mosek::fusion::DomainError(std::string ("Integer domain not allowed in a constraint"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1264 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1262)).as<::mosek::fusion::Expression>());
  _1264->eval(rs,ws,xs);
  rs->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _1265 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1265(_1265 ? _1265->raw() : nullptr,_1265 ? _1265->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1266 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1266(_1266 ? _1266->raw() : nullptr,_1266 ? _1266->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1267 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1267(_1267 ? _1267->raw() : nullptr,_1267 ? _1267->size(0) : 0);
  int _1268 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1269 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1270 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1271 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  bool _1272 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1273 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1274 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1275 = mosek::fusion::p_WorkStack::_get_impl(rs)->bfix_base;
  int _1276 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  std::vector<int> _7211;
  for (int _1278 = (int)0, _7212 = _1268; _1278 < _7212 ; ++_1278)
  {
    _7211.push_back(_ptr__1265[safe_add( _1269,_1278 )]);
  }
  auto _7213 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7211.size()),_7211.begin(),_7211.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1277 = _7213;
  _checked_ptr_1<int> _ptr__1277(_1277 ? _1277->raw() : nullptr,_1277 ? _1277->size(0) : 0);
  if (((NULL != mosek::fusion::p_ConeDomain::_get_impl(_1263)->shape.get()) && (!::mosek::fusion::p_Set::match(_1277,mosek::fusion::p_ConeDomain::_get_impl(_1263)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  int _7214;
  bool _7215 = _1263->axisIsSet();
  if (_7215)
  {
    _7214 = _1263->getAxis();
  }
  else
  {
    _7214 = (_1268 - (int)1);
  }
  int _1279 = _7214;
  int _1280 = _ptr__1277[_1279];
  int _1281 = (int)1;
  int _1282 = (int)1;
  int _1283 = (int)1;
  {
    int _7216 = (int)0;
    int _7217 = _1268;
    for (int _1284 = _7216; _1284 < _7217; ++_1284)
    {
      {
        _1283 *= _ptr__1277[_1284];
      }
    }
    int _7218 = (int)0;
    int _7219 = _1279;
    for (int _1285 = _7218; _1285 < _7219; ++_1285)
    {
      {
        _1282 *= _ptr__1277[_1285];
      }
    }
    int _7220 = safe_add( _1279,(int)1 );
    int _7221 = _1268;
    for (int _1286 = _7220; _1286 < _7221; ++_1286)
    {
      {
        _1281 *= _ptr__1277[_1286];
      }
    }
  }
  int _1287 = safe_mul( _1282,_1281 );
  if (((mosek::fusion::p_ConeDomain::_get_impl(_1263)->key == ::mosek::fusion::QConeKey::InQCone) && (_1280 < (int)2)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1280)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for quadratic cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1263)->key == ::mosek::fusion::QConeKey::InRotatedQCone) && (_1280 < (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1280)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for rotated quadratic cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1263)->key == ::mosek::fusion::QConeKey::InPExpCone) && (_1280 != (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1280)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for exponential cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1263)->key == ::mosek::fusion::QConeKey::InPPowCone) && (_1280 < (int)2)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1280)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for power cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1263)->key == ::mosek::fusion::QConeKey::InDExpCone) && (_1280 != (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1280)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for dual exponential cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1263)->key == ::mosek::fusion::QConeKey::InDPowCone) && (_1280 < (int)2)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1280)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for dual power cone"))->toString());
    }
  }
  {}
  int _1288 = natvarmap_alloc(_1283);
  std::shared_ptr< monty::ndarray< int,1 > > _1289 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1283)));
  _checked_ptr_1<int> _ptr__1289(_1289 ? _1289->raw() : nullptr,_1289 ? _1289->size(0) : 0);
  natvarmap->get(_1288,_1289,(int)0);
  int _1290 = natconemap_alloc(_1287);
  int _7222 = (int)0;
  int _7223 = _1283;
  for (int _1291 = _7222; _1291 < _7223; ++_1291)
  {
    {
      ((*natvarmap_idx)(_ptr__1289[_1291])) = _1288;
    }
  }
  task_var_putboundlist_fr(_1289);
  std::shared_ptr< monty::ndarray< int,1 > > _7224;
  bool _7225 = (_1279 < ((int)((_1277)->size(0)) - (int)1));
  if (_7225)
  {
    _7224 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_1289)->size(0)))));
  }
  else
  {
    _7224 = _1289;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1292 = _7224;
  _checked_ptr_1<int> _ptr__1292(_1292 ? _1292->raw() : nullptr,_1292 ? _1292->size(0) : 0);
  if ((_1279 < ((int)((_1277)->size(0)) - (int)1)))
  {
    {
      int _1293 = (int)0;
      int _7226 = (int)0;
      int _7227 = _1282;
      for (int _1294 = _7226; _1294 < _7227; ++_1294)
      {
        {
          int _7228 = (int)0;
          int _7229 = _1281;
          for (int _1295 = _7228; _1295 < _7229; ++_1295)
          {
            {
              int _7230 = (int)0;
              int _7231 = _1280;
              for (int _1296 = _7230; _1296 < _7231; ++_1296)
              {
                {
                  _ptr__1292[_1293] = _ptr__1289[safe_add( safe_mul( safe_add( safe_mul( _1294,_1280 ),_1296 ),_1281 ),_1295 )];
                  ++ _1293;
                }
              }
            }
          }
        }
      }
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _1297 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1287)));
  _checked_ptr_1<int> _ptr__1297(_1297 ? _1297->raw() : nullptr,_1297 ? _1297->size(0) : 0);
  natconemap->get(_1290,_1297,(int)0);
  ((*natconemap_dim)(_1290)) = _1280;
  if ((mosek::fusion::p_ConeDomain::_get_impl(_1263)->key == ::mosek::fusion::QConeKey::InQCone))
  {
    {
      task_put_quadcones(_1297,_1280,_1287,_1292);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1263)->key == ::mosek::fusion::QConeKey::InRotatedQCone))
  {
    {
      task_put_rquadcones(_1297,_1280,_1287,_1292);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1263)->key == ::mosek::fusion::QConeKey::InPExpCone))
  {
    {
      task_put_pexpcones(_1297,_1280,_1287,_1292);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1263)->key == ::mosek::fusion::QConeKey::InPPowCone))
  {
    {
      std::vector<double> _7232;
      for (int _1298 = (int)0, _7233 = _1287; _1298 < _7233 ; ++_1298)
      {
        _7232.push_back(mosek::fusion::p_ConeDomain::_get_impl(_1263)->alpha);
      }
      auto _7234 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7232.size()),_7232.begin(),_7232.end()));
      task_put_ppowcones(_1297,_1280,_1287,_1292,_7234);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1263)->key == ::mosek::fusion::QConeKey::InDExpCone))
  {
    {
      task_put_dexpcones(_1297,_1280,_1287,_1292);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1263)->key == ::mosek::fusion::QConeKey::InDPowCone))
  {
    {
      std::vector<double> _7235;
      for (int _1299 = (int)0, _7236 = _1287; _1299 < _7236 ; ++_1299)
      {
        _7235.push_back(mosek::fusion::p_ConeDomain::_get_impl(_1263)->alpha);
      }
      auto _7237 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7235.size()),_7235.begin(),_7235.end()));
      task_put_dpowcones(_1297,_1280,_1287,_1292,_7237);
    }
  }
  else
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Internal error: Invalid cone type"));
    }
  }
  ((*vars)(_1288)) = nullptr;
  std::shared_ptr< monty::ndarray< double,1 > > _1300 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1283)));
  _checked_ptr_1<double> _ptr__1300(_1300 ? _1300->raw() : nullptr,_1300 ? _1300->size(0) : 0);
  int _1301 = natconmap_alloc(_1283);
  std::shared_ptr< monty::ndarray< int,1 > > _1302 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1283)));
  _checked_ptr_1<int> _ptr__1302(_1302 ? _1302->raw() : nullptr,_1302 ? _1302->size(0) : 0);
  natconmap->get(_1301,_1302,(int)0);
  ((*natconmap_type)(_1301)) = safe_add( _1288,(int)6 );
  {
    int _7238 = (int)0;
    int _7239 = _1283;
    for (int _1303 = _7238; _1303 < _7239; ++_1303)
    {
      {
        ((*natconmap_efix)(_ptr__1302[_1303])) = _ptr__1267[safe_add( _1275,_1303 )];
      }
    }
    int _7240 = (int)0;
    int _7241 = _1283;
    for (int _1304 = _7240; _1304 < _7241; ++_1304)
    {
      {
        ((*natconmap_lb)(_ptr__1302[_1304])) = (int)0;
      }
    }
    int _7242 = (int)0;
    int _7243 = _1283;
    for (int _1305 = _7242; _1305 < _7243; ++_1305)
    {
      {
        ((*natconmap_ub)(_ptr__1302[_1305])) = (int)0;
      }
    }
    int _7244 = (int)0;
    int _7245 = _1283;
    for (int _1306 = _7244; _1306 < _7245; ++_1306)
    {
      {
        ((*natconmap_slackidx)(_ptr__1302[_1306])) = safe_add( _ptr__1289[_1306],(int)1 );
      }
    }
    int _7246 = (int)0;
    int _7247 = _1283;
    for (int _1307 = _7246; _1307 < _7247; ++_1307)
    {
      {
        ((*natconmap_blockid)(_ptr__1302[_1307])) = _1301;
      }
    }
    int _7248 = (int)0;
    int _7249 = _1283;
    for (int _1308 = _7248; _1308 < _7249; ++_1308)
    {
      {
        ((*natconmap_idx)(_ptr__1302[_1308])) = _1308;
      }
    }
  }
  putarows(_1302,rs,_1270,_1271,_1273,_1274,_1276);
  task_con_putboundlist_fx(_1302,_1300);
  std::vector<double> _7250;
  for (int _1309 = (int)0, _7251 = (int)((_1302)->size(0)); _1309 < _7251 ; ++_1309)
  {
    _7250.push_back((-1.0));
  }
  auto _7252 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7250.size()),_7250.begin(),_7250.end()));
  task_putaijlist(_1302,_1289,_7252,(long long)((int)((_1302)->size(0))));
  std::vector<int> _7253;
  for (int _1310 = (int)0, _7254 = _1270; _1310 < _7254 ; ++_1310)
  {
    _7253.push_back(bfixidx);
  }
  auto _7255 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7253.size()),_7253.begin(),_7253.end()));
  std::vector<double> _7256;
  for (int _1311 = (int)0, _7257 = _1270; _1311 < _7257 ; ++_1311)
  {
    _7256.push_back(_ptr__1267[safe_add( _1275,_1311 )]);
  }
  auto _7258 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7256.size()),_7256.begin(),_7256.end()));
  task_putaijlist(_1302,_7255,_7258,(long long)(_1270));
  monty::rc_ptr< ::mosek::fusion::ConicConstraint > _1312 = ::mosek::fusion::p_ConicConstraint::_new_ConicConstraint(::mosek::fusion::Model::t(_pubthis),_1261,_1263,_1277,_1301,_1302,_1289);
  ((*cons)(_1301)) = (_1312).as<::mosek::fusion::ModelConstraint>();
  if (((int)((_1261).size()) > (int)0))
  {
    {
      con_map->setItem(_1261,_1301);
    }
  }
  {}
  return (_1312).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1313,monty::rc_ptr< ::mosek::fusion::Expression > _1314,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1315){
  if ((((int)((_1313).size()) > (int)0) && hasConstraint(_1313)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1313)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if (mosek::fusion::p_LinearDomain::_get_impl(_1315)->cardinal_flag)
  {
    {
      throw ::mosek::fusion::DomainError(std::string ("Integer domain not allowed in a constraint"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1316 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1314)).as<::mosek::fusion::Expression>());
  _1316->eval(rs,ws,xs);
  rs->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _1317 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1317(_1317 ? _1317->raw() : nullptr,_1317 ? _1317->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1318 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1318(_1318 ? _1318->raw() : nullptr,_1318 ? _1318->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1319 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1319(_1319 ? _1319->raw() : nullptr,_1319 ? _1319->size(0) : 0);
  int _1320 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1321 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1322 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1323 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  bool _1324 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1325 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1326 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1327 = mosek::fusion::p_WorkStack::_get_impl(rs)->bfix_base;
  int _1328 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  std::vector<int> _7259;
  for (int _1330 = (int)0, _7260 = _1320; _1330 < _7260 ; ++_1330)
  {
    _7259.push_back(_ptr__1317[safe_add( _1321,_1330 )]);
  }
  auto _7261 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7259.size()),_7259.begin(),_7259.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1329 = _7261;
  _checked_ptr_1<int> _ptr__1329(_1329 ? _1329->raw() : nullptr,_1329 ? _1329->size(0) : 0);
  if (((NULL != mosek::fusion::p_LinearDomain::_get_impl(_1315)->shape.get()) && (!::mosek::fusion::p_Set::match(_1329,mosek::fusion::p_LinearDomain::_get_impl(_1315)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  int _1331 = (int)1;
  int _7262 = (int)0;
  int _7263 = _1320;
  for (int _1332 = _7262; _1332 < _7263; ++_1332)
  {
    {
      _1331 *= _ptr__1329[_1332];
    }
  }
  std::shared_ptr< monty::ndarray< double,1 > > _1333;
  _checked_ptr_1<double> _ptr__1333(_1333 ? _1333->raw() : nullptr,_1333 ? _1333->size(0) : 0);
  int _1334 = natconmap_alloc(_1331);
  std::shared_ptr< monty::ndarray< int,1 > > _1335 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1331)));
  _checked_ptr_1<int> _ptr__1335(_1335 ? _1335->raw() : nullptr,_1335 ? _1335->size(0) : 0);
  natconmap->get(_1334,_1335,(int)0);
  putarows(_1335,rs,_1322,_1323,_1325,_1326,_1328);
  {
    std::shared_ptr< monty::ndarray< int,1 > > _1336 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1322)));
    _checked_ptr_1<int> _ptr__1336(_1336 ? _1336->raw() : nullptr,_1336 ? _1336->size(0) : 0);
    std::shared_ptr< monty::ndarray< double,1 > > _1337 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1322)));
    _checked_ptr_1<double> _ptr__1337(_1337 ? _1337->raw() : nullptr,_1337 ? _1337->size(0) : 0);
    int _7264 = (int)0;
    int _7265 = _1322;
    for (int _1338 = _7264; _1338 < _7265; ++_1338)
    {
      {
        _ptr__1336[_1338] = bfixidx;
        _ptr__1337[_1338] = _ptr__1319[safe_add( _1327,_1338 )];
      }
    }
    task_putaijlist(_1335,_1336,_1337,(long long)(_1322));
  }
  {
    std::shared_ptr< monty::ndarray< int,2 > > _1339 = mosek::fusion::p_LinearDomain::_get_impl(_1315)->sparsity;
    bool _1340 = mosek::fusion::p_LinearDomain::_get_impl(_1315)->empty;
    std::shared_ptr< monty::ndarray< double,1 > > _1341 = mosek::fusion::p_LinearDomain::_get_impl(_1315)->bnd;
    _checked_ptr_1<double> _ptr__1341(_1341 ? _1341->raw() : nullptr,_1341 ? _1341->size(0) : 0);
    bool _1342 = mosek::fusion::p_LinearDomain::_get_impl(_1315)->scalable;
    std::shared_ptr< monty::ndarray< double,1 > > _1343 = natconmap_efix;
    _checked_ptr_1<double> _ptr__1343(_1343 ? _1343->raw() : nullptr,_1343 ? _1343->size(0) : 0);
    std::shared_ptr< monty::ndarray< double,1 > > _1344 = natconmap_lb;
    _checked_ptr_1<double> _ptr__1344(_1344 ? _1344->raw() : nullptr,_1344 ? _1344->size(0) : 0);
    std::shared_ptr< monty::ndarray< double,1 > > _1345 = natconmap_ub;
    _checked_ptr_1<double> _ptr__1345(_1345 ? _1345->raw() : nullptr,_1345 ? _1345->size(0) : 0);
    {
      int _7266 = (int)0;
      int _7267 = _1322;
      for (int _1346 = _7266; _1346 < _7267; ++_1346)
      {
        {
          _ptr__1343[_ptr__1335[_1346]] = _ptr__1319[safe_add( _1327,_1346 )];
        }
      }
      if ((NULL == _1341.get()))
      {
        {
          int _7268 = (int)0;
          int _7269 = _1322;
          for (int _1347 = _7268; _1347 < _7269; ++_1347)
          {
            {
              _ptr__1344[_ptr__1335[_1347]] = (int)0;
              _ptr__1345[_ptr__1335[_1347]] = (int)0;
            }
          }
        }
      }
      else if(_1342)
      {
        {
          int _7270 = (int)0;
          int _7271 = _1322;
          for (int _1348 = _7270; _1348 < _7271; ++_1348)
          {
            {
              _ptr__1344[_ptr__1335[_1348]] = _ptr__1341[(int)0];
              _ptr__1345[_ptr__1335[_1348]] = _ptr__1341[(int)0];
            }
          }
        }
      }
      else if((NULL != _1339.get()))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _1349 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1320)));
          _checked_ptr_1<int> _ptr__1349(_1349 ? _1349->raw() : nullptr,_1349 ? _1349->size(0) : 0);
          _ptr__1349[(_1320 - (int)1)] = (int)1;
          int _7272 = (int)1;
          int _7273 = _1320;
          for (int _1350 = _7272; _1350 < _7273; ++_1350)
          {
            {
              _ptr__1349[((_1320 - _1350) - (int)1)] = safe_mul( _ptr__1349[(_1320 - _1350)],_ptr__1329[(_1320 - _1350)] );
            }
          }
          int _7274 = (int)0;
          int _7275 = (int)((_1339)->size(0));
          for (int _1351 = _7274; _1351 < _7275; ++_1351)
          {
            {
              int _1352 = (int)0;
              int _7276 = (int)0;
              int _7277 = _1320;
              for (int _1353 = _7276; _1353 < _7277; ++_1353)
              {
                {
                  _1352 += safe_mul( _ptr__1349[_1353],((*_1339)(_1351,_1353)) );
                }
              }
              _ptr__1344[_ptr__1335[_1352]] = _ptr__1341[_1351];
              _ptr__1345[_ptr__1335[_1352]] = _ptr__1341[_1351];
            }
          }
        }
      }
      else if(_1340)
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _1354 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1320)));
          _checked_ptr_1<int> _ptr__1354(_1354 ? _1354->raw() : nullptr,_1354 ? _1354->size(0) : 0);
          _ptr__1354[(_1320 - (int)1)] = (int)1;
          int _7278 = (int)1;
          int _7279 = _1320;
          for (int _1355 = _7278; _1355 < _7279; ++_1355)
          {
            {
              _ptr__1354[((_1320 - _1355) - (int)1)] = safe_mul( _ptr__1354[(_1320 - _1355)],_ptr__1329[(_1320 - _1355)] );
            }
          }
          int _7280 = (int)0;
          int _7281 = (int)((_1339)->size(0));
          for (int _1356 = _7280; _1356 < _7281; ++_1356)
          {
            {
              int _1357 = (int)0;
              int _7282 = (int)0;
              int _7283 = _1320;
              for (int _1358 = _7282; _1358 < _7283; ++_1358)
              {
                {
                  _1357 += safe_mul( _ptr__1354[_1358],((*_1339)(_1356,_1358)) );
                }
              }
              _ptr__1344[_ptr__1335[_1357]] = (int)0;
              _ptr__1345[_ptr__1335[_1357]] = (int)0;
            }
          }
        }
      }
      else
      {
        {
          int _7284 = (int)0;
          int _7285 = _1322;
          for (int _1359 = _7284; _1359 < _7285; ++_1359)
          {
            {
              _ptr__1344[_ptr__1335[_1359]] = _ptr__1341[_1359];
              _ptr__1345[_ptr__1335[_1359]] = _ptr__1341[_1359];
            }
          }
        }
      }
    }
    std::vector<double> _7286;
    for (int _1360 = (int)0, _7287 = (int)((_1335)->size(0)); _1360 < _7287 ; ++_1360)
    {
      _7286.push_back(_ptr__1344[_ptr__1335[_1360]]);
    }
    auto _7288 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7286.size()),_7286.begin(),_7286.end()));
    _1333 = _7288;
    _ptr__1333.update(_1333 ? _1333->raw() : nullptr, _1333 ? _1333->size(0) : 0);
  }
  int _7289 = (int)0;
  int _7290 = _1331;
  for (int _1361 = _7289; _1361 < _7290; ++_1361)
  {
    {
      ((*natconmap_idx)(_ptr__1335[_1361])) = _1334;
      ((*natconmap_slackidx)(_ptr__1335[_1361])) = (int)0;
    }
  }
  if ((mosek::fusion::p_LinearDomain::_get_impl(_1315)->key == ::mosek::fusion::RelationKey::IsFree))
  {
    {
      ((*natconmap_type)(_1334)) = (int)1;
      task_con_putboundlist_fr(_1335);
    }
  }
  {}
  if ((mosek::fusion::p_LinearDomain::_get_impl(_1315)->key == ::mosek::fusion::RelationKey::LessThan))
  {
    {
      ((*natconmap_type)(_1334)) = (int)3;
      task_con_putboundlist_up(_1335,_1333);
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_1315)->key == ::mosek::fusion::RelationKey::GreaterThan))
  {
    {
      ((*natconmap_type)(_1334)) = (int)2;
      task_con_putboundlist_lo(_1335,_1333);
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_1315)->key == ::mosek::fusion::RelationKey::EqualsTo))
  {
    {
      ((*natconmap_type)(_1334)) = (int)5;
      task_con_putboundlist_fx(_1335,_1333);
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::LinearConstraint > _1362 = ::mosek::fusion::p_LinearConstraint::_new_LinearConstraint(::mosek::fusion::Model::t(_pubthis),_1313,_1334,_1329,_1335);
  ((*cons)(_1334)) = (_1362).as<::mosek::fusion::ModelConstraint>();
  if (((int)((_1313).size()) > (int)0))
  {
    {
      con_map->setItem(_1313,_1334);
    }
  }
  {}
  return (_1362).as<::mosek::fusion::Constraint>();
}
std::string mosek::fusion::Model::getVersion  ( ) { return mosek::fusion::p_Model::getVersion(); }std::string mosek::fusion::p_Model::getVersion(){
  return ::mosek::fusion::p_BaseModel::env_getversion();
}
bool mosek::fusion::Model :: hasConstraint(const std::string & _1363) { return mosek::fusion::p_Model::_get_impl(this)->hasConstraint(_1363); }bool mosek::fusion::p_Model::hasConstraint(const std::string & _1363){
  return con_map->hasItem(_1363);
}
bool mosek::fusion::Model :: hasVariable(const std::string & _1364) { return mosek::fusion::p_Model::_get_impl(this)->hasVariable(_1364); }bool mosek::fusion::p_Model::hasVariable(const std::string & _1364){
  return var_map->hasItem(_1364);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__getConstraint(int _1365) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getConstraint(_1365); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::getConstraint(int _1365) { return __mosek_2fusion_2Model__getConstraint(_1365); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__getConstraint(int _1365){
  return (((*cons)(_1365))).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__getConstraint(const std::string & _1366) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getConstraint(_1366); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::getConstraint(const std::string &  _1366) { return __mosek_2fusion_2Model__getConstraint(_1366); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__getConstraint(const std::string & _1366){
  monty::rc_ptr< ::mosek::fusion::ModelConstraint > _7291;
  bool _7292 = con_map->hasItem(_1366);
  if (_7292)
  {
    _7291 = ((*cons)(con_map->getItem(_1366)));
  }
  else
  {
    _7291 = nullptr;
  }
  return (_7291).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__getVariable(int _1367) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getVariable(_1367); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::getVariable(int _1367) { return __mosek_2fusion_2Model__getVariable(_1367); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__getVariable(int _1367){
  return (((*vars)(_1367))).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__getVariable(const std::string & _1368) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getVariable(_1368); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::getVariable(const std::string &  _1368) { return __mosek_2fusion_2Model__getVariable(_1368); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__getVariable(const std::string & _1368){
  if (var_map->hasItem(_1368))
  {
    {
      int _1369 = var_map->getItem(_1368);
      if ((_1369 < (int)0))
      {
        {
          return (((*barvars)((-safe_add( _1369,(int)1 ))))).as<::mosek::fusion::Variable>();
        }
      }
      else
      {
        {
          return (((*vars)(_1369))).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
  else
  {
    {
      return nullptr;
    }
  }
}
std::string mosek::fusion::Model :: getName() { return mosek::fusion::p_Model::_get_impl(this)->getName(); }std::string mosek::fusion::p_Model::getName(){
  return model_name;
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Model :: __mosek_2fusion_2Model__clone() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__clone(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Model::clone() { return __mosek_2fusion_2Model__clone(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Model::__mosek_2fusion_2Model__clone(){
  return ::mosek::fusion::p_Model::_new_Model(::mosek::fusion::Model::t(_pubthis));
}
void mosek::fusion::p_Model::destroy(){xs.reset();ws.reset();rs.reset();con_map.reset();cons.reset();natconmap_type.reset();natconmap_ub.reset();natconmap_lb.reset();natconmap_efix.reset();natconmap_idx.reset();natconmap_slackidx.reset();natconmap_blockid.reset();natconmap.reset();initsol_xx_flag.reset();initsol_xx.reset();var_map.reset();barvars.reset();natbarvarmap_ptr.reset();natbarvarmap_num.reset();natbarvar_dim.reset();natbarvar_ptr.reset();natbarvar_j.reset();natbarvar_i.reset();natbarvar_idx.reset();natvarmap_type.reset();natconemap_dim.reset();natconemap.reset();vars.reset();natvarmap_idx.reset();natvarmap_blockid.reset();natvarmap.reset();}void mosek::fusion::Model::destroy() { mosek::fusion::p_Model::_get_impl(this)->destroy(); }mosek::fusion::SliceVariable::SliceVariable(mosek::fusion::p_SliceVariable *_impl) : mosek::fusion::BaseVariable(_impl) { /*std::cout << "SliceVariable()" << this << std::endl; */ }mosek::fusion::SliceVariable::~SliceVariable() {  /* std::cout << "~SliceVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_SliceVariable::p_SliceVariable  (::mosek::fusion::SliceVariable * _pubthis) :     mosek::fusion::p_BaseVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SliceVariable::t mosek::fusion::p_SliceVariable::_new_SliceVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1370,    std::shared_ptr< monty::ndarray< int,1 > > _1371,    std::shared_ptr< monty::ndarray< long long,1 > > _1372,    std::shared_ptr< monty::ndarray< long long,1 > > _1373){ return new mosek::fusion::SliceVariable(_1370,_1371,_1372,_1373); }mosek::fusion::SliceVariable::SliceVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1370,    std::shared_ptr< monty::ndarray< int,1 > > _1371,    std::shared_ptr< monty::ndarray< long long,1 > > _1372,    std::shared_ptr< monty::ndarray< long long,1 > > _1373) :    SliceVariable(new mosek::fusion::p_SliceVariable(this)){ mosek::fusion::p_SliceVariable::_get_impl(this)->_initialize(_1370,_1371,_1372,_1373); }void mosek::fusion::p_SliceVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1370,    std::shared_ptr< monty::ndarray< int,1 > > _1371,    std::shared_ptr< monty::ndarray< long long,1 > > _1372,    std::shared_ptr< monty::ndarray< long long,1 > > _1373){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1371(_1371 ? _1371->raw() : nullptr, _1371 ? _1371->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1372(_1372 ? _1372->raw() : nullptr, _1372 ? _1372->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1373(_1373 ? _1373->raw() : nullptr, _1373 ? _1373->size(0) : 0);
    mosek::fusion::p_BaseVariable::_initialize(_1370,_1371,_1372,_1373);
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->nativeidxs = _1373;
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->sparsity = _1372;
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->shape = _1371;
  }
}void mosek::fusion::p_SliceVariable::destroy(){shape.reset();sparsity.reset();nativeidxs.reset();}void mosek::fusion::SliceVariable::destroy() { mosek::fusion::p_SliceVariable::_get_impl(this)->destroy(); }mosek::fusion::SymRangedVariable::SymRangedVariable(mosek::fusion::p_SymRangedVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "SymRangedVariable()" << this << std::endl; */ }mosek::fusion::SymRangedVariable::~SymRangedVariable() {  /* std::cout << "~SymRangedVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_SymRangedVariable::p_SymRangedVariable  (::mosek::fusion::SymRangedVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SymRangedVariable::t mosek::fusion::p_SymRangedVariable::_new_SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1374,    monty::rc_ptr< ::mosek::fusion::Model > _1375){ return new mosek::fusion::SymRangedVariable(_1374,_1375); }mosek::fusion::SymRangedVariable::SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1374,    monty::rc_ptr< ::mosek::fusion::Model > _1375) :    SymRangedVariable(new mosek::fusion::p_SymRangedVariable(this)){ mosek::fusion::p_SymRangedVariable::_get_impl(this)->_initialize(_1374,_1375); }void mosek::fusion::p_SymRangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1374,    monty::rc_ptr< ::mosek::fusion::Model > _1375){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1374,_1375);
    names_flushed = mosek::fusion::p_SymRangedVariable::_get_impl(_1374)->names_flushed;
    name = mosek::fusion::p_SymRangedVariable::_get_impl(_1374)->name;
    sparsity = mosek::fusion::p_SymRangedVariable::_get_impl(_1374)->sparsity;
    nativeidxs = mosek::fusion::p_SymRangedVariable::_get_impl(_1374)->nativeidxs;
    dim = mosek::fusion::p_SymRangedVariable::_get_impl(_1374)->dim;
  }
}mosek::fusion::SymRangedVariable::t mosek::fusion::p_SymRangedVariable::_new_SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1376,    const std::string &  _1377,    long long _1378,    int _1379,    std::shared_ptr< monty::ndarray< long long,1 > > _1380,    std::shared_ptr< monty::ndarray< int,1 > > _1381){ return new mosek::fusion::SymRangedVariable(_1376,_1377,_1378,_1379,_1380,_1381); }mosek::fusion::SymRangedVariable::SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1376,    const std::string &  _1377,    long long _1378,    int _1379,    std::shared_ptr< monty::ndarray< long long,1 > > _1380,    std::shared_ptr< monty::ndarray< int,1 > > _1381) :    SymRangedVariable(new mosek::fusion::p_SymRangedVariable(this)){ mosek::fusion::p_SymRangedVariable::_get_impl(this)->_initialize(_1376,_1377,_1378,_1379,_1380,_1381); }void mosek::fusion::p_SymRangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1376,    const std::string &  _1377,    long long _1378,    int _1379,    std::shared_ptr< monty::ndarray< long long,1 > > _1380,    std::shared_ptr< monty::ndarray< int,1 > > _1381){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__1380(_1380 ? _1380->raw() : nullptr, _1380 ? _1380->size(0) : 0);
    _checked_ptr_1<int> _ptr__1381(_1381 ? _1381->raw() : nullptr, _1381 ? _1381->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1376,_1377,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1379),(int)(_1379)}),_1378,::mosek::fusion::p_SymRangedVariable::mirror_sp(_1379,_1380),::mosek::fusion::p_SymRangedVariable::mirror_idxs(_1379,_1380,_1381));
    names_flushed = false;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->name = _1377;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->nativeidxs = _1381;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->sparsity = _1380;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->dim = _1379;
  }
}void mosek::fusion::p_SymRangedVariable::dual_u(int _1382,std::shared_ptr< monty::ndarray< double,1 > > _1383){
  _checked_ptr_1<double> _ptr__1383(_1383 ? _1383->raw() : nullptr, _1383 ? _1383->size(0) : 0);
  dual_lu(_1382,_1383,false);
}
void mosek::fusion::p_SymRangedVariable::dual_l(int _1384,std::shared_ptr< monty::ndarray< double,1 > > _1385){
  _checked_ptr_1<double> _ptr__1385(_1385 ? _1385->raw() : nullptr, _1385 ? _1385->size(0) : 0);
  dual_lu(_1384,_1385,true);
}
void mosek::fusion::p_SymRangedVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1386 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      if ((NULL == sparsity.get()))
      {
        {
          int _7293 = (int)0;
          int _7294 = (int)((nativeidxs)->size(0));
          for (int _1387 = _7293; _1387 < _7294; ++_1387)
          {
            {
              std::string _7295;
              bool _7296 = ((int)((name).size()) == (int)0);
              if (_7296)
              {
                _7295 = std::string ("");
              }
              else
              {
                _7295 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((_1387 / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((_1387 % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString();
              }
              mosek::fusion::p_Model::_get_impl(_1386.get())->varname(((*nativeidxs)(_1387)),_7295);
            }
          }
        }
      }
      else
      {
        {
          int _7297 = (int)0;
          int _7298 = (int)((sparsity)->size(0));
          for (int _1388 = _7297; _1388 < _7298; ++_1388)
          {
            {
              mosek::fusion::p_Model::_get_impl(_1386.get())->varname(((*nativeidxs)(_1388)),::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1388)) / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1388)) % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString());
            }
          }
        }
      }
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_SymRangedVariable::__mosek_2fusion_2SymRangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1389){
  return (::mosek::fusion::p_SymRangedVariable::_new_SymRangedVariable(::mosek::fusion::SymRangedVariable::t(_pubthis),_1389)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymRangedVariable::mirror_idxs(int _1390,std::shared_ptr< monty::ndarray< long long,1 > > _1391,std::shared_ptr< monty::ndarray< int,1 > > _1392){
  _checked_ptr_1<long long> _ptr__1391(_1391 ? _1391->raw() : nullptr, _1391 ? _1391->size(0) : 0);
  _checked_ptr_1<int> _ptr__1392(_1392 ? _1392->raw() : nullptr, _1392 ? _1392->size(0) : 0);
  if ((NULL == _1391.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1393 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1390,_1390 ))));
      _checked_ptr_1<long long> _ptr__1393(_1393 ? _1393->raw() : nullptr,_1393 ? _1393->size(0) : 0);
      int _1394 = (int)0;
      {
        int _7299 = (int)0;
        int _7300 = _1390;
        for (int _1395 = _7299; _1395 < _7300; ++_1395)
        {
          {
            _ptr__1393[safe_add( safe_mul( _1395,_1390 ),_1395 )] = safe_add( _ptr__1392[_1394],(int)1 );
            ++ _1394;
            int _7301 = safe_add( _1395,(int)1 );
            int _7302 = _1390;
            for (int _1396 = _7301; _1396 < _7302; ++_1396)
            {
              {
                _ptr__1393[safe_add( safe_mul( _1395,_1390 ),_1396 )] = safe_add( _ptr__1392[_1394],(int)1 );
                _ptr__1393[safe_add( safe_mul( _1396,_1390 ),_1395 )] = safe_add( _ptr__1392[_1394],(int)1 );
                ++ _1394;
              }
            }
          }
        }
      }
      return _1393;
    }
  }
  else
  {
    {
      int _1397 = (int)0;
      {
        int _7303 = (int)0;
        int _7304 = (int)((_1391)->size(0));
        for (int _1398 = _7303; _1398 < _7304; ++_1398)
        {
          {
            int _7305;
            bool _7306 = ((_ptr__1391[_1398] % safe_add( _1390,(int)1 )) == (int)0);
            if (_7306)
            {
              _7305 = (int)1;
            }
            else
            {
              _7305 = (int)2;
            }
            _1397 += _7305;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1399 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1397)));
      _checked_ptr_1<long long> _ptr__1399(_1399 ? _1399->raw() : nullptr,_1399 ? _1399->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1400 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1397)));
      _checked_ptr_1<long long> _ptr__1400(_1400 ? _1400->raw() : nullptr,_1400 ? _1400->size(0) : 0);
      {
        int _1401 = (int)0;
        int _7307 = (int)0;
        int _7308 = (int)((_1391)->size(0));
        for (int _1402 = _7307; _1402 < _7308; ++_1402)
        {
          {
            long long _1403 = (_ptr__1391[_1402] / _1390);
            long long _1404 = (_ptr__1391[_1402] % _1390);
            _ptr__1399[_1401] = _ptr__1391[_1402];
            _ptr__1400[_1401] = safe_add( _ptr__1392[_1402],(int)1 );
            ++ _1401;
            if ((_1403 != _1404))
            {
              {
                _ptr__1399[_1401] = safe_add( safe_mul( _1404,_1390 ),_1403 );
                _ptr__1400[_1401] = safe_add( _ptr__1392[_1402],(int)1 );
                ++ _1401;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7309;
      for (int _1406 = (int)0, _7310 = _1397; _1406 < _7310 ; ++_1406)
      {
        _7309.push_back(_1406);
      }
      auto _7311 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7309.size()),_7309.begin(),_7309.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1405 = _7311;
      _checked_ptr_1<long long> _ptr__1405(_1405 ? _1405->raw() : nullptr,_1405 ? _1405->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1405,_1399,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1397));
      std::vector<long long> _7312;
      for (int _1407 = (int)0, _7313 = _1397; _1407 < _7313 ; ++_1407)
      {
        _7312.push_back(_ptr__1400[_ptr__1405[_1407]]);
      }
      auto _7314 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7312.size()),_7312.begin(),_7312.end()));
      return _7314;
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymRangedVariable::mirror_sp(int _1408,std::shared_ptr< monty::ndarray< long long,1 > > _1409){
  _checked_ptr_1<long long> _ptr__1409(_1409 ? _1409->raw() : nullptr, _1409 ? _1409->size(0) : 0);
  if ((NULL == _1409.get()))
  {
    {
      return nullptr;
    }
  }
  else
  {
    {
      int _1410 = (int)0;
      {
        int _7315 = (int)0;
        int _7316 = (int)((_1409)->size(0));
        for (int _1411 = _7315; _1411 < _7316; ++_1411)
        {
          {
            int _7317;
            bool _7318 = ((_ptr__1409[_1411] % safe_add( _1408,(int)1 )) == (int)0);
            if (_7318)
            {
              _7317 = (int)1;
            }
            else
            {
              _7317 = (int)2;
            }
            _1410 += _7317;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1412 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1410)));
      _checked_ptr_1<long long> _ptr__1412(_1412 ? _1412->raw() : nullptr,_1412 ? _1412->size(0) : 0);
      {
        int _1413 = (int)0;
        int _7319 = (int)0;
        int _7320 = (int)((_1409)->size(0));
        for (int _1414 = _7319; _1414 < _7320; ++_1414)
        {
          {
            long long _1415 = (_ptr__1409[_1414] / _1408);
            long long _1416 = (_ptr__1409[_1414] % _1408);
            _ptr__1412[_1413] = _ptr__1409[_1414];
            ++ _1413;
            if ((_1415 != _1416))
            {
              {
                _ptr__1412[_1413] = safe_add( safe_mul( _1416,_1408 ),_1415 );
                ++ _1413;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7321;
      for (int _1418 = (int)0, _7322 = _1410; _1418 < _7322 ; ++_1418)
      {
        _7321.push_back(_1418);
      }
      auto _7323 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7321.size()),_7321.begin(),_7321.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1417 = _7323;
      _checked_ptr_1<long long> _ptr__1417(_1417 ? _1417->raw() : nullptr,_1417 ? _1417->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1417,_1412,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1410));
      std::vector<long long> _7324;
      for (int _1419 = (int)0, _7325 = _1410; _1419 < _7325 ; ++_1419)
      {
        _7324.push_back(_ptr__1412[_ptr__1417[_1419]]);
      }
      auto _7326 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7324.size()),_7324.begin(),_7324.end()));
      return _7326;
    }
  }
}
void mosek::fusion::p_SymRangedVariable::destroy(){sparsity.reset();nativeidxs.reset();}void mosek::fusion::SymRangedVariable::destroy() { mosek::fusion::p_SymRangedVariable::_get_impl(this)->destroy(); }mosek::fusion::RangedVariable::RangedVariable(mosek::fusion::p_RangedVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "RangedVariable()" << this << std::endl; */ }mosek::fusion::RangedVariable::~RangedVariable() {  /* std::cout << "~RangedVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_RangedVariable::p_RangedVariable  (::mosek::fusion::RangedVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::RangedVariable::t mosek::fusion::p_RangedVariable::_new_RangedVariable  (monty::rc_ptr< ::mosek::fusion::RangedVariable > _1420,    monty::rc_ptr< ::mosek::fusion::Model > _1421){ return new mosek::fusion::RangedVariable(_1420,_1421); }mosek::fusion::RangedVariable::RangedVariable  (monty::rc_ptr< ::mosek::fusion::RangedVariable > _1420,    monty::rc_ptr< ::mosek::fusion::Model > _1421) :    RangedVariable(new mosek::fusion::p_RangedVariable(this)){ mosek::fusion::p_RangedVariable::_get_impl(this)->_initialize(_1420,_1421); }void mosek::fusion::p_RangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::RangedVariable > _1420,    monty::rc_ptr< ::mosek::fusion::Model > _1421){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1420,_1421);
    name = mosek::fusion::p_RangedVariable::_get_impl(_1420)->name;
    nativeidxs = mosek::fusion::p_RangedVariable::_get_impl(_1420)->nativeidxs;
    sparsity = mosek::fusion::p_RangedVariable::_get_impl(_1420)->sparsity;
    names_flushed = mosek::fusion::p_RangedVariable::_get_impl(_1420)->names_flushed;
    shape = mosek::fusion::p_RangedVariable::_get_impl(_1420)->shape;
  }
}mosek::fusion::RangedVariable::t mosek::fusion::p_RangedVariable::_new_RangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1422,    const std::string &  _1423,    long long _1424,    std::shared_ptr< monty::ndarray< int,1 > > _1425,    std::shared_ptr< monty::ndarray< long long,1 > > _1426,    std::shared_ptr< monty::ndarray< int,1 > > _1427){ return new mosek::fusion::RangedVariable(_1422,_1423,_1424,_1425,_1426,_1427); }mosek::fusion::RangedVariable::RangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1422,    const std::string &  _1423,    long long _1424,    std::shared_ptr< monty::ndarray< int,1 > > _1425,    std::shared_ptr< monty::ndarray< long long,1 > > _1426,    std::shared_ptr< monty::ndarray< int,1 > > _1427) :    RangedVariable(new mosek::fusion::p_RangedVariable(this)){ mosek::fusion::p_RangedVariable::_get_impl(this)->_initialize(_1422,_1423,_1424,_1425,_1426,_1427); }void mosek::fusion::p_RangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1422,    const std::string &  _1423,    long long _1424,    std::shared_ptr< monty::ndarray< int,1 > > _1425,    std::shared_ptr< monty::ndarray< long long,1 > > _1426,    std::shared_ptr< monty::ndarray< int,1 > > _1427){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1425(_1425 ? _1425->raw() : nullptr, _1425 ? _1425->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1426(_1426 ? _1426->raw() : nullptr, _1426 ? _1426->size(0) : 0);
    _checked_ptr_1<int> _ptr__1427(_1427 ? _1427->raw() : nullptr, _1427 ? _1427->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1422,_1423,_1425,_1424,_1426,::mosek::fusion::p_RangedVariable::globalNativeIndexes(_1427));
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->nativeidxs = _1427;
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->sparsity = _1426;
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->name = _1423;
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->shape = _1425;
    names_flushed = false;
  }
}monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::RangedVariable :: __mosek_2fusion_2RangedVariable__elementDesc(long long _1428,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1429) { return mosek::fusion::p_RangedVariable::_get_impl(this)->__mosek_2fusion_2RangedVariable__elementDesc(_1428,_1429); }monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::RangedVariable::elementDesc(long long _1428,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1429) { return __mosek_2fusion_2RangedVariable__elementDesc(_1428,_1429); }
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_RangedVariable::__mosek_2fusion_2RangedVariable__elementDesc(long long _1428,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1429){
  _pubthis->elementName(_1428,_1429);
  _1429->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" : in range"));
  return _1429;
}
void mosek::fusion::p_RangedVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1430 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1431 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
      _1431->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
      if ((_pubthis->getND() > (int)0))
      {
        {
          _1431->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
          int _7327 = (int)1;
          int _7328 = _pubthis->getND();
          for (int _1432 = _7327; _1432 < _7328; ++_1432)
          {
            {
              _1431->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1432);
            }
          }
        }
      }
      {}
      _1431->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
      mosek::fusion::p_Model::_get_impl(_1430.get())->varnames(nativeidxs,_1431->toString(),_pubthis->getShape(),sparsity);
      names_flushed = true;
    }
  }
  {}
}
void mosek::fusion::p_RangedVariable::dual_u(int _1433,std::shared_ptr< monty::ndarray< double,1 > > _1434){
  _checked_ptr_1<double> _ptr__1434(_1434 ? _1434->raw() : nullptr, _1434 ? _1434->size(0) : 0);
  dual_lu(_1433,_1434,false);
}
void mosek::fusion::p_RangedVariable::dual_l(int _1435,std::shared_ptr< monty::ndarray< double,1 > > _1436){
  _checked_ptr_1<double> _ptr__1436(_1436 ? _1436->raw() : nullptr, _1436 ? _1436->size(0) : 0);
  dual_lu(_1435,_1436,true);
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_RangedVariable::__mosek_2fusion_2RangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1437){
  return (::mosek::fusion::p_RangedVariable::_new_RangedVariable(::mosek::fusion::RangedVariable::t(_pubthis),_1437)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_RangedVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1438){
  _checked_ptr_1<int> _ptr__1438(_1438 ? _1438->raw() : nullptr, _1438 ? _1438->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1439 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_1438)->size(0)))));
  _checked_ptr_1<long long> _ptr__1439(_1439 ? _1439->raw() : nullptr,_1439 ? _1439->size(0) : 0);
  int _7329 = (int)0;
  int _7330 = (int)((_1438)->size(0));
  for (int _1440 = _7329; _1440 < _7330; ++_1440)
  {
    {
      _ptr__1439[_1440] = safe_add( _ptr__1438[_1440],(int)1 );
    }
  }
  return _1439;
}
void mosek::fusion::p_RangedVariable::destroy(){shape.reset();nativeidxs.reset();sparsity.reset();}void mosek::fusion::RangedVariable::destroy() { mosek::fusion::p_RangedVariable::_get_impl(this)->destroy(); }mosek::fusion::LinearPSDVariable::LinearPSDVariable(mosek::fusion::p_LinearPSDVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "LinearPSDVariable()" << this << std::endl; */ }mosek::fusion::LinearPSDVariable::~LinearPSDVariable() {  /* std::cout << "~LinearPSDVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearPSDVariable::p_LinearPSDVariable  (::mosek::fusion::LinearPSDVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearPSDVariable::t mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1441,    monty::rc_ptr< ::mosek::fusion::Model > _1442){ return new mosek::fusion::LinearPSDVariable(_1441,_1442); }mosek::fusion::LinearPSDVariable::LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1441,    monty::rc_ptr< ::mosek::fusion::Model > _1442) :    LinearPSDVariable(new mosek::fusion::p_LinearPSDVariable(this)){ mosek::fusion::p_LinearPSDVariable::_get_impl(this)->_initialize(_1441,_1442); }void mosek::fusion::p_LinearPSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1441,    monty::rc_ptr< ::mosek::fusion::Model > _1442){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1441,_1442);
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->conedim = mosek::fusion::p_LinearPSDVariable::_get_impl(_1441)->conedim;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->varid = mosek::fusion::p_LinearPSDVariable::_get_impl(_1441)->varid;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->name = mosek::fusion::p_LinearPSDVariable::_get_impl(_1441)->name;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->shape = mosek::fusion::p_LinearPSDVariable::_get_impl(_1441)->shape;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->nativeidxs = mosek::fusion::p_LinearPSDVariable::_get_impl(_1441)->nativeidxs;
  }
}mosek::fusion::LinearPSDVariable::t mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1443,    const std::string &  _1444,    int _1445,    std::shared_ptr< monty::ndarray< int,1 > > _1446,    int _1447,    std::shared_ptr< monty::ndarray< long long,1 > > _1448){ return new mosek::fusion::LinearPSDVariable(_1443,_1444,_1445,_1446,_1447,_1448); }mosek::fusion::LinearPSDVariable::LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1443,    const std::string &  _1444,    int _1445,    std::shared_ptr< monty::ndarray< int,1 > > _1446,    int _1447,    std::shared_ptr< monty::ndarray< long long,1 > > _1448) :    LinearPSDVariable(new mosek::fusion::p_LinearPSDVariable(this)){ mosek::fusion::p_LinearPSDVariable::_get_impl(this)->_initialize(_1443,_1444,_1445,_1446,_1447,_1448); }void mosek::fusion::p_LinearPSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1443,    const std::string &  _1444,    int _1445,    std::shared_ptr< monty::ndarray< int,1 > > _1446,    int _1447,    std::shared_ptr< monty::ndarray< long long,1 > > _1448){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1446(_1446 ? _1446->raw() : nullptr, _1446 ? _1446->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1448(_1448 ? _1448->raw() : nullptr, _1448 ? _1448->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1443,_1444,_1446,_1445,nullptr,::mosek::fusion::p_LinearPSDVariable::globalNativeIndexes(_1448));
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->name = _1444;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->conedim = _1447;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->varid = _1445;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->shape = _1446;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->nativeidxs = _1448;
  }
}void mosek::fusion::p_LinearPSDVariable::flushNames(){
}
std::string mosek::fusion::LinearPSDVariable :: toString() { return mosek::fusion::p_LinearPSDVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_LinearPSDVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1449 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1449->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PSDVariable("));
  if (((int)((name).size()) > (int)0))
  {
    {
      _1449->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("',"));
    }
  }
  {}
  _1449->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7331 = (int)1;
  int _7332 = (int)((shape)->size(0));
  for (int _1450 = _7331; _1450 < _7332; ++_1450)
  {
    {
      _1449->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1450)));
    }
  }
  _1449->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _1449->toString();
}
void mosek::fusion::LinearPSDVariable :: make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _1451) { mosek::fusion::p_LinearPSDVariable::_get_impl(this)->make_continuous(_1451); }void mosek::fusion::p_LinearPSDVariable::make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _1451){
  _checked_ptr_1<long long> _ptr__1451(_1451 ? _1451->raw() : nullptr, _1451 ? _1451->size(0) : 0);
}
void mosek::fusion::LinearPSDVariable :: make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _1452) { mosek::fusion::p_LinearPSDVariable::_get_impl(this)->make_integer(_1452); }void mosek::fusion::p_LinearPSDVariable::make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _1452){
  _checked_ptr_1<long long> _ptr__1452(_1452 ? _1452->raw() : nullptr, _1452 ? _1452->size(0) : 0);
  throw ::mosek::fusion::UnimplementedError(std::string ("Cannot make PSDVariable elements integer"));
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_LinearPSDVariable::__mosek_2fusion_2LinearPSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1453){
  return (::mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable(::mosek::fusion::LinearPSDVariable::t(_pubthis),_1453)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_LinearPSDVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< long long,1 > > _1454){
  _checked_ptr_1<long long> _ptr__1454(_1454 ? _1454->raw() : nullptr, _1454 ? _1454->size(0) : 0);
  std::vector<long long> _7333;
  for (int _1455 = (int)0, _7334 = (int)((_1454)->size(0)); _1455 < _7334 ; ++_1455)
  {
    _7333.push_back((-safe_add( _ptr__1454[_1455],(int)1 )));
  }
  auto _7335 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7333.size()),_7333.begin(),_7333.end()));
  return _7335;
}
void mosek::fusion::p_LinearPSDVariable::destroy(){shape.reset();nativeidxs.reset();}void mosek::fusion::LinearPSDVariable::destroy() { mosek::fusion::p_LinearPSDVariable::_get_impl(this)->destroy(); }mosek::fusion::PSDVariable::PSDVariable(mosek::fusion::p_PSDVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "PSDVariable()" << this << std::endl; */ }mosek::fusion::PSDVariable::~PSDVariable() {  /* std::cout << "~PSDVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_PSDVariable::p_PSDVariable  (::mosek::fusion::PSDVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::PSDVariable::t mosek::fusion::p_PSDVariable::_new_PSDVariable  (monty::rc_ptr< ::mosek::fusion::PSDVariable > _1456,    monty::rc_ptr< ::mosek::fusion::Model > _1457){ return new mosek::fusion::PSDVariable(_1456,_1457); }mosek::fusion::PSDVariable::PSDVariable  (monty::rc_ptr< ::mosek::fusion::PSDVariable > _1456,    monty::rc_ptr< ::mosek::fusion::Model > _1457) :    PSDVariable(new mosek::fusion::p_PSDVariable(this)){ mosek::fusion::p_PSDVariable::_get_impl(this)->_initialize(_1456,_1457); }void mosek::fusion::p_PSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::PSDVariable > _1456,    monty::rc_ptr< ::mosek::fusion::Model > _1457){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1456,_1457);
    varid = mosek::fusion::p_PSDVariable::_get_impl(_1456)->varid;
    nativeidxs = mosek::fusion::p_PSDVariable::_get_impl(_1456)->nativeidxs;
    name = mosek::fusion::p_PSDVariable::_get_impl(_1456)->name;
    shape = mosek::fusion::p_PSDVariable::_get_impl(_1456)->shape;
    conedim1 = mosek::fusion::p_PSDVariable::_get_impl(_1456)->conedim1;
    conedim2 = mosek::fusion::p_PSDVariable::_get_impl(_1456)->conedim2;
  }
}mosek::fusion::PSDVariable::t mosek::fusion::p_PSDVariable::_new_PSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1458,    const std::string &  _1459,    int _1460,    std::shared_ptr< monty::ndarray< int,1 > > _1461,    int _1462,    int _1463,    std::shared_ptr< monty::ndarray< long long,1 > > _1464){ return new mosek::fusion::PSDVariable(_1458,_1459,_1460,_1461,_1462,_1463,_1464); }mosek::fusion::PSDVariable::PSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1458,    const std::string &  _1459,    int _1460,    std::shared_ptr< monty::ndarray< int,1 > > _1461,    int _1462,    int _1463,    std::shared_ptr< monty::ndarray< long long,1 > > _1464) :    PSDVariable(new mosek::fusion::p_PSDVariable(this)){ mosek::fusion::p_PSDVariable::_get_impl(this)->_initialize(_1458,_1459,_1460,_1461,_1462,_1463,_1464); }void mosek::fusion::p_PSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1458,    const std::string &  _1459,    int _1460,    std::shared_ptr< monty::ndarray< int,1 > > _1461,    int _1462,    int _1463,    std::shared_ptr< monty::ndarray< long long,1 > > _1464){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1461(_1461 ? _1461->raw() : nullptr, _1461 ? _1461->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1464(_1464 ? _1464->raw() : nullptr, _1464 ? _1464->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1458,_1459,_1461,_1460,nullptr,::mosek::fusion::p_PSDVariable::fullnativeidxs(_1461,_1462,_1463,_1464));
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->varid = _1460;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->nativeidxs = _1464;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->name = _1459;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->shape = _1461;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->conedim1 = _1462;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->conedim2 = _1463;
  }
}void mosek::fusion::p_PSDVariable::flushNames(){
}
std::string mosek::fusion::PSDVariable :: toString() { return mosek::fusion::p_PSDVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_PSDVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1465 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1465->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PSDVariable("));
  if (((int)((name).size()) > (int)0))
  {
    {
      _1465->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("',"));
    }
  }
  {}
  _1465->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7336 = (int)1;
  int _7337 = (int)((shape)->size(0));
  for (int _1466 = _7336; _1466 < _7337; ++_1466)
  {
    {
      _1465->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1466)));
    }
  }
  _1465->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _1465->toString();
}
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::PSDVariable :: __mosek_2fusion_2PSDVariable__elementDesc(long long _1467,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1468) { return mosek::fusion::p_PSDVariable::_get_impl(this)->__mosek_2fusion_2PSDVariable__elementDesc(_1467,_1468); }monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::PSDVariable::elementDesc(long long _1467,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1468) { return __mosek_2fusion_2PSDVariable__elementDesc(_1467,_1468); }
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_PSDVariable::__mosek_2fusion_2PSDVariable__elementDesc(long long _1467,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1468){
  _pubthis->elementName(_1467,_1468);
  _1468->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" : element in positive semidefinite cone"));
  return _1468;
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_PSDVariable::__mosek_2fusion_2PSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1469){
  return (::mosek::fusion::p_PSDVariable::_new_PSDVariable(::mosek::fusion::PSDVariable::t(_pubthis),_1469)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_PSDVariable::fullnativeidxs(std::shared_ptr< monty::ndarray< int,1 > > _1470,int _1471,int _1472,std::shared_ptr< monty::ndarray< long long,1 > > _1473){
  _checked_ptr_1<int> _ptr__1470(_1470 ? _1470->raw() : nullptr, _1470 ? _1470->size(0) : 0);
  _checked_ptr_1<long long> _ptr__1473(_1473 ? _1473->raw() : nullptr, _1473 ? _1473->size(0) : 0);
  int _1474 = (int)((_1470)->size(0));
  bool _1475 = (_1471 < _1472);
  int _7338;
  bool _7339 = _1475;
  if (_7339)
  {
    _7338 = _1471;
  }
  else
  {
    _7338 = _1472;
  }
  int _1476 = _7338;
  int _7340;
  bool _7341 = (!_1475);
  if (_7341)
  {
    _7340 = _1471;
  }
  else
  {
    _7340 = _1472;
  }
  int _1477 = _7340;
  int _1478 = (int)1;
  int _7342 = (int)0;
  int _7343 = _1476;
  for (int _1479 = _7342; _1479 < _7343; ++_1479)
  {
    {
      _1478 *= _ptr__1470[_1479];
    }
  }
  int _1480 = _ptr__1470[_1476];
  int _1481 = (int)1;
  int _7344 = safe_add( _1476,(int)1 );
  int _7345 = _1477;
  for (int _1482 = _7344; _1482 < _7345; ++_1482)
  {
    {
      _1481 *= _ptr__1470[_1482];
    }
  }
  int _1483 = _ptr__1470[_1477];
  int _1484 = (int)1;
  int _7346 = safe_add( _1477,(int)1 );
  int _7347 = _1474;
  for (int _1485 = _7346; _1485 < _7347; ++_1485)
  {
    {
      _1484 *= _ptr__1470[_1485];
    }
  }
  int _1486 = safe_mul( safe_mul( safe_mul( safe_mul( _1478,_1480 ),_1481 ),_1483 ),_1484 );
  std::shared_ptr< monty::ndarray< long long,1 > > _1487 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1486)));
  _checked_ptr_1<long long> _ptr__1487(_1487 ? _1487->raw() : nullptr,_1487 ? _1487->size(0) : 0);
  int _1488 = _1484;
  int _1489 = safe_mul( _1488,_1483 );
  int _1490 = safe_mul( _1489,_1481 );
  int _1491 = safe_mul( _1490,_1490 );
  {
    int _1492 = (int)0;
    int _7348 = (int)0;
    int _7349 = _1478;
    for (int _1493 = _7348; _1493 < _7349; ++_1493)
    {
      {
        int _7350 = (int)0;
        int _7351 = _1483;
        for (int _1494 = _7350; _1494 < _7351; ++_1494)
        {
          {
            int _7352 = (int)0;
            int _7353 = _1481;
            for (int _1495 = _7352; _1495 < _7353; ++_1495)
            {
              {
                int _7354 = _1494;
                int _7355 = _1480;
                for (int _1496 = _7354; _1496 < _7355; ++_1496)
                {
                  {
                    int _7356 = (int)0;
                    int _7357 = _1484;
                    for (int _1497 = _7356; _1497 < _7357; ++_1497)
                    {
                      {
                        _ptr__1487[safe_add( safe_add( safe_add( safe_add( safe_mul( _1493,_1491 ),safe_mul( _1496,_1490 ) ),safe_mul( _1495,_1489 ) ),safe_mul( _1494,_1488 ) ),_1497 )] = (-safe_add( _ptr__1473[_1492],(int)1 ));
                        _ptr__1487[safe_add( safe_add( safe_add( safe_add( safe_mul( _1493,_1491 ),safe_mul( _1494,_1490 ) ),safe_mul( _1495,_1489 ) ),safe_mul( _1496,_1488 ) ),_1497 )] = (-safe_add( _ptr__1473[_1492],(int)1 ));
                        ++ _1492;
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return _1487;
}
void mosek::fusion::p_PSDVariable::destroy(){shape.reset();nativeidxs.reset();}void mosek::fusion::PSDVariable::destroy() { mosek::fusion::p_PSDVariable::_get_impl(this)->destroy(); }mosek::fusion::SymLinearVariable::SymLinearVariable(mosek::fusion::p_SymLinearVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "SymLinearVariable()" << this << std::endl; */ }mosek::fusion::SymLinearVariable::~SymLinearVariable() {  /* std::cout << "~SymLinearVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_SymLinearVariable::p_SymLinearVariable  (::mosek::fusion::SymLinearVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SymLinearVariable::t mosek::fusion::p_SymLinearVariable::_new_SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1498,    monty::rc_ptr< ::mosek::fusion::Model > _1499){ return new mosek::fusion::SymLinearVariable(_1498,_1499); }mosek::fusion::SymLinearVariable::SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1498,    monty::rc_ptr< ::mosek::fusion::Model > _1499) :    SymLinearVariable(new mosek::fusion::p_SymLinearVariable(this)){ mosek::fusion::p_SymLinearVariable::_get_impl(this)->_initialize(_1498,_1499); }void mosek::fusion::p_SymLinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1498,    monty::rc_ptr< ::mosek::fusion::Model > _1499){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1498,_1499);
    names_flushed = mosek::fusion::p_SymLinearVariable::_get_impl(_1498)->names_flushed;
    name = mosek::fusion::p_SymLinearVariable::_get_impl(_1498)->name;
    sparsity = mosek::fusion::p_SymLinearVariable::_get_impl(_1498)->sparsity;
    nativeidxs = mosek::fusion::p_SymLinearVariable::_get_impl(_1498)->nativeidxs;
    dim = mosek::fusion::p_SymLinearVariable::_get_impl(_1498)->dim;
  }
}mosek::fusion::SymLinearVariable::t mosek::fusion::p_SymLinearVariable::_new_SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1500,    const std::string &  _1501,    long long _1502,    int _1503,    std::shared_ptr< monty::ndarray< long long,1 > > _1504,    std::shared_ptr< monty::ndarray< int,1 > > _1505){ return new mosek::fusion::SymLinearVariable(_1500,_1501,_1502,_1503,_1504,_1505); }mosek::fusion::SymLinearVariable::SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1500,    const std::string &  _1501,    long long _1502,    int _1503,    std::shared_ptr< monty::ndarray< long long,1 > > _1504,    std::shared_ptr< monty::ndarray< int,1 > > _1505) :    SymLinearVariable(new mosek::fusion::p_SymLinearVariable(this)){ mosek::fusion::p_SymLinearVariable::_get_impl(this)->_initialize(_1500,_1501,_1502,_1503,_1504,_1505); }void mosek::fusion::p_SymLinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1500,    const std::string &  _1501,    long long _1502,    int _1503,    std::shared_ptr< monty::ndarray< long long,1 > > _1504,    std::shared_ptr< monty::ndarray< int,1 > > _1505){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__1504(_1504 ? _1504->raw() : nullptr, _1504 ? _1504->size(0) : 0);
    _checked_ptr_1<int> _ptr__1505(_1505 ? _1505->raw() : nullptr, _1505 ? _1505->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1500,_1501,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1503),(int)(_1503)}),_1502,::mosek::fusion::p_SymLinearVariable::mirror_sp(_1503,_1504),::mosek::fusion::p_SymLinearVariable::mirror_idxs(_1503,_1504,_1505));
    names_flushed = false;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->name = _1501;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->nativeidxs = _1505;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->sparsity = _1504;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->dim = _1503;
  }
}void mosek::fusion::p_SymLinearVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1506 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      if ((NULL == sparsity.get()))
      {
        {
          int _7358 = (int)0;
          int _7359 = (int)((nativeidxs)->size(0));
          for (int _1507 = _7358; _1507 < _7359; ++_1507)
          {
            {
              std::string _7360;
              bool _7361 = ((int)((name).size()) == (int)0);
              if (_7361)
              {
                _7360 = std::string ("");
              }
              else
              {
                _7360 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((_1507 / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((_1507 % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString();
              }
              mosek::fusion::p_Model::_get_impl(_1506.get())->varname(((*nativeidxs)(_1507)),_7360);
            }
          }
        }
      }
      else
      {
        {
          int _7362 = (int)0;
          int _7363 = (int)((sparsity)->size(0));
          for (int _1508 = _7362; _1508 < _7363; ++_1508)
          {
            {
              mosek::fusion::p_Model::_get_impl(_1506.get())->varname(((*nativeidxs)(_1508)),::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1508)) / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1508)) % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString());
            }
          }
        }
      }
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_SymLinearVariable::__mosek_2fusion_2SymLinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1509){
  return (::mosek::fusion::p_SymLinearVariable::_new_SymLinearVariable(::mosek::fusion::SymLinearVariable::t(_pubthis),_1509)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymLinearVariable::mirror_idxs(int _1510,std::shared_ptr< monty::ndarray< long long,1 > > _1511,std::shared_ptr< monty::ndarray< int,1 > > _1512){
  _checked_ptr_1<long long> _ptr__1511(_1511 ? _1511->raw() : nullptr, _1511 ? _1511->size(0) : 0);
  _checked_ptr_1<int> _ptr__1512(_1512 ? _1512->raw() : nullptr, _1512 ? _1512->size(0) : 0);
  if ((NULL == _1511.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1513 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1510,_1510 ))));
      _checked_ptr_1<long long> _ptr__1513(_1513 ? _1513->raw() : nullptr,_1513 ? _1513->size(0) : 0);
      int _1514 = (int)0;
      {
        int _7364 = (int)0;
        int _7365 = _1510;
        for (int _1515 = _7364; _1515 < _7365; ++_1515)
        {
          {
            _ptr__1513[safe_add( safe_mul( _1515,_1510 ),_1515 )] = safe_add( _ptr__1512[_1514],(int)1 );
            ++ _1514;
            int _7366 = safe_add( _1515,(int)1 );
            int _7367 = _1510;
            for (int _1516 = _7366; _1516 < _7367; ++_1516)
            {
              {
                _ptr__1513[safe_add( safe_mul( _1515,_1510 ),_1516 )] = safe_add( _ptr__1512[_1514],(int)1 );
                _ptr__1513[safe_add( safe_mul( _1516,_1510 ),_1515 )] = safe_add( _ptr__1512[_1514],(int)1 );
                ++ _1514;
              }
            }
          }
        }
      }
      return _1513;
    }
  }
  else
  {
    {
      int _1517 = (int)0;
      {
        int _7368 = (int)0;
        int _7369 = (int)((_1511)->size(0));
        for (int _1518 = _7368; _1518 < _7369; ++_1518)
        {
          {
            int _7370;
            bool _7371 = ((_ptr__1511[_1518] % safe_add( _1510,(int)1 )) == (int)0);
            if (_7371)
            {
              _7370 = (int)1;
            }
            else
            {
              _7370 = (int)2;
            }
            _1517 += _7370;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1519 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1517)));
      _checked_ptr_1<long long> _ptr__1519(_1519 ? _1519->raw() : nullptr,_1519 ? _1519->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1520 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1517)));
      _checked_ptr_1<long long> _ptr__1520(_1520 ? _1520->raw() : nullptr,_1520 ? _1520->size(0) : 0);
      {
        int _1521 = (int)0;
        int _7372 = (int)0;
        int _7373 = (int)((_1511)->size(0));
        for (int _1522 = _7372; _1522 < _7373; ++_1522)
        {
          {
            long long _1523 = (_ptr__1511[_1522] / _1510);
            long long _1524 = (_ptr__1511[_1522] % _1510);
            _ptr__1519[_1521] = _ptr__1511[_1522];
            _ptr__1520[_1521] = safe_add( _ptr__1512[_1522],(int)1 );
            ++ _1521;
            if ((_1523 != _1524))
            {
              {
                _ptr__1519[_1521] = safe_add( safe_mul( _1524,_1510 ),_1523 );
                _ptr__1520[_1521] = safe_add( _ptr__1512[_1522],(int)1 );
                ++ _1521;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7374;
      for (int _1526 = (int)0, _7375 = _1517; _1526 < _7375 ; ++_1526)
      {
        _7374.push_back(_1526);
      }
      auto _7376 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7374.size()),_7374.begin(),_7374.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1525 = _7376;
      _checked_ptr_1<long long> _ptr__1525(_1525 ? _1525->raw() : nullptr,_1525 ? _1525->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1525,_1519,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1517));
      std::vector<long long> _7377;
      for (int _1527 = (int)0, _7378 = _1517; _1527 < _7378 ; ++_1527)
      {
        _7377.push_back(_ptr__1520[_ptr__1525[_1527]]);
      }
      auto _7379 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7377.size()),_7377.begin(),_7377.end()));
      return _7379;
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymLinearVariable::mirror_sp(int _1528,std::shared_ptr< monty::ndarray< long long,1 > > _1529){
  _checked_ptr_1<long long> _ptr__1529(_1529 ? _1529->raw() : nullptr, _1529 ? _1529->size(0) : 0);
  if ((NULL == _1529.get()))
  {
    {
      return nullptr;
    }
  }
  else
  {
    {
      int _1530 = (int)0;
      {
        int _7380 = (int)0;
        int _7381 = (int)((_1529)->size(0));
        for (int _1531 = _7380; _1531 < _7381; ++_1531)
        {
          {
            int _7382;
            bool _7383 = ((_ptr__1529[_1531] % safe_add( _1528,(int)1 )) == (int)0);
            if (_7383)
            {
              _7382 = (int)1;
            }
            else
            {
              _7382 = (int)2;
            }
            _1530 += _7382;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1532 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1530)));
      _checked_ptr_1<long long> _ptr__1532(_1532 ? _1532->raw() : nullptr,_1532 ? _1532->size(0) : 0);
      {
        int _1533 = (int)0;
        int _7384 = (int)0;
        int _7385 = (int)((_1529)->size(0));
        for (int _1534 = _7384; _1534 < _7385; ++_1534)
        {
          {
            long long _1535 = (_ptr__1529[_1534] / _1528);
            long long _1536 = (_ptr__1529[_1534] % _1528);
            _ptr__1532[_1533] = _ptr__1529[_1534];
            ++ _1533;
            if ((_1535 != _1536))
            {
              {
                _ptr__1532[_1533] = safe_add( safe_mul( _1536,_1528 ),_1535 );
                ++ _1533;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7386;
      for (int _1538 = (int)0, _7387 = _1530; _1538 < _7387 ; ++_1538)
      {
        _7386.push_back(_1538);
      }
      auto _7388 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7386.size()),_7386.begin(),_7386.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1537 = _7388;
      _checked_ptr_1<long long> _ptr__1537(_1537 ? _1537->raw() : nullptr,_1537 ? _1537->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1537,_1532,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1530));
      std::vector<long long> _7389;
      for (int _1539 = (int)0, _7390 = _1530; _1539 < _7390 ; ++_1539)
      {
        _7389.push_back(_ptr__1532[_ptr__1537[_1539]]);
      }
      auto _7391 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7389.size()),_7389.begin(),_7389.end()));
      return _7391;
    }
  }
}
void mosek::fusion::p_SymLinearVariable::destroy(){sparsity.reset();nativeidxs.reset();}void mosek::fusion::SymLinearVariable::destroy() { mosek::fusion::p_SymLinearVariable::_get_impl(this)->destroy(); }mosek::fusion::LinearVariable::LinearVariable(mosek::fusion::p_LinearVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "LinearVariable()" << this << std::endl; */ }mosek::fusion::LinearVariable::~LinearVariable() {  /* std::cout << "~LinearVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearVariable::p_LinearVariable  (::mosek::fusion::LinearVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearVariable::t mosek::fusion::p_LinearVariable::_new_LinearVariable  (monty::rc_ptr< ::mosek::fusion::LinearVariable > _1540,    monty::rc_ptr< ::mosek::fusion::Model > _1541){ return new mosek::fusion::LinearVariable(_1540,_1541); }mosek::fusion::LinearVariable::LinearVariable  (monty::rc_ptr< ::mosek::fusion::LinearVariable > _1540,    monty::rc_ptr< ::mosek::fusion::Model > _1541) :    LinearVariable(new mosek::fusion::p_LinearVariable(this)){ mosek::fusion::p_LinearVariable::_get_impl(this)->_initialize(_1540,_1541); }void mosek::fusion::p_LinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearVariable > _1540,    monty::rc_ptr< ::mosek::fusion::Model > _1541){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1540,_1541);
    names_flushed = mosek::fusion::p_LinearVariable::_get_impl(_1540)->names_flushed;
    nativeidxs = mosek::fusion::p_LinearVariable::_get_impl(_1540)->nativeidxs;
    sparsity = mosek::fusion::p_LinearVariable::_get_impl(_1540)->sparsity;
    shape = mosek::fusion::p_LinearVariable::_get_impl(_1540)->shape;
    name = mosek::fusion::p_LinearVariable::_get_impl(_1540)->name;
  }
}mosek::fusion::LinearVariable::t mosek::fusion::p_LinearVariable::_new_LinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1542,    const std::string &  _1543,    long long _1544,    std::shared_ptr< monty::ndarray< int,1 > > _1545,    std::shared_ptr< monty::ndarray< long long,1 > > _1546,    std::shared_ptr< monty::ndarray< int,1 > > _1547){ return new mosek::fusion::LinearVariable(_1542,_1543,_1544,_1545,_1546,_1547); }mosek::fusion::LinearVariable::LinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1542,    const std::string &  _1543,    long long _1544,    std::shared_ptr< monty::ndarray< int,1 > > _1545,    std::shared_ptr< monty::ndarray< long long,1 > > _1546,    std::shared_ptr< monty::ndarray< int,1 > > _1547) :    LinearVariable(new mosek::fusion::p_LinearVariable(this)){ mosek::fusion::p_LinearVariable::_get_impl(this)->_initialize(_1542,_1543,_1544,_1545,_1546,_1547); }void mosek::fusion::p_LinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1542,    const std::string &  _1543,    long long _1544,    std::shared_ptr< monty::ndarray< int,1 > > _1545,    std::shared_ptr< monty::ndarray< long long,1 > > _1546,    std::shared_ptr< monty::ndarray< int,1 > > _1547){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1545(_1545 ? _1545->raw() : nullptr, _1545 ? _1545->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1546(_1546 ? _1546->raw() : nullptr, _1546 ? _1546->size(0) : 0);
    _checked_ptr_1<int> _ptr__1547(_1547 ? _1547->raw() : nullptr, _1547 ? _1547->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1542,_1543,_1545,_1544,_1546,::mosek::fusion::p_LinearVariable::globalNativeIndexes(_1547));
    names_flushed = false;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->name = _1543;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->nativeidxs = _1547;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->sparsity = _1546;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->shape = _1545;
  }
}std::string mosek::fusion::LinearVariable :: toString() { return mosek::fusion::p_LinearVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_LinearVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1548 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1548->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("LinearVariable(("));
  if (((int)((shape)->size(0)) > (int)0))
  {
    {
      _1548->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
      int _7392 = (int)1;
      int _7393 = (int)((shape)->size(0));
      for (int _1549 = _7392; _1549 < _7393; ++_1549)
      {
        {
          _1548->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1549)));
        }
      }
    }
  }
  {}
  _1548->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("))"));
  return _1548->toString();
}
void mosek::fusion::p_LinearVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1550 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1551 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
      _1551->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
      if ((_pubthis->getND() > (int)0))
      {
        {
          _1551->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
          int _7394 = (int)1;
          int _7395 = _pubthis->getND();
          for (int _1552 = _7394; _1552 < _7395; ++_1552)
          {
            {
              _1551->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1552);
            }
          }
        }
      }
      {}
      _1551->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
      std::shared_ptr< monty::ndarray< int,1 > > _7396;
      bool _7397 = (_pubthis->getND() > (int)0);
      if (_7397)
      {
        _7396 = _pubthis->getShape();
      }
      else
      {
        _7396 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1)});
      }
      mosek::fusion::p_Model::_get_impl(_1550.get())->varnames(nativeidxs,_1551->toString(),_7396,sparsity);
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_LinearVariable::__mosek_2fusion_2LinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1553){
  return (::mosek::fusion::p_LinearVariable::_new_LinearVariable(::mosek::fusion::LinearVariable::t(_pubthis),_1553)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_LinearVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1554){
  _checked_ptr_1<int> _ptr__1554(_1554 ? _1554->raw() : nullptr, _1554 ? _1554->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1555 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_1554)->size(0)))));
  _checked_ptr_1<long long> _ptr__1555(_1555 ? _1555->raw() : nullptr,_1555 ? _1555->size(0) : 0);
  int _7398 = (int)0;
  int _7399 = (int)((_1554)->size(0));
  for (int _1556 = _7398; _1556 < _7399; ++_1556)
  {
    {
      _ptr__1555[_1556] = safe_add( _ptr__1554[_1556],(int)1 );
    }
  }
  return _1555;
}
void mosek::fusion::p_LinearVariable::destroy(){shape.reset();sparsity.reset();nativeidxs.reset();}void mosek::fusion::LinearVariable::destroy() { mosek::fusion::p_LinearVariable::_get_impl(this)->destroy(); }mosek::fusion::ConicVariable::ConicVariable(mosek::fusion::p_ConicVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "ConicVariable()" << this << std::endl; */ }mosek::fusion::ConicVariable::~ConicVariable() {  /* std::cout << "~ConicVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_ConicVariable::p_ConicVariable  (::mosek::fusion::ConicVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ConicVariable::t mosek::fusion::p_ConicVariable::_new_ConicVariable  (monty::rc_ptr< ::mosek::fusion::ConicVariable > _1557,    monty::rc_ptr< ::mosek::fusion::Model > _1558){ return new mosek::fusion::ConicVariable(_1557,_1558); }mosek::fusion::ConicVariable::ConicVariable  (monty::rc_ptr< ::mosek::fusion::ConicVariable > _1557,    monty::rc_ptr< ::mosek::fusion::Model > _1558) :    ConicVariable(new mosek::fusion::p_ConicVariable(this)){ mosek::fusion::p_ConicVariable::_get_impl(this)->_initialize(_1557,_1558); }void mosek::fusion::p_ConicVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::ConicVariable > _1557,    monty::rc_ptr< ::mosek::fusion::Model > _1558){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1557,_1558);
    names_flushed = mosek::fusion::p_ConicVariable::_get_impl(_1557)->names_flushed;
    shape = mosek::fusion::p_ConicVariable::_get_impl(_1557)->shape;
    nativeidxs = mosek::fusion::p_ConicVariable::_get_impl(_1557)->nativeidxs;
    shape = mosek::fusion::p_ConicVariable::_get_impl(_1557)->shape;
    varid = mosek::fusion::p_ConicVariable::_get_impl(_1557)->varid;
    name = mosek::fusion::p_ConicVariable::_get_impl(_1557)->name;
  }
}mosek::fusion::ConicVariable::t mosek::fusion::p_ConicVariable::_new_ConicVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1559,    const std::string &  _1560,    int _1561,    std::shared_ptr< monty::ndarray< int,1 > > _1562,    std::shared_ptr< monty::ndarray< int,1 > > _1563){ return new mosek::fusion::ConicVariable(_1559,_1560,_1561,_1562,_1563); }mosek::fusion::ConicVariable::ConicVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1559,    const std::string &  _1560,    int _1561,    std::shared_ptr< monty::ndarray< int,1 > > _1562,    std::shared_ptr< monty::ndarray< int,1 > > _1563) :    ConicVariable(new mosek::fusion::p_ConicVariable(this)){ mosek::fusion::p_ConicVariable::_get_impl(this)->_initialize(_1559,_1560,_1561,_1562,_1563); }void mosek::fusion::p_ConicVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1559,    const std::string &  _1560,    int _1561,    std::shared_ptr< monty::ndarray< int,1 > > _1562,    std::shared_ptr< monty::ndarray< int,1 > > _1563){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1562(_1562 ? _1562->raw() : nullptr, _1562 ? _1562->size(0) : 0);
    _checked_ptr_1<int> _ptr__1563(_1563 ? _1563->raw() : nullptr, _1563 ? _1563->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1559,_1560,_1562,_1561,nullptr,::mosek::fusion::p_ConicVariable::globalNativeIndexes(_1563));
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->name = _1560;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->names_flushed = false;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->varid = _1561;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->shape = _1562;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->nativeidxs = _1563;
  }
}std::string mosek::fusion::ConicVariable :: toString() { return mosek::fusion::p_ConicVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_ConicVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1564 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1564->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ConicVariable( "));
  if (((int)((name).size()) > (int)0))
  {
    {
      _1564->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("',"));
    }
  }
  {}
  _1564->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("("));
  _1564->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7400 = (int)1;
  int _7401 = (int)((shape)->size(0));
  for (int _1565 = _7400; _1565 < _7401; ++_1565)
  {
    {
      _1564->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1565)));
    }
  }
  _1564->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") )"));
  return _1564->toString();
}
void mosek::fusion::p_ConicVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1566 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1567 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
      _1567->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
      _1567->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
      int _7402 = (int)1;
      int _7403 = _pubthis->getND();
      for (int _1568 = _7402; _1568 < _7403; ++_1568)
      {
        {
          _1567->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1568);
        }
      }
      _1567->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
      std::shared_ptr< monty::ndarray< int,1 > > _7404;
      bool _7405 = (_pubthis->getND() > (int)0);
      if (_7405)
      {
        _7404 = _pubthis->getShape();
      }
      else
      {
        _7404 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)});
      }
      mosek::fusion::p_Model::_get_impl(_1566.get())->varnames(nativeidxs,_1567->toString(),_7404,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_ConicVariable::__mosek_2fusion_2ConicVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1569){
  return (::mosek::fusion::p_ConicVariable::_new_ConicVariable(::mosek::fusion::ConicVariable::t(_pubthis),_1569)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_ConicVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1570){
  _checked_ptr_1<int> _ptr__1570(_1570 ? _1570->raw() : nullptr, _1570 ? _1570->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1571 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_1570)->size(0)))));
  _checked_ptr_1<long long> _ptr__1571(_1571 ? _1571->raw() : nullptr,_1571 ? _1571->size(0) : 0);
  int _7406 = (int)0;
  int _7407 = (int)((_1570)->size(0));
  for (int _1572 = _7406; _1572 < _7407; ++_1572)
  {
    {
      _ptr__1571[_1572] = safe_add( _ptr__1570[_1572],(int)1 );
    }
  }
  return _1571;
}
void mosek::fusion::p_ConicVariable::destroy(){nativeidxs.reset();shape.reset();}void mosek::fusion::ConicVariable::destroy() { mosek::fusion::p_ConicVariable::_get_impl(this)->destroy(); }mosek::fusion::ModelVariable::ModelVariable(mosek::fusion::p_ModelVariable *_impl) : mosek::fusion::BaseVariable(_impl) { /*std::cout << "ModelVariable()" << this << std::endl; */ }mosek::fusion::ModelVariable::~ModelVariable() {  /* std::cout << "~ModelVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_ModelVariable::p_ModelVariable  (::mosek::fusion::ModelVariable * _pubthis) :     mosek::fusion::p_BaseVariable(_pubthis),    _pubthis(_pubthis){}void mosek::fusion::p_ModelVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::ModelVariable > _1573,    monty::rc_ptr< ::mosek::fusion::Model > _1574){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseVariable::_initialize(_1573,_1574);
    name = mosek::fusion::p_ModelVariable::_get_impl(_1573)->name;
    varid = mosek::fusion::p_ModelVariable::_get_impl(_1573)->varid;
    nativeidxs = mosek::fusion::p_ModelVariable::_get_impl(_1573)->nativeidxs;
    shape = mosek::fusion::p_ModelVariable::_get_impl(_1573)->shape;
    sparsity = mosek::fusion::p_ModelVariable::_get_impl(_1573)->sparsity;
  }
}void mosek::fusion::p_ModelVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1575,    const std::string &  _1576,    std::shared_ptr< monty::ndarray< int,1 > > _1577,    long long _1578,    std::shared_ptr< monty::ndarray< long long,1 > > _1579,    std::shared_ptr< monty::ndarray< long long,1 > > _1580){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1577(_1577 ? _1577->raw() : nullptr, _1577 ? _1577->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1579(_1579 ? _1579->raw() : nullptr, _1579 ? _1579->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1580(_1580 ? _1580->raw() : nullptr, _1580 ? _1580->size(0) : 0);
    mosek::fusion::p_BaseVariable::_initialize(_1575,_1577,_1579,_1580);
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->name = _1576;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->varid = _1578;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->shape = _1577;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->sparsity = _1579;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->nativeidxs = _1580;
  }
}void mosek::fusion::ModelVariable :: elementName(long long _1581,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1582) { mosek::fusion::p_ModelVariable::_get_impl(this)->elementName(_1581,_1582); }void mosek::fusion::p_ModelVariable::elementName(long long _1581,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1582){
  std::string _7408;
  bool _7409 = ((int)((name).size()) == (int)0);
  if (_7409)
  {
    _7408 = std::string ("_");
  }
  else
  {
    _7408 = name;
  }
  _1582->__mosek_2fusion_2Utils_2StringBuffer__a(_7408)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a(::mosek::fusion::p_Set::indexToString(shape,_1581))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
}
void mosek::fusion::p_ModelVariable::destroy(){sparsity.reset();shape.reset();nativeidxs.reset();}void mosek::fusion::ModelVariable::destroy() { mosek::fusion::p_ModelVariable::_get_impl(this)->destroy(); }mosek::fusion::NilVariable::NilVariable(mosek::fusion::p_NilVariable *_impl) : mosek::fusion::BaseVariable(_impl) { /*std::cout << "NilVariable()" << this << std::endl; */ }mosek::fusion::NilVariable::~NilVariable() {  /* std::cout << "~NilVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_NilVariable::p_NilVariable  (::mosek::fusion::NilVariable * _pubthis) :     mosek::fusion::p_BaseVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::NilVariable::t mosek::fusion::p_NilVariable::_new_NilVariable  (std::shared_ptr< monty::ndarray< int,1 > > _1584){ return new mosek::fusion::NilVariable(_1584); }mosek::fusion::NilVariable::NilVariable  (std::shared_ptr< monty::ndarray< int,1 > > _1584) :    NilVariable(new mosek::fusion::p_NilVariable(this)){ mosek::fusion::p_NilVariable::_get_impl(this)->_initialize(_1584); }void mosek::fusion::p_NilVariable::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _1584){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1584(_1584 ? _1584->raw() : nullptr, _1584 ? _1584->size(0) : 0);
    mosek::fusion::p_BaseVariable::_initialize(nullptr,::mosek::fusion::Utils::Tools::arraycopy(_1584),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))));
    std::vector<int> _7410;
    for (int _1585 = (int)0, _7411 = (int)((_1584)->size(0)); _1585 < _7411 ; ++_1585)
    {
      _7410.push_back(_ptr__1584[_1585]);
    }
    auto _7412 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7410.size()),_7410.begin(),_7410.end()));
    mosek::fusion::p_NilVariable::_get_impl(::mosek::fusion::NilVariable::t(_pubthis))->shape = _7412;
  }
}mosek::fusion::NilVariable::t mosek::fusion::p_NilVariable::_new_NilVariable  (){ return new mosek::fusion::NilVariable(); }mosek::fusion::NilVariable::NilVariable  () :    NilVariable(new mosek::fusion::p_NilVariable(this)){ mosek::fusion::p_NilVariable::_get_impl(this)->_initialize(); }void mosek::fusion::p_NilVariable::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_NilVariable::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1)}));
  }
}void mosek::fusion::p_NilVariable::flushNames(){
}
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__elementDesc(long long _1586,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1587) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__elementDesc(_1586,_1587); }monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::NilVariable::elementDesc(long long _1586,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1587) { return __mosek_2fusion_2NilVariable__elementDesc(_1586,_1587); }
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__elementDesc(long long _1586,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1587){
  return _1587;
}
void mosek::fusion::NilVariable :: elementName(long long _1588,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1589) { mosek::fusion::p_NilVariable::_get_impl(this)->elementName(_1588,_1589); }void mosek::fusion::p_NilVariable::elementName(long long _1588,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1589){
}
int mosek::fusion::NilVariable :: numInst() { return mosek::fusion::p_NilVariable::_get_impl(this)->numInst(); }int mosek::fusion::p_NilVariable::numInst(){
  return (int)0;
}
int mosek::fusion::NilVariable :: inst(int _1590,std::shared_ptr< monty::ndarray< long long,1 > > _1591,std::shared_ptr< monty::ndarray< long long,1 > > _1592) { return mosek::fusion::p_NilVariable::_get_impl(this)->inst(_1590,_1591,_1592); }int mosek::fusion::p_NilVariable::inst(int _1590,std::shared_ptr< monty::ndarray< long long,1 > > _1591,std::shared_ptr< monty::ndarray< long long,1 > > _1592){
  _checked_ptr_1<long long> _ptr__1591(_1591 ? _1591->raw() : nullptr, _1591 ? _1591->size(0) : 0);
  _checked_ptr_1<long long> _ptr__1592(_1592 ? _1592->raw() : nullptr, _1592 ? _1592->size(0) : 0);
  return (int)0;
}
void mosek::fusion::NilVariable :: inst(int _1593,std::shared_ptr< monty::ndarray< long long,1 > > _1594) { mosek::fusion::p_NilVariable::_get_impl(this)->inst(_1593,_1594); }void mosek::fusion::p_NilVariable::inst(int _1593,std::shared_ptr< monty::ndarray< long long,1 > > _1594){
  _checked_ptr_1<long long> _ptr__1594(_1594 ? _1594->raw() : nullptr, _1594 ? _1594->size(0) : 0);
}
void mosek::fusion::NilVariable :: set_values(std::shared_ptr< monty::ndarray< double,1 > > _1595,bool _1596) { mosek::fusion::p_NilVariable::_get_impl(this)->set_values(_1595,_1596); }void mosek::fusion::p_NilVariable::set_values(std::shared_ptr< monty::ndarray< double,1 > > _1595,bool _1596){
  _checked_ptr_1<double> _ptr__1595(_1595 ? _1595->raw() : nullptr, _1595 ? _1595->size(0) : 0);
}
void mosek::fusion::NilVariable :: values(int _1597,std::shared_ptr< monty::ndarray< double,1 > > _1598,bool _1599) { mosek::fusion::p_NilVariable::_get_impl(this)->values(_1597,_1598,_1599); }void mosek::fusion::p_NilVariable::values(int _1597,std::shared_ptr< monty::ndarray< double,1 > > _1598,bool _1599){
  _checked_ptr_1<double> _ptr__1598(_1598 ? _1598->raw() : nullptr, _1598 ? _1598->size(0) : 0);
}
void mosek::fusion::NilVariable :: make_continuous() { mosek::fusion::p_NilVariable::_get_impl(this)->make_continuous(); }void mosek::fusion::p_NilVariable::make_continuous(){
}
void mosek::fusion::NilVariable :: make_integer() { mosek::fusion::p_NilVariable::_get_impl(this)->make_integer(); }void mosek::fusion::p_NilVariable::make_integer(){
}
std::string mosek::fusion::NilVariable :: toString() { return mosek::fusion::p_NilVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_NilVariable::toString(){
  return std::string ("NilVariable");
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1600) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__index(_1600); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::index(std::shared_ptr< monty::ndarray< int,1 > > _1600) { return __mosek_2fusion_2NilVariable__index(_1600); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1600) { return __mosek_2fusion_2NilVariable__index(_1600); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1600) { return __mosek_2fusion_2NilVariable__index(_1600); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1600){
  _checked_ptr_1<int> _ptr__1600(_1600 ? _1600->raw() : nullptr, _1600 ? _1600->size(0) : 0);
  std::vector<int> _7413;
  for (int _1601 = (int)0, _7414 = (int)((shape)->size(0)); _1601 < _7414 ; ++_1601)
  {
    _7413.push_back((int)1);
  }
  auto _7415 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7413.size()),_7413.begin(),_7413.end()));
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_7415)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__index(int _1602) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__index(_1602); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::index(int _1602) { return __mosek_2fusion_2NilVariable__index(_1602); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__index(int _1602) { return __mosek_2fusion_2NilVariable__index(_1602); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__index(int _1602) { return __mosek_2fusion_2NilVariable__index(_1602); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__index(int _1602){
  std::vector<int> _7416;
  for (int _1603 = (int)0, _7417 = (int)((shape)->size(0)); _1603 < _7417 ; ++_1603)
  {
    _7416.push_back((int)1);
  }
  auto _7418 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7416.size()),_7416.begin(),_7416.end()));
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_7418)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1604,std::shared_ptr< monty::ndarray< int,1 > > _1605) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__slice(_1604,_1605); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::slice(std::shared_ptr< monty::ndarray< int,1 > > _1604,std::shared_ptr< monty::ndarray< int,1 > > _1605) { return __mosek_2fusion_2NilVariable__slice(_1604,_1605); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1604,std::shared_ptr< monty::ndarray< int,1 > > _1605) { return __mosek_2fusion_2NilVariable__slice(_1604,_1605); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1604,std::shared_ptr< monty::ndarray< int,1 > > _1605) { return __mosek_2fusion_2NilVariable__slice(_1604,_1605); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1604,std::shared_ptr< monty::ndarray< int,1 > > _1605){
  _checked_ptr_1<int> _ptr__1604(_1604 ? _1604->raw() : nullptr, _1604 ? _1604->size(0) : 0);
  _checked_ptr_1<int> _ptr__1605(_1605 ? _1605->raw() : nullptr, _1605 ? _1605->size(0) : 0);
  if ((((int)((shape)->size(0)) != (int)((_1604)->size(0))) || ((int)((shape)->size(0)) != (int)((_1605)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching slice shape"));
    }
  }
  {}
  int _7419 = (int)0;
  int _7420 = (int)((_1604)->size(0));
  for (int _1606 = _7419; _1606 < _7420; ++_1606)
  {
    {
      if (((_ptr__1605[_1606] > _ptr__1604[_1606]) || ((_ptr__1604[_1606] < (int)0) || (_ptr__1605[_1606] >= ((*shape)(_1606))))))
      {
        {
          throw ::mosek::fusion::SliceError(std::string ("Slice is out of bounds"));
        }
      }
      {}
    }
  }
  std::vector<int> _7421;
  for (int _1607 = (int)0, _7422 = (int)((shape)->size(0)); _1607 < _7422 ; ++_1607)
  {
    _7421.push_back((_ptr__1605[_1607] - _ptr__1604[_1607]));
  }
  auto _7423 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7421.size()),_7421.begin(),_7421.end()));
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_7423)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__slice(int _1608,int _1609) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__slice(_1608,_1609); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::slice(int _1608,int _1609) { return __mosek_2fusion_2NilVariable__slice(_1608,_1609); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__slice(int _1608,int _1609) { return __mosek_2fusion_2NilVariable__slice(_1608,_1609); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__slice(int _1608,int _1609) { return __mosek_2fusion_2NilVariable__slice(_1608,_1609); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__slice(int _1608,int _1609){
  if (((_1609 > _1608) || ((_1608 < (int)0) || (_1609 > ((*shape)((int)0))))))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Slice is out of bounds"));
    }
  }
  else if(((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching slice shape"));
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((_1609 - _1608))}))).as<::mosek::fusion::Variable>();
    }
  }
}
void mosek::fusion::p_NilVariable::destroy(){shape.reset();}void mosek::fusion::NilVariable::destroy() { mosek::fusion::p_NilVariable::_get_impl(this)->destroy(); }mosek::fusion::BaseVariable::BaseVariable(mosek::fusion::p_BaseVariable *_impl) : _impl(_impl) { /*std::cout << "BaseVariable() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::BaseVariable::~BaseVariable() { delete _impl; _impl = nullptr; }mosek::fusion::p_BaseVariable::p_BaseVariable  (::mosek::fusion::BaseVariable * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_BaseVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::BaseVariable > _1610,    monty::rc_ptr< ::mosek::fusion::Model > _1611){monty::rc_reserve __reserve_this(_pubthis);   {
    model = _1611;
    shape = mosek::fusion::p_BaseVariable::_get_impl(_1610)->shape;
    sparsity = mosek::fusion::p_BaseVariable::_get_impl(_1610)->sparsity;
    nativeidxs = mosek::fusion::p_BaseVariable::_get_impl(_1610)->nativeidxs;
  }
}void mosek::fusion::p_BaseVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1612,    std::shared_ptr< monty::ndarray< int,1 > > _1613,    std::shared_ptr< monty::ndarray< long long,1 > > _1614,    std::shared_ptr< monty::ndarray< long long,1 > > _1615){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1613(_1613 ? _1613->raw() : nullptr, _1613 ? _1613->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1614(_1614 ? _1614->raw() : nullptr, _1614 ? _1614->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1615(_1615 ? _1615->raw() : nullptr, _1615 ? _1615->size(0) : 0);
    model = _1612;
    mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->shape = _1613;
    mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity = _1614;
    mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs = _1615;
  }
}std::string mosek::fusion::BaseVariable :: toString() { return mosek::fusion::p_BaseVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_BaseVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1616 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1616->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Variable(("));
  if (((int)((shape)->size(0)) > (int)0))
  {
    {
      _1616->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
      int _7424 = (int)1;
      int _7425 = (int)((shape)->size(0));
      for (int _1617 = _7424; _1617 < _7425; ++_1617)
      {
        {
          _1616->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1617)));
        }
      }
    }
  }
  {}
  _1616->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("))"));
  return _1616->toString();
}
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__eval() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseVariable::eval() { return __mosek_2fusion_2BaseVariable__eval(); }
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseVariable::__mosek_2fusion_2Expression__eval() { return __mosek_2fusion_2BaseVariable__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__eval(){
  return _pubthis->__mosek_2fusion_2BaseVariable__asExpr()->__mosek_2fusion_2Expression__eval();
}
void mosek::fusion::BaseVariable :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _1618,monty::rc_ptr< ::mosek::fusion::WorkStack > _1619,monty::rc_ptr< ::mosek::fusion::WorkStack > _1620) { mosek::fusion::p_BaseVariable::_get_impl(this)->eval(_1618,_1619,_1620); }void mosek::fusion::p_BaseVariable::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _1618,monty::rc_ptr< ::mosek::fusion::WorkStack > _1619,monty::rc_ptr< ::mosek::fusion::WorkStack > _1620){
  int _1621 = (int)((nativeidxs)->size(0));
  int _1622 = _1621;
  int _1623 = (int)((shape)->size(0));
  bool _1624 = (NULL != sparsity.get());
  _1618->alloc_expr(_1623,_1622,_1621,_1624);
  int _1625 = mosek::fusion::p_WorkStack::_get_impl(_1618)->ptr_base;
  int _1626 = mosek::fusion::p_WorkStack::_get_impl(_1618)->nidxs_base;
  int _1627 = mosek::fusion::p_WorkStack::_get_impl(_1618)->sp_base;
  int _1628 = mosek::fusion::p_WorkStack::_get_impl(_1618)->cof_base;
  int _1629 = mosek::fusion::p_WorkStack::_get_impl(_1618)->bfix_base;
  int _1630 = mosek::fusion::p_WorkStack::_get_impl(_1618)->shape_base;
  std::shared_ptr< monty::ndarray< int,1 > > _1631 = mosek::fusion::p_WorkStack::_get_impl(_1618)->i32;
  _checked_ptr_1<int> _ptr__1631(_1631 ? _1631->raw() : nullptr,_1631 ? _1631->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1632 = mosek::fusion::p_WorkStack::_get_impl(_1618)->i64;
  _checked_ptr_1<long long> _ptr__1632(_1632 ? _1632->raw() : nullptr,_1632 ? _1632->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1633 = mosek::fusion::p_WorkStack::_get_impl(_1618)->f64;
  _checked_ptr_1<double> _ptr__1633(_1633 ? _1633->raw() : nullptr,_1633 ? _1633->size(0) : 0);
  int _7426 = (int)0;
  int _7427 = _1623;
  for (int _1634 = _7426; _1634 < _7427; ++_1634)
  {
    {
      _ptr__1631[safe_add( _1630,_1634 )] = ((*shape)(_1634));
    }
  }
  {
    int _7428 = (int)0;
    int _7429 = safe_add( _1621,(int)1 );
    for (int _1635 = _7428; _1635 < _7429; ++_1635)
    {
      {
        _ptr__1631[safe_add( _1625,_1635 )] = _1635;
      }
    }
    int _7430 = (int)0;
    int _7431 = _1621;
    for (int _1636 = _7430; _1636 < _7431; ++_1636)
    {
      {
        _ptr__1632[safe_add( _1626,_1636 )] = ((*nativeidxs)(_1636));
      }
    }
    if (_1624)
    {
      {
        int _7432 = (int)0;
        int _7433 = _1621;
        for (int _1637 = _7432; _1637 < _7433; ++_1637)
        {
          {
            _ptr__1632[safe_add( _1627,_1637 )] = ((*sparsity)(_1637));
          }
        }
      }
    }
    {}
    int _7434 = (int)0;
    int _7435 = _1621;
    for (int _1638 = _7434; _1638 < _7435; ++_1638)
    {
      {
        _ptr__1633[safe_add( _1628,_1638 )] = 1.0;
      }
    }
    int _7436 = (int)0;
    int _7437 = _1621;
    for (int _1639 = _7436; _1639 < _7437; ++_1639)
    {
      {
        _ptr__1633[safe_add( _1629,_1639 )] = 0.0;
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__reshape(int _1640,int _1641,int _1642) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__reshape(_1640,_1641,_1642); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::reshape(int _1640,int _1641,int _1642) { return __mosek_2fusion_2BaseVariable__reshape(_1640,_1641,_1642); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__reshape(int _1640,int _1641,int _1642) { return __mosek_2fusion_2BaseVariable__reshape(_1640,_1641,_1642); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__reshape(int _1640,int _1641,int _1642){
  return _pubthis->__mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1640),(int)(_1641),(int)(_1642)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__reshape(int _1643,int _1644) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__reshape(_1643,_1644); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::reshape(int _1643,int _1644) { return __mosek_2fusion_2BaseVariable__reshape(_1643,_1644); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__reshape(int _1643,int _1644) { return __mosek_2fusion_2BaseVariable__reshape(_1643,_1644); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__reshape(int _1643,int _1644){
  return _pubthis->__mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1643),(int)(_1644)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__reshape(int _1645) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__reshape(_1645); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::reshape(int _1645) { return __mosek_2fusion_2BaseVariable__reshape(_1645); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__reshape(int _1645) { return __mosek_2fusion_2BaseVariable__reshape(_1645); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__reshape(int _1645){
  return _pubthis->__mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1645)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1646) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__reshape(_1646); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::reshape(std::shared_ptr< monty::ndarray< int,1 > > _1646) { return __mosek_2fusion_2BaseVariable__reshape(_1646); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1646) { return __mosek_2fusion_2BaseVariable__reshape(_1646); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1646){
  _checked_ptr_1<int> _ptr__1646(_1646 ? _1646->raw() : nullptr, _1646 ? _1646->size(0) : 0);
  long long _1647 = (int)1;
  int _7438 = (int)0;
  int _7439 = (int)((_1646)->size(0));
  for (int _1648 = _7438; _1648 < _7439; ++_1648)
  {
    {
      if ((_ptr__1646[_1648] < (int)0))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid shape"));
        }
      }
      {}
      _1647 *= _ptr__1646[_1648];
    }
  }
  if ((_1647 != _pubthis->getSize()))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Shape size does not match variable size"));
    }
  }
  {}
  std::vector<int> _7440;
  for (int _1649 = (int)0, _7441 = (int)((_1646)->size(0)); _1649 < _7441 ; ++_1649)
  {
    _7440.push_back(_ptr__1646[_1649]);
  }
  auto _7442 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7440.size()),_7440.begin(),_7440.end()));
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_7442,sparsity,nativeidxs)).as<::mosek::fusion::Variable>();
}
void mosek::fusion::BaseVariable :: setLevel(std::shared_ptr< monty::ndarray< double,1 > > _1650) { mosek::fusion::p_BaseVariable::_get_impl(this)->setLevel(_1650); }void mosek::fusion::p_BaseVariable::setLevel(std::shared_ptr< monty::ndarray< double,1 > > _1650){
  _checked_ptr_1<double> _ptr__1650(_1650 ? _1650->raw() : nullptr, _1650 ? _1650->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      if (((int)((_1650)->size(0)) != (int)((nativeidxs)->size(0))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid length of solution values vector"));
        }
      }
      {}
      model->setVariableValues(true,nativeidxs,_1650);
    }
  }
  else
  {
    {
      if (((int)((_1650)->size(0)) != _pubthis->getSize()))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid length of solution values vector"));
        }
      }
      {}
      std::vector<double> _7443;
      for (int _1652 = (int)0, _7444 = (int)((nativeidxs)->size(0)); _1652 < _7444 ; ++_1652)
      {
        _7443.push_back(_ptr__1650[((*sparsity)(_1652))]);
      }
      auto _7445 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7443.size()),_7443.begin(),_7443.end()));
      std::shared_ptr< monty::ndarray< double,1 > > _1651 = _7445;
      _checked_ptr_1<double> _ptr__1651(_1651 ? _1651->raw() : nullptr,_1651 ? _1651->size(0) : 0);
      model->setVariableValues(true,nativeidxs,_1651);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__getModel() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::BaseVariable::getModel() { return __mosek_2fusion_2BaseVariable__getModel(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__getModel() { return __mosek_2fusion_2BaseVariable__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__getModel(){
  return model;
}
int mosek::fusion::BaseVariable :: getND() { return mosek::fusion::p_BaseVariable::_get_impl(this)->getND(); }int mosek::fusion::p_BaseVariable::getND(){
  return (int)((shape)->size(0));
}
int mosek::fusion::BaseVariable :: getDim(int _1653) { return mosek::fusion::p_BaseVariable::_get_impl(this)->getDim(_1653); }int mosek::fusion::p_BaseVariable::getDim(int _1653){
  return ((*shape)(_1653));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::BaseVariable :: getShape() { return mosek::fusion::p_BaseVariable::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_BaseVariable::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
long long mosek::fusion::BaseVariable :: getSize() { return mosek::fusion::p_BaseVariable::_get_impl(this)->getSize(); }long long mosek::fusion::p_BaseVariable::getSize(){
  long long _1654 = (long long)1;
  int _7446 = (int)0;
  int _7447 = (int)((shape)->size(0));
  for (int _1655 = _7446; _1655 < _7447; ++_1655)
  {
    {
      _1654 *= ((*shape)(_1655));
    }
  }
  return _1654;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::BaseVariable :: dual() { return mosek::fusion::p_BaseVariable::_get_impl(this)->dual(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_BaseVariable::dual(){
  std::shared_ptr< monty::ndarray< double,1 > > _1656 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__1656(_1656 ? _1656->raw() : nullptr,_1656 ? _1656->size(0) : 0);
  model->getVariableValues(false,nativeidxs,_1656,(int)0);
  if ((NULL != sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _1657 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<double> _ptr__1657(_1657 ? _1657->raw() : nullptr,_1657 ? _1657->size(0) : 0);
      int _7448 = (int)0;
      int _7449 = (int)((nativeidxs)->size(0));
      for (int _1658 = _7448; _1658 < _7449; ++_1658)
      {
        {
          _ptr__1657[((*sparsity)(_1658))] = _ptr__1656[_1658];
        }
      }
      _1656 = _1657;
      _ptr__1656.update(_1656 ? _1656->raw() : nullptr, _1656 ? _1656->size(0) : 0);
    }
  }
  {}
  return _1656;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::BaseVariable :: level() { return mosek::fusion::p_BaseVariable::_get_impl(this)->level(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_BaseVariable::level(){
  std::shared_ptr< monty::ndarray< double,1 > > _1659 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__1659(_1659 ? _1659->raw() : nullptr,_1659 ? _1659->size(0) : 0);
  model->getVariableValues(true,nativeidxs,_1659,(int)0);
  if ((NULL != sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _1660 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<double> _ptr__1660(_1660 ? _1660->raw() : nullptr,_1660 ? _1660->size(0) : 0);
      int _7450 = (int)0;
      int _7451 = (int)((nativeidxs)->size(0));
      for (int _1661 = _7450; _1661 < _7451; ++_1661)
      {
        {
          _ptr__1660[((*sparsity)(_1661))] = _ptr__1659[_1661];
        }
      }
      _1659 = _1660;
      _ptr__1659.update(_1659 ? _1659->raw() : nullptr, _1659 ? _1659->size(0) : 0);
    }
  }
  {}
  return _1659;
}
void mosek::fusion::BaseVariable :: makeContinuous() { mosek::fusion::p_BaseVariable::_get_impl(this)->makeContinuous(); }void mosek::fusion::p_BaseVariable::makeContinuous(){
  _pubthis->make_continuous();
}
void mosek::fusion::BaseVariable :: makeInteger() { mosek::fusion::p_BaseVariable::_get_impl(this)->makeInteger(); }void mosek::fusion::p_BaseVariable::makeInteger(){
  _pubthis->make_integer();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__transpose() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__transpose(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::transpose() { return __mosek_2fusion_2BaseVariable__transpose(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__transpose() { return __mosek_2fusion_2BaseVariable__transpose(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__transpose(){
  if (((int)((shape)->size(0)) == (int)1))
  {
    {
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(((*shape)((int)0)))}),sparsity,nativeidxs)).as<::mosek::fusion::Variable>();
    }
  }
  else if(((int)((shape)->size(0)) > (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid shape for operation"));
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1662 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((nativeidxs)->size(0)))));
      _checked_ptr_1<long long> _ptr__1662(_1662 ? _1662->raw() : nullptr,_1662 ? _1662->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _7452;
      bool _7453 = (NULL == sparsity.get());
      if (_7453)
      {
        _7452 = nullptr;
      }
      else
      {
        _7452 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((nativeidxs)->size(0)))));
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1663 = _7452;
      _checked_ptr_1<long long> _ptr__1663(_1663 ? _1663->raw() : nullptr,_1663 ? _1663->size(0) : 0);
      if ((NULL == sparsity.get()))
      {
        {
          int _1664 = (int)0;
          int _7454 = (int)0;
          int _7455 = ((*shape)((int)1));
          for (int _1665 = _7454; _1665 < _7455; ++_1665)
          {
            {
              int _7456 = (int)0;
              int _7457 = ((*shape)((int)0));
              for (int _1666 = _7456; _1666 < _7457; ++_1666)
              {
                {
                  _ptr__1662[_1664] = ((*nativeidxs)(safe_add( safe_mul( _1666,((*shape)((int)1)) ),_1665 )));
                  ++ _1664;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _1667 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( ((*shape)((int)1)),(int)1 ))));
          _checked_ptr_1<int> _ptr__1667(_1667 ? _1667->raw() : nullptr,_1667 ? _1667->size(0) : 0);
          int _1668 = ((*shape)((int)0));
          int _1669 = ((*shape)((int)1));
          int _7458 = (int)0;
          int _7459 = (int)((sparsity)->size(0));
          for (int _1670 = _7458; _1670 < _7459; ++_1670)
          {
            {
              ++ _ptr__1667[safe_add( (((*sparsity)(_1670)) % _1669),(int)1 )];
            }
          }
          int _7460 = (int)0;
          int _7461 = _1669;
          for (int _1671 = _7460; _1671 < _7461; ++_1671)
          {
            {
              _ptr__1667[safe_add( _1671,(int)1 )] += _ptr__1667[_1671];
            }
          }
          int _7462 = (int)0;
          int _7463 = (int)((sparsity)->size(0));
          for (int _1672 = _7462; _1672 < _7463; ++_1672)
          {
            {
              long long _1673 = (((*sparsity)(_1672)) % _1669);
              _ptr__1662[_ptr__1667[_1673]] = ((*nativeidxs)(_1672));
              _ptr__1663[_ptr__1667[_1673]] = safe_add( (((*sparsity)(_1672)) / _1669),safe_mul( (((*sparsity)(_1672)) % _1669),_1668 ) );
              ++ _ptr__1667[_1673];
            }
          }
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*shape)((int)1))),(int)(((*shape)((int)0)))}),_1663,_1662)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(int _1674,int _1675,int _1676) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1674,_1675,_1676); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(int _1674,int _1675,int _1676) { return __mosek_2fusion_2BaseVariable__index(_1674,_1675,_1676); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(int _1674,int _1675,int _1676) { return __mosek_2fusion_2BaseVariable__index(_1674,_1675,_1676); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(int _1674,int _1675,int _1676){
  return _pubthis->__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1674),(int)(_1675),(int)(_1676)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(int _1677,int _1678) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1677,_1678); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(int _1677,int _1678) { return __mosek_2fusion_2BaseVariable__index(_1677,_1678); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(int _1677,int _1678) { return __mosek_2fusion_2BaseVariable__index(_1677,_1678); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(int _1677,int _1678){
  return _pubthis->__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1677),(int)(_1678)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1679) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1679); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(std::shared_ptr< monty::ndarray< int,1 > > _1679) { return __mosek_2fusion_2BaseVariable__index(_1679); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1679) { return __mosek_2fusion_2BaseVariable__index(_1679); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1679){
  _checked_ptr_1<int> _ptr__1679(_1679 ? _1679->raw() : nullptr, _1679 ? _1679->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _1680 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)1,(int)((_1679)->size(0)))));
  int _7464 = (int)0;
  int _7465 = (int)((_1679)->size(0));
  for (int _1681 = _7464; _1681 < _7465; ++_1681)
  {
    {
      ((*_1680)((int)0,_1681)) = _ptr__1679[_1681];
    }
  }
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(_1680)->__mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(int _1682) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1682); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(int _1682) { return __mosek_2fusion_2BaseVariable__index(_1682); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(int _1682) { return __mosek_2fusion_2BaseVariable__index(_1682); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(int _1682){
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1682)}))->__mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1683,std::shared_ptr< monty::ndarray< int,1 > > _1684,std::shared_ptr< monty::ndarray< int,1 > > _1685) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1683,_1684,_1685); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1683,std::shared_ptr< monty::ndarray< int,1 > > _1684,std::shared_ptr< monty::ndarray< int,1 > > _1685) { return __mosek_2fusion_2BaseVariable__pick(_1683,_1684,_1685); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1683,std::shared_ptr< monty::ndarray< int,1 > > _1684,std::shared_ptr< monty::ndarray< int,1 > > _1685) { return __mosek_2fusion_2BaseVariable__pick(_1683,_1684,_1685); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1683,std::shared_ptr< monty::ndarray< int,1 > > _1684,std::shared_ptr< monty::ndarray< int,1 > > _1685){
  _checked_ptr_1<int> _ptr__1683(_1683 ? _1683->raw() : nullptr, _1683 ? _1683->size(0) : 0);
  _checked_ptr_1<int> _ptr__1684(_1684 ? _1684->raw() : nullptr, _1684 ? _1684->size(0) : 0);
  _checked_ptr_1<int> _ptr__1685(_1685 ? _1685->raw() : nullptr, _1685 ? _1685->size(0) : 0);
  if (((int)((shape)->size(0)) != (int)3))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  if ((((int)((_1683)->size(0)) != (int)((_1684)->size(0))) || ((int)((_1683)->size(0)) != (int)((_1685)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching argument lengths"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,2 > > _1686 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_1683)->size(0)),(int)3)));
  int _7466 = (int)0;
  int _7467 = (int)((_1683)->size(0));
  for (int _1687 = _7466; _1687 < _7467; ++_1687)
  {
    {
      ((*_1686)(_1687,(int)0)) = _ptr__1683[_1687];
      ((*_1686)(_1687,(int)1)) = _ptr__1684[_1687];
      ((*_1686)(_1687,(int)2)) = _ptr__1685[_1687];
    }
  }
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(_1686);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1688,std::shared_ptr< monty::ndarray< int,1 > > _1689) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1688,_1689); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1688,std::shared_ptr< monty::ndarray< int,1 > > _1689) { return __mosek_2fusion_2BaseVariable__pick(_1688,_1689); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1688,std::shared_ptr< monty::ndarray< int,1 > > _1689) { return __mosek_2fusion_2BaseVariable__pick(_1688,_1689); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1688,std::shared_ptr< monty::ndarray< int,1 > > _1689){
  _checked_ptr_1<int> _ptr__1688(_1688 ? _1688->raw() : nullptr, _1688 ? _1688->size(0) : 0);
  _checked_ptr_1<int> _ptr__1689(_1689 ? _1689->raw() : nullptr, _1689 ? _1689->size(0) : 0);
  if ((((int)((shape)->size(0)) != (int)2) || ((int)((_1688)->size(0)) != (int)((_1689)->size(0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,2 > > _1690 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_1688)->size(0)),(int)2)));
  int _7468 = (int)0;
  int _7469 = (int)((_1688)->size(0));
  for (int _1691 = _7468; _1691 < _7469; ++_1691)
  {
    {
      ((*_1690)(_1691,(int)0)) = _ptr__1688[_1691];
      ((*_1690)(_1691,(int)1)) = _ptr__1689[_1691];
    }
  }
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(_1690);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1692) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1692); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,2 > > _1692) { return __mosek_2fusion_2BaseVariable__pick(_1692); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1692) { return __mosek_2fusion_2BaseVariable__pick(_1692); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1692){
  if (((int)((shape)->size(0)) != (int)((_1692)->size(1))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  bool _1693 = false;
  int _7470 = (int)0;
  int _7471 = (int)((_1692)->size(0));
  for (int _1694 = _7470; _1694 < _7471; ++_1694)
  {
    {
      int _7472 = (int)0;
      int _7473 = (int)((_1692)->size(1));
      for (int _1695 = _7472; _1695 < _7473; ++_1695)
      {
        {
          if (((((*_1692)(_1694,_1695)) < (int)0) || (((*_1692)(_1694,_1695)) >= ((*shape)(_1695)))))
          {
            {
              _1693 = true;
            }
          }
          {}
        }
      }
    }
  }
  if (_1693)
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  int _1696 = (int)((shape)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _1697 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1696)));
  _checked_ptr_1<long long> _ptr__1697(_1697 ? _1697->raw() : nullptr,_1697 ? _1697->size(0) : 0);
  _ptr__1697[(_1696 - (int)1)] = (int)1;
  int _7474 = (int)1;
  int _7475 = _1696;
  for (int _1698 = _7474; _1698 < _7475; ++_1698)
  {
    {
      _ptr__1697[((_1696 - _1698) - (int)1)] = safe_mul( _ptr__1697[(_1696 - _1698)],((*shape)((_1696 - _1698))) );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1699 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_1692)->size(0)))});
  _checked_ptr_1<int> _ptr__1699(_1699 ? _1699->raw() : nullptr,_1699 ? _1699->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1700;
  _checked_ptr_1<long long> _ptr__1700(_1700 ? _1700->raw() : nullptr,_1700 ? _1700->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1701 = nullptr;
  _checked_ptr_1<long long> _ptr__1701(_1701 ? _1701->raw() : nullptr,_1701 ? _1701->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      _1700 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_1692)->size(0)))));
      _ptr__1700.update(_1700 ? _1700->raw() : nullptr, _1700 ? _1700->size(0) : 0);
      {
        int _7476 = (int)0;
        int _7477 = (int)((_1692)->size(0));
        for (int _1702 = _7476; _1702 < _7477; ++_1702)
        {
          {
            long long _1703 = (long long)0;
            int _7478 = (int)0;
            int _7479 = _1696;
            for (int _1704 = _7478; _1704 < _7479; ++_1704)
            {
              {
                _1703 += safe_mul( _ptr__1697[_1704],((*_1692)(_1702,_1704)) );
              }
            }
            _ptr__1700[_1702] = ((*nativeidxs)(_1703));
          }
        }
      }
    }
  }
  else
  {
    {
      int _1705 = (int)0;
      int _7480 = (int)0;
      int _7481 = (int)((_1692)->size(0));
      for (int _1706 = _7480; _1706 < _7481; ++_1706)
      {
        {
          long long _1707 = (long long)0;
          int _7482 = (int)0;
          int _7483 = _1696;
          for (int _1708 = _7482; _1708 < _7483; ++_1708)
          {
            {
              _1707 += safe_mul( _ptr__1697[_1708],((*_1692)(_1706,_1708)) );
            }
          }
          if ((::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1707) >= (int)0))
          {
            {
              ++ _1705;
            }
          }
          {}
        }
      }
      _1700 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1705)));
      _ptr__1700.update(_1700 ? _1700->raw() : nullptr, _1700 ? _1700->size(0) : 0);
      _1701 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1705)));
      _ptr__1701.update(_1701 ? _1701->raw() : nullptr, _1701 ? _1701->size(0) : 0);
      {
        int _1709 = (int)0;
        int _7484 = (int)0;
        int _7485 = (int)((_1692)->size(0));
        for (int _1710 = _7484; _1710 < _7485; ++_1710)
        {
          {
            long long _1711 = (long long)0;
            int _7486 = (int)0;
            int _7487 = _1696;
            for (int _1712 = _7486; _1712 < _7487; ++_1712)
            {
              {
                _1711 += safe_mul( _ptr__1697[_1712],((*_1692)(_1710,_1712)) );
              }
            }
            int _1713 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1711);
            if ((_1713 >= (int)0))
            {
              {
                _ptr__1700[_1709] = ((*nativeidxs)(_1713));
                _ptr__1701[_1709] = _1710;
                ++ _1709;
              }
            }
            {}
          }
        }
      }
      if ((_1705 == (int)((_1692)->size(0))))
      {
        {
          _1701 = nullptr;
          _ptr__1701.update(_1701 ? _1701->raw() : nullptr, _1701 ? _1701->size(0) : 0);
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1699,_1701,_1700)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1714) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1714); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1714) { return __mosek_2fusion_2BaseVariable__pick(_1714); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1714) { return __mosek_2fusion_2BaseVariable__pick(_1714); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1714){
  _checked_ptr_1<int> _ptr__1714(_1714 ? _1714->raw() : nullptr, _1714 ? _1714->size(0) : 0);
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  bool _1715 = false;
  int _7488 = (int)0;
  int _7489 = (int)((_1714)->size(0));
  for (int _1716 = _7488; _1716 < _7489; ++_1716)
  {
    {
      if (((_ptr__1714[_1716] < (int)0) || (_ptr__1714[_1716] >= ((*shape)((int)0)))))
      {
        {
          _1715 = true;
        }
      }
      {}
    }
  }
  if (_1715)
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< long long,1 > > _1717;
  _checked_ptr_1<long long> _ptr__1717(_1717 ? _1717->raw() : nullptr,_1717 ? _1717->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1718 = nullptr;
  _checked_ptr_1<long long> _ptr__1718(_1718 ? _1718->raw() : nullptr,_1718 ? _1718->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      std::vector<long long> _7490;
      for (int _1719 = (int)0, _7491 = (int)((_1714)->size(0)); _1719 < _7491 ; ++_1719)
      {
        _7490.push_back(((*nativeidxs)(_ptr__1714[_1719])));
      }
      auto _7492 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7490.size()),_7490.begin(),_7490.end()));
      _1717 = _7492;
      _ptr__1717.update(_1717 ? _1717->raw() : nullptr, _1717 ? _1717->size(0) : 0);
    }
  }
  else
  {
    {
      int _1720 = (int)0;
      int _7493 = (int)0;
      int _7494 = (int)((_1714)->size(0));
      for (int _1721 = _7493; _1721 < _7494; ++_1721)
      {
        {
          if ((::mosek::fusion::p_CommonTools::binarySearch(sparsity,(long long)(_ptr__1714[_1721])) >= (int)0))
          {
            {
              ++ _1720;
            }
          }
          {}
        }
      }
      _1717 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1720)));
      _ptr__1717.update(_1717 ? _1717->raw() : nullptr, _1717 ? _1717->size(0) : 0);
      _1718 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1720)));
      _ptr__1718.update(_1718 ? _1718->raw() : nullptr, _1718 ? _1718->size(0) : 0);
      int _1722 = (int)0;
      int _7495 = (int)0;
      int _7496 = (int)((_1714)->size(0));
      for (int _1723 = _7495; _1723 < _7496; ++_1723)
      {
        {
          int _1724 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,(long long)(_ptr__1714[_1723]));
          if ((_1724 >= (int)0))
          {
            {
              _ptr__1718[_1722] = _1723;
              _ptr__1717[_1722] = ((*nativeidxs)(_1724));
              ++ _1722;
            }
          }
          {}
        }
      }
      if ((_1720 == (int)((_1714)->size(0))))
      {
        {
          _1718 = nullptr;
          _ptr__1718.update(_1718 ? _1718->raw() : nullptr, _1718 ? _1718->size(0) : 0);
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_1714)->size(0)))}),_1718,_1717)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__antidiag(int _1725) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__antidiag(_1725); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::antidiag(int _1725) { return __mosek_2fusion_2BaseVariable__antidiag(_1725); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__antidiag(int _1725) { return __mosek_2fusion_2BaseVariable__antidiag(_1725); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__antidiag(int _1725){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("antidiag() only works on two-dimensional objects"));
    }
  }
  else if(((_1725 >= ((*shape)((int)1))) || ((-_1725) >= ((*shape)((int)2)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Diagonal index out of bounds"));
    }
  }
  {}
  if ((_1725 >= (int)0))
  {
    {
      int _7497;
      bool _7498 = (((*shape)((int)0)) < (((*shape)((int)1)) - _1725));
      if (_7498)
      {
        _7497 = ((*shape)((int)0));
      }
      else
      {
        _7497 = (((*shape)((int)1)) - _1725);
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)(((((*shape)((int)1)) - (int)1) - _1725))}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((-(int)1))}),_7497);
    }
  }
  else
  {
    {
      int _7499;
      bool _7500 = (((*shape)((int)1)) < safe_add( ((*shape)((int)0)),_1725 ));
      if (_7500)
      {
        _7499 = ((*shape)((int)1));
      }
      else
      {
        _7499 = safe_add( ((*shape)((int)0)),_1725 );
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((-_1725)),(int)((((*shape)((int)1)) - (int)1))}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((-(int)1))}),_7499);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__antidiag() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__antidiag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::antidiag() { return __mosek_2fusion_2BaseVariable__antidiag(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__antidiag() { return __mosek_2fusion_2BaseVariable__antidiag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__antidiag(){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("antidiag() only works on two-dimensional objects"));
    }
  }
  {}
  int _7501;
  bool _7502 = (((*shape)((int)0)) < ((*shape)((int)1)));
  if (_7502)
  {
    _7501 = ((*shape)((int)0));
  }
  else
  {
    _7501 = ((*shape)((int)1));
  }
  return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)((((*shape)((int)1)) - (int)1))}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((-(int)1))}),_7501);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__diag(int _1726) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__diag(_1726); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::diag(int _1726) { return __mosek_2fusion_2BaseVariable__diag(_1726); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__diag(int _1726) { return __mosek_2fusion_2BaseVariable__diag(_1726); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__diag(int _1726){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("diag() only works on two-dimensional objects"));
    }
  }
  else if(((_1726 >= ((*shape)((int)1))) || ((-_1726) >= ((*shape)((int)2)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Diagonal index out of bounds"));
    }
  }
  {}
  if ((_1726 >= (int)0))
  {
    {
      int _7503;
      bool _7504 = (((*shape)((int)0)) < (((*shape)((int)1)) - _1726));
      if (_7504)
      {
        _7503 = ((*shape)((int)0));
      }
      else
      {
        _7503 = (((*shape)((int)1)) - _1726);
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)(_1726)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1)}),_7503);
    }
  }
  else
  {
    {
      int _7505;
      bool _7506 = (((*shape)((int)1)) < safe_add( ((*shape)((int)0)),_1726 ));
      if (_7506)
      {
        _7505 = ((*shape)((int)1));
      }
      else
      {
        _7505 = safe_add( ((*shape)((int)0)),_1726 );
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((-_1726)),(int)((int)0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1)}),_7505);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__diag() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__diag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::diag() { return __mosek_2fusion_2BaseVariable__diag(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__diag() { return __mosek_2fusion_2BaseVariable__diag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__diag(){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("diag() only works on two-dimensional objects"));
    }
  }
  {}
  int _7507;
  bool _7508 = (((*shape)((int)0)) < ((*shape)((int)1)));
  if (_7508)
  {
    _7507 = ((*shape)((int)0));
  }
  else
  {
    _7507 = ((*shape)((int)1));
  }
  return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)((int)0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1)}),_7507);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > > _1727,std::shared_ptr< monty::ndarray< int,1 > > _1728,int _1729){
  _checked_ptr_1<int> _ptr__1727(_1727 ? _1727->raw() : nullptr, _1727 ? _1727->size(0) : 0);
  _checked_ptr_1<int> _ptr__1728(_1728 ? _1728->raw() : nullptr, _1728 ? _1728->size(0) : 0);
  int _1730 = (int)((shape)->size(0));
  if (((_1730 != (int)((_1727)->size(0))) || (_1730 != (int)((_1728)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid start or step definition"));
    }
  }
  {}
  int _7509 = (int)0;
  int _7510 = _1730;
  for (int _1731 = _7509; _1731 < _7510; ++_1731)
  {
    {
      if (((_ptr__1727[_1731] < (int)0) || (_ptr__1727[_1731] >= ((*shape)(_1731)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Start element is out of bounds"));
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1732 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1730)));
  _checked_ptr_1<long long> _ptr__1732(_1732 ? _1732->raw() : nullptr,_1732 ? _1732->size(0) : 0);
  _ptr__1732[(_1730 - (int)1)] = (int)1;
  int _7511 = (int)1;
  int _7512 = _1730;
  for (int _1733 = _7511; _1733 < _7512; ++_1733)
  {
    {
      _ptr__1732[((_1730 - _1733) - (int)1)] = safe_mul( _ptr__1732[(_1730 - _1733)],((*shape)((_1730 - _1733))) );
    }
  }
  long long _1734 = (long long)0;
  int _7513 = (int)0;
  int _7514 = (int)((_1728)->size(0));
  for (int _1735 = _7513; _1735 < _7514; ++_1735)
  {
    {
      _1734 += safe_mul( _ptr__1727[_1735],_ptr__1732[_1735] );
    }
  }
  long long _1736 = (long long)0;
  int _7515 = (int)0;
  int _7516 = (int)((_1728)->size(0));
  for (int _1737 = _7515; _1737 < _7516; ++_1737)
  {
    {
      _1736 += safe_mul( _ptr__1728[_1737],_ptr__1732[_1737] );
    }
  }
  if ((NULL == sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1738 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1729)));
      _checked_ptr_1<long long> _ptr__1738(_1738 ? _1738->raw() : nullptr,_1738 ? _1738->size(0) : 0);
      int _7517 = (int)0;
      int _7518 = _1729;
      for (int _1739 = _7517; _1739 < _7518; ++_1739)
      {
        {
          _ptr__1738[_1739] = ((*nativeidxs)(safe_add( _1734,safe_mul( _1736,_1739 ) )));
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1729)}),nullptr,_1738)).as<::mosek::fusion::Variable>();
    }
  }
  else
  {
    {
      int _1740 = (int)0;
      int _7519 = (int)0;
      int _7520 = _1729;
      for (int _1741 = _7519; _1741 < _7520; ++_1741)
      {
        {
          long long _1742 = safe_add( _1734,safe_mul( _1736,_1741 ) );
          int _1743 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1742);
          if ((_1743 >= (int)0))
          {
            {
              ++ _1740;
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1744 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1740)));
      _checked_ptr_1<long long> _ptr__1744(_1744 ? _1744->raw() : nullptr,_1744 ? _1744->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1745 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1740)));
      _checked_ptr_1<long long> _ptr__1745(_1745 ? _1745->raw() : nullptr,_1745 ? _1745->size(0) : 0);
      int _1746 = (int)0;
      int _7521 = (int)0;
      int _7522 = _1729;
      for (int _1747 = _7521; _1747 < _7522; ++_1747)
      {
        {
          _ptr__1744[_1747] = ((*nativeidxs)(safe_add( _1734,safe_mul( _1736,_1747 ) )));
          long long _1748 = safe_add( _1734,safe_mul( _1736,_1747 ) );
          int _1749 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1748);
          if ((_1749 >= (int)0))
          {
            {
              _ptr__1745[_1746] = _1747;
              _ptr__1744[_1746] = ((*nativeidxs)(_1749));
              ++ _1746;
            }
          }
          {}
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1729)}),_1745,_1744)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1750,std::shared_ptr< monty::ndarray< int,1 > > _1751) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__slice(_1750,_1751); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::slice(std::shared_ptr< monty::ndarray< int,1 > > _1750,std::shared_ptr< monty::ndarray< int,1 > > _1751) { return __mosek_2fusion_2BaseVariable__slice(_1750,_1751); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1750,std::shared_ptr< monty::ndarray< int,1 > > _1751) { return __mosek_2fusion_2BaseVariable__slice(_1750,_1751); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1750,std::shared_ptr< monty::ndarray< int,1 > > _1751){
  _checked_ptr_1<int> _ptr__1750(_1750 ? _1750->raw() : nullptr, _1750 ? _1750->size(0) : 0);
  _checked_ptr_1<int> _ptr__1751(_1751 ? _1751->raw() : nullptr, _1751 ? _1751->size(0) : 0);
  if (((int)((_1750)->size(0)) != (int)((_1751)->size(0))))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
    }
  }
  else if(((int)((_1750)->size(0)) != (int)((shape)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  else
  {
    {
      int _7523 = (int)0;
      int _7524 = (int)((shape)->size(0));
      for (int _1752 = _7523; _1752 < _7524; ++_1752)
      {
        {
          if (((_ptr__1750[_1752] < (int)0) || (_ptr__1751[_1752] > ((*shape)(_1752)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
            }
          }
          else if((_ptr__1750[_1752] > _ptr__1751[_1752]))
          {
            {
              throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
            }
          }
          {}
        }
      }
      int _1753 = (int)((shape)->size(0));
      std::vector<int> _7525;
      for (int _1755 = (int)0, _7526 = _1753; _1755 < _7526 ; ++_1755)
      {
        _7525.push_back((_ptr__1751[_1755] - _ptr__1750[_1755]));
      }
      auto _7527 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7525.size()),_7525.begin(),_7525.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _1754 = _7527;
      _checked_ptr_1<int> _ptr__1754(_1754 ? _1754->raw() : nullptr,_1754 ? _1754->size(0) : 0);
      int _1756 = (int)1;
      int _7528 = (int)0;
      int _7529 = _1753;
      for (int _1757 = _7528; _1757 < _7529; ++_1757)
      {
        {
          _1756 *= (_ptr__1751[_1757] - _ptr__1750[_1757]);
        }
      }
      if ((_1756 == (int)0))
      {
        {
          return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
        }
      }
      else if((NULL != sparsity.get()))
      {
        {
          int _1758 = (int)0;
          std::shared_ptr< monty::ndarray< int,1 > > _1759 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1753)));
          _checked_ptr_1<int> _ptr__1759(_1759 ? _1759->raw() : nullptr,_1759 ? _1759->size(0) : 0);
          int _7530 = (int)0;
          int _7531 = (int)((sparsity)->size(0));
          for (int _1760 = _7530; _1760 < _7531; ++_1760)
          {
            {
              long long _1761 = ((*sparsity)(_1760));
              int _7532 = (int)1;
              int _7533 = _1753;
              for (int _1762 = _7532; _1762 < _7533; ++_1762)
              {
                {
                  _ptr__1759[(_1753 - _1762)] = (int)(_1761 % ((*shape)((_1753 - _1762))));
                  _1761 /= ((*shape)((_1753 - _1762)));
                }
              }
              _ptr__1759[(int)0] = (int)_1761;
              int _1763 = (int)0;
              while ( ((_ptr__1759[_1763] >= _ptr__1750[_1763]) && (_ptr__1759[_1763] < _ptr__1751[_1763])) )
              {
                {
                  ++ _1763;
                }
              }
              if ((_1763 == _1753))
              {
                {
                  ++ _1758;
                }
              }
              {}
            }
          }
          int _1764 = (int)0;
          std::shared_ptr< monty::ndarray< long long,1 > > _1765 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1758)));
          _checked_ptr_1<long long> _ptr__1765(_1765 ? _1765->raw() : nullptr,_1765 ? _1765->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1766 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1758)));
          _checked_ptr_1<long long> _ptr__1766(_1766 ? _1766->raw() : nullptr,_1766 ? _1766->size(0) : 0);
          int _7534 = (int)0;
          int _7535 = (int)((sparsity)->size(0));
          for (int _1767 = _7534; _1767 < _7535; ++_1767)
          {
            {
              long long _1768 = ((*sparsity)(_1767));
              int _7536 = (int)1;
              int _7537 = _1753;
              for (int _1769 = _7536; _1769 < _7537; ++_1769)
              {
                {
                  _ptr__1759[(_1753 - _1769)] = (int)(_1768 % ((*shape)((_1753 - _1769))));
                  _1768 /= ((*shape)((_1753 - _1769)));
                }
              }
              _ptr__1759[(int)0] = (int)_1768;
              int _1770 = (int)0;
              while ( ((_ptr__1759[_1770] >= _ptr__1750[_1770]) && (_ptr__1759[_1770] < _ptr__1751[_1770])) )
              {
                {
                  ++ _1770;
                }
              }
              if ((_1770 == _1753))
              {
                {
                  _ptr__1765[_1764] = ((*nativeidxs)(_1767));
                  int _1771 = (int)0;
                  int _7538 = (int)0;
                  int _7539 = _1753;
                  for (int _1772 = _7538; _1772 < _7539; ++_1772)
                  {
                    {
                      _1771 = safe_add( safe_mul( _1771,_ptr__1754[_1772] ),(_ptr__1759[_1772] - _ptr__1750[_1772]) );
                    }
                  }
                  _ptr__1766[_1764] = _1771;
                  ++ _1764;
                }
              }
              {}
            }
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1754,_1766,_1765)).as<::mosek::fusion::Variable>();
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _1773 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1756)));
          _checked_ptr_1<long long> _ptr__1773(_1773 ? _1773->raw() : nullptr,_1773 ? _1773->size(0) : 0);
          {
            std::shared_ptr< monty::ndarray< int,1 > > _1774 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1753)));
            _checked_ptr_1<int> _ptr__1774(_1774 ? _1774->raw() : nullptr,_1774 ? _1774->size(0) : 0);
            _ptr__1774[(_1753 - (int)1)] = (int)1;
            int _7540 = (int)1;
            int _7541 = _1753;
            for (int _1775 = _7540; _1775 < _7541; ++_1775)
            {
              {
                _ptr__1774[((_1753 - _1775) - (int)1)] = safe_mul( _ptr__1774[(_1753 - _1775)],((*shape)((_1753 - _1775))) );
              }
            }
            int _1776 = (int)0;
            int _7542 = (int)0;
            int _7543 = _1753;
            for (int _1777 = _7542; _1777 < _7543; ++_1777)
            {
              {
                _1776 += safe_mul( _ptr__1750[_1777],_ptr__1774[_1777] );
              }
            }
            std::vector<int> _7544;
            for (int _1779 = (int)0, _7545 = _1753; _1779 < _7545 ; ++_1779)
            {
              _7544.push_back(_1776);
            }
            auto _7546 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7544.size()),_7544.begin(),_7544.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _1778 = _7546;
            _checked_ptr_1<int> _ptr__1778(_1778 ? _1778->raw() : nullptr,_1778 ? _1778->size(0) : 0);
            std::vector<int> _7547;
            for (int _1781 = (int)0, _7548 = _1753; _1781 < _7548 ; ++_1781)
            {
              _7547.push_back(_ptr__1750[_1781]);
            }
            auto _7549 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7547.size()),_7547.begin(),_7547.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _1780 = _7549;
            _checked_ptr_1<int> _ptr__1780(_1780 ? _1780->raw() : nullptr,_1780 ? _1780->size(0) : 0);
            int _7550 = (int)0;
            int _7551 = _1756;
            for (int _1782 = _7550; _1782 < _7551; ++_1782)
            {
              {
                _ptr__1773[_1782] = ((*nativeidxs)(_ptr__1778[(_1753 - (int)1)]));
                _ptr__1780[(_1753 - (int)1)] += (int)1;
                _ptr__1778[(_1753 - (int)1)] += _ptr__1774[(_1753 - (int)1)];
                if ((_ptr__1780[(_1753 - (int)1)] >= _ptr__1751[(_1753 - (int)1)]))
                {
                  {
                    int _1783 = (_1753 - (int)1);
                    while ( ((_1783 > (int)0) && (_ptr__1780[_1783] >= _ptr__1751[_1783])) )
                    {
                      {
                        _ptr__1780[_1783] = _ptr__1750[_1783];
                        _ptr__1780[(_1783 - (int)1)] += (int)1;
                        _ptr__1778[(_1783 - (int)1)] += _ptr__1774[(_1783 - (int)1)];
                        -- _1783;
                      }
                    }
                    int _7552 = safe_add( _1783,(int)1 );
                    int _7553 = _1753;
                    for (int _1784 = _7552; _1784 < _7553; ++_1784)
                    {
                      {
                        _ptr__1778[_1784] = _ptr__1778[_1783];
                      }
                    }
                  }
                }
                {}
              }
            }
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1754,nullptr,_1773)).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__slice(int _1785,int _1786) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__slice(_1785,_1786); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::slice(int _1785,int _1786) { return __mosek_2fusion_2BaseVariable__slice(_1785,_1786); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__slice(int _1785,int _1786) { return __mosek_2fusion_2BaseVariable__slice(_1785,_1786); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__slice(int _1785,int _1786){
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  {}
  if (((_1785 == (int)0) && (_1786 == ((*shape)((int)0)))))
  {
    {
      return (::mosek::fusion::BaseVariable::t(_pubthis)).as<::mosek::fusion::Variable>();
    }
  }
  else if(((_1785 < (int)0) || (_1786 > ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
    }
  }
  else if((_1785 > _1786))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
    }
  }
  else if((_1785 == _1786))
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
    }
  }
  else if((NULL != sparsity.get()))
  {
    {
      int _1787 = (_1786 - _1785);
      int _1788 = (int)0;
      int _1789 = ::mosek::fusion::p_CommonTools::binarySearchL(sparsity,(long long)(_1785));
      int _1790 = ::mosek::fusion::p_CommonTools::binarySearchL(sparsity,(long long)(_1786));
      std::vector<long long> _7554;
      for (int _1791 = _1789, _7555 = _1790; _1791 < _7555 ; ++_1791)
      {
        _7554.push_back((((*sparsity)(_1791)) - _1785));
      }
      auto _7556 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7554.size()),_7554.begin(),_7554.end()));
      std::vector<long long> _7557;
      for (int _1792 = _1789, _7558 = _1790; _1792 < _7558 ; ++_1792)
      {
        _7557.push_back(((*nativeidxs)(_1792)));
      }
      auto _7559 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7557.size()),_7557.begin(),_7557.end()));
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1787)}),_7556,_7559)).as<::mosek::fusion::Variable>();
    }
  }
  else
  {
    {
      int _1793 = (_1786 - _1785);
      std::shared_ptr< monty::ndarray< long long,1 > > _1794 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1793)));
      _checked_ptr_1<long long> _ptr__1794(_1794 ? _1794->raw() : nullptr,_1794 ? _1794->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(nativeidxs,_1785,_1794,(int)0,_1793);
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1793)}),nullptr,_1794)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__asExpr() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__asExpr(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseVariable::asExpr() { return __mosek_2fusion_2BaseVariable__asExpr(); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__asExpr() { return __mosek_2fusion_2BaseVariable__asExpr(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__asExpr(){
  return (::mosek::fusion::p_ExprFromVar::_new_ExprFromVar((::mosek::fusion::BaseVariable::t(_pubthis)).as<::mosek::fusion::Variable>())).as<::mosek::fusion::Expression>();
}
int mosek::fusion::BaseVariable :: inst(int _1795,std::shared_ptr< monty::ndarray< long long,1 > > _1796,int _1797,std::shared_ptr< monty::ndarray< long long,1 > > _1798) { return mosek::fusion::p_BaseVariable::_get_impl(this)->inst(_1795,_1796,_1797,_1798); }int mosek::fusion::p_BaseVariable::inst(int _1795,std::shared_ptr< monty::ndarray< long long,1 > > _1796,int _1797,std::shared_ptr< monty::ndarray< long long,1 > > _1798){
  _checked_ptr_1<long long> _ptr__1796(_1796 ? _1796->raw() : nullptr, _1796 ? _1796->size(0) : 0);
  _checked_ptr_1<long long> _ptr__1798(_1798 ? _1798->raw() : nullptr, _1798 ? _1798->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1799 = mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs;
  _checked_ptr_1<long long> _ptr__1799(_1799 ? _1799->raw() : nullptr,_1799 ? _1799->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1800 = mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity;
  _checked_ptr_1<long long> _ptr__1800(_1800 ? _1800->raw() : nullptr,_1800 ? _1800->size(0) : 0);
  if ((NULL == _1800.get()))
  {
    {
      int _7560 = (int)0;
      int _7561 = (int)((_1799)->size(0));
      for (int _1801 = _7560; _1801 < _7561; ++_1801)
      {
        {
          _ptr__1796[safe_add( _1801,_1795 )] = _1801;
          _ptr__1798[safe_add( _1801,_1797 )] = _ptr__1799[_1801];
        }
      }
    }
  }
  else
  {
    {
      int _7562 = (int)0;
      int _7563 = (int)((mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity)->size(0));
      for (int _1802 = _7562; _1802 < _7563; ++_1802)
      {
        {
          _ptr__1796[safe_add( _1795,_1802 )] = _ptr__1800[_1802];
          _ptr__1798[safe_add( _1802,_1797 )] = _ptr__1799[_1802];
        }
      }
    }
  }
  return (int)((mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs)->size(0));
}
int mosek::fusion::BaseVariable :: numInst() { return mosek::fusion::p_BaseVariable::_get_impl(this)->numInst(); }int mosek::fusion::p_BaseVariable::numInst(){
  return (int)((nativeidxs)->size(0));
}
void mosek::fusion::BaseVariable :: inst(int _1803,std::shared_ptr< monty::ndarray< long long,1 > > _1804) { mosek::fusion::p_BaseVariable::_get_impl(this)->inst(_1803,_1804); }void mosek::fusion::p_BaseVariable::inst(int _1803,std::shared_ptr< monty::ndarray< long long,1 > > _1804){
  _checked_ptr_1<long long> _ptr__1804(_1804 ? _1804->raw() : nullptr, _1804 ? _1804->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      int _7564 = (int)0;
      int _7565 = (int)((nativeidxs)->size(0));
      for (int _1805 = _7564; _1805 < _7565; ++_1805)
      {
        {
          _ptr__1804[safe_add( _1803,_1805 )] = ((*nativeidxs)(_1805));
        }
      }
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _1806 = _pubthis->getShape();
      _checked_ptr_1<int> _ptr__1806(_1806 ? _1806->raw() : nullptr,_1806 ? _1806->size(0) : 0);
      int _1807 = (int)1;
      int _7566 = (int)0;
      int _7567 = (int)((_1806)->size(0));
      for (int _1808 = _7566; _1808 < _7567; ++_1808)
      {
        {
          _1807 *= _ptr__1806[_1808];
        }
      }
      int _7568 = (int)0;
      int _7569 = _1807;
      for (int _1809 = _7568; _1809 < _7569; ++_1809)
      {
        {
          _ptr__1804[safe_add( _1803,_1809 )] = (int)0;
        }
      }
      int _7570 = (int)0;
      int _7571 = (int)((sparsity)->size(0));
      for (int _1810 = _7570; _1810 < _7571; ++_1810)
      {
        {
          _ptr__1804[safe_add( _1803,((*sparsity)(_1810)) )] = ((*nativeidxs)(_1810));
        }
      }
    }
  }
}
void mosek::fusion::BaseVariable :: set_values(std::shared_ptr< monty::ndarray< double,1 > > _1811,bool _1812) { mosek::fusion::p_BaseVariable::_get_impl(this)->set_values(_1811,_1812); }void mosek::fusion::p_BaseVariable::set_values(std::shared_ptr< monty::ndarray< double,1 > > _1811,bool _1812){
  _checked_ptr_1<double> _ptr__1811(_1811 ? _1811->raw() : nullptr, _1811 ? _1811->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      _pubthis->__mosek_2fusion_2BaseVariable__getModel()->setVariableValues(_1812,nativeidxs,_1811);
    }
  }
  else
  {
    {
      int _1813 = (int)1;
      int _7572 = (int)0;
      int _7573 = (int)((shape)->size(0));
      for (int _1814 = _7572; _1814 < _7573; ++_1814)
      {
        {
          _1813 *= ((*shape)(_1814));
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1815 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1813)));
      _checked_ptr_1<long long> _ptr__1815(_1815 ? _1815->raw() : nullptr,_1815 ? _1815->size(0) : 0);
      int _7574 = (int)0;
      int _7575 = (int)((nativeidxs)->size(0));
      for (int _1816 = _7574; _1816 < _7575; ++_1816)
      {
        {
          _ptr__1815[((*sparsity)(_1816))] = ((*nativeidxs)(_1816));
        }
      }
      _pubthis->__mosek_2fusion_2BaseVariable__getModel()->setVariableValues(_1812,_1815,_1811);
    }
  }
}
void mosek::fusion::p_BaseVariable::dual_lu(int _1817,std::shared_ptr< monty::ndarray< double,1 > > _1818,bool _1819){
  _checked_ptr_1<double> _ptr__1818(_1818 ? _1818->raw() : nullptr, _1818 ? _1818->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      model->getVariableDuals(_1819,nativeidxs,_1818,_1817);
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1820 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<long long> _ptr__1820(_1820 ? _1820->raw() : nullptr,_1820 ? _1820->size(0) : 0);
      int _7576 = (int)0;
      int _7577 = (int)((sparsity)->size(0));
      for (int _1821 = _7576; _1821 < _7577; ++_1821)
      {
        {
          _ptr__1820[((*sparsity)(_1821))] = ((*nativeidxs)(_1821));
        }
      }
      model->getVariableDuals(_1819,_1820,_1818,_1817);
    }
  }
}
void mosek::fusion::BaseVariable :: values(int _1822,std::shared_ptr< monty::ndarray< double,1 > > _1823,bool _1824) { mosek::fusion::p_BaseVariable::_get_impl(this)->values(_1822,_1823,_1824); }void mosek::fusion::p_BaseVariable::values(int _1822,std::shared_ptr< monty::ndarray< double,1 > > _1823,bool _1824){
  _checked_ptr_1<double> _ptr__1823(_1823 ? _1823->raw() : nullptr, _1823 ? _1823->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      model->getVariableValues(_1824,nativeidxs,_1823,_1822);
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1825 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<long long> _ptr__1825(_1825 ? _1825->raw() : nullptr,_1825 ? _1825->size(0) : 0);
      int _7578 = (int)0;
      int _7579 = (int)((sparsity)->size(0));
      for (int _1826 = _7578; _1826 < _7579; ++_1826)
      {
        {
          _ptr__1825[((*sparsity)(_1826))] = ((*nativeidxs)(_1826));
        }
      }
      model->getVariableValues(_1824,_1825,_1823,_1822);
    }
  }
}
void mosek::fusion::BaseVariable :: make_continuous() { mosek::fusion::p_BaseVariable::_get_impl(this)->make_continuous(); }void mosek::fusion::p_BaseVariable::make_continuous(){
  mosek::fusion::p_Model::_get_impl(_pubthis->__mosek_2fusion_2BaseVariable__getModel().get())->make_continuous(nativeidxs);
}
void mosek::fusion::BaseVariable :: make_integer() { mosek::fusion::p_BaseVariable::_get_impl(this)->make_integer(); }void mosek::fusion::p_BaseVariable::make_integer(){
  mosek::fusion::p_Model::_get_impl(_pubthis->__mosek_2fusion_2BaseVariable__getModel().get())->make_integer(nativeidxs);
}
void mosek::fusion::p_BaseVariable::destroy(){sparsity.reset();nativeidxs.reset();model.reset();shape.reset();}void mosek::fusion::BaseVariable::destroy() { mosek::fusion::p_BaseVariable::_get_impl(this)->destroy(); }monty::rc_ptr< mosek::fusion::Model > mosek::fusion::Variable::getModel() { return __mosek_2fusion_2Variable__getModel(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::reshape(int _1834,int _1835,int _1836) { return __mosek_2fusion_2Variable__reshape(_1834,_1835,_1836); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::reshape(int _1837,int _1838) { return __mosek_2fusion_2Variable__reshape(_1837,_1838); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::reshape(int _1839) { return __mosek_2fusion_2Variable__reshape(_1839); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::reshape(std::shared_ptr< monty::ndarray< int,1 > > _1840) { return __mosek_2fusion_2Variable__reshape(_1840); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::transpose() { return __mosek_2fusion_2Variable__transpose(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1846,std::shared_ptr< monty::ndarray< int,1 > > _1847,std::shared_ptr< monty::ndarray< int,1 > > _1848) { return __mosek_2fusion_2Variable__pick(_1846,_1847,_1848); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1849,std::shared_ptr< monty::ndarray< int,1 > > _1850) { return __mosek_2fusion_2Variable__pick(_1849,_1850); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,2 > > _1851) { return __mosek_2fusion_2Variable__pick(_1851); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,2 > > _1851) { return __mosek_2fusion_2Variable__pick(_1851); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,1 > > _1852) { return __mosek_2fusion_2Variable__pick(_1852); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1852) { return __mosek_2fusion_2Variable__pick(_1852); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::antidiag() { return __mosek_2fusion_2Variable__antidiag(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::antidiag(int _1853) { return __mosek_2fusion_2Variable__antidiag(_1853); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::diag() { return __mosek_2fusion_2Variable__diag(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::diag(int _1854) { return __mosek_2fusion_2Variable__diag(_1854); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__index(std::shared_ptr< monty::ndarray< int,1 > > _1855) { return __mosek_2fusion_2Variable__index(_1855); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(std::shared_ptr< monty::ndarray< int,1 > > _1855) { return __mosek_2fusion_2Variable__index(_1855); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(int _1856,int _1857,int _1858) { return __mosek_2fusion_2Variable__index(_1856,_1857,_1858); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(int _1859,int _1860) { return __mosek_2fusion_2Variable__index(_1859,_1860); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__index(int _1861) { return __mosek_2fusion_2Variable__index(_1861); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(int _1861) { return __mosek_2fusion_2Variable__index(_1861); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__slice(std::shared_ptr< monty::ndarray< int,1 > > _1862,std::shared_ptr< monty::ndarray< int,1 > > _1863) { return __mosek_2fusion_2Variable__slice(_1862,_1863); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::slice(std::shared_ptr< monty::ndarray< int,1 > > _1862,std::shared_ptr< monty::ndarray< int,1 > > _1863) { return __mosek_2fusion_2Variable__slice(_1862,_1863); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__slice(int _1864,int _1865) { return __mosek_2fusion_2Variable__slice(_1864,_1865); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::slice(int _1864,int _1865) { return __mosek_2fusion_2Variable__slice(_1864,_1865); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::asExpr() { return __mosek_2fusion_2Variable__asExpr(); }
mosek::fusion::Var::Var(mosek::fusion::p_Var *_impl) : _impl(_impl) { /*std::cout << "Var() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Var::~Var() { delete _impl; _impl = nullptr; }mosek::fusion::p_Var::p_Var  (::mosek::fusion::Var * _pubthis) :     _pubthis(_pubthis){}monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::empty  ( std::shared_ptr< monty::ndarray< int,1 > > _1866) { return mosek::fusion::p_Var::empty(_1866); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::empty(std::shared_ptr< monty::ndarray< int,1 > > _1866){
  _checked_ptr_1<int> _ptr__1866(_1866 ? _1866->raw() : nullptr, _1866 ? _1866->size(0) : 0);
  int _7580 = (int)0;
  int _7581 = (int)((_1866)->size(0));
  for (int _1867 = _7580; _1867 < _7581; ++_1867)
  {
    {
      if ((_ptr__1866[_1867] < (int)0))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid shape"));
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_1866)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::compress  ( monty::rc_ptr< ::mosek::fusion::Variable > _1868) { return mosek::fusion::p_Var::compress(_1868); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::compress(monty::rc_ptr< ::mosek::fusion::Variable > _1868){
  std::shared_ptr< monty::ndarray< int,1 > > _1869 = _1868->getShape();
  _checked_ptr_1<int> _ptr__1869(_1869 ? _1869->raw() : nullptr,_1869 ? _1869->size(0) : 0);
  int _1870 = (int)((_1869)->size(0));
  int _1871 = (int)0;
  int _7582 = (int)0;
  int _7583 = _1870;
  for (int _1872 = _7582; _1872 < _7583; ++_1872)
  {
    {
      if ((_ptr__1869[_1872] != (int)1))
      {
        {
          ++ _1871;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1873 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1871)));
  _checked_ptr_1<int> _ptr__1873(_1873 ? _1873->raw() : nullptr,_1873 ? _1873->size(0) : 0);
  {
    int _1874 = (int)0;
    int _7584 = (int)0;
    int _7585 = _1870;
    for (int _1875 = _7584; _1875 < _7585; ++_1875)
    {
      {
        if ((_ptr__1869[_1875] != (int)1))
        {
          {
            _ptr__1873[_1874] = _ptr__1869[_1875];
            ++ _1874;
          }
        }
        {}
      }
    }
  }
  return ::mosek::fusion::p_Var::reshape(_1868,_1873);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::reshape  ( monty::rc_ptr< ::mosek::fusion::Variable > _1876,    int _1877) { return mosek::fusion::p_Var::reshape(_1876,_1877); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1876,int _1877){
  return ::mosek::fusion::p_Var::reshape(_1876,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1877)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::reshape  ( monty::rc_ptr< ::mosek::fusion::Variable > _1878,    int _1879,    int _1880) { return mosek::fusion::p_Var::reshape(_1878,_1879,_1880); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1878,int _1879,int _1880){
  return ::mosek::fusion::p_Var::reshape(_1878,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1879),(int)(_1880)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::flatten  ( monty::rc_ptr< ::mosek::fusion::Variable > _1881) { return mosek::fusion::p_Var::flatten(_1881); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::flatten(monty::rc_ptr< ::mosek::fusion::Variable > _1881){
  return ::mosek::fusion::p_Var::reshape(_1881,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)::mosek::fusion::p_Set::size(_1881->getShape()))}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::reshape  ( monty::rc_ptr< ::mosek::fusion::Variable > _1882,    std::shared_ptr< monty::ndarray< int,1 > > _1883) { return mosek::fusion::p_Var::reshape(_1882,_1883); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1882,std::shared_ptr< monty::ndarray< int,1 > > _1883){
  _checked_ptr_1<int> _ptr__1883(_1883 ? _1883->raw() : nullptr, _1883 ? _1883->size(0) : 0);
  return _1882->__mosek_2fusion_2Variable__reshape(_1883);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::index_permute_(monty::rc_ptr< ::mosek::fusion::Variable > _1884,std::shared_ptr< monty::ndarray< int,1 > > _1885){
  _checked_ptr_1<int> _ptr__1885(_1885 ? _1885->raw() : nullptr, _1885 ? _1885->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1886;
  _checked_ptr_1<long long> _ptr__1886(_1886 ? _1886->raw() : nullptr,_1886 ? _1886->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1887;
  _checked_ptr_1<long long> _ptr__1887(_1887 ? _1887->raw() : nullptr,_1887 ? _1887->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1888 = _1884->getShape();
  _checked_ptr_1<int> _ptr__1888(_1888 ? _1888->raw() : nullptr,_1888 ? _1888->size(0) : 0);
  int _1889 = (int)((_1888)->size(0));
  int _1890 = (int)1;
  int _7586 = (int)0;
  int _7587 = _1889;
  for (int _1891 = _7586; _1891 < _7587; ++_1891)
  {
    {
      _1890 *= _ptr__1888[_1891];
    }
  }
  int _1892 = _1884->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _1893 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1889)));
  _checked_ptr_1<long long> _ptr__1893(_1893 ? _1893->raw() : nullptr,_1893 ? _1893->size(0) : 0);
  _ptr__1893[(_1889 - (int)1)] = (int)1;
  int _7588 = (int)1;
  int _7589 = _1889;
  for (int _1894 = _7588; _1894 < _7589; ++_1894)
  {
    {
      _ptr__1893[((_1889 - _1894) - (int)1)] = safe_mul( _ptr__1893[(_1889 - _1894)],_ptr__1888[_ptr__1885[(_1889 - _1894)]] );
    }
  }
  if ((_1892 < _1890))
  {
    {
      _1886 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1892)));
      _ptr__1886.update(_1886 ? _1886->raw() : nullptr, _1886 ? _1886->size(0) : 0);
      _1887 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1892)));
      _ptr__1887.update(_1887 ? _1887->raw() : nullptr, _1887 ? _1887->size(0) : 0);
      _1884->inst((int)0,_1886,(int)0,_1887);
    }
  }
  else
  {
    {
      _1886 = nullptr;
      _ptr__1886.update(_1886 ? _1886->raw() : nullptr, _1886 ? _1886->size(0) : 0);
      _1887 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1892)));
      _ptr__1887.update(_1887 ? _1887->raw() : nullptr, _1887 ? _1887->size(0) : 0);
      _1884->inst((int)0,_1887);
    }
  }
  if ((NULL == _1886.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1895 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1892)));
      _checked_ptr_1<long long> _ptr__1895(_1895 ? _1895->raw() : nullptr,_1895 ? _1895->size(0) : 0);
      {
        std::shared_ptr< monty::ndarray< int,1 > > _1896 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1889)));
        _checked_ptr_1<int> _ptr__1896(_1896 ? _1896->raw() : nullptr,_1896 ? _1896->size(0) : 0);
        int _7590 = (int)0;
        int _7591 = _1892;
        for (int _1897 = _7590; _1897 < _7591; ++_1897)
        {
          {
            int _1898 = _1897;
            int _7592 = (int)0;
            int _7593 = _1889;
            for (int _1899 = _7592; _1899 < _7593; ++_1899)
            {
              {
                _ptr__1896[((_1889 - _1897) - (int)1)] = (_1898 % _ptr__1888[((_1889 - _1897) - (int)1)]);
                _1898 /= _ptr__1888[((_1889 - _1897) - (int)1)];
              }
            }
            int _1900 = (int)0;
            int _7594 = (int)0;
            int _7595 = _1889;
            for (int _1901 = _7594; _1901 < _7595; ++_1901)
            {
              {
                _1900 += (int)safe_mul( _ptr__1896[_ptr__1885[_1901]],_ptr__1893[_1901] );
              }
            }
            _ptr__1895[_1900] = _ptr__1887[_1897];
          }
        }
      }
      _1887 = _1895;
      _ptr__1887.update(_1887 ? _1887->raw() : nullptr, _1887 ? _1887->size(0) : 0);
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1902 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1892)));
      _checked_ptr_1<long long> _ptr__1902(_1902 ? _1902->raw() : nullptr,_1902 ? _1902->size(0) : 0);
      {
        std::shared_ptr< monty::ndarray< int,1 > > _1903 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1889)));
        _checked_ptr_1<int> _ptr__1903(_1903 ? _1903->raw() : nullptr,_1903 ? _1903->size(0) : 0);
        int _7596 = (int)0;
        int _7597 = _1892;
        for (int _1904 = _7596; _1904 < _7597; ++_1904)
        {
          {
            int _1905 = _1904;
            int _7598 = (int)0;
            int _7599 = _1889;
            for (int _1906 = _7598; _1906 < _7599; ++_1906)
            {
              {
                _ptr__1903[((_1889 - _1904) - (int)1)] = (_1905 % _ptr__1888[((_1889 - _1904) - (int)1)]);
                _1905 /= _ptr__1888[((_1889 - _1904) - (int)1)];
              }
            }
            int _1907 = (int)0;
            int _7600 = (int)0;
            int _7601 = _1889;
            for (int _1908 = _7600; _1908 < _7601; ++_1908)
            {
              {
                _1907 += (int)safe_mul( _ptr__1903[_ptr__1885[_1908]],_ptr__1893[_1908] );
              }
            }
            _ptr__1902[_1904] = _1907;
          }
        }
      }
      std::vector<long long> _7602;
      for (int _1910 = (int)0, _7603 = _1892; _1910 < _7603 ; ++_1910)
      {
        _7602.push_back(_1910);
      }
      auto _7604 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7602.size()),_7602.begin(),_7602.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1909 = _7604;
      _checked_ptr_1<long long> _ptr__1909(_1909 ? _1909->raw() : nullptr,_1909 ? _1909->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1909,_1902,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1892));
      std::vector<long long> _7605;
      for (int _1911 = (int)0, _7606 = _1892; _1911 < _7606 ; ++_1911)
      {
        _7605.push_back(_ptr__1886[_ptr__1909[_1911]]);
      }
      auto _7607 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7605.size()),_7605.begin(),_7605.end()));
      _1886 = _7607;
      _ptr__1886.update(_1886 ? _1886->raw() : nullptr, _1886 ? _1886->size(0) : 0);
      std::vector<long long> _7608;
      for (int _1912 = (int)0, _7609 = _1892; _1912 < _7609 ; ++_1912)
      {
        _7608.push_back(_ptr__1887[_ptr__1909[_1912]]);
      }
      auto _7610 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7608.size()),_7608.begin(),_7608.end()));
      _1887 = _7610;
      _ptr__1887.update(_1887 ? _1887->raw() : nullptr, _1887 ? _1887->size(0) : 0);
    }
  }
  std::vector<int> _7611;
  for (int _1913 = (int)0, _7612 = _1889; _1913 < _7612 ; ++_1913)
  {
    _7611.push_back(_ptr__1888[_ptr__1885[_1913]]);
  }
  auto _7613 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7611.size()),_7611.begin(),_7611.end()));
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1884->__mosek_2fusion_2Variable__getModel(),_7613,_1886,_1887)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hrepeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1914,    int _1915) { return mosek::fusion::p_Var::hrepeat(_1914,_1915); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1914,int _1915){
  return ::mosek::fusion::p_Var::drepeat(_1914,(int)1,_1915);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vrepeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1916,    int _1917) { return mosek::fusion::p_Var::vrepeat(_1916,_1917); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1916,int _1917){
  return ::mosek::fusion::p_Var::drepeat(_1916,(int)0,_1917);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::repeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1918,    int _1919) { return mosek::fusion::p_Var::repeat(_1918,_1919); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::repeat(monty::rc_ptr< ::mosek::fusion::Variable > _1918,int _1919){
  return ::mosek::fusion::p_Var::drepeat(_1918,(int)0,_1919);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::repeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1920,    int _1921,    int _1922) { return mosek::fusion::p_Var::repeat(_1920,_1921,_1922); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::repeat(monty::rc_ptr< ::mosek::fusion::Variable > _1920,int _1921,int _1922){
  return ::mosek::fusion::p_Var::drepeat(_1920,_1921,_1922);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::drepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1923,int _1924,int _1925){
  if ((_1925 < (int)0))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Cannot repeat less than 0 times"));
    }
  }
  else if((_1925 == (int)0))
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
    }
  }
  else if((_1925 == (int)1))
  {
    {
      return _1923;
    }
  }
  else
  {
    {
      monty::rc_ptr< ::mosek::fusion::Model > _1926 = _1923->__mosek_2fusion_2Variable__getModel();
      std::shared_ptr< monty::ndarray< int,1 > > _1927 = _1923->getShape();
      _checked_ptr_1<int> _ptr__1927(_1927 ? _1927->raw() : nullptr,_1927 ? _1927->size(0) : 0);
      int _1928 = (int)((_1927)->size(0));
      if (((_1924 < (int)0) || (_1924 > _1928)))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
        }
      }
      {}
      long long _1929 = ::mosek::fusion::p_Set::size(_1927);
      int _1930 = _1923->numInst();
      int _1931 = safe_mul( _1930,_1925 );
      int _1932 = (int)1;
      int _7614 = (int)0;
      int _7615 = _1924;
      for (int _1933 = _7614; _1933 < _7615; ++_1933)
      {
        {
          _1932 *= _ptr__1927[_1933];
        }
      }
      int _7616;
      bool _7617 = (_1924 < _1928);
      if (_7617)
      {
        _7616 = _ptr__1927[_1924];
      }
      else
      {
        _7616 = (int)1;
      }
      int _1934 = _7616;
      int _1935 = safe_mul( _1934,_1925 );
      int _1936 = (int)1;
      int _7618 = safe_add( _1924,(int)1 );
      int _7619 = _1928;
      for (int _1937 = _7618; _1937 < _7619; ++_1937)
      {
        {
          _1936 *= _ptr__1927[_1937];
        }
      }
      int _7620;
      bool _7621 = (_1924 < _1928);
      if (_7621)
      {
        _7620 = _1928;
      }
      else
      {
        _7620 = safe_add( _1924,(int)1 );
      }
      int _1938 = _7620;
      std::shared_ptr< monty::ndarray< int,1 > > _1939 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1938)));
      _checked_ptr_1<int> _ptr__1939(_1939 ? _1939->raw() : nullptr,_1939 ? _1939->size(0) : 0);
      int _7622 = (int)0;
      int _7623 = _1928;
      for (int _1940 = _7622; _1940 < _7623; ++_1940)
      {
        {
          _ptr__1939[_1940] = _ptr__1927[_1940];
        }
      }
      int _7624 = _1928;
      int _7625 = _1938;
      for (int _1941 = _7624; _1941 < _7625; ++_1941)
      {
        {
          _ptr__1939[_1941] = (int)1;
        }
      }
      _ptr__1939[_1924] = _1935;
      if ((_1930 < _1929))
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _1942 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1930)));
          _checked_ptr_1<long long> _ptr__1942(_1942 ? _1942->raw() : nullptr,_1942 ? _1942->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1943 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1930)));
          _checked_ptr_1<long long> _ptr__1943(_1943 ? _1943->raw() : nullptr,_1943 ? _1943->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1944 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1931)));
          _checked_ptr_1<long long> _ptr__1944(_1944 ? _1944->raw() : nullptr,_1944 ? _1944->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1945 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1931)));
          _checked_ptr_1<long long> _ptr__1945(_1945 ? _1945->raw() : nullptr,_1945 ? _1945->size(0) : 0);
          _1923->inst((int)0,_1943,(int)0,_1942);
          {
            int _1946 = safe_mul( _1935,_1936 );
            int _1947 = safe_mul( _1934,_1936 );
            int _1948 = _1936;
            if ((_1924 == (int)0))
            {
              {
                int _1949 = (int)0;
                int _7626 = (int)0;
                int _7627 = _1925;
                for (int _1950 = _7626; _1950 < _7627; ++_1950)
                {
                  {
                    int _7628 = (int)0;
                    int _7629 = _1930;
                    for (int _1951 = _7628; _1951 < _7629; ++_1951)
                    {
                      {
                        _ptr__1945[_1949] = safe_add( _ptr__1943[_1951],safe_mul( _1950,_1929 ) );
                        _ptr__1944[_1949] = _ptr__1942[_1951];
                        ++ _1949;
                      }
                    }
                  }
                }
                return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1926,_1939,_1945,_1944)).as<::mosek::fusion::Variable>();
              }
            }
            else if((_1924 >= _1928))
            {
              {
                int _1952 = (int)0;
                int _7630 = (int)0;
                int _7631 = _1930;
                for (int _1953 = _7630; _1953 < _7631; ++_1953)
                {
                  {
                    int _7632 = (int)0;
                    int _7633 = _1925;
                    for (int _1954 = _7632; _1954 < _7633; ++_1954)
                    {
                      {
                        _ptr__1945[_1952] = safe_add( safe_mul( _ptr__1943[_1953],_1925 ),_1954 );
                        _ptr__1944[_1952] = _ptr__1942[_1953];
                        ++ _1952;
                      }
                    }
                  }
                }
                return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1926,_1939,_1945,_1944)).as<::mosek::fusion::Variable>();
              }
            }
            else
            {
              {
                int _1955 = (int)0;
                int _7634 = (int)0;
                int _7635 = _1930;
                for (int _1956 = _7634; _1956 < _7635; ++_1956)
                {
                  {
                    long long _1957 = (_ptr__1943[_1956] / _1947);
                    long long _1958 = ((_ptr__1943[_1956] / _1948) % _1934);
                    long long _1959 = (_ptr__1943[_1956] % _1936);
                    int _7636 = (int)0;
                    int _7637 = _1925;
                    for (int _1960 = _7636; _1960 < _7637; ++_1960)
                    {
                      {
                        _ptr__1945[_1955] = safe_add( safe_add( safe_mul( _1957,_1946 ),safe_mul( safe_add( _1958,safe_mul( _1934,_1960 ) ),_1936 ) ),_1959 );
                        _ptr__1944[_1955] = _ptr__1942[_1956];
                        ++ _1955;
                      }
                    }
                  }
                }
                int _1961 = (int)1;
                int _7638 = (int)0;
                int _7639 = _1938;
                for (int _1962 = _7638; _1962 < _7639; ++_1962)
                {
                  {
                    if ((_1961 < _ptr__1939[_1962]))
                    {
                      {
                        _1961 = _ptr__1939[_1962];
                      }
                    }
                    {}
                  }
                }
                std::shared_ptr< monty::ndarray< int,1 > > _1963 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1931)));
                _checked_ptr_1<int> _ptr__1963(_1963 ? _1963->raw() : nullptr,_1963 ? _1963->size(0) : 0);
                std::shared_ptr< monty::ndarray< int,1 > > _1964 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1931)));
                _checked_ptr_1<int> _ptr__1964(_1964 ? _1964->raw() : nullptr,_1964 ? _1964->size(0) : 0);
                {
                  std::shared_ptr< monty::ndarray< int,1 > > _1965 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _1961,(int)1 ))));
                  _checked_ptr_1<int> _ptr__1965(_1965 ? _1965->raw() : nullptr,_1965 ? _1965->size(0) : 0);
                  std::shared_ptr< monty::ndarray< long long,1 > > _1966 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1938)));
                  _checked_ptr_1<long long> _ptr__1966(_1966 ? _1966->raw() : nullptr,_1966 ? _1966->size(0) : 0);
                  _ptr__1966[(_1938 - (int)1)] = (int)1;
                  int _7640 = (int)1;
                  int _7641 = _1938;
                  for (int _1967 = _7640; _1967 < _7641; ++_1967)
                  {
                    {
                      _ptr__1966[((_1938 - _1967) - (int)1)] = safe_mul( _ptr__1966[(_1938 - _1967)],_ptr__1939[(_1938 - _1967)] );
                    }
                  }
                  int _7642 = (int)0;
                  int _7643 = _1931;
                  for (int _1968 = _7642; _1968 < _7643; ++_1968)
                  {
                    {
                      _ptr__1963[_1968] = _1968;
                    }
                  }
                  int _7644 = (int)0;
                  int _7645 = _1938;
                  for (int _1969 = _7644; _1969 < _7645; ++_1969)
                  {
                    {
                      int _1970 = ((_1938 - _1969) - (int)1);
                      int _7646 = (int)0;
                      int _7647 = safe_add( _ptr__1939[_1970],(int)1 );
                      for (int _1971 = _7646; _1971 < _7647; ++_1971)
                      {
                        {
                          _ptr__1965[_1971] = (int)0;
                        }
                      }
                      int _7648 = (int)0;
                      int _7649 = _1931;
                      for (int _1972 = _7648; _1972 < _7649; ++_1972)
                      {
                        {
                          ++ _ptr__1965[safe_add( ((_ptr__1945[_1972] / _ptr__1966[_1970]) % _ptr__1939[_1970]),(int)1 )];
                        }
                      }
                      int _7650 = (int)0;
                      int _7651 = _ptr__1939[_1970];
                      for (int _1973 = _7650; _1973 < _7651; ++_1973)
                      {
                        {
                          _ptr__1965[safe_add( _1973,(int)1 )] += _ptr__1965[_1973];
                        }
                      }
                      int _7652 = (int)0;
                      int _7653 = _1931;
                      for (int _1974 = _7652; _1974 < _7653; ++_1974)
                      {
                        {
                          int _1975 = _ptr__1963[_1974];
                          long long _1976 = ((_ptr__1945[_1975] / _ptr__1966[_1970]) % _ptr__1939[_1970]);
                          _ptr__1964[_ptr__1965[_1976]] = _1975;
                          ++ _ptr__1965[_1976];
                        }
                      }
                      std::shared_ptr< monty::ndarray< int,1 > > _1977 = _1963;
                      _checked_ptr_1<int> _ptr__1977(_1977 ? _1977->raw() : nullptr,_1977 ? _1977->size(0) : 0);
                      _1963 = _1964;
                      _ptr__1963.update(_1963 ? _1963->raw() : nullptr, _1963 ? _1963->size(0) : 0);
                      _1964 = _1977;
                      _ptr__1964.update(_1964 ? _1964->raw() : nullptr, _1964 ? _1964->size(0) : 0);
                    }
                  }
                }
                std::vector<long long> _7654;
                for (int _1978 = (int)0, _7655 = _1931; _1978 < _7655 ; ++_1978)
                {
                  _7654.push_back(_ptr__1945[_ptr__1963[_1978]]);
                }
                auto _7656 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7654.size()),_7654.begin(),_7654.end()));
                std::vector<long long> _7657;
                for (int _1979 = (int)0, _7658 = _1931; _1979 < _7658 ; ++_1979)
                {
                  _7657.push_back(_ptr__1944[_ptr__1963[_1979]]);
                }
                auto _7659 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7657.size()),_7657.begin(),_7657.end()));
                return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1926,_1939,_7656,_7659)).as<::mosek::fusion::Variable>();
              }
            }
          }
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _1980 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1930)));
          _checked_ptr_1<long long> _ptr__1980(_1980 ? _1980->raw() : nullptr,_1980 ? _1980->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1981 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1930,_1925 ))));
          _checked_ptr_1<long long> _ptr__1981(_1981 ? _1981->raw() : nullptr,_1981 ? _1981->size(0) : 0);
          _1923->inst((int)0,_1980);
          int _1982 = safe_mul( _1935,_1936 );
          int _1983 = _1936;
          int _1984 = (int)0;
          int _7660 = (int)0;
          int _7661 = _1932;
          for (int _1985 = _7660; _1985 < _7661; ++_1985)
          {
            {
              int _7662 = (int)0;
              int _7663 = _1934;
              for (int _1986 = _7662; _1986 < _7663; ++_1986)
              {
                {
                  int _7664 = (int)0;
                  int _7665 = _1936;
                  for (int _1987 = _7664; _1987 < _7665; ++_1987)
                  {
                    {
                      int _7666 = (int)0;
                      int _7667 = _1925;
                      for (int _1988 = _7666; _1988 < _7667; ++_1988)
                      {
                        {
                          _ptr__1981[safe_add( safe_add( safe_mul( _1985,_1982 ),safe_mul( safe_add( _1986,safe_mul( _1988,_1934 ) ),_1983 ) ),_1987 )] = _ptr__1980[_1984];
                        }
                      }
                      ++ _1984;
                    }
                  }
                }
              }
            }
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1926,_1939,nullptr,_1981)).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _1989) { return mosek::fusion::p_Var::stack(_1989); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _1989){
  std::vector<monty::rc_ptr< ::mosek::fusion::Variable >> _7668;
  for (int _1990 = (int)0, _7669 = (int)((_1989)->size(0)); _1990 < _7669 ; ++_1990)
  {
    _7668.push_back(::mosek::fusion::p_Var::dstack(((*_1989)(_1990)),(int)1));
  }
  auto _7670 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(_7668.size()),_7668.begin(),_7668.end()));
  return ::mosek::fusion::p_Var::dstack(_7670,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1991,    monty::rc_ptr< ::mosek::fusion::Variable > _1992,    monty::rc_ptr< ::mosek::fusion::Variable > _1993) { return mosek::fusion::p_Var::vstack(_1991,_1992,_1993); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vstack(monty::rc_ptr< ::mosek::fusion::Variable > _1991,monty::rc_ptr< ::mosek::fusion::Variable > _1992,monty::rc_ptr< ::mosek::fusion::Variable > _1993){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1991.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1992.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1993.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1994,    monty::rc_ptr< ::mosek::fusion::Variable > _1995) { return mosek::fusion::p_Var::vstack(_1994,_1995); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vstack(monty::rc_ptr< ::mosek::fusion::Variable > _1994,monty::rc_ptr< ::mosek::fusion::Variable > _1995){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1994.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1995.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1996) { return mosek::fusion::p_Var::vstack(_1996); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1996){
  return ::mosek::fusion::p_Var::dstack(_1996,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1997,    monty::rc_ptr< ::mosek::fusion::Variable > _1998,    monty::rc_ptr< ::mosek::fusion::Variable > _1999) { return mosek::fusion::p_Var::hstack(_1997,_1998,_1999); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hstack(monty::rc_ptr< ::mosek::fusion::Variable > _1997,monty::rc_ptr< ::mosek::fusion::Variable > _1998,monty::rc_ptr< ::mosek::fusion::Variable > _1999){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1997.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1998.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1999.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _2000,    monty::rc_ptr< ::mosek::fusion::Variable > _2001) { return mosek::fusion::p_Var::hstack(_2000,_2001); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hstack(monty::rc_ptr< ::mosek::fusion::Variable > _2000,monty::rc_ptr< ::mosek::fusion::Variable > _2001){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_2000.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_2001.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2002) { return mosek::fusion::p_Var::hstack(_2002); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2002){
  return ::mosek::fusion::p_Var::dstack(_2002,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( monty::rc_ptr< ::mosek::fusion::Variable > _2003,    monty::rc_ptr< ::mosek::fusion::Variable > _2004,    monty::rc_ptr< ::mosek::fusion::Variable > _2005,    int _2006) { return mosek::fusion::p_Var::stack(_2003,_2004,_2005,_2006); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(monty::rc_ptr< ::mosek::fusion::Variable > _2003,monty::rc_ptr< ::mosek::fusion::Variable > _2004,monty::rc_ptr< ::mosek::fusion::Variable > _2005,int _2006){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_2003.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_2004.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_2005.get())}),_2006);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( monty::rc_ptr< ::mosek::fusion::Variable > _2007,    monty::rc_ptr< ::mosek::fusion::Variable > _2008,    int _2009) { return mosek::fusion::p_Var::stack(_2007,_2008,_2009); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(monty::rc_ptr< ::mosek::fusion::Variable > _2007,monty::rc_ptr< ::mosek::fusion::Variable > _2008,int _2009){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_2007.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_2008.get())}),_2009);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2010,    int _2011) { return mosek::fusion::p_Var::stack(_2010,_2011); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2010,int _2011){
  int _2012 = _2011;
  int _7671 = (int)0;
  int _7672 = (int)((_2010)->size(0));
  for (int _2013 = _7671; _2013 < _7672; ++_2013)
  {
    {
      if ((_2012 < ((*_2010)(_2013))->getND()))
      {
        {
          _2012 = ((*_2010)(_2013))->getND();
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Var::dstack(_2010,_2011);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::promote  ( monty::rc_ptr< ::mosek::fusion::Variable > _2014,    int _2015) { return mosek::fusion::p_Var::promote(_2014,_2015); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::promote(monty::rc_ptr< ::mosek::fusion::Variable > _2014,int _2015){
  if ((_2015 > _2014->getND()))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _2016 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2015)));
      _checked_ptr_1<int> _ptr__2016(_2016 ? _2016->raw() : nullptr,_2016 ? _2016->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2017 = _2014->getShape();
      _checked_ptr_1<int> _ptr__2017(_2017 ? _2017->raw() : nullptr,_2017 ? _2017->size(0) : 0);
      int _7673 = (int)0;
      int _7674 = (int)((_2017)->size(0));
      for (int _2018 = _7673; _2018 < _7674; ++_2018)
      {
        {
          _ptr__2016[_2018] = _ptr__2017[_2018];
        }
      }
      int _7675 = (int)((_2017)->size(0));
      int _7676 = _2015;
      for (int _2019 = _7675; _2019 < _7676; ++_2019)
      {
        {
          _ptr__2016[_2019] = (int)1;
        }
      }
      return _2014->__mosek_2fusion_2Variable__reshape(_2016);
    }
  }
  else
  {
    {
      return _2014;
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2020,int _2021){
  if ((_2021 < (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Model > _2022 = nullptr;
  {
    int _7677 = (int)0;
    int _7678 = (int)((_2020)->size(0));
    for (int _2023 = _7677; _2023 < _7678; ++_2023)
    {
      {
        if ((NULL == _2022.get()))
        {
          {
            _2022 = ((*_2020)(_2023))->__mosek_2fusion_2Variable__getModel();
          }
        }
        else if(((NULL != ((*_2020)(_2023))->__mosek_2fusion_2Variable__getModel().get()) && (((*_2020)(_2023))->__mosek_2fusion_2Variable__getModel() != _2022)))
        {
          {
            monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2024 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
            std::string _7679;
            bool _7680 = ((int)((mosek::fusion::p_Model::_get_impl(_2022.get())->getName()).size()) > (int)0);
            if (_7680)
            {
              _7679 = mosek::fusion::p_Model::_get_impl(_2022.get())->getName();
            }
            else
            {
              _7679 = std::string ("?");
            }
            std::string _2025 = _7679;
            std::string _7681;
            bool _7682 = ((int)((mosek::fusion::p_Model::_get_impl(((*_2020)(_2023))->__mosek_2fusion_2Variable__getModel().get())->getName()).size()) > (int)0);
            if (_7682)
            {
              _7681 = mosek::fusion::p_Model::_get_impl(((*_2020)(_2023))->__mosek_2fusion_2Variable__getModel().get())->getName();
            }
            else
            {
              _7681 = std::string ("?");
            }
            std::string _2026 = _7681;
            _2024->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Variables belong to different models: '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2025)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("' and '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2026)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"));
            throw ::mosek::fusion::ModelError(_2024->toString());
          }
        }
        {}
      }
    }
  }
  if (((int)((_2020)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
    }
  }
  else if(((int)((_2020)->size(0)) == (int)1))
  {
    {
      return ((*_2020)((int)1));
    }
  }
  else
  {
    {
      int _2027 = (int)((_2020)->size(0));
      std::vector<int> _7683;
      for (int _2029 = (int)0, _7684 = _2027; _2029 < _7684 ; ++_2029)
      {
        _7683.push_back(((*_2020)(_2029))->numInst());
      }
      auto _7685 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7683.size()),_7683.begin(),_7683.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2028 = _7685;
      _checked_ptr_1<int> _ptr__2028(_2028 ? _2028->raw() : nullptr,_2028 ? _2028->size(0) : 0);
      std::vector<std::shared_ptr< monty::ndarray< int,1 > >> _7686;
      for (int _2031 = (int)0, _7687 = _2027; _2031 < _7687 ; ++_2031)
      {
        _7686.push_back(((*_2020)(_2031))->getShape());
      }
      auto _7688 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape(_7686.size()),_7686.begin(),_7686.end()));
      std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _2030 = _7688;
      std::vector<int> _7689;
      for (int _2033 = (int)0, _7690 = _2027; _2033 < _7690 ; ++_2033)
      {
        _7689.push_back((int)((((*_2030)(_2033)))->size(0)));
      }
      auto _7691 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7689.size()),_7689.begin(),_7689.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2032 = _7691;
      _checked_ptr_1<int> _ptr__2032(_2032 ? _2032->raw() : nullptr,_2032 ? _2032->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2034 = ((*_2030)((int)0));
      _checked_ptr_1<int> _ptr__2034(_2034 ? _2034->raw() : nullptr,_2034 ? _2034->size(0) : 0);
      int _2035 = _ptr__2032[(int)0];
      int _2036 = (int)0;
      int _7692 = (int)0;
      int _7693 = _2027;
      for (int _2037 = _7692; _2037 < _7693; ++_2037)
      {
        {
          _2036 += _ptr__2028[_2037];
        }
      }
      int _2038 = safe_add( _2021,(int)1 );
      int _7694 = (int)0;
      int _7695 = _2027;
      for (int _2039 = _7694; _2039 < _7695; ++_2039)
      {
        {
          if ((_2038 < _ptr__2032[_2039]))
          {
            {
              _2038 = _ptr__2032[_2039];
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2040 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2038)));
      _checked_ptr_1<int> _ptr__2040(_2040 ? _2040->raw() : nullptr,_2040 ? _2040->size(0) : 0);
      int _7696 = (int)0;
      int _7697 = _2035;
      for (int _2041 = _7696; _2041 < _7697; ++_2041)
      {
        {
          _ptr__2040[_2041] = _ptr__2034[_2041];
        }
      }
      int _7698 = _2035;
      int _7699 = _2038;
      for (int _2042 = _7698; _2042 < _7699; ++_2042)
      {
        {
          _ptr__2040[_2042] = (int)1;
        }
      }
      _ptr__2040[_2021] = (int)0;
      int _7700 = (int)0;
      int _7701 = _2027;
      for (int _2043 = _7700; _2043 < _7701; ++_2043)
      {
        {
          int _7702;
          bool _7703 = ((int)((((*_2030)(_2043)))->size(0)) > _2021);
          if (_7703)
          {
            _7702 = ((*((*_2030)(_2043)))(_2021));
          }
          else
          {
            _7702 = (int)1;
          }
          _ptr__2040[_2021] += _7702;
        }
      }
      int _7704 = (int)0;
      int _7705 = _2027;
      for (int _2044 = _7704; _2044 < _7705; ++_2044)
      {
        {
          int _7706 = (int)0;
          int _7707 = (int)((((*_2030)(_2044)))->size(0));
          for (int _2045 = _7706; _2045 < _7707; ++_2045)
          {
            {
              if (((_2045 != _2021) && (((*((*_2030)(_2044)))(_2045)) != _ptr__2040[_2045])))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Variable dimensions do not match"));
                }
              }
              {}
            }
          }
          int _7708 = (int)((((*_2030)(_2044)))->size(0));
          int _7709 = _2038;
          for (int _2046 = _7708; _2046 < _7709; ++_2046)
          {
            {
              if (((_2046 != _2021) && ((int)1 != _ptr__2040[_2046])))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Variable dimensions do not match"));
                }
              }
              {}
            }
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _2047 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2036)));
      _checked_ptr_1<long long> _ptr__2047(_2047 ? _2047->raw() : nullptr,_2047 ? _2047->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2048 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2036)));
      _checked_ptr_1<long long> _ptr__2048(_2048 ? _2048->raw() : nullptr,_2048 ? _2048->size(0) : 0);
      std::vector<int> _7710;
      for (int _2050 = (int)0, _7711 = (int)((_2020)->size(0)); _2050 < _7711 ; ++_2050)
      {
        int _7712;
        bool _7713 = (_2021 < (int)((((*_2030)(_2050)))->size(0)));
        if (_7713)
        {
          _7712 = ((*((*_2030)(_2050)))(_2021));
        }
        else
        {
          _7712 = (int)1;
        }
        _7710.push_back(_7712);
      }
      auto _7714 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7710.size()),_7710.begin(),_7710.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2049 = _7714;
      _checked_ptr_1<int> _ptr__2049(_2049 ? _2049->raw() : nullptr,_2049 ? _2049->size(0) : 0);
      int _2051 = (int)1;
      int _7715 = (int)0;
      int _7716 = _2021;
      for (int _2052 = _7715; _2052 < _7716; ++_2052)
      {
        {
          int _7717;
          bool _7718 = (_2052 < (int)((_2034)->size(0)));
          if (_7718)
          {
            _7717 = _ptr__2034[_2052];
          }
          else
          {
            _7717 = (int)1;
          }
          _2051 *= _7717;
        }
      }
      int _2053 = (int)0;
      int _7719 = (int)0;
      int _7720 = _2027;
      for (int _2054 = _7719; _2054 < _7720; ++_2054)
      {
        {
          _2053 += _ptr__2049[_2054];
        }
      }
      int _2055 = (int)1;
      int _7721 = safe_add( _2021,(int)1 );
      int _7722 = (int)((_2034)->size(0));
      for (int _2056 = _7721; _2056 < _7722; ++_2056)
      {
        {
          _2055 *= _ptr__2034[_2056];
        }
      }
      if ((_2051 == (int)1))
      {
        {
          int _2057 = (int)0;
          long long _2058 = (int)0;
          int _7723 = (int)0;
          int _7724 = _2027;
          for (int _2059 = _7723; _2059 < _7724; ++_2059)
          {
            {
              ((*_2020)(_2059))->inst(_2057,_2048,_2057,_2047);
              int _7725 = (int)0;
              int _7726 = _ptr__2028[_2059];
              for (int _2060 = _7725; _2060 < _7726; ++_2060)
              {
                {
                  _ptr__2048[_2057] += _2058;
                  ++ _2057;
                }
              }
              _2058 += ::mosek::fusion::p_Set::size(((*_2030)(_2059)));
            }
          }
          std::shared_ptr< monty::ndarray< long long,1 > > _7727;
          bool _7728 = (_2036 < safe_mul( safe_mul( _2051,_2053 ),_2055 ));
          if (_7728)
          {
            _7727 = _2048;
          }
          else
          {
            _7727 = nullptr;
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_2022,_2040,_7727,_2047)).as<::mosek::fusion::Variable>();
        }
      }
      else
      {
        {
          int _2061 = (int)0;
          int _7729 = (int)0;
          int _7730 = _2027;
          for (int _2062 = _7729; _2062 < _7730; ++_2062)
          {
            {
              _2061 += ((*_2020)(_2062))->inst(_2061,_2048,_2061,_2047);
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _2063 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2036)));
          _checked_ptr_1<int> _ptr__2063(_2063 ? _2063->raw() : nullptr,_2063 ? _2063->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2064 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2036)));
          _checked_ptr_1<int> _ptr__2064(_2064 ? _2064->raw() : nullptr,_2064 ? _2064->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2065 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2027)));
          _checked_ptr_1<int> _ptr__2065(_2065 ? _2065->raw() : nullptr,_2065 ? _2065->size(0) : 0);
          int _7731 = (int)0;
          int _7732 = (_2027 - (int)1);
          for (int _2066 = _7731; _2066 < _7732; ++_2066)
          {
            {
              _ptr__2065[safe_add( _2066,(int)1 )] = safe_add( _ptr__2065[_2066],_ptr__2049[_2066] );
            }
          }
          int _7733 = (int)0;
          int _7734 = _2036;
          for (int _2067 = _7733; _2067 < _7734; ++_2067)
          {
            {
              _ptr__2063[_2067] = _2067;
            }
          }
          int _2068 = (int)0;
          int _7735 = (int)0;
          int _7736 = _2027;
          for (int _2069 = _7735; _2069 < _7736; ++_2069)
          {
            {
              int _7737 = (int)0;
              int _7738 = _ptr__2028[_2069];
              for (int _2070 = _7737; _2070 < _7738; ++_2070)
              {
                {
                  long long _2071 = (_ptr__2048[_2068] / safe_mul( _ptr__2049[_2069],_2055 ));
                  long long _2072 = ((_ptr__2048[_2068] / _2055) % _ptr__2049[_2069]);
                  long long _2073 = (_ptr__2048[_2068] % _2055);
                  _ptr__2048[_2068] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _2071,_2053 ),_2072 ),_ptr__2065[_2069] ),_2055 ),_2073 );
                  ++ _2068;
                }
              }
            }
          }
          int _2074 = (int)1;
          int _7739 = (int)0;
          int _7740 = _2038;
          for (int _2075 = _7739; _2075 < _7740; ++_2075)
          {
            {
              int _7741;
              bool _7742 = (_2074 < _ptr__2040[_2075]);
              if (_7742)
              {
                _7741 = _ptr__2040[_2075];
              }
              else
              {
                _7741 = _2074;
              }
              _2074 = _7741;
            }
          }
          std::shared_ptr< monty::ndarray< long long,1 > > _2076 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2038)));
          _checked_ptr_1<long long> _ptr__2076(_2076 ? _2076->raw() : nullptr,_2076 ? _2076->size(0) : 0);
          _ptr__2076[(_2038 - (int)1)] = (int)1;
          int _7743 = (int)1;
          int _7744 = _2038;
          for (int _2077 = _7743; _2077 < _7744; ++_2077)
          {
            {
              _ptr__2076[((_2038 - _2077) - (int)1)] = safe_mul( _ptr__2076[(_2038 - _2077)],_ptr__2040[(_2038 - _2077)] );
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _2078 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _2074,(int)1 ))));
          _checked_ptr_1<int> _ptr__2078(_2078 ? _2078->raw() : nullptr,_2078 ? _2078->size(0) : 0);
          int _7745 = (int)0;
          int _7746 = _2038;
          for (int _2079 = _7745; _2079 < _7746; ++_2079)
          {
            {
              int _2080 = ((_2038 - _2079) - (int)1);
              int _7747 = (int)0;
              int _7748 = safe_add( _ptr__2040[_2080],(int)1 );
              for (int _2081 = _7747; _2081 < _7748; ++_2081)
              {
                {
                  _ptr__2078[_2081] = (int)0;
                }
              }
              int _7749 = (int)0;
              int _7750 = _2036;
              for (int _2082 = _7749; _2082 < _7750; ++_2082)
              {
                {
                  ++ _ptr__2078[safe_add( ((_ptr__2048[_2082] / _ptr__2076[_2080]) % _ptr__2040[_2080]),(int)1 )];
                }
              }
              int _7751 = (int)0;
              int _7752 = _ptr__2040[_2080];
              for (int _2083 = _7751; _2083 < _7752; ++_2083)
              {
                {
                  _ptr__2078[safe_add( _2083,(int)1 )] += _ptr__2078[_2083];
                }
              }
              int _7753 = (int)0;
              int _7754 = _2036;
              for (int _2084 = _7753; _2084 < _7754; ++_2084)
              {
                {
                  int _2085 = _ptr__2063[_2084];
                  long long _2086 = ((_ptr__2048[_2085] / _ptr__2076[_2080]) % _ptr__2040[_2080]);
                  _ptr__2064[_ptr__2078[_2086]] = _2085;
                  ++ _ptr__2078[_2086];
                }
              }
              std::shared_ptr< monty::ndarray< int,1 > > _2087 = _2063;
              _checked_ptr_1<int> _ptr__2087(_2087 ? _2087->raw() : nullptr,_2087 ? _2087->size(0) : 0);
              _2063 = _2064;
              _ptr__2063.update(_2063 ? _2063->raw() : nullptr, _2063 ? _2063->size(0) : 0);
              _2064 = _2087;
              _ptr__2064.update(_2064 ? _2064->raw() : nullptr, _2064 ? _2064->size(0) : 0);
            }
          }
          std::shared_ptr< monty::ndarray< long long,1 > > _7755;
          bool _7756 = (_2036 < safe_mul( safe_mul( _2051,_2053 ),_2055 ));
          if (_7756)
          {
            std::vector<long long> _7757;
            for (int _2088 = (int)0, _7758 = _2036; _2088 < _7758 ; ++_2088)
            {
              _7757.push_back(_ptr__2048[_ptr__2063[_2088]]);
            }
            auto _7759 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7757.size()),_7757.begin(),_7757.end()));
            _7755 = _7759;
          }
          else
          {
            _7755 = nullptr;
          }
          std::vector<long long> _7760;
          for (int _2089 = (int)0, _7761 = _2036; _2089 < _7761 ; ++_2089)
          {
            _7760.push_back(_ptr__2047[_ptr__2063[_2089]]);
          }
          auto _7762 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7760.size()),_7760.begin(),_7760.end()));
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_2022,_2040,_7755,_7762)).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
}
void mosek::fusion::p_Var::destroy(){}void mosek::fusion::Var::destroy() { mosek::fusion::p_Var::_get_impl(this)->destroy(); }mosek::fusion::LinearPSDConstraint::LinearPSDConstraint(mosek::fusion::p_LinearPSDConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "LinearPSDConstraint()" << this << std::endl; */ }mosek::fusion::LinearPSDConstraint::~LinearPSDConstraint() {  /* std::cout << "~LinearPSDConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearPSDConstraint::p_LinearPSDConstraint  (::mosek::fusion::LinearPSDConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearPSDConstraint::t mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2090,    monty::rc_ptr< ::mosek::fusion::Model > _2091){ return new mosek::fusion::LinearPSDConstraint(_2090,_2091); }mosek::fusion::LinearPSDConstraint::LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2090,    monty::rc_ptr< ::mosek::fusion::Model > _2091) :    LinearPSDConstraint(new mosek::fusion::p_LinearPSDConstraint(this)){ mosek::fusion::p_LinearPSDConstraint::_get_impl(this)->_initialize(_2090,_2091); }void mosek::fusion::p_LinearPSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2090,    monty::rc_ptr< ::mosek::fusion::Model > _2091){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2090,_2091);
    conid = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2090)->conid;
    slackidxs = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2090)->slackidxs;
    nativeidxs = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2090)->nativeidxs;
    conedim = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2090)->conedim;
    shape = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2090)->shape;
  }
}mosek::fusion::LinearPSDConstraint::t mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2092,    const std::string &  _2093,    int _2094,    std::shared_ptr< monty::ndarray< int,1 > > _2095,    int _2096,    std::shared_ptr< monty::ndarray< int,1 > > _2097,    std::shared_ptr< monty::ndarray< long long,1 > > _2098){ return new mosek::fusion::LinearPSDConstraint(_2092,_2093,_2094,_2095,_2096,_2097,_2098); }mosek::fusion::LinearPSDConstraint::LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2092,    const std::string &  _2093,    int _2094,    std::shared_ptr< monty::ndarray< int,1 > > _2095,    int _2096,    std::shared_ptr< monty::ndarray< int,1 > > _2097,    std::shared_ptr< monty::ndarray< long long,1 > > _2098) :    LinearPSDConstraint(new mosek::fusion::p_LinearPSDConstraint(this)){ mosek::fusion::p_LinearPSDConstraint::_get_impl(this)->_initialize(_2092,_2093,_2094,_2095,_2096,_2097,_2098); }void mosek::fusion::p_LinearPSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2092,    const std::string &  _2093,    int _2094,    std::shared_ptr< monty::ndarray< int,1 > > _2095,    int _2096,    std::shared_ptr< monty::ndarray< int,1 > > _2097,    std::shared_ptr< monty::ndarray< long long,1 > > _2098){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2095(_2095 ? _2095->raw() : nullptr, _2095 ? _2095->size(0) : 0);
    _checked_ptr_1<int> _ptr__2097(_2097 ? _2097->raw() : nullptr, _2097 ? _2097->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2098(_2098 ? _2098->raw() : nullptr, _2098 ? _2098->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2092,_2093,_2095,_2097);
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->conid = _2094;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->slackidxs = _2098;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->nativeidxs = _2097;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->conedim = _2096;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->shape = _2095;
  }
}void mosek::fusion::p_LinearPSDConstraint::domainToString(long long _2099,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2100){
  std::shared_ptr< monty::ndarray< int,1 > > _2101 = ::mosek::fusion::p_Set::idxtokey(shape,_2099);
  _checked_ptr_1<int> _ptr__2101(_2101 ? _2101->raw() : nullptr,_2101 ? _2101->size(0) : 0);
  _2100->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" : element ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2101[(int)0]);
  int _7763 = (int)1;
  int _7764 = (int)((_2101)->size(0));
  for (int _2102 = _7763; _2102 < _7764; ++_2102)
  {
    {
      _2100->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2101[_2102]);
    }
  }
  _2100->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") in a positive semi-definite cone of size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7765 = (int)1;
  int _7766 = (int)((_2101)->size(0));
  for (int _2103 = _7765; _2103 < _7766; ++_2103)
  {
    {
      _2100->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_2103)));
    }
  }
  _2100->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_LinearPSDConstraint::__mosek_2fusion_2LinearPSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2104){
  return (::mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint(::mosek::fusion::LinearPSDConstraint::t(_pubthis),_2104)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_LinearPSDConstraint::destroy(){shape.reset();slackidxs.reset();nativeidxs.reset();}void mosek::fusion::LinearPSDConstraint::destroy() { mosek::fusion::p_LinearPSDConstraint::_get_impl(this)->destroy(); }mosek::fusion::PSDConstraint::PSDConstraint(mosek::fusion::p_PSDConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "PSDConstraint()" << this << std::endl; */ }mosek::fusion::PSDConstraint::~PSDConstraint() {  /* std::cout << "~PSDConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_PSDConstraint::p_PSDConstraint  (::mosek::fusion::PSDConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::PSDConstraint::t mosek::fusion::p_PSDConstraint::_new_PSDConstraint  (monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2105,    monty::rc_ptr< ::mosek::fusion::Model > _2106){ return new mosek::fusion::PSDConstraint(_2105,_2106); }mosek::fusion::PSDConstraint::PSDConstraint  (monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2105,    monty::rc_ptr< ::mosek::fusion::Model > _2106) :    PSDConstraint(new mosek::fusion::p_PSDConstraint(this)){ mosek::fusion::p_PSDConstraint::_get_impl(this)->_initialize(_2105,_2106); }void mosek::fusion::p_PSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2105,    monty::rc_ptr< ::mosek::fusion::Model > _2106){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2105,_2106);
    conid = mosek::fusion::p_PSDConstraint::_get_impl(_2105)->conid;
    name = mosek::fusion::p_PSDConstraint::_get_impl(_2105)->name;
    shape = mosek::fusion::p_PSDConstraint::_get_impl(_2105)->shape;
    slackidxs = mosek::fusion::p_PSDConstraint::_get_impl(_2105)->slackidxs;
    nativeidxs = mosek::fusion::p_PSDConstraint::_get_impl(_2105)->nativeidxs;
    names_flushed = mosek::fusion::p_PSDConstraint::_get_impl(_2105)->names_flushed;
    conedim0 = mosek::fusion::p_PSDConstraint::_get_impl(_2105)->conedim0;
    conedim1 = mosek::fusion::p_PSDConstraint::_get_impl(_2105)->conedim1;
  }
}mosek::fusion::PSDConstraint::t mosek::fusion::p_PSDConstraint::_new_PSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2107,    const std::string &  _2108,    int _2109,    std::shared_ptr< monty::ndarray< int,1 > > _2110,    int _2111,    int _2112,    std::shared_ptr< monty::ndarray< long long,1 > > _2113,    std::shared_ptr< monty::ndarray< int,1 > > _2114){ return new mosek::fusion::PSDConstraint(_2107,_2108,_2109,_2110,_2111,_2112,_2113,_2114); }mosek::fusion::PSDConstraint::PSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2107,    const std::string &  _2108,    int _2109,    std::shared_ptr< monty::ndarray< int,1 > > _2110,    int _2111,    int _2112,    std::shared_ptr< monty::ndarray< long long,1 > > _2113,    std::shared_ptr< monty::ndarray< int,1 > > _2114) :    PSDConstraint(new mosek::fusion::p_PSDConstraint(this)){ mosek::fusion::p_PSDConstraint::_get_impl(this)->_initialize(_2107,_2108,_2109,_2110,_2111,_2112,_2113,_2114); }void mosek::fusion::p_PSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2107,    const std::string &  _2108,    int _2109,    std::shared_ptr< monty::ndarray< int,1 > > _2110,    int _2111,    int _2112,    std::shared_ptr< monty::ndarray< long long,1 > > _2113,    std::shared_ptr< monty::ndarray< int,1 > > _2114){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2110(_2110 ? _2110->raw() : nullptr, _2110 ? _2110->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2113(_2113 ? _2113->raw() : nullptr, _2113 ? _2113->size(0) : 0);
    _checked_ptr_1<int> _ptr__2114(_2114 ? _2114->raw() : nullptr, _2114 ? _2114->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2107,_2108,_2110,::mosek::fusion::p_PSDConstraint::computenidxs(_2110,_2111,_2112,_2114));
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->conid = _2109;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->nativeidxs = _2114;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->slackidxs = _2113;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->name = _2108;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->shape = _2110;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->conedim0 = _2111;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->conedim1 = _2112;
    names_flushed = false;
  }
}std::string mosek::fusion::PSDConstraint :: toString() { return mosek::fusion::p_PSDConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_PSDConstraint::toString(){
  throw ::mosek::fusion::UnimplementedError(std::string ("PSDConstraint.toString not implemented"));
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_PSDConstraint::__mosek_2fusion_2PSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2115){
  return (::mosek::fusion::p_PSDConstraint::_new_PSDConstraint(::mosek::fusion::PSDConstraint::t(_pubthis),_2115)).as<::mosek::fusion::ModelConstraint>();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_PSDConstraint::computenidxs(std::shared_ptr< monty::ndarray< int,1 > > _2116,int _2117,int _2118,std::shared_ptr< monty::ndarray< int,1 > > _2119){
  _checked_ptr_1<int> _ptr__2116(_2116 ? _2116->raw() : nullptr, _2116 ? _2116->size(0) : 0);
  _checked_ptr_1<int> _ptr__2119(_2119 ? _2119->raw() : nullptr, _2119 ? _2119->size(0) : 0);
  int _2120 = (int)((_2116)->size(0));
  bool _2121 = (_2117 < _2118);
  int _7767;
  bool _7768 = _2121;
  if (_7768)
  {
    _7767 = _2117;
  }
  else
  {
    _7767 = _2118;
  }
  int _2122 = _7767;
  int _7769;
  bool _7770 = _2121;
  if (_7770)
  {
    _7769 = _2118;
  }
  else
  {
    _7769 = _2117;
  }
  int _2123 = _7769;
  std::shared_ptr< monty::ndarray< int,1 > > _2124 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1)});
  _checked_ptr_1<int> _ptr__2124(_2124 ? _2124->raw() : nullptr,_2124 ? _2124->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2125 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)5)));
  _checked_ptr_1<int> _ptr__2125(_2125 ? _2125->raw() : nullptr,_2125 ? _2125->size(0) : 0);
  int _2126 = (int)1;
  int _7771 = (int)0;
  int _7772 = (int)((_2116)->size(0));
  for (int _2127 = _7771; _2127 < _7772; ++_2127)
  {
    {
      _2126 *= _ptr__2116[_2127];
    }
  }
  int _7773 = (int)0;
  int _7774 = _2122;
  for (int _2128 = _7773; _2128 < _7774; ++_2128)
  {
    {
      _ptr__2124[(int)0] *= _ptr__2116[_2128];
    }
  }
  _ptr__2124[(int)1] = _ptr__2116[_2122];
  int _7775 = safe_add( _2122,(int)1 );
  int _7776 = _2123;
  for (int _2129 = _7775; _2129 < _7776; ++_2129)
  {
    {
      _ptr__2124[(int)2] *= _ptr__2116[_2129];
    }
  }
  _ptr__2124[(int)3] = _ptr__2116[_2123];
  int _7777 = safe_add( _2123,(int)1 );
  int _7778 = _2120;
  for (int _2130 = _7777; _2130 < _7778; ++_2130)
  {
    {
      _ptr__2124[(int)4] *= _ptr__2116[_2130];
    }
  }
  _ptr__2125[(int)4] = (int)1;
  int _7779 = (int)1;
  int _7780 = (int)5;
  for (int _2131 = _7779; _2131 < _7780; ++_2131)
  {
    {
      _ptr__2125[(((int)5 - _2131) - (int)1)] = safe_mul( _ptr__2125[((int)5 - _2131)],_ptr__2124[((int)5 - _2131)] );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2132 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2126)));
  _checked_ptr_1<int> _ptr__2132(_2132 ? _2132->raw() : nullptr,_2132 ? _2132->size(0) : 0);
  int _2133 = (int)0;
  if (_2121)
  {
    {
      int _7781 = (int)0;
      int _7782 = _ptr__2124[(int)0];
      for (int _2134 = _7781; _2134 < _7782; ++_2134)
      {
        {
          int _7783 = (int)0;
          int _7784 = _ptr__2124[(int)1];
          for (int _2135 = _7783; _2135 < _7784; ++_2135)
          {
            {
              int _7785 = (int)0;
              int _7786 = _ptr__2124[(int)2];
              for (int _2136 = _7785; _2136 < _7786; ++_2136)
              {
                {
                  int _7787 = _2135;
                  int _7788 = _ptr__2124[(int)1];
                  for (int _2137 = _7787; _2137 < _7788; ++_2137)
                  {
                    {
                      int _7789 = (int)0;
                      int _7790 = _ptr__2124[(int)4];
                      for (int _2138 = _7789; _2138 < _7790; ++_2138)
                      {
                        {
                          _ptr__2132[safe_add( safe_add( safe_add( safe_add( safe_mul( _2134,_ptr__2125[(int)0] ),safe_mul( _2135,_ptr__2125[(int)1] ) ),safe_mul( _2136,_ptr__2125[(int)2] ) ),safe_mul( _2137,_ptr__2125[(int)3] ) ),safe_mul( _2138,_ptr__2125[(int)4] ) )] = _ptr__2119[_2133];
                          _ptr__2132[safe_add( safe_add( safe_add( safe_add( safe_mul( _2134,_ptr__2125[(int)0] ),safe_mul( _2137,_ptr__2125[(int)1] ) ),safe_mul( _2136,_ptr__2125[(int)2] ) ),safe_mul( _2135,_ptr__2125[(int)3] ) ),safe_mul( _2138,_ptr__2125[(int)4] ) )] = _ptr__2119[_2133];
                          ++ _2133;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _7791 = (int)0;
      int _7792 = _ptr__2124[(int)0];
      for (int _2139 = _7791; _2139 < _7792; ++_2139)
      {
        {
          int _7793 = (int)0;
          int _7794 = _ptr__2124[(int)1];
          for (int _2140 = _7793; _2140 < _7794; ++_2140)
          {
            {
              int _7795 = (int)0;
              int _7796 = _ptr__2124[(int)2];
              for (int _2141 = _7795; _2141 < _7796; ++_2141)
              {
                {
                  int _7797 = (int)0;
                  int _7798 = safe_add( _2140,(int)1 );
                  for (int _2142 = _7797; _2142 < _7798; ++_2142)
                  {
                    {
                      int _7799 = (int)0;
                      int _7800 = _ptr__2124[(int)4];
                      for (int _2143 = _7799; _2143 < _7800; ++_2143)
                      {
                        {
                          _ptr__2132[safe_add( safe_add( safe_add( safe_add( safe_mul( _2139,_ptr__2125[(int)0] ),safe_mul( _2140,_ptr__2125[(int)1] ) ),safe_mul( _2141,_ptr__2125[(int)2] ) ),safe_mul( _2142,_ptr__2125[(int)3] ) ),safe_mul( _2143,_ptr__2125[(int)4] ) )] = _ptr__2119[_2133];
                          _ptr__2132[safe_add( safe_add( safe_add( safe_add( safe_mul( _2139,_ptr__2125[(int)0] ),safe_mul( _2142,_ptr__2125[(int)1] ) ),safe_mul( _2141,_ptr__2125[(int)2] ) ),safe_mul( _2140,_ptr__2125[(int)3] ) ),safe_mul( _2143,_ptr__2125[(int)4] ) )] = _ptr__2119[_2133];
                          ++ _2133;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return _2132;
}
void mosek::fusion::p_PSDConstraint::destroy(){shape.reset();slackidxs.reset();nativeidxs.reset();}void mosek::fusion::PSDConstraint::destroy() { mosek::fusion::p_PSDConstraint::_get_impl(this)->destroy(); }mosek::fusion::ConstraintCache::ConstraintCache(mosek::fusion::p_ConstraintCache *_impl) : _impl(_impl) { /*std::cout << "ConstraintCache() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ConstraintCache::~ConstraintCache() { delete _impl; _impl = nullptr; }mosek::fusion::p_ConstraintCache::p_ConstraintCache  (::mosek::fusion::ConstraintCache * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_barmatidx() { return _impl->barmatidx; }
void mosek::fusion::ConstraintCache::set_barmatidx(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barmatidx = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_barsubj() { return _impl->barsubj; }
void mosek::fusion::ConstraintCache::set_barsubj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubj = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_barsubi() { return _impl->barsubi; }
void mosek::fusion::ConstraintCache::set_barsubi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubi = _val; }
long long mosek::fusion::ConstraintCache::get_nbarnz() { return _impl->nbarnz; }
void mosek::fusion::ConstraintCache::set_nbarnz(long long _val) { _impl->nbarnz = _val; }
long long mosek::fusion::ConstraintCache::get_nunordered() { return _impl->nunordered; }
void mosek::fusion::ConstraintCache::set_nunordered(long long _val) { _impl->nunordered = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_buffer_subi() { return _impl->buffer_subi; }
void mosek::fusion::ConstraintCache::set_buffer_subi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->buffer_subi = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_buffer_subj() { return _impl->buffer_subj; }
void mosek::fusion::ConstraintCache::set_buffer_subj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->buffer_subj = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConstraintCache::get_buffer_cof() { return _impl->buffer_cof; }
void mosek::fusion::ConstraintCache::set_buffer_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->buffer_cof = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConstraintCache::get_bfix() { return _impl->bfix; }
void mosek::fusion::ConstraintCache::set_bfix(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bfix = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConstraintCache::get_cof() { return _impl->cof; }
void mosek::fusion::ConstraintCache::set_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->cof = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_subi() { return _impl->subi; }
void mosek::fusion::ConstraintCache::set_subi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->subi = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_subj() { return _impl->subj; }
void mosek::fusion::ConstraintCache::set_subj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->subj = _val; }
long long mosek::fusion::ConstraintCache::get_nnz() { return _impl->nnz; }
void mosek::fusion::ConstraintCache::set_nnz(long long _val) { _impl->nnz = _val; }
int mosek::fusion::ConstraintCache::get_nrows() { return _impl->nrows; }
void mosek::fusion::ConstraintCache::set_nrows(int _val) { _impl->nrows = _val; }
mosek::fusion::ConstraintCache::t mosek::fusion::p_ConstraintCache::_new_ConstraintCache  (monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2144){ return new mosek::fusion::ConstraintCache(_2144); }mosek::fusion::ConstraintCache::ConstraintCache  (monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2144) :    ConstraintCache(new mosek::fusion::p_ConstraintCache(this)){ mosek::fusion::p_ConstraintCache::_get_impl(this)->_initialize(_2144); }void mosek::fusion::p_ConstraintCache::_initialize  (monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2144){monty::rc_reserve __reserve_this(_pubthis);   {
    nrows = mosek::fusion::p_ConstraintCache::_get_impl(_2144)->nrows;
    nnz = mosek::fusion::p_ConstraintCache::_get_impl(_2144)->nnz;
    std::shared_ptr< monty::ndarray< int,1 > > _7801;
    bool _7802 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2144)->subj.get());
    if (_7802)
    {
      _7801 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2144)->subj);
    }
    else
    {
      _7801 = nullptr;
    }
    subj = _7801;
    std::shared_ptr< monty::ndarray< int,1 > > _7803;
    bool _7804 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2144)->subi.get());
    if (_7804)
    {
      _7803 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2144)->subi);
    }
    else
    {
      _7803 = nullptr;
    }
    subi = _7803;
    std::shared_ptr< monty::ndarray< double,1 > > _7805;
    bool _7806 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2144)->cof.get());
    if (_7806)
    {
      _7805 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2144)->cof);
    }
    else
    {
      _7805 = nullptr;
    }
    cof = _7805;
    std::shared_ptr< monty::ndarray< double,1 > > _7807;
    bool _7808 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2144)->bfix.get());
    if (_7808)
    {
      _7807 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2144)->bfix);
    }
    else
    {
      _7807 = nullptr;
    }
    bfix = _7807;
    std::shared_ptr< monty::ndarray< double,1 > > _7809;
    bool _7810 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2144)->buffer_cof.get());
    if (_7810)
    {
      _7809 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2144)->buffer_cof);
    }
    else
    {
      _7809 = nullptr;
    }
    buffer_cof = _7809;
    std::shared_ptr< monty::ndarray< int,1 > > _7811;
    bool _7812 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2144)->buffer_subj.get());
    if (_7812)
    {
      _7811 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2144)->buffer_subj);
    }
    else
    {
      _7811 = nullptr;
    }
    buffer_subj = _7811;
    std::shared_ptr< monty::ndarray< int,1 > > _7813;
    bool _7814 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2144)->buffer_subi.get());
    if (_7814)
    {
      _7813 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2144)->buffer_subi);
    }
    else
    {
      _7813 = nullptr;
    }
    buffer_subi = _7813;
    nunordered = mosek::fusion::p_ConstraintCache::_get_impl(_2144)->nunordered;
    nbarnz = mosek::fusion::p_ConstraintCache::_get_impl(_2144)->nbarnz;
    std::shared_ptr< monty::ndarray< int,1 > > _7815;
    bool _7816 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2144)->barsubi.get());
    if (_7816)
    {
      _7815 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2144)->barsubi);
    }
    else
    {
      _7815 = nullptr;
    }
    barsubi = _7815;
    std::shared_ptr< monty::ndarray< int,1 > > _7817;
    bool _7818 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2144)->barsubj.get());
    if (_7818)
    {
      _7817 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2144)->barsubj);
    }
    else
    {
      _7817 = nullptr;
    }
    barsubj = _7817;
    std::shared_ptr< monty::ndarray< int,1 > > _7819;
    bool _7820 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2144)->barmatidx.get());
    if (_7820)
    {
      _7819 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2144)->barmatidx);
    }
    else
    {
      _7819 = nullptr;
    }
    barmatidx = _7819;
  }
}mosek::fusion::ConstraintCache::t mosek::fusion::p_ConstraintCache::_new_ConstraintCache  (std::shared_ptr< monty::ndarray< long long,1 > > _2145,    std::shared_ptr< monty::ndarray< double,1 > > _2146,    std::shared_ptr< monty::ndarray< int,1 > > _2147,    std::shared_ptr< monty::ndarray< double,1 > > _2148,    std::shared_ptr< monty::ndarray< int,1 > > _2149,    std::shared_ptr< monty::ndarray< int,1 > > _2150,    std::shared_ptr< monty::ndarray< int,1 > > _2151){ return new mosek::fusion::ConstraintCache(_2145,_2146,_2147,_2148,_2149,_2150,_2151); }mosek::fusion::ConstraintCache::ConstraintCache  (std::shared_ptr< monty::ndarray< long long,1 > > _2145,    std::shared_ptr< monty::ndarray< double,1 > > _2146,    std::shared_ptr< monty::ndarray< int,1 > > _2147,    std::shared_ptr< monty::ndarray< double,1 > > _2148,    std::shared_ptr< monty::ndarray< int,1 > > _2149,    std::shared_ptr< monty::ndarray< int,1 > > _2150,    std::shared_ptr< monty::ndarray< int,1 > > _2151) :    ConstraintCache(new mosek::fusion::p_ConstraintCache(this)){ mosek::fusion::p_ConstraintCache::_get_impl(this)->_initialize(_2145,_2146,_2147,_2148,_2149,_2150,_2151); }void mosek::fusion::p_ConstraintCache::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _2145,    std::shared_ptr< monty::ndarray< double,1 > > _2146,    std::shared_ptr< monty::ndarray< int,1 > > _2147,    std::shared_ptr< monty::ndarray< double,1 > > _2148,    std::shared_ptr< monty::ndarray< int,1 > > _2149,    std::shared_ptr< monty::ndarray< int,1 > > _2150,    std::shared_ptr< monty::ndarray< int,1 > > _2151){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__2145(_2145 ? _2145->raw() : nullptr, _2145 ? _2145->size(0) : 0);
    _checked_ptr_1<double> _ptr__2146(_2146 ? _2146->raw() : nullptr, _2146 ? _2146->size(0) : 0);
    _checked_ptr_1<int> _ptr__2147(_2147 ? _2147->raw() : nullptr, _2147 ? _2147->size(0) : 0);
    _checked_ptr_1<double> _ptr__2148(_2148 ? _2148->raw() : nullptr, _2148 ? _2148->size(0) : 0);
    _checked_ptr_1<int> _ptr__2149(_2149 ? _2149->raw() : nullptr, _2149 ? _2149->size(0) : 0);
    _checked_ptr_1<int> _ptr__2150(_2150 ? _2150->raw() : nullptr, _2150 ? _2150->size(0) : 0);
    _checked_ptr_1<int> _ptr__2151(_2151 ? _2151->raw() : nullptr, _2151 ? _2151->size(0) : 0);
    nrows = ((int)((_2145)->size(0)) - (int)1);
    nnz = _ptr__2145[((int)((_2145)->size(0)) - (int)1)];
    subj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nnz)));
    subi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nnz)));
    cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(nnz)));
    if ((NULL != _2148.get()))
    {
      {
        bfix = _2148;
      }
    }
    else
    {
      {
        bfix = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(nrows)));
      }
    }
    if (((NULL != _2149.get()) && ((NULL != _2150.get()) && (NULL != _2151.get()))))
    {
      {
        nbarnz = (int)((_2149)->size(0));
        if ((nbarnz > (int)((_2150)->size(0))))
        {
          {
            nbarnz = (int)((_2150)->size(0));
          }
        }
        {}
        if ((nbarnz > (int)((_2151)->size(0))))
        {
          {
            nbarnz = (int)((_2151)->size(0));
          }
        }
        {}
        barsubi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nbarnz)));
        barsubj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nbarnz)));
        barmatidx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nbarnz)));
        ::mosek::fusion::Utils::Tools::arraycopy(_2149,(long long)((int)0),barsubi,(long long)((int)0),nbarnz);
        ::mosek::fusion::Utils::Tools::arraycopy(_2150,(long long)((int)0),barsubj,(long long)((int)0),nbarnz);
        ::mosek::fusion::Utils::Tools::arraycopy(_2151,(long long)((int)0),barmatidx,(long long)((int)0),nbarnz);
      }
    }
    else
    {
      {
        nbarnz = (int)0;
        barsubi = nullptr;
        barsubj = nullptr;
        barmatidx = nullptr;
      }
    }
    ::mosek::fusion::Utils::Tools::arraycopy(_2147,(long long)0,subj,(long long)0,nnz);
    ::mosek::fusion::Utils::Tools::arraycopy(_2146,(long long)0,cof,(long long)0,nnz);
    int _7821 = (int)0;
    int _7822 = nrows;
    for (int _2152 = _7821; _2152 < _7822; ++_2152)
    {
      {
        long long _7823 = _ptr__2145[_2152];
        long long _7824 = _ptr__2145[safe_add( _2152,(int)1 )];
        for (long long _2153 = _7823; _2153 < _7824; ++_2153)
        {
          {
            ((*subi)(_2153)) = _2152;
          }
        }
      }
    }
    buffer_cof = nullptr;
    buffer_subj = nullptr;
    buffer_subi = nullptr;
    nunordered = (long long)0;
  }
}void mosek::fusion::p_ConstraintCache::unchecked_add_fx(std::shared_ptr< monty::ndarray< double,1 > > _2154){
  _checked_ptr_1<double> _ptr__2154(_2154 ? _2154->raw() : nullptr, _2154 ? _2154->size(0) : 0);
  int _7825 = (int)0;
  int _7826 = nrows;
  for (int _2155 = _7825; _2155 < _7826; ++_2155)
  {
    {
      ((*bfix)(_2155)) = (((*bfix)(_2155)) + _ptr__2154[_2155]);
    }
  }
}
long long mosek::fusion::p_ConstraintCache::order_barentries(){
  std::vector<long long> _7827;
  for (long long _2157 = (long long)0, _7828 = nbarnz; _2157 < _7828 ; ++_2157)
  {
    _7827.push_back(_2157);
  }
  auto _7829 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7827.size()),_7827.begin(),_7827.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _2156 = _7829;
  _checked_ptr_1<long long> _ptr__2156(_2156 ? _2156->raw() : nullptr,_2156 ? _2156->size(0) : 0);
  if ((!::mosek::fusion::p_Sort::issorted(_2156,barsubi,barsubj,(long long)((int)0),nbarnz,false)))
  {
    {
      ::mosek::fusion::p_Sort::argsort(_2156,barsubi,barsubj,(long long)((int)0),nbarnz,false);
      std::shared_ptr< monty::ndarray< int,1 > > _2158 = barsubi;
      _checked_ptr_1<int> _ptr__2158(_2158 ? _2158->raw() : nullptr,_2158 ? _2158->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2159 = barsubj;
      _checked_ptr_1<int> _ptr__2159(_2159 ? _2159->raw() : nullptr,_2159 ? _2159->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2160 = barmatidx;
      _checked_ptr_1<int> _ptr__2160(_2160 ? _2160->raw() : nullptr,_2160 ? _2160->size(0) : 0);
      std::vector<int> _7830;
      for (long long _2161 = (int)0, _7831 = nbarnz; _2161 < _7831 ; ++_2161)
      {
        _7830.push_back(_ptr__2158[_ptr__2156[_2161]]);
      }
      auto _7832 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7830.size()),_7830.begin(),_7830.end()));
      barsubi = _7832;
      std::vector<int> _7833;
      for (long long _2162 = (int)0, _7834 = nbarnz; _2162 < _7834 ; ++_2162)
      {
        _7833.push_back(_ptr__2159[_ptr__2156[_2162]]);
      }
      auto _7835 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7833.size()),_7833.begin(),_7833.end()));
      barsubj = _7835;
      std::vector<int> _7836;
      for (long long _2163 = (int)0, _7837 = nbarnz; _2163 < _7837 ; ++_2163)
      {
        _7836.push_back(_ptr__2160[_ptr__2156[_2163]]);
      }
      auto _7838 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7836.size()),_7836.begin(),_7836.end()));
      barmatidx = _7838;
    }
  }
  {}
  return nbarnz;
}
void mosek::fusion::p_ConstraintCache::add_bar(std::shared_ptr< monty::ndarray< int,1 > > _2164,std::shared_ptr< monty::ndarray< int,1 > > _2165,std::shared_ptr< monty::ndarray< int,1 > > _2166){
  _checked_ptr_1<int> _ptr__2164(_2164 ? _2164->raw() : nullptr, _2164 ? _2164->size(0) : 0);
  _checked_ptr_1<int> _ptr__2165(_2165 ? _2165->raw() : nullptr, _2165 ? _2165->size(0) : 0);
  _checked_ptr_1<int> _ptr__2166(_2166 ? _2166->raw() : nullptr, _2166 ? _2166->size(0) : 0);
  if ((NULL != _2164.get()))
  {
    {
      int _2167 = (int)((_2164)->size(0));
      if (((int)((_2164)->size(0)) <= safe_add( nbarnz,_2167 )))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2168 = barsubi;
          _checked_ptr_1<int> _ptr__2168(_2168 ? _2168->raw() : nullptr,_2168 ? _2168->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2169 = barsubj;
          _checked_ptr_1<int> _ptr__2169(_2169 ? _2169->raw() : nullptr,_2169 ? _2169->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2170 = barmatidx;
          _checked_ptr_1<int> _ptr__2170(_2170 ? _2170->raw() : nullptr,_2170 ? _2170->size(0) : 0);
          long long _7839;
          bool _7840 = (safe_mul( (int)2,nbarnz ) > safe_add( nbarnz,_2167 ));
          if (_7840)
          {
            _7839 = safe_mul( (int)2,nbarnz );
          }
          else
          {
            _7839 = safe_add( nbarnz,safe_mul( _2167,(int)2 ) );
          }
          long long _2171 = _7839;
          barsubi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2171)));
          barsubj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2171)));
          barmatidx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2171)));
          if ((nbarnz > (int)0))
          {
            {
              ::mosek::fusion::Utils::Tools::arraycopy(_2168,(long long)((int)0),barsubi,(long long)((int)0),nbarnz);
              ::mosek::fusion::Utils::Tools::arraycopy(_2169,(long long)((int)0),barsubj,(long long)((int)0),nbarnz);
              ::mosek::fusion::Utils::Tools::arraycopy(_2170,(long long)((int)0),barmatidx,(long long)((int)0),nbarnz);
            }
          }
          {}
        }
      }
      {}
      ::mosek::fusion::Utils::Tools::arraycopy(_2164,(long long)((int)0),barsubi,nbarnz,(long long)(_2167));
      ::mosek::fusion::Utils::Tools::arraycopy(_2165,(long long)((int)0),barsubj,nbarnz,(long long)(_2167));
      ::mosek::fusion::Utils::Tools::arraycopy(_2166,(long long)((int)0),barmatidx,nbarnz,(long long)(_2167));
      nbarnz += _2167;
    }
  }
  {}
}
void mosek::fusion::p_ConstraintCache::unchecked_add_l(std::shared_ptr< monty::ndarray< long long,1 > > _2172,std::shared_ptr< monty::ndarray< int,1 > > _2173,std::shared_ptr< monty::ndarray< double,1 > > _2174,std::shared_ptr< monty::ndarray< double,1 > > _2175){
  _checked_ptr_1<long long> _ptr__2172(_2172 ? _2172->raw() : nullptr, _2172 ? _2172->size(0) : 0);
  _checked_ptr_1<int> _ptr__2173(_2173 ? _2173->raw() : nullptr, _2173 ? _2173->size(0) : 0);
  _checked_ptr_1<double> _ptr__2174(_2174 ? _2174->raw() : nullptr, _2174 ? _2174->size(0) : 0);
  _checked_ptr_1<double> _ptr__2175(_2175 ? _2175->raw() : nullptr, _2175 ? _2175->size(0) : 0);
  long long _2176 = safe_add( nunordered,_ptr__2172[nrows] );
  long long _2177 = _ptr__2172[nrows];
  std::shared_ptr< monty::ndarray< int,1 > > _2178;
  _checked_ptr_1<int> _ptr__2178(_2178 ? _2178->raw() : nullptr,_2178 ? _2178->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2179;
  _checked_ptr_1<int> _ptr__2179(_2179 ? _2179->raw() : nullptr,_2179 ? _2179->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2180;
  _checked_ptr_1<double> _ptr__2180(_2180 ? _2180->raw() : nullptr,_2180 ? _2180->size(0) : 0);
  if (((NULL == buffer_cof.get()) || ((int)((buffer_cof)->size(0)) < _2176)))
  {
    {
      _2178 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2176)));
      _ptr__2178.update(_2178 ? _2178->raw() : nullptr, _2178 ? _2178->size(0) : 0);
      _2179 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2176)));
      _ptr__2179.update(_2179 ? _2179->raw() : nullptr, _2179 ? _2179->size(0) : 0);
      _2180 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2176)));
      _ptr__2180.update(_2180 ? _2180->raw() : nullptr, _2180 ? _2180->size(0) : 0);
      if ((NULL != buffer_cof.get()))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(buffer_subi,(long long)0,_2178,(long long)0,nunordered);
          ::mosek::fusion::Utils::Tools::arraycopy(buffer_subj,(long long)0,_2179,(long long)0,nunordered);
          ::mosek::fusion::Utils::Tools::arraycopy(buffer_cof,(long long)0,_2180,(long long)0,nunordered);
        }
      }
      {}
    }
  }
  else
  {
    {
      _2178 = buffer_subi;
      _ptr__2178.update(_2178 ? _2178->raw() : nullptr, _2178 ? _2178->size(0) : 0);
      _2179 = buffer_subj;
      _ptr__2179.update(_2179 ? _2179->raw() : nullptr, _2179 ? _2179->size(0) : 0);
      _2180 = buffer_cof;
      _ptr__2180.update(_2180 ? _2180->raw() : nullptr, _2180 ? _2180->size(0) : 0);
    }
  }
  int _7841 = (int)0;
  int _7842 = nrows;
  for (int _2181 = _7841; _2181 < _7842; ++_2181)
  {
    {
      long long _7843 = _ptr__2172[_2181];
      long long _7844 = _ptr__2172[safe_add( _2181,(int)1 )];
      for (long long _2182 = _7843; _2182 < _7844; ++_2182)
      {
        {
          _ptr__2178[safe_add( nunordered,_2182 )] = _2181;
        }
      }
    }
  }
  ::mosek::fusion::Utils::Tools::arraycopy(_2173,(long long)0,_2179,nunordered,_2177);
  ::mosek::fusion::Utils::Tools::arraycopy(_2174,(long long)0,_2180,nunordered,_2177);
  buffer_subi = _2178;
  buffer_subj = _2179;
  buffer_cof = _2180;
  if ((NULL != _2175.get()))
  {
    {
      int _7845 = (int)0;
      int _7846 = nrows;
      for (int _2183 = _7845; _2183 < _7846; ++_2183)
      {
        {
          ((*bfix)(_2183)) = (((*bfix)(_2183)) + _ptr__2175[_2183]);
        }
      }
    }
  }
  {}
  nunordered = _2176;
}
void mosek::fusion::ConstraintCache :: add(std::shared_ptr< monty::ndarray< long long,1 > > _2184,std::shared_ptr< monty::ndarray< int,1 > > _2185,std::shared_ptr< monty::ndarray< double,1 > > _2186,std::shared_ptr< monty::ndarray< double,1 > > _2187) { mosek::fusion::p_ConstraintCache::_get_impl(this)->add(_2184,_2185,_2186,_2187); }void mosek::fusion::p_ConstraintCache::add(std::shared_ptr< monty::ndarray< long long,1 > > _2184,std::shared_ptr< monty::ndarray< int,1 > > _2185,std::shared_ptr< monty::ndarray< double,1 > > _2186,std::shared_ptr< monty::ndarray< double,1 > > _2187){
  _checked_ptr_1<long long> _ptr__2184(_2184 ? _2184->raw() : nullptr, _2184 ? _2184->size(0) : 0);
  _checked_ptr_1<int> _ptr__2185(_2185 ? _2185->raw() : nullptr, _2185 ? _2185->size(0) : 0);
  _checked_ptr_1<double> _ptr__2186(_2186 ? _2186->raw() : nullptr, _2186 ? _2186->size(0) : 0);
  _checked_ptr_1<double> _ptr__2187(_2187 ? _2187->raw() : nullptr, _2187 ? _2187->size(0) : 0);
  if ((((int)((_2184)->size(0)) != safe_add( nrows,(int)1 )) || ((NULL != _2187.get()) && ((int)((_2187)->size(0)) != nrows))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching expression lengths"));
    }
  }
  {}
  unchecked_add_l(_2184,_2185,_2186,_2187);
}
long long mosek::fusion::ConstraintCache :: flush(std::shared_ptr< monty::ndarray< int,1 > > _2188,std::shared_ptr< monty::ndarray< int,1 > > _2189,std::shared_ptr< monty::ndarray< double,1 > > _2190,std::shared_ptr< monty::ndarray< double,1 > > _2191) { return mosek::fusion::p_ConstraintCache::_get_impl(this)->flush(_2188,_2189,_2190,_2191); }long long mosek::fusion::p_ConstraintCache::flush(std::shared_ptr< monty::ndarray< int,1 > > _2188,std::shared_ptr< monty::ndarray< int,1 > > _2189,std::shared_ptr< monty::ndarray< double,1 > > _2190,std::shared_ptr< monty::ndarray< double,1 > > _2191){
  _checked_ptr_1<int> _ptr__2188(_2188 ? _2188->raw() : nullptr, _2188 ? _2188->size(0) : 0);
  _checked_ptr_1<int> _ptr__2189(_2189 ? _2189->raw() : nullptr, _2189 ? _2189->size(0) : 0);
  _checked_ptr_1<double> _ptr__2190(_2190 ? _2190->raw() : nullptr, _2190 ? _2190->size(0) : 0);
  _checked_ptr_1<double> _ptr__2191(_2191 ? _2191->raw() : nullptr, _2191 ? _2191->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2192 = nullptr;
  _checked_ptr_1<long long> _ptr__2192(_2192 ? _2192->raw() : nullptr,_2192 ? _2192->size(0) : 0);
  if (((NULL != bfix.get()) && (NULL != _2191.get())))
  {
    {
      int _7847 = (int)0;
      int _7848 = nrows;
      for (int _2193 = _7847; _2193 < _7848; ++_2193)
      {
        {
          _ptr__2191[_2193] = ((*bfix)(_2193));
        }
      }
    }
  }
  {}
  if ((nunordered == (long long)0))
  {
    {
      return (long long)0;
    }
  }
  {}
  bool _2194 = false;
  {
    int _2195 = (int)1;
    while ( ((_2195 < nunordered) && ((((*buffer_subi)((_2195 - (int)1))) < ((*buffer_subi)(_2195))) || ((((*buffer_subi)((_2195 - (int)1))) == ((*buffer_subi)(_2195))) && (((*buffer_subj)((_2195 - (int)1))) <= ((*buffer_subj)(_2195)))))) )
    {
      {
        ++ _2195;
      }
    }
    _2194 = (_2195 == nunordered);
  }
  if ((!_2194))
  {
    {
      std::vector<long long> _7849;
      for (long long _2196 = (int)0, _7850 = nunordered; _2196 < _7850 ; ++_2196)
      {
        _7849.push_back(_2196);
      }
      auto _7851 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7849.size()),_7849.begin(),_7849.end()));
      _2192 = _7851;
      _ptr__2192.update(_2192 ? _2192->raw() : nullptr, _2192 ? _2192->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_2192,buffer_subi,buffer_subj,(long long)0,nunordered);
    }
  }
  {}
  long long _2197 = nnz;
  std::shared_ptr< monty::ndarray< int,1 > > _2198 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( nunordered,_2197 ))));
  _checked_ptr_1<int> _ptr__2198(_2198 ? _2198->raw() : nullptr,_2198 ? _2198->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2199 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( nunordered,_2197 ))));
  _checked_ptr_1<int> _ptr__2199(_2199 ? _2199->raw() : nullptr,_2199 ? _2199->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2200 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_add( nunordered,_2197 ))));
  _checked_ptr_1<double> _ptr__2200(_2200 ? _2200->raw() : nullptr,_2200 ? _2200->size(0) : 0);
  long long _2201 = (long long)0;
  if (_2194)
  {
    {
      long long _2202 = (long long)0;
      int _2203 = (int)0;
      long long _2204 = nunordered;
      long long _2205 = _2197;
      int _2206 = (int)0;
      int _2207 = (int)0;
      while ( ((_2207 < _2205) && (_2206 < _2204)) )
      {
        {
          if (((((*subi)(_2207)) < ((*buffer_subi)(_2206))) || ((((*subi)(_2207)) == ((*buffer_subi)(_2206))) && (((*subj)(_2207)) < ((*buffer_subj)(_2206))))))
          {
            {
              _ptr__2198[_2203] = ((*subi)(_2207));
              _ptr__2199[_2203] = ((*subj)(_2207));
              _ptr__2200[_2203] = ((*cof)(_2207));
              ++ _2207;
              ++ _2203;
            }
          }
          else if(((((*subi)(_2207)) > ((*buffer_subi)(_2206))) || ((((*subi)(_2207)) == ((*buffer_subi)(_2206))) && (((*subj)(_2207)) > ((*buffer_subj)(_2206))))))
          {
            {
              _ptr__2198[_2203] = ((*buffer_subi)(_2206));
              _ptr__2199[_2203] = ((*buffer_subj)(_2206));
              _ptr__2200[_2203] = ((*buffer_cof)(_2206));
              _ptr__2188[_2201] = _ptr__2198[_2203];
              _ptr__2189[_2201] = _ptr__2199[_2203];
              _ptr__2190[_2201] = _ptr__2200[_2203];
              ++ _2201;
              ++ _2206;
              ++ _2203;
            }
          }
          else
          {
            {
              _ptr__2198[_2203] = ((*subi)(_2207));
              _ptr__2199[_2203] = ((*subj)(_2207));
              _ptr__2200[_2203] = ((*cof)(_2207));
              while ( ((_2207 < (int)((subi)->size(0))) && ((_2206 < (int)((buffer_subi)->size(0))) && ((((*subi)(_2207)) == ((*buffer_subi)(_2206))) && (((*subj)(_2207)) == ((*buffer_subj)(_2206)))))) )
              {
                {
                  _ptr__2200[_2203] = (_ptr__2200[_2203] + ((*buffer_cof)(_2206)));
                  ++ _2206;
                }
              }
              _ptr__2188[_2201] = _ptr__2198[_2203];
              _ptr__2189[_2201] = _ptr__2199[_2203];
              _ptr__2190[_2201] = _ptr__2200[_2203];
              ++ _2201;
              ++ _2207;
              ++ _2203;
            }
          }
        }
      }
      while ( (_2207 < _2205) )
      {
        {
          _ptr__2198[_2203] = ((*subi)(_2207));
          _ptr__2199[_2203] = ((*subj)(_2207));
          _ptr__2200[_2203] = ((*cof)(_2207));
          ++ _2207;
          ++ _2203;
        }
      }
      while ( (_2206 < _2204) )
      {
        {
          _ptr__2198[_2203] = ((*buffer_subi)(_2206));
          _ptr__2199[_2203] = ((*buffer_subj)(_2206));
          _ptr__2200[_2203] = ((*buffer_cof)(_2206));
          _ptr__2188[_2201] = _ptr__2198[_2203];
          _ptr__2189[_2201] = _ptr__2199[_2203];
          _ptr__2190[_2201] = _ptr__2200[_2203];
          ++ _2201;
          ++ _2206;
          ++ _2203;
        }
      }
      nnz = _2203;
    }
  }
  else
  {
    {
      long long _2208 = (long long)0;
      int _2209 = (int)0;
      long long _2210 = nunordered;
      long long _2211 = _2197;
      int _2212 = (int)0;
      int _2213 = (int)0;
      while ( ((_2213 < _2211) && (_2212 < _2210)) )
      {
        {
          if (((((*subi)(_2213)) < ((*buffer_subi)(_ptr__2192[_2212]))) || ((((*subi)(_2213)) == ((*buffer_subi)(_ptr__2192[_2212]))) && (((*subj)(_2213)) < ((*buffer_subj)(_ptr__2192[_2212]))))))
          {
            {
              _ptr__2198[_2209] = ((*subi)(_2213));
              _ptr__2199[_2209] = ((*subj)(_2213));
              _ptr__2200[_2209] = ((*cof)(_2213));
              ++ _2213;
              ++ _2209;
            }
          }
          else if(((((*subi)(_2213)) > ((*buffer_subi)(_ptr__2192[_2212]))) || ((((*subi)(_2213)) == ((*buffer_subi)(_ptr__2192[_2212]))) && (((*subj)(_2213)) > ((*buffer_subj)(_ptr__2192[_2212]))))))
          {
            {
              _ptr__2198[_2209] = ((*buffer_subi)(_ptr__2192[_2212]));
              _ptr__2199[_2209] = ((*buffer_subj)(_ptr__2192[_2212]));
              _ptr__2200[_2209] = ((*buffer_cof)(_ptr__2192[_2212]));
              _ptr__2188[_2201] = _ptr__2198[_2209];
              _ptr__2189[_2201] = _ptr__2199[_2209];
              _ptr__2190[_2201] = _ptr__2200[_2209];
              ++ _2201;
              ++ _2212;
              ++ _2209;
            }
          }
          else
          {
            {
              _ptr__2198[_2209] = ((*subi)(_2213));
              _ptr__2199[_2209] = ((*subj)(_2213));
              _ptr__2200[_2209] = ((*cof)(_2213));
              while ( ((((*subi)(_2213)) == ((*buffer_subi)(_ptr__2192[_2212]))) && (((*subj)(_2213)) == ((*buffer_subj)(_ptr__2192[_2212])))) )
              {
                {
                  _ptr__2200[_2209] = (_ptr__2200[_2209] + ((*buffer_cof)(_ptr__2192[_2212])));
                  ++ _2212;
                }
              }
              _ptr__2188[_2201] = _ptr__2198[_2209];
              _ptr__2189[_2201] = _ptr__2199[_2209];
              _ptr__2190[_2201] = _ptr__2200[_2209];
              ++ _2201;
              ++ _2213;
              ++ _2209;
            }
          }
        }
      }
      nnz = _2209;
    }
  }
  subi = _2198;
  subj = _2199;
  cof = _2200;
  nunordered = (long long)0;
  return _2201;
}
long long mosek::fusion::ConstraintCache :: numUnsorted() { return mosek::fusion::p_ConstraintCache::_get_impl(this)->numUnsorted(); }long long mosek::fusion::p_ConstraintCache::numUnsorted(){
  return nunordered;
}
monty::rc_ptr< ::mosek::fusion::ConstraintCache > mosek::fusion::p_ConstraintCache::__mosek_2fusion_2ConstraintCache__clone(){
  return ::mosek::fusion::p_ConstraintCache::_new_ConstraintCache(::mosek::fusion::ConstraintCache::t(_pubthis));
}
void mosek::fusion::p_ConstraintCache::destroy(){barmatidx.reset();barsubj.reset();barsubi.reset();buffer_subi.reset();buffer_subj.reset();buffer_cof.reset();bfix.reset();cof.reset();subi.reset();subj.reset();}void mosek::fusion::ConstraintCache::destroy() { mosek::fusion::p_ConstraintCache::_get_impl(this)->destroy(); }mosek::fusion::SliceConstraint::SliceConstraint(mosek::fusion::p_SliceConstraint *_impl) : mosek::fusion::Constraint(_impl) { /*std::cout << "SliceConstraint()" << this << std::endl; */ }mosek::fusion::SliceConstraint::~SliceConstraint() {  /* std::cout << "~SliceConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_SliceConstraint::p_SliceConstraint  (::mosek::fusion::SliceConstraint * _pubthis) :     mosek::fusion::p_Constraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SliceConstraint::t mosek::fusion::p_SliceConstraint::_new_SliceConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2214,    std::shared_ptr< monty::ndarray< int,1 > > _2215,    std::shared_ptr< monty::ndarray< int,1 > > _2216){ return new mosek::fusion::SliceConstraint(_2214,_2215,_2216); }mosek::fusion::SliceConstraint::SliceConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2214,    std::shared_ptr< monty::ndarray< int,1 > > _2215,    std::shared_ptr< monty::ndarray< int,1 > > _2216) :    SliceConstraint(new mosek::fusion::p_SliceConstraint(this)){ mosek::fusion::p_SliceConstraint::_get_impl(this)->_initialize(_2214,_2215,_2216); }void mosek::fusion::p_SliceConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2214,    std::shared_ptr< monty::ndarray< int,1 > > _2215,    std::shared_ptr< monty::ndarray< int,1 > > _2216){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2215(_2215 ? _2215->raw() : nullptr, _2215 ? _2215->size(0) : 0);
    _checked_ptr_1<int> _ptr__2216(_2216 ? _2216->raw() : nullptr, _2216 ? _2216->size(0) : 0);
    mosek::fusion::p_Constraint::_initialize(_2214,_2215,_2216);
  }
}std::string mosek::fusion::SliceConstraint :: toString() { return mosek::fusion::p_SliceConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_SliceConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2217 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2217->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("SliceConstraint()"));
  return _2217->toString();
}
void mosek::fusion::p_SliceConstraint::destroy(){}void mosek::fusion::SliceConstraint::destroy() { mosek::fusion::p_SliceConstraint::_get_impl(this)->destroy(); }mosek::fusion::RangedConstraint::RangedConstraint(mosek::fusion::p_RangedConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "RangedConstraint()" << this << std::endl; */ }mosek::fusion::RangedConstraint::~RangedConstraint() {  /* std::cout << "~RangedConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_RangedConstraint::p_RangedConstraint  (::mosek::fusion::RangedConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::RangedConstraint::t mosek::fusion::p_RangedConstraint::_new_RangedConstraint  (monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2218,    monty::rc_ptr< ::mosek::fusion::Model > _2219){ return new mosek::fusion::RangedConstraint(_2218,_2219); }mosek::fusion::RangedConstraint::RangedConstraint  (monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2218,    monty::rc_ptr< ::mosek::fusion::Model > _2219) :    RangedConstraint(new mosek::fusion::p_RangedConstraint(this)){ mosek::fusion::p_RangedConstraint::_get_impl(this)->_initialize(_2218,_2219); }void mosek::fusion::p_RangedConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2218,    monty::rc_ptr< ::mosek::fusion::Model > _2219){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2218,_2219);
    shape = mosek::fusion::p_RangedConstraint::_get_impl(_2218)->shape;
    nativeidxs = mosek::fusion::p_RangedConstraint::_get_impl(_2218)->nativeidxs;
  }
}mosek::fusion::RangedConstraint::t mosek::fusion::p_RangedConstraint::_new_RangedConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2220,    const std::string &  _2221,    std::shared_ptr< monty::ndarray< int,1 > > _2222,    std::shared_ptr< monty::ndarray< int,1 > > _2223){ return new mosek::fusion::RangedConstraint(_2220,_2221,_2222,_2223); }mosek::fusion::RangedConstraint::RangedConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2220,    const std::string &  _2221,    std::shared_ptr< monty::ndarray< int,1 > > _2222,    std::shared_ptr< monty::ndarray< int,1 > > _2223) :    RangedConstraint(new mosek::fusion::p_RangedConstraint(this)){ mosek::fusion::p_RangedConstraint::_get_impl(this)->_initialize(_2220,_2221,_2222,_2223); }void mosek::fusion::p_RangedConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2220,    const std::string &  _2221,    std::shared_ptr< monty::ndarray< int,1 > > _2222,    std::shared_ptr< monty::ndarray< int,1 > > _2223){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2222(_2222 ? _2222->raw() : nullptr, _2222 ? _2222->size(0) : 0);
    _checked_ptr_1<int> _ptr__2223(_2223 ? _2223->raw() : nullptr, _2223 ? _2223->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2220,_2221,_2222,_2223);
    mosek::fusion::p_RangedConstraint::_get_impl(::mosek::fusion::RangedConstraint::t(_pubthis))->shape = _2222;
    mosek::fusion::p_RangedConstraint::_get_impl(::mosek::fusion::RangedConstraint::t(_pubthis))->nativeidxs = _2223;
  }
}monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_RangedConstraint::__mosek_2fusion_2RangedConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2224){
  return (::mosek::fusion::p_RangedConstraint::_new_RangedConstraint(::mosek::fusion::RangedConstraint::t(_pubthis),_2224)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_RangedConstraint::destroy(){nativeidxs.reset();shape.reset();}void mosek::fusion::RangedConstraint::destroy() { mosek::fusion::p_RangedConstraint::_get_impl(this)->destroy(); }mosek::fusion::ConicConstraint::ConicConstraint(mosek::fusion::p_ConicConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "ConicConstraint()" << this << std::endl; */ }mosek::fusion::ConicConstraint::~ConicConstraint() {  /* std::cout << "~ConicConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_ConicConstraint::p_ConicConstraint  (::mosek::fusion::ConicConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ConicConstraint::t mosek::fusion::p_ConicConstraint::_new_ConicConstraint  (monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2225,    monty::rc_ptr< ::mosek::fusion::Model > _2226){ return new mosek::fusion::ConicConstraint(_2225,_2226); }mosek::fusion::ConicConstraint::ConicConstraint  (monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2225,    monty::rc_ptr< ::mosek::fusion::Model > _2226) :    ConicConstraint(new mosek::fusion::p_ConicConstraint(this)){ mosek::fusion::p_ConicConstraint::_get_impl(this)->_initialize(_2225,_2226); }void mosek::fusion::p_ConicConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2225,    monty::rc_ptr< ::mosek::fusion::Model > _2226){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2225,_2226);
    dom = mosek::fusion::p_ConicConstraint::_get_impl(_2225)->dom;
    conid = mosek::fusion::p_ConicConstraint::_get_impl(_2225)->conid;
    shape = mosek::fusion::p_ConicConstraint::_get_impl(_2225)->shape;
    name = mosek::fusion::p_ConicConstraint::_get_impl(_2225)->name;
    nativeidxs = mosek::fusion::p_ConicConstraint::_get_impl(_2225)->nativeidxs;
    nativeslack = mosek::fusion::p_ConicConstraint::_get_impl(_2225)->nativeslack;
    names_flushed = mosek::fusion::p_ConicConstraint::_get_impl(_2225)->names_flushed;
  }
}mosek::fusion::ConicConstraint::t mosek::fusion::p_ConicConstraint::_new_ConicConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2227,    const std::string &  _2228,    monty::rc_ptr< ::mosek::fusion::ConeDomain > _2229,    std::shared_ptr< monty::ndarray< int,1 > > _2230,    int _2231,    std::shared_ptr< monty::ndarray< int,1 > > _2232,    std::shared_ptr< monty::ndarray< int,1 > > _2233){ return new mosek::fusion::ConicConstraint(_2227,_2228,_2229,_2230,_2231,_2232,_2233); }mosek::fusion::ConicConstraint::ConicConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2227,    const std::string &  _2228,    monty::rc_ptr< ::mosek::fusion::ConeDomain > _2229,    std::shared_ptr< monty::ndarray< int,1 > > _2230,    int _2231,    std::shared_ptr< monty::ndarray< int,1 > > _2232,    std::shared_ptr< monty::ndarray< int,1 > > _2233) :    ConicConstraint(new mosek::fusion::p_ConicConstraint(this)){ mosek::fusion::p_ConicConstraint::_get_impl(this)->_initialize(_2227,_2228,_2229,_2230,_2231,_2232,_2233); }void mosek::fusion::p_ConicConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2227,    const std::string &  _2228,    monty::rc_ptr< ::mosek::fusion::ConeDomain > _2229,    std::shared_ptr< monty::ndarray< int,1 > > _2230,    int _2231,    std::shared_ptr< monty::ndarray< int,1 > > _2232,    std::shared_ptr< monty::ndarray< int,1 > > _2233){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2230(_2230 ? _2230->raw() : nullptr, _2230 ? _2230->size(0) : 0);
    _checked_ptr_1<int> _ptr__2232(_2232 ? _2232->raw() : nullptr, _2232 ? _2232->size(0) : 0);
    _checked_ptr_1<int> _ptr__2233(_2233 ? _2233->raw() : nullptr, _2233 ? _2233->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2227,_2228,_2230,_2232);
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->dom = _2229;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->shape = _2230;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->name = _2228;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->nativeidxs = _2232;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->nativeslack = _2233;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->conid = _2231;
    names_flushed = false;
  }
}void mosek::fusion::p_ConicConstraint::flushNames(){
  ::mosek::fusion::p_ModelConstraint::flushNames();
  int _2234 = (int)((nativeslack)->size(0));
  monty::rc_ptr< ::mosek::fusion::Model > _2235 = _pubthis->__mosek_2fusion_2Constraint__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      if (((int)((name).size()) == (int)0))
      {
        {
          int _7852 = (int)0;
          int _7853 = _2234;
          for (int _2236 = _7852; _2236 < _7853; ++_2236)
          {
            {
              mosek::fusion::p_Model::_get_impl(_2235.get())->task_var_name(((*nativeslack)(_2236)),std::string (""));
            }
          }
        }
      }
      else
      {
        {
          monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2237 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
          int _7854 = (int)0;
          int _7855 = _2234;
          for (int _2238 = _7854; _2238 < _7855; ++_2238)
          {
            {
              mosek::fusion::p_Model::_get_impl(_2235.get())->task_var_name(((*nativeslack)(_2238)),_2237->__mosek_2fusion_2Utils_2StringBuffer__clear()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a(::mosek::fusion::p_Set::indexToString(shape,(long long)(_2238)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("].coneslack"))->toString());
            }
          }
        }
      }
      names_flushed = true;
    }
  }
  {}
}
std::string mosek::fusion::ConicConstraint :: toString() { return mosek::fusion::p_ConicConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_ConicConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2239 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2239->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ConicConstraint('"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("')"));
  return _2239->toString();
}
void mosek::fusion::p_ConicConstraint::domainToString(long long _2240,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2241){
  throw ::mosek::fusion::UnimplementedError(std::string ("ConicConstraint.domainToString"));
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_ConicConstraint::__mosek_2fusion_2ConicConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2242){
  return (::mosek::fusion::p_ConicConstraint::_new_ConicConstraint(::mosek::fusion::ConicConstraint::t(_pubthis),_2242)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_ConicConstraint::destroy(){nativeslack.reset();nativeidxs.reset();shape.reset();dom.reset();}void mosek::fusion::ConicConstraint::destroy() { mosek::fusion::p_ConicConstraint::_get_impl(this)->destroy(); }mosek::fusion::LinearConstraint::LinearConstraint(mosek::fusion::p_LinearConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "LinearConstraint()" << this << std::endl; */ }mosek::fusion::LinearConstraint::~LinearConstraint() {  /* std::cout << "~LinearConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearConstraint::p_LinearConstraint  (::mosek::fusion::LinearConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearConstraint::t mosek::fusion::p_LinearConstraint::_new_LinearConstraint  (monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2243,    monty::rc_ptr< ::mosek::fusion::Model > _2244){ return new mosek::fusion::LinearConstraint(_2243,_2244); }mosek::fusion::LinearConstraint::LinearConstraint  (monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2243,    monty::rc_ptr< ::mosek::fusion::Model > _2244) :    LinearConstraint(new mosek::fusion::p_LinearConstraint(this)){ mosek::fusion::p_LinearConstraint::_get_impl(this)->_initialize(_2243,_2244); }void mosek::fusion::p_LinearConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2243,    monty::rc_ptr< ::mosek::fusion::Model > _2244){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2243,_2244);
    conid = mosek::fusion::p_LinearConstraint::_get_impl(_2243)->conid;
    name = mosek::fusion::p_LinearConstraint::_get_impl(_2243)->name;
  }
}mosek::fusion::LinearConstraint::t mosek::fusion::p_LinearConstraint::_new_LinearConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2245,    const std::string &  _2246,    int _2247,    std::shared_ptr< monty::ndarray< int,1 > > _2248,    std::shared_ptr< monty::ndarray< int,1 > > _2249){ return new mosek::fusion::LinearConstraint(_2245,_2246,_2247,_2248,_2249); }mosek::fusion::LinearConstraint::LinearConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2245,    const std::string &  _2246,    int _2247,    std::shared_ptr< monty::ndarray< int,1 > > _2248,    std::shared_ptr< monty::ndarray< int,1 > > _2249) :    LinearConstraint(new mosek::fusion::p_LinearConstraint(this)){ mosek::fusion::p_LinearConstraint::_get_impl(this)->_initialize(_2245,_2246,_2247,_2248,_2249); }void mosek::fusion::p_LinearConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2245,    const std::string &  _2246,    int _2247,    std::shared_ptr< monty::ndarray< int,1 > > _2248,    std::shared_ptr< monty::ndarray< int,1 > > _2249){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2248(_2248 ? _2248->raw() : nullptr, _2248 ? _2248->size(0) : 0);
    _checked_ptr_1<int> _ptr__2249(_2249 ? _2249->raw() : nullptr, _2249 ? _2249->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2245,_2246,_2248,_2249);
    mosek::fusion::p_LinearConstraint::_get_impl(::mosek::fusion::LinearConstraint::t(_pubthis))->conid = _2247;
    mosek::fusion::p_LinearConstraint::_get_impl(::mosek::fusion::LinearConstraint::t(_pubthis))->name = _2246;
  }
}std::string mosek::fusion::LinearConstraint :: toString() { return mosek::fusion::p_LinearConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_LinearConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2250 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2250->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("LinearConstraint('"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("')"));
  return _2250->toString();
}
void mosek::fusion::p_LinearConstraint::domainToString(long long _2251,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2252){
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_LinearConstraint::__mosek_2fusion_2LinearConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2253){
  return (::mosek::fusion::p_LinearConstraint::_new_LinearConstraint(::mosek::fusion::LinearConstraint::t(_pubthis),_2253)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_LinearConstraint::destroy(){}void mosek::fusion::LinearConstraint::destroy() { mosek::fusion::p_LinearConstraint::_get_impl(this)->destroy(); }mosek::fusion::ModelConstraint::ModelConstraint(mosek::fusion::p_ModelConstraint *_impl) : mosek::fusion::Constraint(_impl) { /*std::cout << "ModelConstraint()" << this << std::endl; */ }mosek::fusion::ModelConstraint::~ModelConstraint() {  /* std::cout << "~ModelConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_ModelConstraint::p_ModelConstraint  (::mosek::fusion::ModelConstraint * _pubthis) :     mosek::fusion::p_Constraint(_pubthis),    _pubthis(_pubthis){}void mosek::fusion::p_ModelConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::ModelConstraint > _2254,    monty::rc_ptr< ::mosek::fusion::Model > _2255){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Constraint::_initialize(_2254,_2255);
    name = mosek::fusion::p_ModelConstraint::_get_impl(_2254)->name;
    names_flushed = mosek::fusion::p_ModelConstraint::_get_impl(_2254)->names_flushed;
    nativeidxs = mosek::fusion::p_ModelConstraint::_get_impl(_2254)->nativeidxs;
    shape = mosek::fusion::p_ModelConstraint::_get_impl(_2254)->shape;
  }
}void mosek::fusion::p_ModelConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2256,    const std::string &  _2257,    std::shared_ptr< monty::ndarray< int,1 > > _2258,    std::shared_ptr< monty::ndarray< int,1 > > _2259){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2258(_2258 ? _2258->raw() : nullptr, _2258 ? _2258->size(0) : 0);
    _checked_ptr_1<int> _ptr__2259(_2259 ? _2259->raw() : nullptr, _2259 ? _2259->size(0) : 0);
    mosek::fusion::p_Constraint::_initialize(_2256,_2258,_2259);
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->name = _2257;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->names_flushed = false;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->nativeidxs = _2259;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->shape = _2258;
  }
}std::string mosek::fusion::ModelConstraint :: toString() { return mosek::fusion::p_ModelConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_ModelConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2260 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2260->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Constraint('"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("')"));
  return _2260->toString();
}
void mosek::fusion::p_ModelConstraint::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _2261 = _pubthis->__mosek_2fusion_2Constraint__getModel();
  if ((!names_flushed))
  {
    {
      if (((int)((name).size()) == (int)0))
      {
        {
          mosek::fusion::p_Model::_get_impl(_2261.get())->connames(nativeidxs,std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_pubthis->getSize())}),std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
        }
      }
      else
      {
        {
          monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2262 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
          _2262->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
          if ((_pubthis->getND() > (int)0))
          {
            {
              _2262->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
              int _7856 = (int)1;
              int _7857 = _pubthis->getND();
              for (int _2263 = _7856; _2263 < _7857; ++_2263)
              {
                {
                  _2262->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2263);
                }
              }
            }
          }
          {}
          _2262->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
          std::shared_ptr< monty::ndarray< int,1 > > _7858;
          bool _7859 = (_pubthis->getND() > (int)0);
          if (_7859)
          {
            _7858 = _pubthis->getShape();
          }
          else
          {
            _7858 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1)});
          }
          mosek::fusion::p_Model::_get_impl(_2261.get())->connames(nativeidxs,_2262->toString(),_7858,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
          names_flushed = true;
        }
      }
    }
  }
  {}
}
void mosek::fusion::p_ModelConstraint::destroy(){shape.reset();nativeidxs.reset();}void mosek::fusion::ModelConstraint::destroy() { mosek::fusion::p_ModelConstraint::_get_impl(this)->destroy(); }mosek::fusion::Constraint::Constraint(mosek::fusion::p_Constraint *_impl) : _impl(_impl) { /*std::cout << "Constraint() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Constraint::~Constraint() { delete _impl; _impl = nullptr; }mosek::fusion::p_Constraint::p_Constraint  (::mosek::fusion::Constraint * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_Constraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Constraint > _2265,    monty::rc_ptr< ::mosek::fusion::Model > _2266){monty::rc_reserve __reserve_this(_pubthis);   {
    model = _2266;
    shape = mosek::fusion::p_Constraint::_get_impl(_2265)->shape;
    nativeidxs = mosek::fusion::p_Constraint::_get_impl(_2265)->nativeidxs;
  }
}void mosek::fusion::p_Constraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2267,    std::shared_ptr< monty::ndarray< int,1 > > _2268,    std::shared_ptr< monty::ndarray< int,1 > > _2269){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2268(_2268 ? _2268->raw() : nullptr, _2268 ? _2268->size(0) : 0);
    _checked_ptr_1<int> _ptr__2269(_2269 ? _2269->raw() : nullptr, _2269 ? _2269->size(0) : 0);
    mosek::fusion::p_Constraint::_get_impl(::mosek::fusion::Constraint::t(_pubthis))->model = _2267;
    mosek::fusion::p_Constraint::_get_impl(::mosek::fusion::Constraint::t(_pubthis))->shape = _2268;
    mosek::fusion::p_Constraint::_get_impl(::mosek::fusion::Constraint::t(_pubthis))->nativeidxs = _2269;
  }
}std::string mosek::fusion::Constraint :: toString() { return mosek::fusion::p_Constraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_Constraint::toString(){
  throw ::mosek::fusion::UnimplementedError(std::string ("Constraint.toString"));
}
void mosek::fusion::p_Constraint::toStringArray(std::shared_ptr< monty::ndarray< long long,1 > > _2270,long long _2271,std::shared_ptr< monty::ndarray< std::string,1 > > _2272){
  _checked_ptr_1<long long> _ptr__2270(_2270 ? _2270->raw() : nullptr, _2270 ? _2270->size(0) : 0);
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::Constraint :: dual() { return mosek::fusion::p_Constraint::_get_impl(this)->dual(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Constraint::dual(){
  std::shared_ptr< monty::ndarray< double,1 > > _2273 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__2273(_2273 ? _2273->raw() : nullptr,_2273 ? _2273->size(0) : 0);
  values(false,(int)0,_2273);
  return _2273;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::Constraint :: level() { return mosek::fusion::p_Constraint::_get_impl(this)->level(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Constraint::level(){
  std::shared_ptr< monty::ndarray< double,1 > > _2274 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__2274(_2274 ? _2274->raw() : nullptr,_2274 ? _2274->size(0) : 0);
  values(true,(int)0,_2274);
  return _2274;
}
void mosek::fusion::p_Constraint::values(bool _2275,int _2276,std::shared_ptr< monty::ndarray< double,1 > > _2277){
  _checked_ptr_1<double> _ptr__2277(_2277 ? _2277->raw() : nullptr, _2277 ? _2277->size(0) : 0);
  model->getConstraintValues(_2275,nativeidxs,_2277,_2276);
}
void mosek::fusion::Constraint :: update(std::shared_ptr< monty::ndarray< double,1 > > _2278) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2278); }void mosek::fusion::p_Constraint::update(std::shared_ptr< monty::ndarray< double,1 > > _2278){
  _checked_ptr_1<double> _ptr__2278(_2278 ? _2278->raw() : nullptr, _2278 ? _2278->size(0) : 0);
  mosek::fusion::p_Model::_get_impl(model.get())->update_bfix(nativeidxs,_2278);
}
void mosek::fusion::Constraint :: update(monty::rc_ptr< ::mosek::fusion::Expression > _2279) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2279); }void mosek::fusion::p_Constraint::update(monty::rc_ptr< ::mosek::fusion::Expression > _2279){
  std::shared_ptr< monty::ndarray< int,1 > > _2280 = _2279->getShape();
  _checked_ptr_1<int> _ptr__2280(_2280 ? _2280->raw() : nullptr,_2280 ? _2280->size(0) : 0);
  if (((int)((shape)->size(0)) < (int)((_2280)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
    }
  }
  {}
  int _7860 = (int)0;
  int _7861 = (int)((_2280)->size(0));
  for (int _2281 = _7860; _2281 < _7861; ++_2281)
  {
    {
      if ((_ptr__2280[_2281] != ((*shape)(_2281))))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  int _7862 = (int)((_2280)->size(0));
  int _7863 = (int)((shape)->size(0));
  for (int _2282 = _7862; _2282 < _7863; ++_2282)
  {
    {
      if ((((*shape)(_2282)) != (int)1))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  mosek::fusion::p_Model::_get_impl(model.get())->update(nativeidxs,_2279);
}
void mosek::fusion::Constraint :: update(monty::rc_ptr< ::mosek::fusion::Expression > _2283,monty::rc_ptr< ::mosek::fusion::Variable > _2284,bool _2285) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2283,_2284,_2285); }void mosek::fusion::p_Constraint::update(monty::rc_ptr< ::mosek::fusion::Expression > _2283,monty::rc_ptr< ::mosek::fusion::Variable > _2284,bool _2285){
  int _2286 = _pubthis->getND();
  std::shared_ptr< monty::ndarray< int,1 > > _2287 = _2283->getShape();
  _checked_ptr_1<int> _ptr__2287(_2287 ? _2287->raw() : nullptr,_2287 ? _2287->size(0) : 0);
  if ((_2286 < (int)((_2287)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
    }
  }
  {}
  int _7864 = (int)0;
  int _7865 = (int)((_2287)->size(0));
  for (int _2288 = _7864; _2288 < _7865; ++_2288)
  {
    {
      if ((_ptr__2287[_2288] != ((*shape)(_2288))))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  int _7866 = (int)((_2287)->size(0));
  int _7867 = (int)((shape)->size(0));
  for (int _2289 = _7866; _2289 < _7867; ++_2289)
  {
    {
      if ((((*shape)(_2289)) != (int)1))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  int _2290 = _2284->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _2291 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2290)));
  _checked_ptr_1<long long> _ptr__2291(_2291 ? _2291->raw() : nullptr,_2291 ? _2291->size(0) : 0);
  if ((_2290 < _2284->getSize()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2292 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2290)));
      _checked_ptr_1<long long> _ptr__2292(_2292 ? _2292->raw() : nullptr,_2292 ? _2292->size(0) : 0);
      _2284->inst((int)0,_2292,(int)0,_2291);
    }
  }
  else
  {
    {
      _2284->inst((int)0,_2291);
    }
  }
  int _7868 = (int)0;
  int _7869 = _2290;
  for (int _2293 = _7868; _2293 < _7869; ++_2293)
  {
    {
      if ((_ptr__2291[_2293] < (int)0))
      {
        {
          throw ::mosek::fusion::UnimplementedError(std::string ("Updating semidefinite terms is currently not possible"));
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2294;
  _checked_ptr_1<int> _ptr__2294(_2294 ? _2294->raw() : nullptr,_2294 ? _2294->size(0) : 0);
  {
    bool _2295 = true;
    int _7870 = (int)0;
    int _7871 = (_2290 - (int)1);
    for (int _2296 = _7870; _2296 < _7871; ++_2296)
    {
      {
        _2295 = (_2295 && (_ptr__2291[_2296] < _ptr__2291[safe_add( _2296,(int)1 )]));
      }
    }
    if (_2295)
    {
      {
        std::vector<int> _7872;
        for (int _2297 = (int)0, _7873 = _2290; _2297 < _7873 ; ++_2297)
        {
          _7872.push_back((int)(_ptr__2291[_2297] - (int)1));
        }
        auto _7874 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7872.size()),_7872.begin(),_7872.end()));
        _2294 = _7874;
        _ptr__2294.update(_2294 ? _2294->raw() : nullptr, _2294 ? _2294->size(0) : 0);
      }
    }
    else
    {
      {
        std::vector<long long> _7875;
        for (int _2299 = (int)0, _7876 = _2290; _2299 < _7876 ; ++_2299)
        {
          _7875.push_back(_2299);
        }
        auto _7877 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7875.size()),_7875.begin(),_7875.end()));
        std::shared_ptr< monty::ndarray< long long,1 > > _2298 = _7877;
        _checked_ptr_1<long long> _ptr__2298(_2298 ? _2298->raw() : nullptr,_2298 ? _2298->size(0) : 0);
        ::mosek::fusion::p_CommonTools::argQsort(_2298,_2291,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_2290));
        int _2300 = (int)1;
        int _7878 = (int)1;
        int _7879 = _2290;
        for (int _2301 = _7878; _2301 < _7879; ++_2301)
        {
          {
            if ((_ptr__2291[_ptr__2298[(_2301 - (int)1)]] < _ptr__2291[_ptr__2298[_2301]]))
            {
              {
                ++ _2300;
              }
            }
            {}
          }
        }
        _2294 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2300)));
        _ptr__2294.update(_2294 ? _2294->raw() : nullptr, _2294 ? _2294->size(0) : 0);
        int _2302 = (int)0;
        _ptr__2294[(int)0] = (int)(_ptr__2291[_ptr__2298[(int)0]] - (int)1);
        int _7880 = (int)1;
        int _7881 = _2290;
        for (int _2303 = _7880; _2303 < _7881; ++_2303)
        {
          {
            if ((_ptr__2291[(_2303 - (int)1)] < _ptr__2291[_2303]))
            {
              {
                _ptr__2294[_2302] = (int)(_ptr__2291[_ptr__2298[_2303]] - (int)1);
                ++ _2302;
              }
            }
            {}
          }
        }
      }
    }
  }
  mosek::fusion::p_Model::_get_impl(model.get())->update(nativeidxs,_2283,_2294,_2285);
}
void mosek::fusion::Constraint :: update(monty::rc_ptr< ::mosek::fusion::Expression > _2304,monty::rc_ptr< ::mosek::fusion::Variable > _2305) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2304,_2305); }void mosek::fusion::p_Constraint::update(monty::rc_ptr< ::mosek::fusion::Expression > _2304,monty::rc_ptr< ::mosek::fusion::Variable > _2305){
  _pubthis->update(_2304,_2305,false);
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__get_model() { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__get_model(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint::get_model() { return __mosek_2fusion_2Constraint__get_model(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__get_model(){
  return model;
}
int mosek::fusion::Constraint :: get_nd() { return mosek::fusion::p_Constraint::_get_impl(this)->get_nd(); }int mosek::fusion::p_Constraint::get_nd(){
  return (int)((shape)->size(0));
}
long long mosek::fusion::Constraint :: size() { return mosek::fusion::p_Constraint::_get_impl(this)->size(); }long long mosek::fusion::p_Constraint::size(){
  long long _2306 = (int)1;
  int _7882 = (int)0;
  int _7883 = (int)((shape)->size(0));
  for (int _2307 = _7882; _2307 < _7883; ++_2307)
  {
    {
      _2306 *= ((*shape)(_2307));
    }
  }
  return _2306;
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::stack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2308,    int _2309) { return mosek::fusion::p_Constraint::stack(_2308,_2309); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2308,int _2309){
  return ::mosek::fusion::p_Constraint::dstack(_2308,_2309);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::stack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2310,    monty::rc_ptr< ::mosek::fusion::Constraint > _2311,    monty::rc_ptr< ::mosek::fusion::Constraint > _2312,    int _2313) { return mosek::fusion::p_Constraint::stack(_2310,_2311,_2312,_2313); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2310,monty::rc_ptr< ::mosek::fusion::Constraint > _2311,monty::rc_ptr< ::mosek::fusion::Constraint > _2312,int _2313){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2310.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2311.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2312.get())}),_2313);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::stack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2314,    monty::rc_ptr< ::mosek::fusion::Constraint > _2315,    int _2316) { return mosek::fusion::p_Constraint::stack(_2314,_2315,_2316); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2314,monty::rc_ptr< ::mosek::fusion::Constraint > _2315,int _2316){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2314.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2315.get())}),_2316);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2317) { return mosek::fusion::p_Constraint::hstack(_2317); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2317){
  return ::mosek::fusion::p_Constraint::dstack(_2317,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2318) { return mosek::fusion::p_Constraint::vstack(_2318); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2318){
  return ::mosek::fusion::p_Constraint::dstack(_2318,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::hstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2319,    monty::rc_ptr< ::mosek::fusion::Constraint > _2320,    monty::rc_ptr< ::mosek::fusion::Constraint > _2321) { return mosek::fusion::p_Constraint::hstack(_2319,_2320,_2321); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2319,monty::rc_ptr< ::mosek::fusion::Constraint > _2320,monty::rc_ptr< ::mosek::fusion::Constraint > _2321){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2319.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2320.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2321.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::vstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2322,    monty::rc_ptr< ::mosek::fusion::Constraint > _2323,    monty::rc_ptr< ::mosek::fusion::Constraint > _2324) { return mosek::fusion::p_Constraint::vstack(_2322,_2323,_2324); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2322,monty::rc_ptr< ::mosek::fusion::Constraint > _2323,monty::rc_ptr< ::mosek::fusion::Constraint > _2324){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2322.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2323.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2324.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::hstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2325,    monty::rc_ptr< ::mosek::fusion::Constraint > _2326) { return mosek::fusion::p_Constraint::hstack(_2325,_2326); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2325,monty::rc_ptr< ::mosek::fusion::Constraint > _2326){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2325.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2326.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::vstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2327,    monty::rc_ptr< ::mosek::fusion::Constraint > _2328) { return mosek::fusion::p_Constraint::vstack(_2327,_2328); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2327,monty::rc_ptr< ::mosek::fusion::Constraint > _2328){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2327.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2328.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2329,int _2330){
  monty::rc_ptr< ::mosek::fusion::Model > _2331 = nullptr;
  {
    int _7884 = (int)0;
    int _7885 = (int)((_2329)->size(0));
    for (int _2332 = _7884; _2332 < _7885; ++_2332)
    {
      {
        if ((NULL == _2331.get()))
        {
          {
            _2331 = ((*_2329)(_2332))->__mosek_2fusion_2Constraint__getModel();
          }
        }
        else if(((NULL != mosek::fusion::p_Constraint::_get_impl(((*_2329)(_2332)))->model.get()) && (mosek::fusion::p_Constraint::_get_impl(((*_2329)(_2332)))->model != _2331)))
        {
          {
            monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2333 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
            std::string _7886;
            bool _7887 = ((int)((mosek::fusion::p_Model::_get_impl(_2331.get())->getName()).size()) > (int)0);
            if (_7887)
            {
              _7886 = mosek::fusion::p_Model::_get_impl(_2331.get())->getName();
            }
            else
            {
              _7886 = std::string ("?");
            }
            std::string _2334 = _7886;
            std::string _7888;
            bool _7889 = ((int)((mosek::fusion::p_Model::_get_impl(((*_2329)(_2332))->__mosek_2fusion_2Constraint__getModel().get())->getName()).size()) > (int)0);
            if (_7889)
            {
              _7888 = mosek::fusion::p_Model::_get_impl(((*_2329)(_2332))->__mosek_2fusion_2Constraint__getModel().get())->getName();
            }
            else
            {
              _7888 = std::string ("?");
            }
            std::string _2335 = _7888;
            _2333->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Constraints belong to different models: '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2334)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("' and '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2335)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"));
            throw ::mosek::fusion::ModelError(_2333->toString());
          }
        }
        {}
      }
    }
  }
  if (((int)((_2329)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))))).as<::mosek::fusion::Constraint>();
    }
  }
  else if(((int)((_2329)->size(0)) == (int)1))
  {
    {
      return ((*_2329)((int)1));
    }
  }
  else
  {
    {
      int _2336 = (int)((_2329)->size(0));
      int _2337 = (int)1;
      int _7890 = (int)0;
      int _7891 = _2336;
      for (int _2338 = _7890; _2338 < _7891; ++_2338)
      {
        {
          int _7892;
          bool _7893 = (((*_2329)(_2338))->getND() > _2337);
          if (_7893)
          {
            _7892 = ((*_2329)(_2338))->getND();
          }
          else
          {
            _7892 = _2337;
          }
          _2337 = _7892;
        }
      }
      if ((_2330 == _2337))
      {
        {
          ++ _2337;
        }
      }
      {}
      std::shared_ptr< monty::ndarray< int,2 > > _2339 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape(_2336,_2337)));
      int _7894 = (int)0;
      int _7895 = _2336;
      for (int _2340 = _7894; _2340 < _7895; ++_2340)
      {
        {
          int _7896 = (int)0;
          int _7897 = _2337;
          for (int _2341 = _7896; _2341 < _7897; ++_2341)
          {
            {
              ((*_2339)(_2340,_2341)) = (int)1;
            }
          }
        }
      }
      std::vector<int> _7898;
      for (int _2343 = (int)0, _7899 = _2336; _2343 < _7899 ; ++_2343)
      {
        _7898.push_back(((*_2329)(_2343))->getSize());
      }
      auto _7900 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7898.size()),_7898.begin(),_7898.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2342 = _7900;
      _checked_ptr_1<int> _ptr__2342(_2342 ? _2342->raw() : nullptr,_2342 ? _2342->size(0) : 0);
      int _2344 = (int)0;
      int _7901 = (int)0;
      int _7902 = _2336;
      for (int _2345 = _7901; _2345 < _7902; ++_2345)
      {
        {
          _2344 += _ptr__2342[_2345];
        }
      }
      int _7903 = (int)0;
      int _7904 = _2336;
      for (int _2346 = _7903; _2346 < _7904; ++_2346)
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2347 = ((*_2329)(_2346))->getShape();
          _checked_ptr_1<int> _ptr__2347(_2347 ? _2347->raw() : nullptr,_2347 ? _2347->size(0) : 0);
          int _7905 = (int)0;
          int _7906 = (int)((_2347)->size(0));
          for (int _2348 = _7905; _2348 < _7906; ++_2348)
          {
            {
              ((*_2339)(_2346,_2348)) = _ptr__2347[_2348];
            }
          }
        }
      }
      if (((_2330 < (int)0) || (_2330 > _2337)))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
        }
      }
      {}
      int _7907 = (int)0;
      int _7908 = _2330;
      for (int _2349 = _7907; _2349 < _7908; ++_2349)
      {
        {
          int _7909 = (int)1;
          int _7910 = _2336;
          for (int _2350 = _7909; _2350 < _7910; ++_2350)
          {
            {
              if ((((*_2339)((int)0,_2349)) != ((*_2339)(_2350,_2349))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Constraint dimensions do not match"));
                }
              }
              {}
            }
          }
        }
      }
      int _7911 = safe_add( _2330,(int)1 );
      int _7912 = _2337;
      for (int _2351 = _7911; _2351 < _7912; ++_2351)
      {
        {
          int _7913 = (int)1;
          int _7914 = _2336;
          for (int _2352 = _7913; _2352 < _7914; ++_2352)
          {
            {
              if ((((*_2339)((int)0,_2351)) != ((*_2339)(_2352,_2351))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Constraint dimensions do not match"));
                }
              }
              {}
            }
          }
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2353 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2344)));
      _checked_ptr_1<int> _ptr__2353(_2353 ? _2353->raw() : nullptr,_2353 ? _2353->size(0) : 0);
      std::vector<int> _7915;
      for (int _2355 = (int)0, _7916 = _2337; _2355 < _7916 ; ++_2355)
      {
        _7915.push_back(((*_2339)((int)0,_2355)));
      }
      auto _7917 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7915.size()),_7915.begin(),_7915.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2354 = _7917;
      _checked_ptr_1<int> _ptr__2354(_2354 ? _2354->raw() : nullptr,_2354 ? _2354->size(0) : 0);
      int _7918 = (int)0;
      int _7919 = _2337;
      for (int _2356 = _7918; _2356 < _7919; ++_2356)
      {
        {
          _ptr__2354[_2330] += ((*_2339)(_2356,_2330));
        }
      }
      {
        int _2357 = (int)((_2354)->size(0));
        std::shared_ptr< monty::ndarray< long long,1 > > _2358 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( (int)((_2329)->size(0)),(int)1 ))));
        _checked_ptr_1<long long> _ptr__2358(_2358 ? _2358->raw() : nullptr,_2358 ? _2358->size(0) : 0);
        int _7920 = (int)0;
        int _7921 = (int)((_2329)->size(0));
        for (int _2359 = _7920; _2359 < _7921; ++_2359)
        {
          {
            _ptr__2358[safe_add( _2359,(int)1 )] = safe_add( _ptr__2358[_2359],((*_2339)(_2359,_2330)) );
          }
        }
        if ((_2330 == (int)0))
        {
          {
            int _2360 = (int)0;
            int _7922 = (int)0;
            int _7923 = _2336;
            for (int _2361 = _7922; _2361 < _7923; ++_2361)
            {
              {
                int _2362 = (int)((mosek::fusion::p_Constraint::_get_impl(((*_2329)(_2361)))->nativeidxs)->size(0));
                ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Constraint::_get_impl(((*_2329)(_2361)))->nativeidxs,(int)0,_2353,_2360,_2362);
                _2360 += _2362;
              }
            }
          }
        }
        else
        {
          {
            std::vector<std::shared_ptr< monty::ndarray< int,1 > >> _7924;
            for (int _2364 = (int)0, _7925 = _2336; _2364 < _7925 ; ++_2364)
            {
              _7924.push_back(mosek::fusion::p_Constraint::_get_impl(((*_2329)(_2364)))->nativeidxs);
            }
            auto _7926 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape(_7924.size()),_7924.begin(),_7924.end()));
            std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _2363 = _7926;
            if ((_2330 < _2337))
            {
              {
                int _2365 = (int)1;
                int _7927 = (int)0;
                int _7928 = _2330;
                for (int _2366 = _7927; _2366 < _7928; ++_2366)
                {
                  {
                    _2365 *= _ptr__2354[_2366];
                  }
                }
                int _2367 = (int)1;
                int _7929 = safe_add( _2330,(int)1 );
                int _7930 = _2337;
                for (int _2368 = _7929; _2368 < _7930; ++_2368)
                {
                  {
                    _2367 *= _ptr__2354[_2368];
                  }
                }
                int _2369 = (int)0;
                int _7931 = (int)0;
                int _7932 = _2365;
                for (int _2370 = _7931; _2370 < _7932; ++_2370)
                {
                  {
                    int _7933 = (int)0;
                    int _7934 = _2336;
                    for (int _2371 = _7933; _2371 < _7934; ++_2371)
                    {
                      {
                        int _2372 = (int)0;
                        int _2373 = ((*_2339)(_2371,_2330));
                        int _7935 = (int)0;
                        int _7936 = _2373;
                        for (int _2374 = _7935; _2374 < _7936; ++_2374)
                        {
                          {
                            int _7937 = (int)0;
                            int _7938 = _2367;
                            for (int _2375 = _7937; _2375 < _7938; ++_2375)
                            {
                              {
                                _ptr__2353[_2369] = ((*mosek::fusion::p_Constraint::_get_impl(((*_2329)(_2336)))->nativeidxs)(safe_add( safe_mul( safe_mul( _2370,_2367 ),_2373 ),_2372 )));
                                ++ _2369;
                                ++ _2372;
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
            else
            {
              {
                int _2376 = (int)1;
                int _7939 = (int)0;
                int _7940 = _2337;
                for (int _2377 = _7939; _2377 < _7940; ++_2377)
                {
                  {
                    _2376 *= _ptr__2354[_2377];
                  }
                }
                int _2378 = (int)0;
                int _7941 = (int)0;
                int _7942 = _2376;
                for (int _2379 = _7941; _2379 < _7942; ++_2379)
                {
                  {
                    int _7943 = (int)0;
                    int _7944 = _2336;
                    for (int _2380 = _7943; _2380 < _7944; ++_2380)
                    {
                      {
                        _ptr__2353[_2378] = ((*((*_2363)(_2380)))(_2379));
                        ++ _2378;
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(_2331,_2354,_2353)).as<::mosek::fusion::Constraint>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2381) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__index(_2381); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::index(std::shared_ptr< monty::ndarray< int,1 > > _2381) { return __mosek_2fusion_2Constraint__index(_2381); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2381){
  _checked_ptr_1<int> _ptr__2381(_2381 ? _2381->raw() : nullptr, _2381 ? _2381->size(0) : 0);
  if (((int)((_2381)->size(0)) != (int)((shape)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("variable shape and slice do not match"));
    }
  }
  else
  {
    {
      int _7945 = (int)0;
      int _7946 = (int)((shape)->size(0));
      for (int _2382 = _7945; _2382 < _7946; ++_2382)
      {
        {
          if (((_ptr__2381[_2382] < (int)0) || (_ptr__2381[_2382] > ((*shape)(_2382)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("index is out of bounds"));
            }
          }
          {}
        }
      }
      int _2383 = (int)((shape)->size(0));
      std::shared_ptr< monty::ndarray< long long,1 > > _2384 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2383)));
      _checked_ptr_1<long long> _ptr__2384(_2384 ? _2384->raw() : nullptr,_2384 ? _2384->size(0) : 0);
      _ptr__2384[(_2383 - (int)1)] = (int)1;
      int _7947 = (int)1;
      int _7948 = _2383;
      for (int _2385 = _7947; _2385 < _7948; ++_2385)
      {
        {
          _ptr__2384[((_2383 - _2385) - (int)1)] = safe_mul( _ptr__2384[(_2383 - _2385)],((*shape)(_2385)) );
        }
      }
      int _2386 = (int)0;
      int _7949 = (int)0;
      int _7950 = _2383;
      for (int _2387 = _7949; _2387 < _7950; ++_2387)
      {
        {
          _2386 += (int)safe_mul( _ptr__2384[_2387],_ptr__2381[_2387] );
        }
      }
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*nativeidxs)(_2386)))}))).as<::mosek::fusion::Constraint>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__index(int _2388) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__index(_2388); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::index(int _2388) { return __mosek_2fusion_2Constraint__index(_2388); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__index(int _2388){
  if ((((int)((shape)->size(0)) == (int)0) && (_2388 == (int)0)))
  {
    {
      return ::mosek::fusion::Constraint::t(_pubthis);
    }
  }
  else if(((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  else if(((_2388 < (int)0) || (_2388 > ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Index is out of bounds"));
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*nativeidxs)(_2388)))}))).as<::mosek::fusion::Constraint>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2389,std::shared_ptr< monty::ndarray< int,1 > > _2390) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__slice(_2389,_2390); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::slice(std::shared_ptr< monty::ndarray< int,1 > > _2389,std::shared_ptr< monty::ndarray< int,1 > > _2390) { return __mosek_2fusion_2Constraint__slice(_2389,_2390); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2389,std::shared_ptr< monty::ndarray< int,1 > > _2390){
  _checked_ptr_1<int> _ptr__2389(_2389 ? _2389->raw() : nullptr, _2389 ? _2389->size(0) : 0);
  _checked_ptr_1<int> _ptr__2390(_2390 ? _2390->raw() : nullptr, _2390 ? _2390->size(0) : 0);
  if (((int)((_2389)->size(0)) != (int)((_2390)->size(0))))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("invalid slice"));
    }
  }
  else if(((int)((_2389)->size(0)) != (int)((shape)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("variable shape and slice do not match"));
    }
  }
  else
  {
    {
      int _7951 = (int)0;
      int _7952 = (int)((shape)->size(0));
      for (int _2391 = _7951; _2391 < _7952; ++_2391)
      {
        {
          if (((_ptr__2389[_2391] < (int)0) || (_ptr__2390[_2391] > ((*shape)(_2391)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("slice is out of bounds"));
            }
          }
          else if((_ptr__2389[_2391] > _ptr__2390[_2391]))
          {
            {
              throw ::mosek::fusion::SliceError(std::string ("invalid slice"));
            }
          }
          {}
        }
      }
      int _2392 = (int)((shape)->size(0));
      std::vector<int> _7953;
      for (int _2394 = (int)0, _7954 = _2392; _2394 < _7954 ; ++_2394)
      {
        _7953.push_back((_ptr__2390[_2394] - _ptr__2389[_2394]));
      }
      auto _7955 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7953.size()),_7953.begin(),_7953.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2393 = _7955;
      _checked_ptr_1<int> _ptr__2393(_2393 ? _2393->raw() : nullptr,_2393 ? _2393->size(0) : 0);
      int _2395 = (int)1;
      int _7956 = (int)0;
      int _7957 = _2392;
      for (int _2396 = _7956; _2396 < _7957; ++_2396)
      {
        {
          _2395 *= (_ptr__2390[_2396] - _ptr__2389[_2396]);
        }
      }
      if ((_2395 == (int)0))
      {
        {
          return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,_2393,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))))).as<::mosek::fusion::Constraint>();
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2397 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2395)));
          _checked_ptr_1<int> _ptr__2397(_2397 ? _2397->raw() : nullptr,_2397 ? _2397->size(0) : 0);
          {
            std::shared_ptr< monty::ndarray< int,1 > > _2398 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2392)));
            _checked_ptr_1<int> _ptr__2398(_2398 ? _2398->raw() : nullptr,_2398 ? _2398->size(0) : 0);
            _ptr__2398[(_2392 - (int)1)] = (int)1;
            int _7958 = (int)1;
            int _7959 = _2392;
            for (int _2399 = _7958; _2399 < _7959; ++_2399)
            {
              {
                _ptr__2398[((_2392 - _2399) - (int)1)] = safe_mul( _ptr__2398[(_2392 - _2399)],((*shape)((_2392 - _2399))) );
              }
            }
            int _2400 = (int)0;
            int _7960 = (int)0;
            int _7961 = _2392;
            for (int _2401 = _7960; _2401 < _7961; ++_2401)
            {
              {
                _2400 += safe_mul( _ptr__2389[_2401],_ptr__2398[_2401] );
              }
            }
            std::vector<int> _7962;
            for (int _2403 = (int)0, _7963 = _2392; _2403 < _7963 ; ++_2403)
            {
              _7962.push_back(_2400);
            }
            auto _7964 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7962.size()),_7962.begin(),_7962.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _2402 = _7964;
            _checked_ptr_1<int> _ptr__2402(_2402 ? _2402->raw() : nullptr,_2402 ? _2402->size(0) : 0);
            std::vector<int> _7965;
            for (int _2405 = (int)0, _7966 = _2392; _2405 < _7966 ; ++_2405)
            {
              _7965.push_back(_ptr__2389[_2405]);
            }
            auto _7967 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7965.size()),_7965.begin(),_7965.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _2404 = _7967;
            _checked_ptr_1<int> _ptr__2404(_2404 ? _2404->raw() : nullptr,_2404 ? _2404->size(0) : 0);
            int _7968 = (int)0;
            int _7969 = _2395;
            for (int _2406 = _7968; _2406 < _7969; ++_2406)
            {
              {
                _ptr__2397[_2406] = ((*nativeidxs)(_ptr__2402[(_2392 - (int)1)]));
                _ptr__2404[(_2392 - (int)1)] += (int)1;
                _ptr__2402[(_2392 - (int)1)] += _ptr__2398[(_2392 - (int)1)];
                if ((_ptr__2404[(_2392 - (int)1)] >= _ptr__2390[(_2392 - (int)1)]))
                {
                  {
                    int _2407 = (_2392 - (int)1);
                    while ( ((_2407 > (int)0) && (_ptr__2404[_2407] >= _ptr__2390[_2407])) )
                    {
                      {
                        _ptr__2404[_2407] = _ptr__2389[_2407];
                        _ptr__2404[(_2407 - (int)1)] += (int)1;
                        _ptr__2402[(_2407 - (int)1)] += _ptr__2398[(_2407 - (int)1)];
                        -- _2407;
                      }
                    }
                    int _7970 = safe_add( _2407,(int)1 );
                    int _7971 = _2392;
                    for (int _2408 = _7970; _2408 < _7971; ++_2408)
                    {
                      {
                        _ptr__2402[_2408] = _ptr__2402[_2407];
                      }
                    }
                  }
                }
                {}
              }
            }
          }
          return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(_pubthis->__mosek_2fusion_2Constraint__getModel(),_2393,_2397)).as<::mosek::fusion::Constraint>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__slice(int _2409,int _2410) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__slice(_2409,_2410); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::slice(int _2409,int _2410) { return __mosek_2fusion_2Constraint__slice(_2409,_2410); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__slice(int _2409,int _2410){
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  {}
  if (((_2409 == (int)0) && (_2410 == ((*shape)((int)0)))))
  {
    {
      return ::mosek::fusion::Constraint::t(_pubthis);
    }
  }
  else if(((_2409 < (int)0) || (_2410 > ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
    }
  }
  else if((_2409 > _2410))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
    }
  }
  else
  {
    {
      std::vector<int> _7972;
      for (int _2411 = _2409, _7973 = _2410; _2411 < _7973 ; ++_2411)
      {
        _7972.push_back(((*nativeidxs)(_2411)));
      }
      auto _7974 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7972.size()),_7972.begin(),_7972.end()));
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((_2410 - _2409))}),_7974)).as<::mosek::fusion::Constraint>();
    }
  }
}
int mosek::fusion::Constraint :: getND() { return mosek::fusion::p_Constraint::_get_impl(this)->getND(); }int mosek::fusion::p_Constraint::getND(){
  return (int)((shape)->size(0));
}
int mosek::fusion::Constraint :: getSize() { return mosek::fusion::p_Constraint::_get_impl(this)->getSize(); }int mosek::fusion::p_Constraint::getSize(){
  int _2412 = (int)1;
  int _7975 = (int)0;
  int _7976 = (int)((shape)->size(0));
  for (int _2413 = _7975; _2413 < _7976; ++_2413)
  {
    {
      _2412 *= ((*shape)(_2413));
    }
  }
  return _2412;
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__getModel() { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint::getModel() { return __mosek_2fusion_2Constraint__getModel(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__getModel(){
  return model;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Constraint :: getShape() { return mosek::fusion::p_Constraint::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Constraint::getShape(){
  std::vector<int> _7977;
  for (int _2414 = (int)0, _7978 = (int)((shape)->size(0)); _2414 < _7978 ; ++_2414)
  {
    _7977.push_back(((*shape)(_2414)));
  }
  auto _7979 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7977.size()),_7977.begin(),_7977.end()));
  return _7979;
}
void mosek::fusion::p_Constraint::destroy(){nativeidxs.reset();shape.reset();model.reset();}void mosek::fusion::Constraint::destroy() { mosek::fusion::p_Constraint::_get_impl(this)->destroy(); }mosek::fusion::Set::Set(mosek::fusion::p_Set *_impl) : _impl(_impl) { /*std::cout << "Set() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Set::~Set() { delete _impl; _impl = nullptr; }mosek::fusion::p_Set::p_Set  (::mosek::fusion::Set * _pubthis) :     _pubthis(_pubthis){}long long mosek::fusion::Set::size  ( std::shared_ptr< monty::ndarray< int,1 > > _2415) { return mosek::fusion::p_Set::size(_2415); }long long mosek::fusion::p_Set::size(std::shared_ptr< monty::ndarray< int,1 > > _2415){
  _checked_ptr_1<int> _ptr__2415(_2415 ? _2415->raw() : nullptr, _2415 ? _2415->size(0) : 0);
  long long _2416 = (long long)1;
  int _7980 = (int)0;
  int _7981 = (int)((_2415)->size(0));
  for (int _2417 = _7980; _2417 < _7981; ++_2417)
  {
    {
      _2416 *= _ptr__2415[_2417];
    }
  }
  return _2416;
}
bool mosek::fusion::Set::match  ( std::shared_ptr< monty::ndarray< int,1 > > _2418,    std::shared_ptr< monty::ndarray< int,1 > > _2419) { return mosek::fusion::p_Set::match(_2418,_2419); }bool mosek::fusion::p_Set::match(std::shared_ptr< monty::ndarray< int,1 > > _2418,std::shared_ptr< monty::ndarray< int,1 > > _2419){
  _checked_ptr_1<int> _ptr__2418(_2418 ? _2418->raw() : nullptr, _2418 ? _2418->size(0) : 0);
  _checked_ptr_1<int> _ptr__2419(_2419 ? _2419->raw() : nullptr, _2419 ? _2419->size(0) : 0);
  if (((int)((_2418)->size(0)) != (int)((_2419)->size(0))))
  {
    {
      return false;
    }
  }
  {}
  int _7982 = (int)0;
  int _7983 = (int)((_2418)->size(0));
  for (int _2420 = _7982; _2420 < _7983; ++_2420)
  {
    {
      if ((_ptr__2418[_2420] != _ptr__2419[_2420]))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
long long mosek::fusion::Set::linearidx  ( std::shared_ptr< monty::ndarray< int,1 > > _2421,    std::shared_ptr< monty::ndarray< int,1 > > _2422) { return mosek::fusion::p_Set::linearidx(_2421,_2422); }long long mosek::fusion::p_Set::linearidx(std::shared_ptr< monty::ndarray< int,1 > > _2421,std::shared_ptr< monty::ndarray< int,1 > > _2422){
  _checked_ptr_1<int> _ptr__2421(_2421 ? _2421->raw() : nullptr, _2421 ? _2421->size(0) : 0);
  _checked_ptr_1<int> _ptr__2422(_2422 ? _2422->raw() : nullptr, _2422 ? _2422->size(0) : 0);
  long long _2423 = _ptr__2422[(int)0];
  int _7984 = (int)1;
  int _7985 = (int)((_2422)->size(0));
  for (int _2424 = _7984; _2424 < _7985; ++_2424)
  {
    {
      _2423 = safe_add( safe_mul( _2423,_ptr__2421[_2424] ),_ptr__2422[_2424] );
    }
  }
  return _2423;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::idxtokey  ( std::shared_ptr< monty::ndarray< int,1 > > _2425,    long long _2426) { return mosek::fusion::p_Set::idxtokey(_2425,_2426); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2425,long long _2426){
  _checked_ptr_1<int> _ptr__2425(_2425 ? _2425->raw() : nullptr, _2425 ? _2425->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2427 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_2425)->size(0)))));
  _checked_ptr_1<int> _ptr__2427(_2427 ? _2427->raw() : nullptr,_2427 ? _2427->size(0) : 0);
  ::mosek::fusion::p_Set::idxtokey(_2425,_2426,_2427);
  return _2427;
}
void mosek::fusion::Set::idxtokey  ( std::shared_ptr< monty::ndarray< int,1 > > _2428,    long long _2429,    std::shared_ptr< monty::ndarray< int,1 > > _2430) { mosek::fusion::p_Set::idxtokey(_2428,_2429,_2430); }void mosek::fusion::p_Set::idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2428,long long _2429,std::shared_ptr< monty::ndarray< int,1 > > _2430){
  _checked_ptr_1<int> _ptr__2428(_2428 ? _2428->raw() : nullptr, _2428 ? _2428->size(0) : 0);
  _checked_ptr_1<int> _ptr__2430(_2430 ? _2430->raw() : nullptr, _2430 ? _2430->size(0) : 0);
  int _2431 = (int)((_2428)->size(0));
  if ((_2431 > (int)0))
  {
    {
      long long _2432 = _2429;
      int _7986 = (int)0;
      int _7987 = (_2431 - (int)1);
      for (int _2433 = _7986; _2433 < _7987; ++_2433)
      {
        {
          _ptr__2430[((_2431 - _2433) - (int)1)] = (int)(_2432 % _ptr__2428[((_2431 - _2433) - (int)1)]);
          _2432 /= _ptr__2428[((_2431 - _2433) - (int)1)];
        }
      }
      _ptr__2430[(int)0] = (int)_2432;
    }
  }
  {}
}
std::string mosek::fusion::Set::indexToString  ( std::shared_ptr< monty::ndarray< int,1 > > _2434,    long long _2435) { return mosek::fusion::p_Set::indexToString(_2434,_2435); }std::string mosek::fusion::p_Set::indexToString(std::shared_ptr< monty::ndarray< int,1 > > _2434,long long _2435){
  _checked_ptr_1<int> _ptr__2434(_2434 ? _2434->raw() : nullptr, _2434 ? _2434->size(0) : 0);
  int _2436 = (int)((_2434)->size(0));
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2437 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  if ((_2436 == (int)0))
  {
    {
      return std::string ("0");
    }
  }
  else if((_2436 == (int)1))
  {
    {
      return _2437->__mosek_2fusion_2Utils_2StringBuffer__a(_2435)->toString();
    }
  }
  else
  {
    {
      long long _2438 = _2435;
      std::shared_ptr< monty::ndarray< int,1 > > _2439 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2436)));
      _checked_ptr_1<int> _ptr__2439(_2439 ? _2439->raw() : nullptr,_2439 ? _2439->size(0) : 0);
      int _7988 = (int)1;
      int _7989 = _2436;
      for (int _2440 = _7988; _2440 < _7989; ++_2440)
      {
        {
          _ptr__2439[(_2436 - _2440)] = (int)(_2438 % _ptr__2434[(_2436 - _2440)]);
          _2438 /= _ptr__2434[(_2436 - _2440)];
        }
      }
      _ptr__2439[(int)0] = (int)_2438;
      _2437->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2439[(int)0]);
      int _7990 = (int)1;
      int _7991 = _2436;
      for (int _2441 = _7990; _2441 < _7991; ++_2441)
      {
        {
          _2437->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2439[_2441]);
        }
      }
      return _2437->toString();
    }
  }
}
std::string mosek::fusion::Set::keyToString  ( std::shared_ptr< monty::ndarray< int,1 > > _2442) { return mosek::fusion::p_Set::keyToString(_2442); }std::string mosek::fusion::p_Set::keyToString(std::shared_ptr< monty::ndarray< int,1 > > _2442){
  _checked_ptr_1<int> _ptr__2442(_2442 ? _2442->raw() : nullptr, _2442 ? _2442->size(0) : 0);
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2443 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2443->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2442[(int)0]);
  int _7992 = (int)1;
  int _7993 = (int)((_2442)->size(0));
  for (int _2444 = _7992; _2444 < _7993; ++_2444)
  {
    {
      _2443->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2442[_2444]);
    }
  }
  return _2443->toString();
}
void mosek::fusion::Set::indexToKey  ( std::shared_ptr< monty::ndarray< int,1 > > _2445,    long long _2446,    std::shared_ptr< monty::ndarray< int,1 > > _2447) { mosek::fusion::p_Set::indexToKey(_2445,_2446,_2447); }void mosek::fusion::p_Set::indexToKey(std::shared_ptr< monty::ndarray< int,1 > > _2445,long long _2446,std::shared_ptr< monty::ndarray< int,1 > > _2447){
  _checked_ptr_1<int> _ptr__2445(_2445 ? _2445->raw() : nullptr, _2445 ? _2445->size(0) : 0);
  _checked_ptr_1<int> _ptr__2447(_2447 ? _2447->raw() : nullptr, _2447 ? _2447->size(0) : 0);
  int _2448 = (int)((_2445)->size(0));
  if ((_2448 == (int)1))
  {
    {
      _ptr__2447[(int)0] = (int)_2446;
    }
  }
  else
  {
    {
      long long _2449 = _2446;
      int _7994 = (int)1;
      int _7995 = _2448;
      for (int _2450 = _7994; _2450 < _7995; ++_2450)
      {
        {
          _ptr__2447[(_2448 - _2450)] = (int)(_2449 % _ptr__2445[(_2448 - _2450)]);
          _2449 /= _ptr__2445[(_2448 - _2450)];
        }
      }
      _ptr__2447[(int)0] = (int)_2449;
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::Set::strides  ( std::shared_ptr< monty::ndarray< int,1 > > _2451) { return mosek::fusion::p_Set::strides(_2451); }std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_Set::strides(std::shared_ptr< monty::ndarray< int,1 > > _2451){
  _checked_ptr_1<int> _ptr__2451(_2451 ? _2451->raw() : nullptr, _2451 ? _2451->size(0) : 0);
  int _2452 = (int)((_2451)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _2453 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2452)));
  _checked_ptr_1<long long> _ptr__2453(_2453 ? _2453->raw() : nullptr,_2453 ? _2453->size(0) : 0);
  _ptr__2453[(_2452 - (int)1)] = (int)1;
  int _7996 = (int)1;
  int _7997 = _2452;
  for (int _2454 = _7996; _2454 < _7997; ++_2454)
  {
    {
      _ptr__2453[((_2452 - _2454) - (int)1)] = safe_mul( _ptr__2453[(_2452 - _2454)],_ptr__2451[(_2452 - _2454)] );
    }
  }
  return _2453;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( std::shared_ptr< monty::ndarray< int,1 > > _2455,    std::shared_ptr< monty::ndarray< int,1 > > _2456) { return mosek::fusion::p_Set::make(_2455,_2456); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(std::shared_ptr< monty::ndarray< int,1 > > _2455,std::shared_ptr< monty::ndarray< int,1 > > _2456){
  _checked_ptr_1<int> _ptr__2455(_2455 ? _2455->raw() : nullptr, _2455 ? _2455->size(0) : 0);
  _checked_ptr_1<int> _ptr__2456(_2456 ? _2456->raw() : nullptr, _2456 ? _2456->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2457 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( (int)((_2455)->size(0)),(int)((_2456)->size(0)) ))));
  _checked_ptr_1<int> _ptr__2457(_2457 ? _2457->raw() : nullptr,_2457 ? _2457->size(0) : 0);
  int _7998 = (int)0;
  int _7999 = (int)((_2455)->size(0));
  for (int _2458 = _7998; _2458 < _7999; ++_2458)
  {
    {
      _ptr__2457[_2458] = _ptr__2455[_2458];
    }
  }
  int _8000 = (int)0;
  int _8001 = (int)((_2456)->size(0));
  for (int _2459 = _8000; _2459 < _8001; ++_2459)
  {
    {
      _ptr__2457[safe_add( (int)((_2455)->size(0)),_2459 )] = _ptr__2456[_2459];
    }
  }
  return _2457;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( std::shared_ptr< monty::ndarray< int,1 > > _2460) { return mosek::fusion::p_Set::make(_2460); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(std::shared_ptr< monty::ndarray< int,1 > > _2460){
  _checked_ptr_1<int> _ptr__2460(_2460 ? _2460->raw() : nullptr, _2460 ? _2460->size(0) : 0);
  std::vector<int> _8002;
  for (int _2461 = (int)0, _8003 = (int)((_2460)->size(0)); _2461 < _8003 ; ++_2461)
  {
    _8002.push_back(_ptr__2460[_2461]);
  }
  auto _8004 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8002.size()),_8002.begin(),_8002.end()));
  return _8004;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( int _2462,    int _2463,    int _2464) { return mosek::fusion::p_Set::make(_2462,_2463,_2464); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(int _2462,int _2463,int _2464){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2462),(int)(_2463),(int)(_2464)});
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( int _2465,    int _2466) { return mosek::fusion::p_Set::make(_2465,_2466); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(int _2465,int _2466){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2465),(int)(_2466)});
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( int _2467) { return mosek::fusion::p_Set::make(_2467); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(int _2467){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2467)});
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::scalar  ( ) { return mosek::fusion::p_Set::scalar(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::scalar(){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( std::shared_ptr< monty::ndarray< std::string,1 > > _2468) { return mosek::fusion::p_Set::make(_2468); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(std::shared_ptr< monty::ndarray< std::string,1 > > _2468){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2468)->size(0)))});
}
void mosek::fusion::p_Set::destroy(){}void mosek::fusion::Set::destroy() { mosek::fusion::p_Set::_get_impl(this)->destroy(); }mosek::fusion::ConeDomain::ConeDomain(mosek::fusion::p_ConeDomain *_impl) : _impl(_impl) { /*std::cout << "ConeDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ConeDomain::~ConeDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_ConeDomain::p_ConeDomain  (::mosek::fusion::ConeDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::ConeDomain::t mosek::fusion::p_ConeDomain::_new_ConeDomain  (mosek::fusion::QConeKey _2469,    double _2470,    std::shared_ptr< monty::ndarray< int,1 > > _2471){ return new mosek::fusion::ConeDomain(_2469,_2470,_2471); }mosek::fusion::ConeDomain::ConeDomain  (mosek::fusion::QConeKey _2469,    double _2470,    std::shared_ptr< monty::ndarray< int,1 > > _2471) :    ConeDomain(new mosek::fusion::p_ConeDomain(this)){ mosek::fusion::p_ConeDomain::_get_impl(this)->_initialize(_2469,_2470,_2471); }void mosek::fusion::p_ConeDomain::_initialize  (mosek::fusion::QConeKey _2469,    double _2470,    std::shared_ptr< monty::ndarray< int,1 > > _2471){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2471(_2471 ? _2471->raw() : nullptr, _2471 ? _2471->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _8005;
    bool _8006 = (NULL != _2471.get());
    if (_8006)
    {
      _8005 = ::mosek::fusion::p_Set::make(_2471);
    }
    else
    {
      _8005 = nullptr;
    }
    shape = _8005;
    mosek::fusion::p_ConeDomain::_get_impl(::mosek::fusion::ConeDomain::t(_pubthis))->alpha = _2470;
    key = _2469;
    axisidx = (int)0;
    axisset = false;
    int_flag = false;
    mosek::fusion::p_ConeDomain::_get_impl(::mosek::fusion::ConeDomain::t(_pubthis))->alpha = _2470;
  }
}mosek::fusion::ConeDomain::t mosek::fusion::p_ConeDomain::_new_ConeDomain  (mosek::fusion::QConeKey _2472,    std::shared_ptr< monty::ndarray< int,1 > > _2473){ return new mosek::fusion::ConeDomain(_2472,_2473); }mosek::fusion::ConeDomain::ConeDomain  (mosek::fusion::QConeKey _2472,    std::shared_ptr< monty::ndarray< int,1 > > _2473) :    ConeDomain(new mosek::fusion::p_ConeDomain(this)){ mosek::fusion::p_ConeDomain::_get_impl(this)->_initialize(_2472,_2473); }void mosek::fusion::p_ConeDomain::_initialize  (mosek::fusion::QConeKey _2472,    std::shared_ptr< monty::ndarray< int,1 > > _2473){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2473(_2473 ? _2473->raw() : nullptr, _2473 ? _2473->size(0) : 0);
    mosek::fusion::p_ConeDomain::_initialize(_2472,1.0,_2473);
  }
}bool mosek::fusion::p_ConeDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2474){
  _checked_ptr_1<int> _ptr__2474(_2474 ? _2474->raw() : nullptr, _2474 ? _2474->size(0) : 0);
  return ((NULL == shape.get()) || ::mosek::fusion::p_Set::match(_2474,shape));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain :: __mosek_2fusion_2ConeDomain__integral() { return mosek::fusion::p_ConeDomain::_get_impl(this)->__mosek_2fusion_2ConeDomain__integral(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain::integral() { return __mosek_2fusion_2ConeDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_ConeDomain::__mosek_2fusion_2ConeDomain__integral(){
  int_flag = true;
  return ::mosek::fusion::ConeDomain::t(_pubthis);
}
bool mosek::fusion::ConeDomain :: axisIsSet() { return mosek::fusion::p_ConeDomain::_get_impl(this)->axisIsSet(); }bool mosek::fusion::p_ConeDomain::axisIsSet(){
  return axisset;
}
int mosek::fusion::ConeDomain :: getAxis() { return mosek::fusion::p_ConeDomain::_get_impl(this)->getAxis(); }int mosek::fusion::p_ConeDomain::getAxis(){
  return axisidx;
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain :: __mosek_2fusion_2ConeDomain__axis(int _2475) { return mosek::fusion::p_ConeDomain::_get_impl(this)->__mosek_2fusion_2ConeDomain__axis(_2475); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain::axis(int _2475) { return __mosek_2fusion_2ConeDomain__axis(_2475); }
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_ConeDomain::__mosek_2fusion_2ConeDomain__axis(int _2475){
  axisidx = _2475;
  axisset = true;
  return ::mosek::fusion::ConeDomain::t(_pubthis);
}
void mosek::fusion::p_ConeDomain::destroy(){shape.reset();}void mosek::fusion::ConeDomain::destroy() { mosek::fusion::p_ConeDomain::_get_impl(this)->destroy(); }mosek::fusion::LinPSDDomain::LinPSDDomain(mosek::fusion::p_LinPSDDomain *_impl) : _impl(_impl) { /*std::cout << "LinPSDDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinPSDDomain::~LinPSDDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinPSDDomain::p_LinPSDDomain  (::mosek::fusion::LinPSDDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinPSDDomain::t mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2476,    int _2477){ return new mosek::fusion::LinPSDDomain(_2476,_2477); }mosek::fusion::LinPSDDomain::LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2476,    int _2477) :    LinPSDDomain(new mosek::fusion::p_LinPSDDomain(this)){ mosek::fusion::p_LinPSDDomain::_get_impl(this)->_initialize(_2476,_2477); }void mosek::fusion::p_LinPSDDomain::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2476,    int _2477){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2476(_2476 ? _2476->raw() : nullptr, _2476 ? _2476->size(0) : 0);
    mosek::fusion::p_LinPSDDomain::_get_impl(::mosek::fusion::LinPSDDomain::t(_pubthis))->conedim = _2477;
    shape = ::mosek::fusion::Utils::Tools::arraycopy(_2476);
  }
}mosek::fusion::LinPSDDomain::t mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2478){ return new mosek::fusion::LinPSDDomain(_2478); }mosek::fusion::LinPSDDomain::LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2478) :    LinPSDDomain(new mosek::fusion::p_LinPSDDomain(this)){ mosek::fusion::p_LinPSDDomain::_get_impl(this)->_initialize(_2478); }void mosek::fusion::p_LinPSDDomain::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2478){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2478(_2478 ? _2478->raw() : nullptr, _2478 ? _2478->size(0) : 0);
    shape = ::mosek::fusion::Utils::Tools::arraycopy(_2478);
    conedim = ((int)((shape)->size(0)) - (int)1);
  }
}mosek::fusion::LinPSDDomain::t mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain  (){ return new mosek::fusion::LinPSDDomain(); }mosek::fusion::LinPSDDomain::LinPSDDomain  () :    LinPSDDomain(new mosek::fusion::p_LinPSDDomain(this)){ mosek::fusion::p_LinPSDDomain::_get_impl(this)->_initialize(); }void mosek::fusion::p_LinPSDDomain::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    conedim = (int)0;
    shape = nullptr;
  }
}void mosek::fusion::p_LinPSDDomain::destroy(){shape.reset();}void mosek::fusion::LinPSDDomain::destroy() { mosek::fusion::p_LinPSDDomain::_get_impl(this)->destroy(); }mosek::fusion::PSDDomain::PSDDomain(mosek::fusion::p_PSDDomain *_impl) : _impl(_impl) { /*std::cout << "PSDDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::PSDDomain::~PSDDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_PSDDomain::p_PSDDomain  (::mosek::fusion::PSDDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::PSDDomain::t mosek::fusion::p_PSDDomain::_new_PSDDomain  (mosek::fusion::PSDKey _2479,    std::shared_ptr< monty::ndarray< int,1 > > _2480,    int _2481,    int _2482){ return new mosek::fusion::PSDDomain(_2479,_2480,_2481,_2482); }mosek::fusion::PSDDomain::PSDDomain  (mosek::fusion::PSDKey _2479,    std::shared_ptr< monty::ndarray< int,1 > > _2480,    int _2481,    int _2482) :    PSDDomain(new mosek::fusion::p_PSDDomain(this)){ mosek::fusion::p_PSDDomain::_get_impl(this)->_initialize(_2479,_2480,_2481,_2482); }void mosek::fusion::p_PSDDomain::_initialize  (mosek::fusion::PSDKey _2479,    std::shared_ptr< monty::ndarray< int,1 > > _2480,    int _2481,    int _2482){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2480(_2480 ? _2480->raw() : nullptr, _2480 ? _2480->size(0) : 0);
    axisIsSet = true;
    shape = _2480;
    key = _2479;
    mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim1 = _2481;
    mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim2 = _2482;
    int _2483 = (int)((shape)->size(0));
    if (((!(((int)((shape)->size(0)) > _2481) && (((int)((shape)->size(0)) > _2482) && ((_2481 >= (int)0) && ((_2482 >= (int)0) && (_2481 != _2482)))))) && (((*shape)(_2481)) == ((*shape)(_2482)))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape or cone dimensions"));
      }
    }
    {}
  }
}mosek::fusion::PSDDomain::t mosek::fusion::p_PSDDomain::_new_PSDDomain  (mosek::fusion::PSDKey _2484,    std::shared_ptr< monty::ndarray< int,1 > > _2485){ return new mosek::fusion::PSDDomain(_2484,_2485); }mosek::fusion::PSDDomain::PSDDomain  (mosek::fusion::PSDKey _2484,    std::shared_ptr< monty::ndarray< int,1 > > _2485) :    PSDDomain(new mosek::fusion::p_PSDDomain(this)){ mosek::fusion::p_PSDDomain::_get_impl(this)->_initialize(_2484,_2485); }void mosek::fusion::p_PSDDomain::_initialize  (mosek::fusion::PSDKey _2484,    std::shared_ptr< monty::ndarray< int,1 > > _2485){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2485(_2485 ? _2485->raw() : nullptr, _2485 ? _2485->size(0) : 0);
    mosek::fusion::p_PSDDomain::_initialize(_2484,_2485,((int)((_2485)->size(0)) - (int)2),((int)((_2485)->size(0)) - (int)1));
  }
}mosek::fusion::PSDDomain::t mosek::fusion::p_PSDDomain::_new_PSDDomain  (mosek::fusion::PSDKey _2486){ return new mosek::fusion::PSDDomain(_2486); }mosek::fusion::PSDDomain::PSDDomain  (mosek::fusion::PSDKey _2486) :    PSDDomain(new mosek::fusion::p_PSDDomain(this)){ mosek::fusion::p_PSDDomain::_get_impl(this)->_initialize(_2486); }void mosek::fusion::p_PSDDomain::_initialize  (mosek::fusion::PSDKey _2486){monty::rc_reserve __reserve_this(_pubthis);   {
    shape = nullptr;
    key = _2486;
    conedim1 = (int)0;
    conedim2 = (int)0;
    axisIsSet = false;
  }
}monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::PSDDomain :: __mosek_2fusion_2PSDDomain__axis(int _2487,int _2488) { return mosek::fusion::p_PSDDomain::_get_impl(this)->__mosek_2fusion_2PSDDomain__axis(_2487,_2488); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::PSDDomain::axis(int _2487,int _2488) { return __mosek_2fusion_2PSDDomain__axis(_2487,_2488); }
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_PSDDomain::__mosek_2fusion_2PSDDomain__axis(int _2487,int _2488){
  mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim1 = _2487;
  mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim2 = _2488;
  axisIsSet = true;
  if (((NULL == shape.get()) && (!((_2487 >= (int)0) && ((_2488 >= (int)0) && (_2487 != _2488))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape or cone dimensions"));
    }
  }
  else if(((NULL != shape.get()) && ((!(((int)((shape)->size(0)) > _2487) && (((int)((shape)->size(0)) > _2488) && ((_2487 >= (int)0) && ((_2488 >= (int)0) && (_2487 != _2488)))))) && (((*shape)(_2487)) == ((*shape)(_2488))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape or cone dimensions"));
    }
  }
  {}
  return ::mosek::fusion::PSDDomain::t(_pubthis);
}
void mosek::fusion::p_PSDDomain::destroy(){shape.reset();}void mosek::fusion::PSDDomain::destroy() { mosek::fusion::p_PSDDomain::_get_impl(this)->destroy(); }mosek::fusion::SymmetricRangeDomain::SymmetricRangeDomain(mosek::fusion::p_SymmetricRangeDomain *_impl) : mosek::fusion::RangeDomain(_impl) { /*std::cout << "SymmetricRangeDomain()" << this << std::endl; */ }mosek::fusion::SymmetricRangeDomain::~SymmetricRangeDomain() {  /* std::cout << "~SymmetricRangeDomain()" << this << std::endl << std::flush; */ }mosek::fusion::p_SymmetricRangeDomain::p_SymmetricRangeDomain  (::mosek::fusion::SymmetricRangeDomain * _pubthis) :     mosek::fusion::p_RangeDomain(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SymmetricRangeDomain::t mosek::fusion::p_SymmetricRangeDomain::_new_SymmetricRangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2489){ return new mosek::fusion::SymmetricRangeDomain(_2489); }mosek::fusion::SymmetricRangeDomain::SymmetricRangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2489) :    SymmetricRangeDomain(new mosek::fusion::p_SymmetricRangeDomain(this)){ mosek::fusion::p_SymmetricRangeDomain::_get_impl(this)->_initialize(_2489); }void mosek::fusion::p_SymmetricRangeDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2489){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_RangeDomain::_initialize(_2489);
    if (((NULL != shape.get()) && (((int)((shape)->size(0)) != (int)2) || (((*shape)((int)0)) != ((*shape)((int)1))))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Only square domains can be symmetric"));
      }
    }
    {}
    int _8007;
    bool _8008 = (NULL == shape.get());
    if (_8008)
    {
      _8007 = (int)0;
    }
    else
    {
      _8007 = ((*shape)((int)0));
    }
    dim = _8007;
  }
}void mosek::fusion::p_SymmetricRangeDomain::destroy(){}void mosek::fusion::SymmetricRangeDomain::destroy() { mosek::fusion::p_SymmetricRangeDomain::_get_impl(this)->destroy(); }mosek::fusion::RangeDomain::RangeDomain(mosek::fusion::p_RangeDomain *_impl) : _impl(_impl) { /*std::cout << "RangeDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::RangeDomain::~RangeDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_RangeDomain::p_RangeDomain  (::mosek::fusion::RangeDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (bool _2490,    std::shared_ptr< monty::ndarray< double,1 > > _2491,    std::shared_ptr< monty::ndarray< double,1 > > _2492,    std::shared_ptr< monty::ndarray< int,1 > > _2493){ return new mosek::fusion::RangeDomain(_2490,_2491,_2492,_2493); }mosek::fusion::RangeDomain::RangeDomain  (bool _2490,    std::shared_ptr< monty::ndarray< double,1 > > _2491,    std::shared_ptr< monty::ndarray< double,1 > > _2492,    std::shared_ptr< monty::ndarray< int,1 > > _2493) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2490,_2491,_2492,_2493); }void mosek::fusion::p_RangeDomain::_initialize  (bool _2490,    std::shared_ptr< monty::ndarray< double,1 > > _2491,    std::shared_ptr< monty::ndarray< double,1 > > _2492,    std::shared_ptr< monty::ndarray< int,1 > > _2493){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2491(_2491 ? _2491->raw() : nullptr, _2491 ? _2491->size(0) : 0);
    _checked_ptr_1<double> _ptr__2492(_2492 ? _2492->raw() : nullptr, _2492 ? _2492->size(0) : 0);
    _checked_ptr_1<int> _ptr__2493(_2493 ? _2493->raw() : nullptr, _2493 ? _2493->size(0) : 0);
    mosek::fusion::p_RangeDomain::_initialize(_2490,_2491,_2492,_2493,nullptr,(int)1);
  }
}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (bool _2494,    std::shared_ptr< monty::ndarray< double,1 > > _2495,    std::shared_ptr< monty::ndarray< double,1 > > _2496,    std::shared_ptr< monty::ndarray< int,1 > > _2497,    std::shared_ptr< monty::ndarray< int,2 > > _2498){ return new mosek::fusion::RangeDomain(_2494,_2495,_2496,_2497,_2498); }mosek::fusion::RangeDomain::RangeDomain  (bool _2494,    std::shared_ptr< monty::ndarray< double,1 > > _2495,    std::shared_ptr< monty::ndarray< double,1 > > _2496,    std::shared_ptr< monty::ndarray< int,1 > > _2497,    std::shared_ptr< monty::ndarray< int,2 > > _2498) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2494,_2495,_2496,_2497,_2498); }void mosek::fusion::p_RangeDomain::_initialize  (bool _2494,    std::shared_ptr< monty::ndarray< double,1 > > _2495,    std::shared_ptr< monty::ndarray< double,1 > > _2496,    std::shared_ptr< monty::ndarray< int,1 > > _2497,    std::shared_ptr< monty::ndarray< int,2 > > _2498){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2495(_2495 ? _2495->raw() : nullptr, _2495 ? _2495->size(0) : 0);
    _checked_ptr_1<double> _ptr__2496(_2496 ? _2496->raw() : nullptr, _2496 ? _2496->size(0) : 0);
    _checked_ptr_1<int> _ptr__2497(_2497 ? _2497->raw() : nullptr, _2497 ? _2497->size(0) : 0);
    mosek::fusion::p_RangeDomain::_initialize(_2494,_2495,_2496,_2497,_2498,(int)1);
  }
}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (bool _2499,    std::shared_ptr< monty::ndarray< double,1 > > _2500,    std::shared_ptr< monty::ndarray< double,1 > > _2501,    std::shared_ptr< monty::ndarray< int,1 > > _2502,    std::shared_ptr< monty::ndarray< int,2 > > _2503,    int _2504){ return new mosek::fusion::RangeDomain(_2499,_2500,_2501,_2502,_2503,_2504); }mosek::fusion::RangeDomain::RangeDomain  (bool _2499,    std::shared_ptr< monty::ndarray< double,1 > > _2500,    std::shared_ptr< monty::ndarray< double,1 > > _2501,    std::shared_ptr< monty::ndarray< int,1 > > _2502,    std::shared_ptr< monty::ndarray< int,2 > > _2503,    int _2504) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2499,_2500,_2501,_2502,_2503,_2504); }void mosek::fusion::p_RangeDomain::_initialize  (bool _2499,    std::shared_ptr< monty::ndarray< double,1 > > _2500,    std::shared_ptr< monty::ndarray< double,1 > > _2501,    std::shared_ptr< monty::ndarray< int,1 > > _2502,    std::shared_ptr< monty::ndarray< int,2 > > _2503,    int _2504){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2500(_2500 ? _2500->raw() : nullptr, _2500 ? _2500->size(0) : 0);
    _checked_ptr_1<double> _ptr__2501(_2501 ? _2501->raw() : nullptr, _2501 ? _2501->size(0) : 0);
    _checked_ptr_1<int> _ptr__2502(_2502 ? _2502->raw() : nullptr, _2502 ? _2502->size(0) : 0);
    cardinal_flag = false;
    shape = _2502;
    sparsity = nullptr;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->scalable = _2499;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->ub = _2501;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->lb = _2500;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = _2503;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->empty = false;
  }
}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2505){ return new mosek::fusion::RangeDomain(_2505); }mosek::fusion::RangeDomain::RangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2505) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2505); }void mosek::fusion::p_RangeDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2505){monty::rc_reserve __reserve_this(_pubthis);   {
    cardinal_flag = mosek::fusion::p_RangeDomain::_get_impl(_2505)->cardinal_flag;
    sparsity = mosek::fusion::p_RangeDomain::_get_impl(_2505)->sparsity;
    scalable = mosek::fusion::p_RangeDomain::_get_impl(_2505)->scalable;
    shape = mosek::fusion::p_RangeDomain::_get_impl(_2505)->shape;
    ub = mosek::fusion::p_RangeDomain::_get_impl(_2505)->ub;
    lb = mosek::fusion::p_RangeDomain::_get_impl(_2505)->lb;
    empty = mosek::fusion::p_RangeDomain::_get_impl(_2505)->empty;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__symmetric() { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__symmetric(); }monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::RangeDomain::symmetric() { return __mosek_2fusion_2RangeDomain__symmetric(); }
monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__symmetric(){
  return ::mosek::fusion::p_SymmetricRangeDomain::_new_SymmetricRangeDomain(::mosek::fusion::RangeDomain::t(_pubthis));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2506) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__sparse(_2506); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::sparse(std::shared_ptr< monty::ndarray< int,2 > > _2506) { return __mosek_2fusion_2RangeDomain__sparse(_2506); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2506){
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2506)->size(0)),(int)((_2506)->size(1)))));
  {
    int _2507 = (int)0;
    for(;(_2507 < (int)((_2506)->size(0)));++ _2507)
    {
      {
        {
          int _2508 = (int)0;
          for(;(_2508 < (int)((_2506)->size(1)));++ _2508)
          {
            {
              ((*mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity)(_2507,_2508)) = ((*_2506)(_2507,_2508));
            }
          }
        }
      }
    }
  }
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2509) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__sparse(_2509); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::sparse(std::shared_ptr< monty::ndarray< int,1 > > _2509) { return __mosek_2fusion_2RangeDomain__sparse(_2509); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2509){
  _checked_ptr_1<int> _ptr__2509(_2509 ? _2509->raw() : nullptr, _2509 ? _2509->size(0) : 0);
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2509)->size(0)),(int)1)));
  int _8009 = (int)0;
  int _8010 = (int)((_2509)->size(0));
  for (int _2510 = _8009; _2510 < _8010; ++_2510)
  {
    {
      ((*mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity)(_2510,(int)0)) = _ptr__2509[_2510];
    }
  }
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__sparse() { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__sparse(); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::sparse() { return __mosek_2fusion_2RangeDomain__sparse(); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__sparse(){
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->empty = true;
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = nullptr;
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__integral() { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__integral(); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::integral() { return __mosek_2fusion_2RangeDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__integral(){
  cardinal_flag = true;
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2511) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__withShape(_2511); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::withShape(std::shared_ptr< monty::ndarray< int,1 > > _2511) { return __mosek_2fusion_2RangeDomain__withShape(_2511); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2511){
  _checked_ptr_1<int> _ptr__2511(_2511 ? _2511->raw() : nullptr, _2511 ? _2511->size(0) : 0);
  shape = _2511;
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
bool mosek::fusion::p_RangeDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2512){
  _checked_ptr_1<int> _ptr__2512(_2512 ? _2512->raw() : nullptr, _2512 ? _2512->size(0) : 0);
  if (scalable)
  {
    {
      return true;
    }
  }
  else if(((int)((shape)->size(0)) != (int)((_2512)->size(0))))
  {
    {
      return false;
    }
  }
  else
  {
    {
      int _8011 = (int)0;
      int _8012 = (int)((shape)->size(0));
      for (int _2513 = _8011; _2513 < _8012; ++_2513)
      {
        {
          if ((((*shape)(_2513)) != _ptr__2512[_2513]))
          {
            {
              return false;
            }
          }
          {}
        }
      }
    }
  }
  return true;
}
void mosek::fusion::p_RangeDomain::destroy(){ub.reset();lb.reset();sparsity.reset();shape.reset();}void mosek::fusion::RangeDomain::destroy() { mosek::fusion::p_RangeDomain::_get_impl(this)->destroy(); }mosek::fusion::SymmetricLinearDomain::SymmetricLinearDomain(mosek::fusion::p_SymmetricLinearDomain *_impl) : _impl(_impl) { /*std::cout << "SymmetricLinearDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SymmetricLinearDomain::~SymmetricLinearDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_SymmetricLinearDomain::p_SymmetricLinearDomain  (::mosek::fusion::SymmetricLinearDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::SymmetricLinearDomain::t mosek::fusion::p_SymmetricLinearDomain::_new_SymmetricLinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2514){ return new mosek::fusion::SymmetricLinearDomain(_2514); }mosek::fusion::SymmetricLinearDomain::SymmetricLinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2514) :    SymmetricLinearDomain(new mosek::fusion::p_SymmetricLinearDomain(this)){ mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->_initialize(_2514); }void mosek::fusion::p_SymmetricLinearDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2514){monty::rc_reserve __reserve_this(_pubthis);   {
    dom = _2514;
    shape = mosek::fusion::p_LinearDomain::_get_impl(_2514)->shape;
    key = mosek::fusion::p_LinearDomain::_get_impl(_2514)->key;
    cardinal_flag = mosek::fusion::p_LinearDomain::_get_impl(_2514)->cardinal_flag;
    sparsity = mosek::fusion::p_LinearDomain::_get_impl(_2514)->sparsity;
    if (((NULL != shape.get()) && (((int)((shape)->size(0)) != (int)2) || (((*shape)((int)0)) != ((*shape)((int)1))))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Only square domains can be symmetric"));
      }
    }
    {}
    int _8013;
    bool _8014 = (NULL == shape.get());
    if (_8014)
    {
      _8013 = (int)0;
    }
    else
    {
      _8013 = ((*shape)((int)0));
    }
    dim = _8013;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain :: __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2515) { return mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->__mosek_2fusion_2SymmetricLinearDomain__sparse(_2515); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain::sparse(std::shared_ptr< monty::ndarray< int,2 > > _2515) { return __mosek_2fusion_2SymmetricLinearDomain__sparse(_2515); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_SymmetricLinearDomain::__mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2515){
  mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2515)->size(0)),(int)((_2515)->size(1)))));
  {
    int _2516 = (int)0;
    for(;(_2516 < (int)((_2515)->size(0)));++ _2516)
    {
      {
        {
          int _2517 = (int)0;
          for(;(_2517 < (int)((_2515)->size(1)));++ _2517)
          {
            {
              ((*mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity)(_2516,_2517)) = ((*_2515)(_2516,_2517));
            }
          }
        }
      }
    }
  }
  return ::mosek::fusion::SymmetricLinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain :: __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2518) { return mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->__mosek_2fusion_2SymmetricLinearDomain__sparse(_2518); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain::sparse(std::shared_ptr< monty::ndarray< int,1 > > _2518) { return __mosek_2fusion_2SymmetricLinearDomain__sparse(_2518); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_SymmetricLinearDomain::__mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2518){
  _checked_ptr_1<int> _ptr__2518(_2518 ? _2518->raw() : nullptr, _2518 ? _2518->size(0) : 0);
  mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2518)->size(0)),(int)1)));
  int _8015 = (int)0;
  int _8016 = (int)((_2518)->size(0));
  for (int _2519 = _8015; _2519 < _8016; ++_2519)
  {
    {
      ((*mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity)(_2519,(int)0)) = _ptr__2518[_2519];
    }
  }
  return ::mosek::fusion::SymmetricLinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain :: __mosek_2fusion_2SymmetricLinearDomain__integral() { return mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->__mosek_2fusion_2SymmetricLinearDomain__integral(); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain::integral() { return __mosek_2fusion_2SymmetricLinearDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_SymmetricLinearDomain::__mosek_2fusion_2SymmetricLinearDomain__integral(){
  cardinal_flag = true;
  return ::mosek::fusion::SymmetricLinearDomain::t(_pubthis);
}
bool mosek::fusion::p_SymmetricLinearDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2520){
  _checked_ptr_1<int> _ptr__2520(_2520 ? _2520->raw() : nullptr, _2520 ? _2520->size(0) : 0);
  int _8017 = (int)0;
  int _8018 = (int)((_2520)->size(0));
  for (int _2521 = _8017; _2521 < _8018; ++_2521)
  {
    {
      if ((_ptr__2520[_2521] == ((*shape)(_2521))))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
void mosek::fusion::p_SymmetricLinearDomain::destroy(){sparsity.reset();shape.reset();dom.reset();}void mosek::fusion::SymmetricLinearDomain::destroy() { mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->destroy(); }mosek::fusion::LinearDomain::LinearDomain(mosek::fusion::p_LinearDomain *_impl) : _impl(_impl) { /*std::cout << "LinearDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinearDomain::~LinearDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinearDomain::p_LinearDomain  (::mosek::fusion::LinearDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinearDomain::t mosek::fusion::p_LinearDomain::_new_LinearDomain  (mosek::fusion::RelationKey _2522,    bool _2523,    std::shared_ptr< monty::ndarray< double,1 > > _2524,    std::shared_ptr< monty::ndarray< int,1 > > _2525){ return new mosek::fusion::LinearDomain(_2522,_2523,_2524,_2525); }mosek::fusion::LinearDomain::LinearDomain  (mosek::fusion::RelationKey _2522,    bool _2523,    std::shared_ptr< monty::ndarray< double,1 > > _2524,    std::shared_ptr< monty::ndarray< int,1 > > _2525) :    LinearDomain(new mosek::fusion::p_LinearDomain(this)){ mosek::fusion::p_LinearDomain::_get_impl(this)->_initialize(_2522,_2523,_2524,_2525); }void mosek::fusion::p_LinearDomain::_initialize  (mosek::fusion::RelationKey _2522,    bool _2523,    std::shared_ptr< monty::ndarray< double,1 > > _2524,    std::shared_ptr< monty::ndarray< int,1 > > _2525){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2524(_2524 ? _2524->raw() : nullptr, _2524 ? _2524->size(0) : 0);
    _checked_ptr_1<int> _ptr__2525(_2525 ? _2525->raw() : nullptr, _2525 ? _2525->size(0) : 0);
    mosek::fusion::p_LinearDomain::_initialize(_2522,_2523,_2524,_2525,nullptr,(int)1);
  }
}mosek::fusion::LinearDomain::t mosek::fusion::p_LinearDomain::_new_LinearDomain  (mosek::fusion::RelationKey _2526,    bool _2527,    std::shared_ptr< monty::ndarray< double,1 > > _2528,    std::shared_ptr< monty::ndarray< int,1 > > _2529,    std::shared_ptr< monty::ndarray< int,2 > > _2530,    int _2531){ return new mosek::fusion::LinearDomain(_2526,_2527,_2528,_2529,_2530,_2531); }mosek::fusion::LinearDomain::LinearDomain  (mosek::fusion::RelationKey _2526,    bool _2527,    std::shared_ptr< monty::ndarray< double,1 > > _2528,    std::shared_ptr< monty::ndarray< int,1 > > _2529,    std::shared_ptr< monty::ndarray< int,2 > > _2530,    int _2531) :    LinearDomain(new mosek::fusion::p_LinearDomain(this)){ mosek::fusion::p_LinearDomain::_get_impl(this)->_initialize(_2526,_2527,_2528,_2529,_2530,_2531); }void mosek::fusion::p_LinearDomain::_initialize  (mosek::fusion::RelationKey _2526,    bool _2527,    std::shared_ptr< monty::ndarray< double,1 > > _2528,    std::shared_ptr< monty::ndarray< int,1 > > _2529,    std::shared_ptr< monty::ndarray< int,2 > > _2530,    int _2531){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2528(_2528 ? _2528->raw() : nullptr, _2528 ? _2528->size(0) : 0);
    _checked_ptr_1<int> _ptr__2529(_2529 ? _2529->raw() : nullptr, _2529 ? _2529->size(0) : 0);
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->scalable = _2527;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->shape = _2529;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->key = _2526;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->bnd = _2528;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = _2530;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->cardinal_flag = false;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->empty = false;
  }
}mosek::fusion::LinearDomain::t mosek::fusion::p_LinearDomain::_new_LinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2532){ return new mosek::fusion::LinearDomain(_2532); }mosek::fusion::LinearDomain::LinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2532) :    LinearDomain(new mosek::fusion::p_LinearDomain(this)){ mosek::fusion::p_LinearDomain::_get_impl(this)->_initialize(_2532); }void mosek::fusion::p_LinearDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2532){monty::rc_reserve __reserve_this(_pubthis);   {
    scalable = mosek::fusion::p_LinearDomain::_get_impl(_2532)->scalable;
    shape = mosek::fusion::p_LinearDomain::_get_impl(_2532)->shape;
    key = mosek::fusion::p_LinearDomain::_get_impl(_2532)->key;
    bnd = mosek::fusion::p_LinearDomain::_get_impl(_2532)->bnd;
    sparsity = mosek::fusion::p_LinearDomain::_get_impl(_2532)->sparsity;
    cardinal_flag = mosek::fusion::p_LinearDomain::_get_impl(_2532)->cardinal_flag;
    empty = mosek::fusion::p_LinearDomain::_get_impl(_2532)->empty;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__symmetric() { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__symmetric(); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::LinearDomain::symmetric() { return __mosek_2fusion_2LinearDomain__symmetric(); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__symmetric(){
  return ::mosek::fusion::p_SymmetricLinearDomain::_new_SymmetricLinearDomain(::mosek::fusion::LinearDomain::t(_pubthis));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2533) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__sparse(_2533); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::sparse(std::shared_ptr< monty::ndarray< int,2 > > _2533) { return __mosek_2fusion_2LinearDomain__sparse(_2533); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2533){
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2533)->size(0)),(int)((_2533)->size(1)))));
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->empty = false;
  {
    int _2534 = (int)0;
    for(;(_2534 < (int)((_2533)->size(0)));++ _2534)
    {
      {
        {
          int _2535 = (int)0;
          for(;(_2535 < (int)((_2533)->size(1)));++ _2535)
          {
            {
              ((*mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity)(_2534,_2535)) = ((*_2533)(_2534,_2535));
            }
          }
        }
      }
    }
  }
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2536) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__sparse(_2536); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::sparse(std::shared_ptr< monty::ndarray< int,1 > > _2536) { return __mosek_2fusion_2LinearDomain__sparse(_2536); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2536){
  _checked_ptr_1<int> _ptr__2536(_2536 ? _2536->raw() : nullptr, _2536 ? _2536->size(0) : 0);
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2536)->size(0)),(int)1)));
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->empty = false;
  int _8019 = (int)0;
  int _8020 = (int)((_2536)->size(0));
  for (int _2537 = _8019; _2537 < _8020; ++_2537)
  {
    {
      ((*mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity)(_2537,(int)0)) = _ptr__2536[_2537];
    }
  }
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__sparse() { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__sparse(); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::sparse() { return __mosek_2fusion_2LinearDomain__sparse(); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__sparse(){
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->empty = true;
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = nullptr;
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__integral() { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__integral(); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::integral() { return __mosek_2fusion_2LinearDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__integral(){
  cardinal_flag = true;
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2538) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__withShape(_2538); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::withShape(std::shared_ptr< monty::ndarray< int,1 > > _2538) { return __mosek_2fusion_2LinearDomain__withShape(_2538); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2538){
  _checked_ptr_1<int> _ptr__2538(_2538 ? _2538->raw() : nullptr, _2538 ? _2538->size(0) : 0);
  shape = _2538;
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
bool mosek::fusion::p_LinearDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2539){
  _checked_ptr_1<int> _ptr__2539(_2539 ? _2539->raw() : nullptr, _2539 ? _2539->size(0) : 0);
  if ((!scalable))
  {
    {
      int _8021 = (int)0;
      int _8022 = (int)((_2539)->size(0));
      for (int _2540 = _8021; _2540 < _8022; ++_2540)
      {
        {
          if ((_ptr__2539[_2540] == ((*shape)(_2540))))
          {
            {
              return false;
            }
          }
          {}
        }
      }
    }
  }
  {}
  return true;
}
void mosek::fusion::p_LinearDomain::destroy(){sparsity.reset();bnd.reset();shape.reset();}void mosek::fusion::LinearDomain::destroy() { mosek::fusion::p_LinearDomain::_get_impl(this)->destroy(); }mosek::fusion::Domain::Domain(mosek::fusion::p_Domain *_impl) : _impl(_impl) { /*std::cout << "Domain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Domain::~Domain() { delete _impl; _impl = nullptr; }mosek::fusion::p_Domain::p_Domain  (::mosek::fusion::Domain * _pubthis) :     _pubthis(_pubthis){}long long mosek::fusion::p_Domain::dimsize(std::shared_ptr< monty::ndarray< int,1 > > _2541){
  _checked_ptr_1<int> _ptr__2541(_2541 ? _2541->raw() : nullptr, _2541 ? _2541->size(0) : 0);
  long long _2542 = (long long)1;
  int _8023 = (int)0;
  int _8024 = (int)((_2541)->size(0));
  for (int _2543 = _8023; _2543 < _8024; ++_2543)
  {
    {
      _2542 *= _ptr__2541[_2543];
    }
  }
  return _2542;
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::mkLinearDomain(mosek::fusion::RelationKey _2544,monty::rc_ptr< ::mosek::fusion::Matrix > _2545){
  if (_2545->isSparse())
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _2546 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2545->numNonzeros())));
      _checked_ptr_1<int> _ptr__2546(_2546 ? _2546->raw() : nullptr,_2546 ? _2546->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2547 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2545->numNonzeros())));
      _checked_ptr_1<int> _ptr__2547(_2547 ? _2547->raw() : nullptr,_2547 ? _2547->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2548 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2545->numNonzeros())));
      _checked_ptr_1<double> _ptr__2548(_2548 ? _2548->raw() : nullptr,_2548 ? _2548->size(0) : 0);
      _2545->getDataAsTriplets(_2546,_2547,_2548);
      std::shared_ptr< monty::ndarray< int,2 > > _2549 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2546)->size(0)),(int)2)));
      int _8025 = (int)0;
      int _8026 = (int)((_2546)->size(0));
      for (int _2550 = _8025; _2550 < _8026; ++_2550)
      {
        {
          ((*_2549)(_2550,(int)0)) = _ptr__2546[_2550];
          ((*_2549)(_2550,(int)1)) = _ptr__2547[_2550];
        }
      }
      return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(_2544,false,_2548,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(mosek::fusion::p_Matrix::_get_impl(_2545)->dimi),(int)(mosek::fusion::p_Matrix::_get_impl(_2545)->dimj)}),_2549,(int)1);
    }
  }
  else
  {
    {
      return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(_2544,false,_2545->getDataAsArray(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(mosek::fusion::p_Matrix::_get_impl(_2545)->dimi),(int)(mosek::fusion::p_Matrix::_get_impl(_2545)->dimj)}),nullptr,(int)1);
    }
  }
}
long long mosek::fusion::p_Domain::prod(std::shared_ptr< monty::ndarray< int,1 > > _2551){
  _checked_ptr_1<int> _ptr__2551(_2551 ? _2551->raw() : nullptr, _2551 ? _2551->size(0) : 0);
  long long _2552 = (int)1;
  int _8027 = (int)0;
  int _8028 = (int)((_2551)->size(0));
  for (int _2553 = _8027; _2553 < _8028; ++_2553)
  {
    {
      _2552 *= _ptr__2551[_2553];
    }
  }
  return _2552;
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(bool _2554,std::shared_ptr< monty::ndarray< double,1 > > _2555,std::shared_ptr< monty::ndarray< double,1 > > _2556,std::shared_ptr< monty::ndarray< int,2 > > _2557,std::shared_ptr< monty::ndarray< int,1 > > _2558){
  _checked_ptr_1<double> _ptr__2555(_2555 ? _2555->raw() : nullptr, _2555 ? _2555->size(0) : 0);
  _checked_ptr_1<double> _ptr__2556(_2556 ? _2556->raw() : nullptr, _2556 ? _2556->size(0) : 0);
  _checked_ptr_1<int> _ptr__2558(_2558 ? _2558->raw() : nullptr, _2558 ? _2558->size(0) : 0);
  if (((!_2554) && ((int)((_2555)->size(0)) != (int)((_2556)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching lengths of upper and lower bounds."));
    }
  }
  {}
  if (((NULL != _2557.get()) && ((int)((_2557)->size(0)) != (int)((_2555)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching lengths of upper/lower bounds and sparsity."));
    }
  }
  {}
  int _8029 = (int)0;
  int _8030 = (int)((_2556)->size(0));
  for (int _2559 = _8029; _2559 < _8030; ++_2559)
  {
    {
      if ((_ptr__2555[_2559] > _ptr__2556[_2559]))
      {
        {
          throw ::mosek::fusion::DomainError(std::string ("Invalid range specified"));
        }
      }
      {}
    }
  }
  if (((NULL != _2558.get()) && (::mosek::fusion::p_Domain::dimsize(_2558) != (int)((_2555)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching dimensions."));
    }
  }
  {}
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(_2554,_2555,_2556,_2558)->__mosek_2fusion_2RangeDomain__sparse(_2557);
}
monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::Domain::symmetric  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2560) { return mosek::fusion::p_Domain::symmetric(_2560); }monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::p_Domain::symmetric(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2560){
  return _2560->__mosek_2fusion_2RangeDomain__symmetric();
}
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::Domain::symmetric  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2561) { return mosek::fusion::p_Domain::symmetric(_2561); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_Domain::symmetric(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2561){
  return _2561->__mosek_2fusion_2LinearDomain__symmetric();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2562,    std::shared_ptr< monty::ndarray< int,2 > > _2563) { return mosek::fusion::p_Domain::sparse(_2562,_2563); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2562,std::shared_ptr< monty::ndarray< int,2 > > _2563){
  return _2562->__mosek_2fusion_2RangeDomain__sparse(_2563);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2564,    std::shared_ptr< monty::ndarray< int,1 > > _2565) { return mosek::fusion::p_Domain::sparse(_2564,_2565); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2564,std::shared_ptr< monty::ndarray< int,1 > > _2565){
  _checked_ptr_1<int> _ptr__2565(_2565 ? _2565->raw() : nullptr, _2565 ? _2565->size(0) : 0);
  return _2564->__mosek_2fusion_2RangeDomain__sparse(_2565);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2566,    std::shared_ptr< monty::ndarray< int,2 > > _2567) { return mosek::fusion::p_Domain::sparse(_2566,_2567); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2566,std::shared_ptr< monty::ndarray< int,2 > > _2567){
  return _2566->__mosek_2fusion_2LinearDomain__sparse(_2567);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2568,    std::shared_ptr< monty::ndarray< int,1 > > _2569) { return mosek::fusion::p_Domain::sparse(_2568,_2569); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2568,std::shared_ptr< monty::ndarray< int,1 > > _2569){
  _checked_ptr_1<int> _ptr__2569(_2569 ? _2569->raw() : nullptr, _2569 ? _2569->size(0) : 0);
  return _2568->__mosek_2fusion_2LinearDomain__sparse(_2569);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::integral  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2570) { return mosek::fusion::p_Domain::integral(_2570); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::integral(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2570){
  return _2570->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::integral  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2571) { return mosek::fusion::p_Domain::integral(_2571); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::integral(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2571){
  return _2571->__mosek_2fusion_2LinearDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::integral  ( monty::rc_ptr< ::mosek::fusion::ConeDomain > _2572) { return mosek::fusion::p_Domain::integral(_2572); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::integral(monty::rc_ptr< ::mosek::fusion::ConeDomain > _2572){
  return _2572->__mosek_2fusion_2ConeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::axis  ( monty::rc_ptr< ::mosek::fusion::ConeDomain > _2573,    int _2574) { return mosek::fusion::p_Domain::axis(_2573,_2574); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::axis(monty::rc_ptr< ::mosek::fusion::ConeDomain > _2573,int _2574){
  return _2573->__mosek_2fusion_2ConeDomain__axis(_2574);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDPowerCone  ( double _2575,    std::shared_ptr< monty::ndarray< int,1 > > _2576) { return mosek::fusion::p_Domain::inDPowerCone(_2575,_2576); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDPowerCone(double _2575,std::shared_ptr< monty::ndarray< int,1 > > _2576){
  _checked_ptr_1<int> _ptr__2576(_2576 ? _2576->raw() : nullptr, _2576 ? _2576->size(0) : 0);
  std::vector<int> _8031;
  for (int _2577 = (int)0, _8032 = (int)((_2576)->size(0)); _2577 < _8032 ; ++_2577)
  {
    _8031.push_back(_ptr__2576[_2577]);
  }
  auto _8033 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8031.size()),_8031.begin(),_8031.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDPowCone,_2575,_8033);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDPowerCone  ( double _2578,    int _2579) { return mosek::fusion::p_Domain::inDPowerCone(_2578,_2579); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDPowerCone(double _2578,int _2579){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDPowCone,_2578,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2579),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDPowerCone  ( double _2580) { return mosek::fusion::p_Domain::inDPowerCone(_2580); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDPowerCone(double _2580){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDPowCone,_2580,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPPowerCone  ( double _2581,    std::shared_ptr< monty::ndarray< int,1 > > _2582) { return mosek::fusion::p_Domain::inPPowerCone(_2581,_2582); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPPowerCone(double _2581,std::shared_ptr< monty::ndarray< int,1 > > _2582){
  _checked_ptr_1<int> _ptr__2582(_2582 ? _2582->raw() : nullptr, _2582 ? _2582->size(0) : 0);
  std::vector<int> _8034;
  for (int _2583 = (int)0, _8035 = (int)((_2582)->size(0)); _2583 < _8035 ; ++_2583)
  {
    _8034.push_back(_ptr__2582[_2583]);
  }
  auto _8036 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8034.size()),_8034.begin(),_8034.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPPowCone,_2581,_8036);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPPowerCone  ( double _2584,    int _2585) { return mosek::fusion::p_Domain::inPPowerCone(_2584,_2585); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPPowerCone(double _2584,int _2585){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPPowCone,_2584,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2585),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPPowerCone  ( double _2586) { return mosek::fusion::p_Domain::inPPowerCone(_2586); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPPowerCone(double _2586){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPPowCone,_2586,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDExpCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2587) { return mosek::fusion::p_Domain::inDExpCone(_2587); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDExpCone(std::shared_ptr< monty::ndarray< int,1 > > _2587){
  _checked_ptr_1<int> _ptr__2587(_2587 ? _2587->raw() : nullptr, _2587 ? _2587->size(0) : 0);
  std::vector<int> _8037;
  for (int _2588 = (int)0, _8038 = (int)((_2587)->size(0)); _2588 < _8038 ; ++_2588)
  {
    _8037.push_back(_ptr__2587[_2588]);
  }
  auto _8039 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8037.size()),_8037.begin(),_8037.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDExpCone,_8039);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDExpCone  ( int _2589) { return mosek::fusion::p_Domain::inDExpCone(_2589); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDExpCone(int _2589){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDExpCone,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2589),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDExpCone  ( ) { return mosek::fusion::p_Domain::inDExpCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDExpCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDExpCone,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPExpCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2590) { return mosek::fusion::p_Domain::inPExpCone(_2590); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPExpCone(std::shared_ptr< monty::ndarray< int,1 > > _2590){
  _checked_ptr_1<int> _ptr__2590(_2590 ? _2590->raw() : nullptr, _2590 ? _2590->size(0) : 0);
  std::vector<int> _8040;
  for (int _2591 = (int)0, _8041 = (int)((_2590)->size(0)); _2591 < _8041 ; ++_2591)
  {
    _8040.push_back(_ptr__2590[_2591]);
  }
  auto _8042 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8040.size()),_8040.begin(),_8040.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPExpCone,_8042);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPExpCone  ( int _2592) { return mosek::fusion::p_Domain::inPExpCone(_2592); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPExpCone(int _2592){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPExpCone,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2592),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPExpCone  ( ) { return mosek::fusion::p_Domain::inPExpCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPExpCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPExpCone,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2593) { return mosek::fusion::p_Domain::inRotatedQCone(_2593); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(std::shared_ptr< monty::ndarray< int,1 > > _2593){
  _checked_ptr_1<int> _ptr__2593(_2593 ? _2593->raw() : nullptr, _2593 ? _2593->size(0) : 0);
  std::vector<int> _8043;
  for (int _2594 = (int)0, _8044 = (int)((_2593)->size(0)); _2594 < _8044 ; ++_2594)
  {
    _8043.push_back(_ptr__2593[_2594]);
  }
  auto _8045 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8043.size()),_8043.begin(),_8043.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,_8045);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( int _2595,    int _2596) { return mosek::fusion::p_Domain::inRotatedQCone(_2595,_2596); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(int _2595,int _2596){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2595),(int)(_2596)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( int _2597) { return mosek::fusion::p_Domain::inRotatedQCone(_2597); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(int _2597){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2597)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( ) { return mosek::fusion::p_Domain::inRotatedQCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2598) { return mosek::fusion::p_Domain::inQCone(_2598); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(std::shared_ptr< monty::ndarray< int,1 > > _2598){
  _checked_ptr_1<int> _ptr__2598(_2598 ? _2598->raw() : nullptr, _2598 ? _2598->size(0) : 0);
  std::vector<int> _8046;
  for (int _2599 = (int)0, _8047 = (int)((_2598)->size(0)); _2599 < _8047 ; ++_2599)
  {
    _8046.push_back(_ptr__2598[_2599]);
  }
  auto _8048 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8046.size()),_8046.begin(),_8046.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,_8048);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( int _2600,    int _2601) { return mosek::fusion::p_Domain::inQCone(_2600,_2601); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(int _2600,int _2601){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2600),(int)(_2601)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( int _2602) { return mosek::fusion::p_Domain::inQCone(_2602); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(int _2602){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2602)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( ) { return mosek::fusion::p_Domain::inQCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::Domain::isLinPSD  ( int _2603,    int _2604) { return mosek::fusion::p_Domain::isLinPSD(_2603,_2604); }monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::p_Domain::isLinPSD(int _2603,int _2604){
  return ::mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain(::mosek::fusion::p_Set::make((safe_mul( _2603,safe_add( _2603,(int)1 ) ) / (int)2),_2604));
}
monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::Domain::isLinPSD  ( int _2605) { return mosek::fusion::p_Domain::isLinPSD(_2605); }monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::p_Domain::isLinPSD(int _2605){
  return ::mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain(::mosek::fusion::p_Set::make((safe_mul( _2605,safe_add( _2605,(int)1 ) ) / (int)2)));
}
monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::Domain::isLinPSD  ( ) { return mosek::fusion::p_Domain::isLinPSD(); }monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::p_Domain::isLinPSD(){
  return ::mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain();
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::isTrilPSD  ( int _2606,    int _2607) { return mosek::fusion::p_Domain::isTrilPSD(_2606,_2607); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::isTrilPSD(int _2606,int _2607){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsTrilPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2607),(int)(_2606),(int)(_2606)}),(int)1,(int)2);
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::isTrilPSD  ( int _2608) { return mosek::fusion::p_Domain::isTrilPSD(_2608); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::isTrilPSD(int _2608){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsTrilPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2608),(int)(_2608)}),(int)0,(int)1);
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::isTrilPSD  ( ) { return mosek::fusion::p_Domain::isTrilPSD(); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::isTrilPSD(){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsTrilPSD);
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::inPSDCone  ( int _2609,    int _2610) { return mosek::fusion::p_Domain::inPSDCone(_2609,_2610); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::inPSDCone(int _2609,int _2610){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsSymPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2610),(int)(_2609),(int)(_2609)}));
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::inPSDCone  ( int _2611) { return mosek::fusion::p_Domain::inPSDCone(_2611); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::inPSDCone(int _2611){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsSymPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2611),(int)(_2611)}));
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::inPSDCone  ( ) { return mosek::fusion::p_Domain::inPSDCone(); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::inPSDCone(){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsSymPSD);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( ) { return mosek::fusion::p_Domain::binary(); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),nullptr)->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( std::shared_ptr< monty::ndarray< int,1 > > _2612) { return mosek::fusion::p_Domain::binary(_2612); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(std::shared_ptr< monty::ndarray< int,1 > > _2612){
  _checked_ptr_1<int> _ptr__2612(_2612 ? _2612->raw() : nullptr, _2612 ? _2612->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),_2612)->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( int _2613,    int _2614) { return mosek::fusion::p_Domain::binary(_2613,_2614); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(int _2613,int _2614){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2613),(int)(_2614)}))->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( int _2615) { return mosek::fusion::p_Domain::binary(_2615); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(int _2615){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2615)}))->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2616,    std::shared_ptr< monty::ndarray< double,1 > > _2617,    std::shared_ptr< monty::ndarray< int,1 > > _2618) { return mosek::fusion::p_Domain::inRange(_2616,_2617,_2618); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2616,std::shared_ptr< monty::ndarray< double,1 > > _2617,std::shared_ptr< monty::ndarray< int,1 > > _2618){
  _checked_ptr_1<double> _ptr__2616(_2616 ? _2616->raw() : nullptr, _2616 ? _2616->size(0) : 0);
  _checked_ptr_1<double> _ptr__2617(_2617 ? _2617->raw() : nullptr, _2617 ? _2617->size(0) : 0);
  _checked_ptr_1<int> _ptr__2618(_2618 ? _2618->raw() : nullptr, _2618 ? _2618->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2616,_2617,_2618);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2619,    double _2620,    std::shared_ptr< monty::ndarray< int,1 > > _2621) { return mosek::fusion::p_Domain::inRange(_2619,_2620,_2621); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2619,double _2620,std::shared_ptr< monty::ndarray< int,1 > > _2621){
  _checked_ptr_1<double> _ptr__2619(_2619 ? _2619->raw() : nullptr, _2619 ? _2619->size(0) : 0);
  _checked_ptr_1<int> _ptr__2621(_2621 ? _2621->raw() : nullptr, _2621 ? _2621->size(0) : 0);
  std::vector<double> _8049;
  for (int _2622 = (int)0, _8050 = (int)((_2619)->size(0)); _2622 < _8050 ; ++_2622)
  {
    _8049.push_back(_2620);
  }
  auto _8051 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8049.size()),_8049.begin(),_8049.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2619,_8051,_2621);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2623,    std::shared_ptr< monty::ndarray< double,1 > > _2624,    std::shared_ptr< monty::ndarray< int,1 > > _2625) { return mosek::fusion::p_Domain::inRange(_2623,_2624,_2625); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2623,std::shared_ptr< monty::ndarray< double,1 > > _2624,std::shared_ptr< monty::ndarray< int,1 > > _2625){
  _checked_ptr_1<double> _ptr__2624(_2624 ? _2624->raw() : nullptr, _2624 ? _2624->size(0) : 0);
  _checked_ptr_1<int> _ptr__2625(_2625 ? _2625->raw() : nullptr, _2625 ? _2625->size(0) : 0);
  std::vector<double> _8052;
  for (int _2626 = (int)0, _8053 = (int)((_2624)->size(0)); _2626 < _8053 ; ++_2626)
  {
    _8052.push_back(_2623);
  }
  auto _8054 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8052.size()),_8052.begin(),_8052.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_8054,_2624,_2625);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2627,    double _2628,    std::shared_ptr< monty::ndarray< int,1 > > _2629) { return mosek::fusion::p_Domain::inRange(_2627,_2628,_2629); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2627,double _2628,std::shared_ptr< monty::ndarray< int,1 > > _2629){
  _checked_ptr_1<int> _ptr__2629(_2629 ? _2629->raw() : nullptr, _2629 ? _2629->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2627)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2628)}),_2629);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2630,    std::shared_ptr< monty::ndarray< double,1 > > _2631) { return mosek::fusion::p_Domain::inRange(_2630,_2631); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2630,std::shared_ptr< monty::ndarray< double,1 > > _2631){
  _checked_ptr_1<double> _ptr__2630(_2630 ? _2630->raw() : nullptr, _2630 ? _2630->size(0) : 0);
  _checked_ptr_1<double> _ptr__2631(_2631 ? _2631->raw() : nullptr, _2631 ? _2631->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2630,_2631,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2630)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2632,    double _2633) { return mosek::fusion::p_Domain::inRange(_2632,_2633); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2632,double _2633){
  _checked_ptr_1<double> _ptr__2632(_2632 ? _2632->raw() : nullptr, _2632 ? _2632->size(0) : 0);
  std::vector<double> _8055;
  for (int _2634 = (int)0, _8056 = (int)((_2632)->size(0)); _2634 < _8056 ; ++_2634)
  {
    _8055.push_back(_2633);
  }
  auto _8057 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8055.size()),_8055.begin(),_8055.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2632,_8057,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2632)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2635,    std::shared_ptr< monty::ndarray< double,1 > > _2636) { return mosek::fusion::p_Domain::inRange(_2635,_2636); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2635,std::shared_ptr< monty::ndarray< double,1 > > _2636){
  _checked_ptr_1<double> _ptr__2636(_2636 ? _2636->raw() : nullptr, _2636 ? _2636->size(0) : 0);
  std::vector<double> _8058;
  for (int _2637 = (int)0, _8059 = (int)((_2636)->size(0)); _2637 < _8059 ; ++_2637)
  {
    _8058.push_back(_2635);
  }
  auto _8060 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8058.size()),_8058.begin(),_8058.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_8060,_2636,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2636)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2638,    double _2639) { return mosek::fusion::p_Domain::inRange(_2638,_2639); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2638,double _2639){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2638)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2639)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( monty::rc_ptr< ::mosek::fusion::Matrix > _2640) { return mosek::fusion::p_Domain::greaterThan(_2640); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(monty::rc_ptr< ::mosek::fusion::Matrix > _2640){
  return ::mosek::fusion::p_Domain::mkLinearDomain(::mosek::fusion::RelationKey::GreaterThan,_2640);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2641,    std::shared_ptr< monty::ndarray< int,1 > > _2642) { return mosek::fusion::p_Domain::greaterThan(_2641,_2642); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _2641,std::shared_ptr< monty::ndarray< int,1 > > _2642){
  _checked_ptr_1<double> _ptr__2641(_2641 ? _2641->raw() : nullptr, _2641 ? _2641->size(0) : 0);
  _checked_ptr_1<int> _ptr__2642(_2642 ? _2642->raw() : nullptr, _2642 ? _2642->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2641),_2642);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( std::shared_ptr< monty::ndarray< double,2 > > _2643) { return mosek::fusion::p_Domain::greaterThan(_2643); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(std::shared_ptr< monty::ndarray< double,2 > > _2643){
  std::vector<double> _8061;
  for (int _2644 = (int)0, _8062 = (int)((_2643)->size(0)); _2644 < _8062 ; ++_2644)
  {
    for (int _2645 = (int)0, _8063 = (int)((_2643)->size(1)); _2645 < _8063 ; ++_2645)
    {
      _8061.push_back(((*_2643)(_2644,_2645)));
    }
  }
  auto _8064 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8061.size()),_8061.begin(),_8061.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,false,_8064,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2643)->size(0))),(int)((int)((_2643)->size(1)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2646) { return mosek::fusion::p_Domain::greaterThan(_2646); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _2646){
  _checked_ptr_1<double> _ptr__2646(_2646 ? _2646->raw() : nullptr, _2646 ? _2646->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2646),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2646)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2647,    std::shared_ptr< monty::ndarray< int,1 > > _2648) { return mosek::fusion::p_Domain::greaterThan(_2647,_2648); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2647,std::shared_ptr< monty::ndarray< int,1 > > _2648){
  _checked_ptr_1<int> _ptr__2648(_2648 ? _2648->raw() : nullptr, _2648 ? _2648->size(0) : 0);
  std::vector<double> _8065;
  for (long long _2649 = (int)0, _8066 = ::mosek::fusion::p_Domain::prod(_2648); _2649 < _8066 ; ++_2649)
  {
    _8065.push_back(_2647);
  }
  auto _8067 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8065.size()),_8065.begin(),_8065.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,_8067,_2648);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2650,    int _2651,    int _2652) { return mosek::fusion::p_Domain::greaterThan(_2650,_2651,_2652); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2650,int _2651,int _2652){
  std::vector<double> _8068;
  for (int _2653 = (int)0, _8069 = safe_mul( _2652,_2651 ); _2653 < _8069 ; ++_2653)
  {
    _8068.push_back(_2650);
  }
  auto _8070 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8068.size()),_8068.begin(),_8068.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,_8070,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2651),(int)(_2652)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2654,    int _2655) { return mosek::fusion::p_Domain::greaterThan(_2654,_2655); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2654,int _2655){
  std::vector<double> _8071;
  for (int _2656 = (int)0, _8072 = _2655; _2656 < _8072 ; ++_2656)
  {
    _8071.push_back(_2654);
  }
  auto _8073 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8071.size()),_8071.begin(),_8071.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,_8073,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2655)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2657) { return mosek::fusion::p_Domain::greaterThan(_2657); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2657){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2657)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( monty::rc_ptr< ::mosek::fusion::Matrix > _2658) { return mosek::fusion::p_Domain::lessThan(_2658); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(monty::rc_ptr< ::mosek::fusion::Matrix > _2658){
  return ::mosek::fusion::p_Domain::mkLinearDomain(::mosek::fusion::RelationKey::LessThan,_2658);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2659,    std::shared_ptr< monty::ndarray< int,1 > > _2660) { return mosek::fusion::p_Domain::lessThan(_2659,_2660); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(std::shared_ptr< monty::ndarray< double,1 > > _2659,std::shared_ptr< monty::ndarray< int,1 > > _2660){
  _checked_ptr_1<double> _ptr__2659(_2659 ? _2659->raw() : nullptr, _2659 ? _2659->size(0) : 0);
  _checked_ptr_1<int> _ptr__2660(_2660 ? _2660->raw() : nullptr, _2660 ? _2660->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2659),_2660);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( std::shared_ptr< monty::ndarray< double,2 > > _2661) { return mosek::fusion::p_Domain::lessThan(_2661); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(std::shared_ptr< monty::ndarray< double,2 > > _2661){
  std::vector<double> _8074;
  for (int _2662 = (int)0, _8075 = (int)((_2661)->size(0)); _2662 < _8075 ; ++_2662)
  {
    for (int _2663 = (int)0, _8076 = (int)((_2661)->size(1)); _2663 < _8076 ; ++_2663)
    {
      _8074.push_back(((*_2661)(_2662,_2663)));
    }
  }
  auto _8077 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8074.size()),_8074.begin(),_8074.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,false,_8077,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2661)->size(0))),(int)((int)((_2661)->size(1)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2664) { return mosek::fusion::p_Domain::lessThan(_2664); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(std::shared_ptr< monty::ndarray< double,1 > > _2664){
  _checked_ptr_1<double> _ptr__2664(_2664 ? _2664->raw() : nullptr, _2664 ? _2664->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2664),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2664)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2665,    std::shared_ptr< monty::ndarray< int,1 > > _2666) { return mosek::fusion::p_Domain::lessThan(_2665,_2666); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2665,std::shared_ptr< monty::ndarray< int,1 > > _2666){
  _checked_ptr_1<int> _ptr__2666(_2666 ? _2666->raw() : nullptr, _2666 ? _2666->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2665)}),_2666);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2667,    int _2668,    int _2669) { return mosek::fusion::p_Domain::lessThan(_2667,_2668,_2669); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2667,int _2668,int _2669){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2667)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2668),(int)(_2669)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2670,    int _2671) { return mosek::fusion::p_Domain::lessThan(_2670,_2671); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2670,int _2671){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2670)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2671)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2672) { return mosek::fusion::p_Domain::lessThan(_2672); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2672){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2672)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( monty::rc_ptr< ::mosek::fusion::Matrix > _2673) { return mosek::fusion::p_Domain::equalsTo(_2673); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(monty::rc_ptr< ::mosek::fusion::Matrix > _2673){
  return ::mosek::fusion::p_Domain::mkLinearDomain(::mosek::fusion::RelationKey::EqualsTo,_2673);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( std::shared_ptr< monty::ndarray< double,1 > > _2674,    std::shared_ptr< monty::ndarray< int,1 > > _2675) { return mosek::fusion::p_Domain::equalsTo(_2674,_2675); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _2674,std::shared_ptr< monty::ndarray< int,1 > > _2675){
  _checked_ptr_1<double> _ptr__2674(_2674 ? _2674->raw() : nullptr, _2674 ? _2674->size(0) : 0);
  _checked_ptr_1<int> _ptr__2675(_2675 ? _2675->raw() : nullptr, _2675 ? _2675->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,false,::mosek::fusion::Utils::Tools::arraycopy(_2674),_2675);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( std::shared_ptr< monty::ndarray< double,2 > > _2676) { return mosek::fusion::p_Domain::equalsTo(_2676); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(std::shared_ptr< monty::ndarray< double,2 > > _2676){
  std::vector<double> _8078;
  for (int _2677 = (int)0, _8079 = (int)((_2676)->size(0)); _2677 < _8079 ; ++_2677)
  {
    for (int _2678 = (int)0, _8080 = (int)((_2676)->size(1)); _2678 < _8080 ; ++_2678)
    {
      _8078.push_back(((*_2676)(_2677,_2678)));
    }
  }
  auto _8081 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8078.size()),_8078.begin(),_8078.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,false,_8081,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2676)->size(0))),(int)((int)((_2676)->size(1)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( std::shared_ptr< monty::ndarray< double,1 > > _2679) { return mosek::fusion::p_Domain::equalsTo(_2679); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _2679){
  _checked_ptr_1<double> _ptr__2679(_2679 ? _2679->raw() : nullptr, _2679 ? _2679->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,false,::mosek::fusion::Utils::Tools::arraycopy(_2679),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2679)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2680,    std::shared_ptr< monty::ndarray< int,1 > > _2681) { return mosek::fusion::p_Domain::equalsTo(_2680,_2681); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2680,std::shared_ptr< monty::ndarray< int,1 > > _2681){
  _checked_ptr_1<int> _ptr__2681(_2681 ? _2681->raw() : nullptr, _2681 ? _2681->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2680)}),_2681);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2682,    int _2683,    int _2684) { return mosek::fusion::p_Domain::equalsTo(_2682,_2683,_2684); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2682,int _2683,int _2684){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2682)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2683),(int)(_2684)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2685,    int _2686) { return mosek::fusion::p_Domain::equalsTo(_2685,_2686); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2685,int _2686){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2685)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2686)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2687) { return mosek::fusion::p_Domain::equalsTo(_2687); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2687){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2687)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( std::shared_ptr< monty::ndarray< int,1 > > _2688) { return mosek::fusion::p_Domain::unbounded(_2688); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(std::shared_ptr< monty::ndarray< int,1 > > _2688){
  _checked_ptr_1<int> _ptr__2688(_2688 ? _2688->raw() : nullptr, _2688 ? _2688->size(0) : 0);
  std::vector<int> _8082;
  for (int _2689 = (int)0, _8083 = (int)((_2688)->size(0)); _2689 < _8083 ; ++_2689)
  {
    _8082.push_back(_ptr__2688[_2689]);
  }
  auto _8084 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8082.size()),_8082.begin(),_8082.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,false,nullptr,_8084);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( int _2690,    int _2691) { return mosek::fusion::p_Domain::unbounded(_2690,_2691); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(int _2690,int _2691){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,false,nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2690),(int)(_2691)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( int _2692) { return mosek::fusion::p_Domain::unbounded(_2692); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(int _2692){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,false,nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2692)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( ) { return mosek::fusion::p_Domain::unbounded(); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,true,nullptr,nullptr);
}
void mosek::fusion::p_Domain::destroy(){}void mosek::fusion::Domain::destroy() { mosek::fusion::p_Domain::_get_impl(this)->destroy(); }mosek::fusion::ExprConst::ExprConst(mosek::fusion::p_ExprConst *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprConst()" << this << std::endl; */ }mosek::fusion::ExprConst::~ExprConst() {  /* std::cout << "~ExprConst()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprConst::p_ExprConst  (::mosek::fusion::ExprConst * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprConst::t mosek::fusion::p_ExprConst::_new_ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2693,    std::shared_ptr< monty::ndarray< long long,1 > > _2694,    std::shared_ptr< monty::ndarray< double,1 > > _2695){ return new mosek::fusion::ExprConst(_2693,_2694,_2695); }mosek::fusion::ExprConst::ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2693,    std::shared_ptr< monty::ndarray< long long,1 > > _2694,    std::shared_ptr< monty::ndarray< double,1 > > _2695) :    ExprConst(new mosek::fusion::p_ExprConst(this)){ mosek::fusion::p_ExprConst::_get_impl(this)->_initialize(_2693,_2694,_2695); }void mosek::fusion::p_ExprConst::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2693,    std::shared_ptr< monty::ndarray< long long,1 > > _2694,    std::shared_ptr< monty::ndarray< double,1 > > _2695){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2693(_2693 ? _2693->raw() : nullptr, _2693 ? _2693->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2694(_2694 ? _2694->raw() : nullptr, _2694 ? _2694->size(0) : 0);
    _checked_ptr_1<double> _ptr__2695(_2695 ? _2695->raw() : nullptr, _2695 ? _2695->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_2693);
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->bfix = ::mosek::fusion::Utils::Tools::arraycopy(_2695);
    std::shared_ptr< monty::ndarray< long long,1 > > _8085;
    bool _8086 = (NULL != _2694.get());
    if (_8086)
    {
      _8085 = ::mosek::fusion::Utils::Tools::arraycopy(_2694);
    }
    else
    {
      _8085 = nullptr;
    }
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->sparsity = _8085;
    ::mosek::fusion::p_ExprConst::validate(_2693,_2695,_2694);
  }
}mosek::fusion::ExprConst::t mosek::fusion::p_ExprConst::_new_ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2696,    std::shared_ptr< monty::ndarray< long long,1 > > _2697,    double _2698){ return new mosek::fusion::ExprConst(_2696,_2697,_2698); }mosek::fusion::ExprConst::ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2696,    std::shared_ptr< monty::ndarray< long long,1 > > _2697,    double _2698) :    ExprConst(new mosek::fusion::p_ExprConst(this)){ mosek::fusion::p_ExprConst::_get_impl(this)->_initialize(_2696,_2697,_2698); }void mosek::fusion::p_ExprConst::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2696,    std::shared_ptr< monty::ndarray< long long,1 > > _2697,    double _2698){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2696(_2696 ? _2696->raw() : nullptr, _2696 ? _2696->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2697(_2697 ? _2697->raw() : nullptr, _2697 ? _2697->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_2696);
    long long _8087;
    bool _8088 = (NULL == _2697.get());
    if (_8088)
    {
      _8087 = ::mosek::fusion::p_Set::size(_2696);
    }
    else
    {
      _8087 = (int)((_2697)->size(0));
    }
    long long _2699 = _8087;
    std::vector<double> _8089;
    for (long long _2700 = (int)0, _8090 = _2699; _2700 < _8090 ; ++_2700)
    {
      _8089.push_back(_2698);
    }
    auto _8091 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8089.size()),_8089.begin(),_8089.end()));
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->bfix = _8091;
    std::shared_ptr< monty::ndarray< long long,1 > > _8092;
    bool _8093 = (NULL != _2697.get());
    if (_8093)
    {
      _8092 = ::mosek::fusion::Utils::Tools::arraycopy(_2697);
    }
    else
    {
      _8092 = nullptr;
    }
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->sparsity = _8092;
    ::mosek::fusion::p_ExprConst::validate(_2696,mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->bfix,_2697);
  }
}void mosek::fusion::ExprConst :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2701,monty::rc_ptr< ::mosek::fusion::WorkStack > _2702,monty::rc_ptr< ::mosek::fusion::WorkStack > _2703) { mosek::fusion::p_ExprConst::_get_impl(this)->eval(_2701,_2702,_2703); }void mosek::fusion::p_ExprConst::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2701,monty::rc_ptr< ::mosek::fusion::WorkStack > _2702,monty::rc_ptr< ::mosek::fusion::WorkStack > _2703){
  std::shared_ptr< monty::ndarray< int,1 > > _2704 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__2704(_2704 ? _2704->raw() : nullptr,_2704 ? _2704->size(0) : 0);
  int _2705 = (int)((bfix)->size(0));
  bool _2706 = ((NULL != sparsity.get()) && ((int)((sparsity)->size(0)) < ::mosek::fusion::p_Set::size(_2704)));
  int _2707 = _2701->alloci32(safe_add( _2705,(int)1 ));
  int _8094;
  bool _8095 = _2706;
  if (_8095)
  {
    _8094 = (int)1;
  }
  else
  {
    _8094 = (int)0;
  }
  _2701->pushi32(_8094);
  _2701->pushi32((int)0);
  _2701->pushi32(_2705);
  int _8096 = (int)0;
  int _8097 = (int)((_2704)->size(0));
  for (int _2708 = _8096; _2708 < _8097; ++_2708)
  {
    {
      _2701->pushi32(_ptr__2704[_2708]);
    }
  }
  _2701->pushi32((int)((_2704)->size(0)));
  if ((NULL != sparsity.get()))
  {
    {
      int _2709 = _2701->alloci64((int)((sparsity)->size(0)));
      std::shared_ptr< monty::ndarray< long long,1 > > _2710 = mosek::fusion::p_WorkStack::_get_impl(_2701)->i64;
      _checked_ptr_1<long long> _ptr__2710(_2710 ? _2710->raw() : nullptr,_2710 ? _2710->size(0) : 0);
      int _8098 = (int)0;
      int _8099 = (int)((sparsity)->size(0));
      for (int _2711 = _8098; _2711 < _8099; ++_2711)
      {
        {
          _ptr__2710[safe_add( _2709,_2711 )] = ((*sparsity)(_2711));
        }
      }
    }
  }
  {}
  int _2712 = _2701->allocf64((int)((bfix)->size(0)));
  std::shared_ptr< monty::ndarray< double,1 > > _2713 = mosek::fusion::p_WorkStack::_get_impl(_2701)->f64;
  _checked_ptr_1<double> _ptr__2713(_2713 ? _2713->raw() : nullptr,_2713 ? _2713->size(0) : 0);
  int _8100 = (int)0;
  int _8101 = (int)((bfix)->size(0));
  for (int _2714 = _8100; _2714 < _8101; ++_2714)
  {
    {
      _ptr__2713[safe_add( _2712,_2714 )] = ((*bfix)(_2714));
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2715 = mosek::fusion::p_WorkStack::_get_impl(_2701)->i32;
  _checked_ptr_1<int> _ptr__2715(_2715 ? _2715->raw() : nullptr,_2715 ? _2715->size(0) : 0);
  int _8102 = (int)0;
  int _8103 = safe_add( _2705,(int)1 );
  for (int _2716 = _8102; _2716 < _8103; ++_2716)
  {
    {
      _ptr__2715[safe_add( _2707,_2716 )] = (int)0;
    }
  }
}
void mosek::fusion::p_ExprConst::validate(std::shared_ptr< monty::ndarray< int,1 > > _2717,std::shared_ptr< monty::ndarray< double,1 > > _2718,std::shared_ptr< monty::ndarray< long long,1 > > _2719){
  _checked_ptr_1<int> _ptr__2717(_2717 ? _2717->raw() : nullptr, _2717 ? _2717->size(0) : 0);
  _checked_ptr_1<double> _ptr__2718(_2718 ? _2718->raw() : nullptr, _2718 ? _2718->size(0) : 0);
  _checked_ptr_1<long long> _ptr__2719(_2719 ? _2719->raw() : nullptr, _2719 ? _2719->size(0) : 0);
  long long _2720 = ::mosek::fusion::p_Set::size(_2717);
  if ((NULL != _2719.get()))
  {
    {
      if (((int)((_2719)->size(0)) != (int)((_2718)->size(0))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Mismatching data lengths"));
        }
      }
      {}
      bool _2721 = false;
      int _8104 = (int)0;
      int _8105 = (int)((_2719)->size(0));
      for (int _2722 = _8104; _2722 < _8105; ++_2722)
      {
        {
          if (((_ptr__2719[_2722] < (int)0) || (_ptr__2719[_2722] >= _2720)))
          {
            {
              _2721 = true;
            }
          }
          {}
        }
      }
      if (_2721)
      {
        {
          throw ::mosek::fusion::IndexError(std::string ("Invalid sparsity index"));
        }
      }
      {}
    }
  }
  else
  {
    {
      if (((int)((_2718)->size(0)) != _2720))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Mismatching data length"));
        }
      }
      {}
    }
  }
}
std::string mosek::fusion::ExprConst :: toString() { return mosek::fusion::p_ExprConst::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprConst::toString(){
  return std::string ("ExprConst()");
}
void mosek::fusion::p_ExprConst::destroy(){sparsity.reset();bfix.reset();}void mosek::fusion::ExprConst::destroy() { mosek::fusion::p_ExprConst::_get_impl(this)->destroy(); }mosek::fusion::ExprPick::ExprPick(mosek::fusion::p_ExprPick *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprPick()" << this << std::endl; */ }mosek::fusion::ExprPick::~ExprPick() {  /* std::cout << "~ExprPick()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprPick::p_ExprPick  (::mosek::fusion::ExprPick * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprPick::t mosek::fusion::p_ExprPick::_new_ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2723,    std::shared_ptr< monty::ndarray< int,2 > > _2724){ return new mosek::fusion::ExprPick(_2723,_2724); }mosek::fusion::ExprPick::ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2723,    std::shared_ptr< monty::ndarray< int,2 > > _2724) :    ExprPick(new mosek::fusion::p_ExprPick(this)){ mosek::fusion::p_ExprPick::_get_impl(this)->_initialize(_2723,_2724); }void mosek::fusion::p_ExprPick::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2723,    std::shared_ptr< monty::ndarray< int,2 > > _2724){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2724)->size(0)))}));
    std::shared_ptr< monty::ndarray< int,1 > > _2725 = _2723->getShape();
    _checked_ptr_1<int> _ptr__2725(_2725 ? _2725->raw() : nullptr,_2725 ? _2725->size(0) : 0);
    int _2726 = (int)((_2725)->size(0));
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->expr = _2723;
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_2724)->size(0)))));
    std::shared_ptr< monty::ndarray< long long,1 > > _2727 = mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs;
    _checked_ptr_1<long long> _ptr__2727(_2727 ? _2727->raw() : nullptr,_2727 ? _2727->size(0) : 0);
    if (((int)((_2724)->size(1)) != _2726))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and index dimensions"));
      }
    }
    {}
    bool _2728 = false;
    int _8106 = (int)0;
    int _8107 = (int)((_2724)->size(0));
    for (int _2729 = _8106; _2729 < _8107; ++_2729)
    {
      {
        int _8108 = (int)0;
        int _8109 = _2726;
        for (int _2730 = _8108; _2730 < _8109; ++_2730)
        {
          {
            if (((((*_2724)(_2729,_2730)) < (int)0) || (((*_2724)(_2729,_2730)) >= _ptr__2725[_2730])))
            {
              {
                _2728 = true;
              }
            }
            {}
          }
        }
      }
    }
    if (_2728)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Pick index out of bounds"));
      }
    }
    {}
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2731 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2726)));
      _checked_ptr_1<long long> _ptr__2731(_2731 ? _2731->raw() : nullptr,_2731 ? _2731->size(0) : 0);
      _ptr__2731[(_2726 - (int)1)] = (int)1;
      int _8110 = (int)1;
      int _8111 = _2726;
      for (int _2732 = _8110; _2732 < _8111; ++_2732)
      {
        {
          _ptr__2731[((_2726 - _2732) - (int)1)] = safe_mul( _ptr__2731[(_2726 - _2732)],_ptr__2725[(_2726 - _2732)] );
        }
      }
      int _8112 = (int)0;
      int _8113 = (int)((_2724)->size(0));
      for (int _2733 = _8112; _2733 < _8113; ++_2733)
      {
        {
          long long _2734 = (long long)0;
          int _8114 = (int)0;
          int _8115 = _2726;
          for (int _2735 = _8114; _2735 < _8115; ++_2735)
          {
            {
              _2734 += safe_mul( _ptr__2731[_2735],((*_2724)(_2733,_2735)) );
            }
          }
          _ptr__2727[_2733] = _2734;
        }
      }
    }
  }
}mosek::fusion::ExprPick::t mosek::fusion::p_ExprPick::_new_ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2736,    std::shared_ptr< monty::ndarray< long long,1 > > _2737){ return new mosek::fusion::ExprPick(_2736,_2737); }mosek::fusion::ExprPick::ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2736,    std::shared_ptr< monty::ndarray< long long,1 > > _2737) :    ExprPick(new mosek::fusion::p_ExprPick(this)){ mosek::fusion::p_ExprPick::_get_impl(this)->_initialize(_2736,_2737); }void mosek::fusion::p_ExprPick::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2736,    std::shared_ptr< monty::ndarray< long long,1 > > _2737){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__2737(_2737 ? _2737->raw() : nullptr, _2737 ? _2737->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2737)->size(0)))}));
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->expr = _2736;
    std::shared_ptr< monty::ndarray< int,1 > > _2738 = _2736->getShape();
    _checked_ptr_1<int> _ptr__2738(_2738 ? _2738->raw() : nullptr,_2738 ? _2738->size(0) : 0);
    long long _2739 = ::mosek::fusion::p_Set::size(_2738);
    bool _2740 = false;
    int _8116 = (int)0;
    int _8117 = (int)((_2737)->size(0));
    for (int _2741 = _8116; _2741 < _8117; ++_2741)
    {
      {
        if (((_ptr__2737[_2741] < (int)0) || (_ptr__2737[_2741] >= _2739)))
        {
          {
            _2740 = true;
          }
        }
        {}
      }
    }
    if (_2740)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Pick index out of bounds"));
      }
    }
    {}
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs = ::mosek::fusion::Utils::Tools::arraycopy(_2737);
  }
}void mosek::fusion::ExprPick :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2742,monty::rc_ptr< ::mosek::fusion::WorkStack > _2743,monty::rc_ptr< ::mosek::fusion::WorkStack > _2744) { mosek::fusion::p_ExprPick::_get_impl(this)->eval(_2742,_2743,_2744); }void mosek::fusion::p_ExprPick::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2742,monty::rc_ptr< ::mosek::fusion::WorkStack > _2743,monty::rc_ptr< ::mosek::fusion::WorkStack > _2744){
  expr->eval(_2743,_2742,_2744);
  _2743->pop_expr();
  int _2745 = mosek::fusion::p_WorkStack::_get_impl(_2743)->nd;
  int _2746 = mosek::fusion::p_WorkStack::_get_impl(_2743)->shape_base;
  int _2747 = mosek::fusion::p_WorkStack::_get_impl(_2743)->nelem;
  int _2748 = mosek::fusion::p_WorkStack::_get_impl(_2743)->nnz;
  bool _2749 = mosek::fusion::p_WorkStack::_get_impl(_2743)->hassp;
  int _2750 = mosek::fusion::p_WorkStack::_get_impl(_2743)->ptr_base;
  int _2751 = mosek::fusion::p_WorkStack::_get_impl(_2743)->sp_base;
  int _2752 = mosek::fusion::p_WorkStack::_get_impl(_2743)->nidxs_base;
  int _2753 = mosek::fusion::p_WorkStack::_get_impl(_2743)->bfix_base;
  int _2754 = mosek::fusion::p_WorkStack::_get_impl(_2743)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _2755 = mosek::fusion::p_WorkStack::_get_impl(_2743)->i32;
  _checked_ptr_1<int> _ptr__2755(_2755 ? _2755->raw() : nullptr,_2755 ? _2755->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2756 = mosek::fusion::p_WorkStack::_get_impl(_2743)->i64;
  _checked_ptr_1<long long> _ptr__2756(_2756 ? _2756->raw() : nullptr,_2756 ? _2756->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2757 = mosek::fusion::p_WorkStack::_get_impl(_2743)->f64;
  _checked_ptr_1<double> _ptr__2757(_2757 ? _2757->raw() : nullptr,_2757 ? _2757->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2758 = mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs;
  _checked_ptr_1<long long> _ptr__2758(_2758 ? _2758->raw() : nullptr,_2758 ? _2758->size(0) : 0);
  if ((!_2749))
  {
    {
      int _2759 = (int)((_2758)->size(0));
      int _2760 = (int)1;
      int _2761 = (int)0;
      int _8118 = (int)0;
      int _8119 = (int)((_2758)->size(0));
      for (int _2762 = _8118; _2762 < _8119; ++_2762)
      {
        {
          _2761 += (_ptr__2755[safe_add( safe_add( _2750,_ptr__2758[_2762] ),(int)1 )] - _ptr__2755[safe_add( _2750,_ptr__2758[_2762] )]);
        }
      }
      _2742->alloc_expr(_2760,_2759,_2761,false);
      int _2763 = mosek::fusion::p_WorkStack::_get_impl(_2742)->cof_base;
      int _2764 = mosek::fusion::p_WorkStack::_get_impl(_2742)->bfix_base;
      int _2765 = mosek::fusion::p_WorkStack::_get_impl(_2742)->nidxs_base;
      int _2766 = mosek::fusion::p_WorkStack::_get_impl(_2742)->ptr_base;
      int _2767 = mosek::fusion::p_WorkStack::_get_impl(_2742)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _2768 = mosek::fusion::p_WorkStack::_get_impl(_2742)->i32;
      _checked_ptr_1<int> _ptr__2768(_2768 ? _2768->raw() : nullptr,_2768 ? _2768->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2769 = mosek::fusion::p_WorkStack::_get_impl(_2742)->i64;
      _checked_ptr_1<long long> _ptr__2769(_2769 ? _2769->raw() : nullptr,_2769 ? _2769->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2770 = mosek::fusion::p_WorkStack::_get_impl(_2742)->f64;
      _checked_ptr_1<double> _ptr__2770(_2770 ? _2770->raw() : nullptr,_2770 ? _2770->size(0) : 0);
      _ptr__2768[_2767] = (int)((_2758)->size(0));
      int _2771 = (int)0;
      _ptr__2768[_2766] = (int)0;
      int _8120 = (int)0;
      int _8121 = (int)((_2758)->size(0));
      for (int _2772 = _8120; _2772 < _8121; ++_2772)
      {
        {
          int _8122 = _ptr__2755[safe_add( _2750,_ptr__2758[_2772] )];
          int _8123 = _ptr__2755[safe_add( safe_add( _2750,_ptr__2758[_2772] ),(int)1 )];
          for (int _2773 = _8122; _2773 < _8123; ++_2773)
          {
            {
              _ptr__2769[safe_add( _2765,_2771 )] = _ptr__2756[safe_add( _2752,_2773 )];
              _ptr__2770[safe_add( _2763,_2771 )] = _ptr__2757[safe_add( _2754,_2773 )];
              ++ _2771;
            }
          }
          _ptr__2770[safe_add( _2764,_2772 )] = _ptr__2757[safe_add( _2753,_ptr__2758[_2772] )];
          _ptr__2768[safe_add( safe_add( _2766,_2772 ),(int)1 )] = _2771;
        }
      }
    }
  }
  else
  {
    {
      int _2774 = (int)1;
      int _2775 = (int)((_2758)->size(0));
      int _2776 = (int)0;
      std::shared_ptr< monty::ndarray< long long,1 > > _2777 = mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs;
      _checked_ptr_1<long long> _ptr__2777(_2777 ? _2777->raw() : nullptr,_2777 ? _2777->size(0) : 0);
      int _2778 = _2744->alloci32((int)((_2777)->size(0)));
      std::shared_ptr< monty::ndarray< int,1 > > _2779 = mosek::fusion::p_WorkStack::_get_impl(_2744)->i32;
      _checked_ptr_1<int> _ptr__2779(_2779 ? _2779->raw() : nullptr,_2779 ? _2779->size(0) : 0);
      int _8124 = (int)0;
      int _8125 = (int)((_2777)->size(0));
      for (int _2780 = _8124; _2780 < _8125; ++_2780)
      {
        {
          int _2781 = _2747;
          int _2782 = (int)0;
          while ( (_2782 < (_2781 - (int)1)) )
          {
            {
              int _2783 = (safe_add( safe_add( _2781,_2782 ),(int)1 ) / (int)2);
              if ((_ptr__2756[safe_add( _2751,_2783 )] >= _ptr__2777[_2780]))
              {
                {
                  _2781 = _2783;
                }
              }
              else
              {
                {
                  _2782 = _2783;
                }
              }
            }
          }
          ++ _2782;
          if (((_2782 < _2747) && (_ptr__2756[safe_add( _2751,_2782 )] == _ptr__2777[_2780])))
          {
            {
              _ptr__2779[safe_add( _2778,_2780 )] = _2782;
              _2776 += (_ptr__2755[safe_add( safe_add( _2750,_2782 ),(int)1 )] - _ptr__2755[safe_add( _2750,_2782 )]);
            }
          }
          else
          {
            {
              _ptr__2779[safe_add( _2778,_2780 )] = (-(int)1);
            }
          }
        }
      }
      _2742->alloc_expr(_2774,_2775,_2776,false);
      int _2784 = mosek::fusion::p_WorkStack::_get_impl(_2742)->ptr_base;
      int _2785 = mosek::fusion::p_WorkStack::_get_impl(_2742)->nidxs_base;
      int _2786 = mosek::fusion::p_WorkStack::_get_impl(_2742)->cof_base;
      int _2787 = mosek::fusion::p_WorkStack::_get_impl(_2742)->bfix_base;
      int _2788 = mosek::fusion::p_WorkStack::_get_impl(_2742)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _2789 = mosek::fusion::p_WorkStack::_get_impl(_2742)->i32;
      _checked_ptr_1<int> _ptr__2789(_2789 ? _2789->raw() : nullptr,_2789 ? _2789->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2790 = mosek::fusion::p_WorkStack::_get_impl(_2742)->i64;
      _checked_ptr_1<long long> _ptr__2790(_2790 ? _2790->raw() : nullptr,_2790 ? _2790->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2791 = mosek::fusion::p_WorkStack::_get_impl(_2742)->f64;
      _checked_ptr_1<double> _ptr__2791(_2791 ? _2791->raw() : nullptr,_2791 ? _2791->size(0) : 0);
      _ptr__2789[_2788] = (int)((_2777)->size(0));
      _ptr__2789[_2784] = (int)0;
      int _2792 = (int)0;
      int _8126 = (int)0;
      int _8127 = (int)((_2777)->size(0));
      for (int _2793 = _8126; _2793 < _8127; ++_2793)
      {
        {
          if ((_ptr__2779[safe_add( _2778,_2793 )] >= (int)0))
          {
            {
              int _2794 = _ptr__2779[safe_add( _2778,_2793 )];
              int _8128 = _ptr__2755[safe_add( _2750,_2794 )];
              int _8129 = _ptr__2755[safe_add( safe_add( _2750,_2794 ),(int)1 )];
              for (int _2795 = _8128; _2795 < _8129; ++_2795)
              {
                {
                  _ptr__2790[safe_add( _2785,_2792 )] = _ptr__2756[safe_add( _2752,_2795 )];
                  _ptr__2791[safe_add( _2786,_2792 )] = _ptr__2757[safe_add( _2754,_2795 )];
                  ++ _2792;
                }
              }
              _ptr__2791[safe_add( _2787,_2793 )] = _ptr__2757[safe_add( _2753,_2794 )];
            }
          }
          else
          {
            {
              _ptr__2791[safe_add( _2787,_2793 )] = 0.0;
            }
          }
          _ptr__2789[safe_add( safe_add( _2784,_2793 ),(int)1 )] = _2792;
        }
      }
    }
  }
}
std::string mosek::fusion::ExprPick :: toString() { return mosek::fusion::p_ExprPick::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprPick::toString(){
  return std::string ("ExprPick()");
}
void mosek::fusion::p_ExprPick::destroy(){idxs.reset();expr.reset();}void mosek::fusion::ExprPick::destroy() { mosek::fusion::p_ExprPick::_get_impl(this)->destroy(); }mosek::fusion::ExprSlice::ExprSlice(mosek::fusion::p_ExprSlice *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprSlice()" << this << std::endl; */ }mosek::fusion::ExprSlice::~ExprSlice() {  /* std::cout << "~ExprSlice()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprSlice::p_ExprSlice  (::mosek::fusion::ExprSlice * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprSlice::t mosek::fusion::p_ExprSlice::_new_ExprSlice  (monty::rc_ptr< ::mosek::fusion::Expression > _2796,    std::shared_ptr< monty::ndarray< int,1 > > _2797,    std::shared_ptr< monty::ndarray< int,1 > > _2798){ return new mosek::fusion::ExprSlice(_2796,_2797,_2798); }mosek::fusion::ExprSlice::ExprSlice  (monty::rc_ptr< ::mosek::fusion::Expression > _2796,    std::shared_ptr< monty::ndarray< int,1 > > _2797,    std::shared_ptr< monty::ndarray< int,1 > > _2798) :    ExprSlice(new mosek::fusion::p_ExprSlice(this)){ mosek::fusion::p_ExprSlice::_get_impl(this)->_initialize(_2796,_2797,_2798); }void mosek::fusion::p_ExprSlice::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2796,    std::shared_ptr< monty::ndarray< int,1 > > _2797,    std::shared_ptr< monty::ndarray< int,1 > > _2798){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2797(_2797 ? _2797->raw() : nullptr, _2797 ? _2797->size(0) : 0);
    _checked_ptr_1<int> _ptr__2798(_2798 ? _2798->raw() : nullptr, _2798 ? _2798->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprSlice::makeShape(_2796->getShape(),_2797,_2798));
    mosek::fusion::p_ExprSlice::_get_impl(::mosek::fusion::ExprSlice::t(_pubthis))->expr = _2796;
    mosek::fusion::p_ExprSlice::_get_impl(::mosek::fusion::ExprSlice::t(_pubthis))->first = _2797;
    mosek::fusion::p_ExprSlice::_get_impl(::mosek::fusion::ExprSlice::t(_pubthis))->last = _2798;
  }
}void mosek::fusion::ExprSlice :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2799,monty::rc_ptr< ::mosek::fusion::WorkStack > _2800,monty::rc_ptr< ::mosek::fusion::WorkStack > _2801) { mosek::fusion::p_ExprSlice::_get_impl(this)->eval(_2799,_2800,_2801); }void mosek::fusion::p_ExprSlice::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2799,monty::rc_ptr< ::mosek::fusion::WorkStack > _2800,monty::rc_ptr< ::mosek::fusion::WorkStack > _2801){
  expr->eval(_2800,_2799,_2801);
  int _2802 = _2800->popi32();
  int _2803 = _2800->popi32(_2802);
  int _2804 = _2800->popi32();
  int _2805 = _2800->popi32();
  bool _2806 = (_2800->popi32() != (int)0);
  int _2807 = _2800->popi32(safe_add( _2804,(int)1 ));
  int _8130;
  bool _8131 = _2806;
  if (_8131)
  {
    _8130 = _2800->popi64(_2804);
  }
  else
  {
    _8130 = (-(int)1);
  }
  int _2808 = _8130;
  int _2809 = _2800->popi64(_2805);
  int _2810 = _2800->popf64(_2804);
  int _2811 = _2800->popf64(_2805);
  std::shared_ptr< monty::ndarray< int,1 > > _2812 = mosek::fusion::p_WorkStack::_get_impl(_2800)->i32;
  _checked_ptr_1<int> _ptr__2812(_2812 ? _2812->raw() : nullptr,_2812 ? _2812->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2813 = mosek::fusion::p_WorkStack::_get_impl(_2800)->i64;
  _checked_ptr_1<long long> _ptr__2813(_2813 ? _2813->raw() : nullptr,_2813 ? _2813->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2814 = mosek::fusion::p_WorkStack::_get_impl(_2800)->f64;
  _checked_ptr_1<double> _ptr__2814(_2814 ? _2814->raw() : nullptr,_2814 ? _2814->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2815 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2802)));
  _checked_ptr_1<long long> _ptr__2815(_2815 ? _2815->raw() : nullptr,_2815 ? _2815->size(0) : 0);
  _ptr__2815[(_2802 - (int)1)] = (int)1;
  int _8132 = (int)1;
  int _8133 = _2802;
  for (int _2816 = _8132; _2816 < _8133; ++_2816)
  {
    {
      _ptr__2815[((_2802 - _2816) - (int)1)] = safe_mul( _ptr__2815[(_2802 - _2816)],_ptr__2812[(safe_add( _2803,_2802 ) - _2816)] );
    }
  }
  int _2817 = (int)0;
  int _2818 = (int)0;
  if (_2806)
  {
    {
      int _8134 = (int)0;
      int _8135 = _2804;
      for (int _2819 = _8134; _2819 < _8135; ++_2819)
      {
        {
          bool _2820 = true;
          int _8136 = (int)0;
          int _8137 = _2802;
          for (int _2821 = _8136; _2821 < _8137; ++_2821)
          {
            {
              long long _2822 = ((_ptr__2813[safe_add( _2808,_2819 )] / _ptr__2815[_2821]) % _ptr__2812[safe_add( _2803,_2821 )]);
              _2820 = (_2820 && ((_2822 >= ((*first)(_2821))) && (_2822 < ((*last)(_2821)))));
            }
          }
          if (_2820)
          {
            {
              _2818 += (_ptr__2812[safe_add( safe_add( _2807,_2819 ),(int)1 )] - _ptr__2812[safe_add( _2807,_2819 )]);
              ++ _2817;
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      _2817 = (int)1;
      int _8138 = (int)0;
      int _8139 = _2802;
      for (int _2823 = _8138; _2823 < _8139; ++_2823)
      {
        {
          _2817 *= (((*last)(_2823)) - ((*first)(_2823)));
        }
      }
      int _8140 = (int)0;
      int _8141 = _2804;
      for (int _2824 = _8140; _2824 < _8141; ++_2824)
      {
        {
          bool _2825 = true;
          int _8142 = (int)0;
          int _8143 = _2802;
          for (int _2826 = _8142; _2826 < _8143; ++_2826)
          {
            {
              long long _2827 = ((_2824 / _ptr__2815[_2826]) % _ptr__2812[safe_add( _2803,_2826 )]);
              _2825 = (_2825 && ((_2827 >= ((*first)(_2826))) && (_2827 < ((*last)(_2826)))));
            }
          }
          if (_2825)
          {
            {
              _2818 += (_ptr__2812[safe_add( safe_add( _2807,_2824 ),(int)1 )] - _ptr__2812[safe_add( _2807,_2824 )]);
            }
          }
          {}
        }
      }
    }
  }
  std::vector<int> _8144;
  for (int _2829 = (int)0, _8145 = _2802; _2829 < _8145 ; ++_2829)
  {
    _8144.push_back((((*last)(_2829)) - ((*first)(_2829))));
  }
  auto _8146 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8144.size()),_8144.begin(),_8144.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _2828 = _8146;
  _checked_ptr_1<int> _ptr__2828(_2828 ? _2828->raw() : nullptr,_2828 ? _2828->size(0) : 0);
  int _2830 = _2799->allocf64(_2818);
  int _2831 = _2799->allocf64(_2817);
  int _2832 = _2799->alloci64(_2818);
  int _8147;
  bool _8148 = _2806;
  if (_8148)
  {
    _8147 = _2799->alloci64(_2817);
  }
  else
  {
    _8147 = (-(int)1);
  }
  int _2833 = _8147;
  int _2834 = _2799->alloci32(safe_add( _2817,(int)1 ));
  int _8149;
  bool _8150 = _2806;
  if (_8150)
  {
    _8149 = (int)1;
  }
  else
  {
    _8149 = (int)0;
  }
  _2799->pushi32(_8149);
  _2799->pushi32(_2818);
  _2799->pushi32(_2817);
  int _8151 = (int)0;
  int _8152 = _2802;
  for (int _2835 = _8151; _2835 < _8152; ++_2835)
  {
    {
      _2799->pushi32(_ptr__2828[_2835]);
    }
  }
  _2799->pushi32(_2802);
  std::shared_ptr< monty::ndarray< int,1 > > _2836 = mosek::fusion::p_WorkStack::_get_impl(_2799)->i32;
  _checked_ptr_1<int> _ptr__2836(_2836 ? _2836->raw() : nullptr,_2836 ? _2836->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2837 = mosek::fusion::p_WorkStack::_get_impl(_2799)->i64;
  _checked_ptr_1<long long> _ptr__2837(_2837 ? _2837->raw() : nullptr,_2837 ? _2837->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2838 = mosek::fusion::p_WorkStack::_get_impl(_2799)->f64;
  _checked_ptr_1<double> _ptr__2838(_2838 ? _2838->raw() : nullptr,_2838 ? _2838->size(0) : 0);
  _ptr__2836[_2834] = (int)0;
  std::shared_ptr< monty::ndarray< long long,1 > > _2839 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2802)));
  _checked_ptr_1<long long> _ptr__2839(_2839 ? _2839->raw() : nullptr,_2839 ? _2839->size(0) : 0);
  _ptr__2839[(_2802 - (int)1)] = (int)1;
  int _8153 = (int)1;
  int _8154 = _2802;
  for (int _2840 = _8153; _2840 < _8154; ++_2840)
  {
    {
      _ptr__2839[((_2802 - _2840) - (int)1)] = safe_mul( _ptr__2839[(_2802 - _2840)],_ptr__2828[(_2802 - _2840)] );
    }
  }
  int _2841 = (int)0;
  int _2842 = (int)0;
  if (_2806)
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _2843 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2802)));
      _checked_ptr_1<int> _ptr__2843(_2843 ? _2843->raw() : nullptr,_2843 ? _2843->size(0) : 0);
      int _8155 = (int)0;
      int _8156 = _2804;
      for (int _2844 = _8155; _2844 < _8156; ++_2844)
      {
        {
          bool _2845 = true;
          int _8157 = (int)0;
          int _8158 = _2802;
          for (int _2846 = _8157; _2846 < _8158; ++_2846)
          {
            {
              _ptr__2843[_2846] = (int)((_ptr__2813[safe_add( _2808,_2844 )] / _ptr__2815[_2846]) % _ptr__2812[safe_add( _2803,_2846 )]);
              _2845 = (_2845 && ((_ptr__2843[_2846] >= ((*first)(_2846))) && (_ptr__2843[_2846] < ((*last)(_2846)))));
            }
          }
          if (_2845)
          {
            {
              int _8159 = _ptr__2812[safe_add( _2807,_2844 )];
              int _8160 = _ptr__2812[safe_add( safe_add( _2807,_2844 ),(int)1 )];
              for (int _2847 = _8159; _2847 < _8160; ++_2847)
              {
                {
                  _ptr__2837[safe_add( _2832,_2842 )] = _ptr__2813[safe_add( _2809,_2847 )];
                  _ptr__2838[safe_add( _2830,_2842 )] = _ptr__2814[safe_add( _2811,_2847 )];
                  ++ _2842;
                }
              }
              long long _2848 = (long long)0;
              int _8161 = (int)0;
              int _8162 = _2802;
              for (int _2849 = _8161; _2849 < _8162; ++_2849)
              {
                {
                  _2848 += safe_mul( _ptr__2839[_2849],(_ptr__2843[_2849] - ((*first)(_2849))) );
                }
              }
              _ptr__2837[safe_add( _2833,_2841 )] = _2848;
              _ptr__2838[safe_add( _2831,_2841 )] = _ptr__2814[safe_add( _2810,_2844 )];
              _ptr__2836[safe_add( safe_add( _2834,_2841 ),(int)1 )] = _2842;
              ++ _2841;
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      int _8163 = (int)0;
      int _8164 = _2804;
      for (int _2850 = _8163; _2850 < _8164; ++_2850)
      {
        {
          bool _2851 = true;
          int _8165 = (int)0;
          int _8166 = _2802;
          for (int _2852 = _8165; _2852 < _8166; ++_2852)
          {
            {
              long long _2853 = ((_2850 / _ptr__2815[_2852]) % _ptr__2812[safe_add( _2803,_2852 )]);
              _2851 = (_2851 && ((_2853 >= ((*first)(_2852))) && (_2853 < ((*last)(_2852)))));
            }
          }
          if (_2851)
          {
            {
              int _8167 = _ptr__2812[safe_add( _2807,_2850 )];
              int _8168 = _ptr__2812[safe_add( safe_add( _2807,_2850 ),(int)1 )];
              for (int _2854 = _8167; _2854 < _8168; ++_2854)
              {
                {
                  _ptr__2837[safe_add( _2832,_2842 )] = _ptr__2813[safe_add( _2809,_2854 )];
                  _ptr__2838[safe_add( _2830,_2842 )] = _ptr__2814[safe_add( _2811,_2854 )];
                  ++ _2842;
                }
              }
              _ptr__2838[safe_add( _2831,_2841 )] = _ptr__2814[safe_add( _2810,_2850 )];
              _ptr__2836[safe_add( safe_add( _2834,_2841 ),(int)1 )] = _2842;
              ++ _2841;
            }
          }
          {}
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprSlice::makeShape(std::shared_ptr< monty::ndarray< int,1 > > _2855,std::shared_ptr< monty::ndarray< int,1 > > _2856,std::shared_ptr< monty::ndarray< int,1 > > _2857){
  _checked_ptr_1<int> _ptr__2855(_2855 ? _2855->raw() : nullptr, _2855 ? _2855->size(0) : 0);
  _checked_ptr_1<int> _ptr__2856(_2856 ? _2856->raw() : nullptr, _2856 ? _2856->size(0) : 0);
  _checked_ptr_1<int> _ptr__2857(_2857 ? _2857->raw() : nullptr, _2857 ? _2857->size(0) : 0);
  if ((((int)((_2855)->size(0)) != (int)((_2856)->size(0))) || ((int)((_2855)->size(0)) != (int)((_2857)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid or mismatching index lengths"));
    }
  }
  {}
  int _8169 = (int)0;
  int _8170 = (int)((_2855)->size(0));
  for (int _2858 = _8169; _2858 < _8170; ++_2858)
  {
    {
      if (((_ptr__2856[_2858] < (int)0) || ((_ptr__2857[_2858] < _ptr__2856[_2858]) || (_ptr__2857[_2858] > _ptr__2855[_2858]))))
      {
        {
          throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
        }
      }
      {}
    }
  }
  std::vector<int> _8171;
  for (int _2859 = (int)0, _8172 = (int)((_2855)->size(0)); _2859 < _8172 ; ++_2859)
  {
    _8171.push_back((_ptr__2857[_2859] - _ptr__2856[_2859]));
  }
  auto _8173 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8171.size()),_8171.begin(),_8171.end()));
  return _8173;
}
std::string mosek::fusion::ExprSlice :: toString() { return mosek::fusion::p_ExprSlice::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprSlice::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2860 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprSlice(["))->__mosek_2fusion_2Utils_2StringBuffer__a(((*first)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (":"))->__mosek_2fusion_2Utils_2StringBuffer__a(((*last)((int)0)));
  int _8174 = (int)1;
  int _8175 = (int)((first)->size(0));
  for (int _2861 = _8174; _2861 < _8175; ++_2861)
  {
    {
      _2860->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*first)(_2861)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (":"))->__mosek_2fusion_2Utils_2StringBuffer__a(((*last)(_2861)));
    }
  }
  _2860->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("],"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _2860->toString();
}
void mosek::fusion::p_ExprSlice::destroy(){last.reset();first.reset();expr.reset();}void mosek::fusion::ExprSlice::destroy() { mosek::fusion::p_ExprSlice::_get_impl(this)->destroy(); }mosek::fusion::ExprPermuteDims::ExprPermuteDims(mosek::fusion::p_ExprPermuteDims *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprPermuteDims()" << this << std::endl; */ }mosek::fusion::ExprPermuteDims::~ExprPermuteDims() {  /* std::cout << "~ExprPermuteDims()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprPermuteDims::p_ExprPermuteDims  (::mosek::fusion::ExprPermuteDims * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprPermuteDims::t mosek::fusion::p_ExprPermuteDims::_new_ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2862,    monty::rc_ptr< ::mosek::fusion::Expression > _2863){ return new mosek::fusion::ExprPermuteDims(_2862,_2863); }mosek::fusion::ExprPermuteDims::ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2862,    monty::rc_ptr< ::mosek::fusion::Expression > _2863) :    ExprPermuteDims(new mosek::fusion::p_ExprPermuteDims(this)){ mosek::fusion::p_ExprPermuteDims::_get_impl(this)->_initialize(_2862,_2863); }void mosek::fusion::p_ExprPermuteDims::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2862,    monty::rc_ptr< ::mosek::fusion::Expression > _2863){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2862(_2862 ? _2862->raw() : nullptr, _2862 ? _2862->size(0) : 0);
    mosek::fusion::p_ExprPermuteDims::_initialize(_2862,_2863,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _2864 = _2863->getShape();
    _checked_ptr_1<int> _ptr__2864(_2864 ? _2864->raw() : nullptr,_2864 ? _2864->size(0) : 0);
    if (((int)((_2862)->size(0)) != (int)((_2864)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid dimension permutation"));
      }
    }
    {}
    std::vector<int> _8176;
    for (int _2866 = (int)0, _8177 = (int)((_2862)->size(0)); _2866 < _8177 ; ++_2866)
    {
      _8176.push_back((int)0);
    }
    auto _8178 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8176.size()),_8176.begin(),_8176.end()));
    std::shared_ptr< monty::ndarray< int,1 > > _2865 = _8178;
    _checked_ptr_1<int> _ptr__2865(_2865 ? _2865->raw() : nullptr,_2865 ? _2865->size(0) : 0);
    int _8179 = (int)0;
    int _8180 = (int)((_2865)->size(0));
    for (int _2867 = _8179; _2867 < _8180; ++_2867)
    {
      {
        if (((_ptr__2862[_2867] < (int)0) || (_ptr__2862[_2867] > (int)((_2864)->size(0)))))
        {
          {
            throw ::mosek::fusion::LengthError(std::string ("Invalid dimension permutation"));
          }
        }
        {}
        ++ _ptr__2865[_ptr__2862[_2867]];
      }
    }
    int _8181 = (int)0;
    int _8182 = (int)((_2865)->size(0));
    for (int _2868 = _8181; _2868 < _8182; ++_2868)
    {
      {
        if (((_ptr__2865[_2868] < (int)1) || (_ptr__2865[_2868] > (int)1)))
        {
          {
            throw ::mosek::fusion::LengthError(std::string ("Invalid dimension permutation"));
          }
        }
        {}
      }
    }
  }
}mosek::fusion::ExprPermuteDims::t mosek::fusion::p_ExprPermuteDims::_new_ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2869,    monty::rc_ptr< ::mosek::fusion::Expression > _2870,    int _2871){ return new mosek::fusion::ExprPermuteDims(_2869,_2870,_2871); }mosek::fusion::ExprPermuteDims::ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2869,    monty::rc_ptr< ::mosek::fusion::Expression > _2870,    int _2871) :    ExprPermuteDims(new mosek::fusion::p_ExprPermuteDims(this)){ mosek::fusion::p_ExprPermuteDims::_get_impl(this)->_initialize(_2869,_2870,_2871); }void mosek::fusion::p_ExprPermuteDims::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2869,    monty::rc_ptr< ::mosek::fusion::Expression > _2870,    int _2871){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2869(_2869 ? _2869->raw() : nullptr, _2869 ? _2869->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprPermuteDims::computeshape(_2869,_2870->getShape()));
    mosek::fusion::p_ExprPermuteDims::_get_impl(::mosek::fusion::ExprPermuteDims::t(_pubthis))->expr = _2870;
    dperm = ::mosek::fusion::Utils::Tools::arraycopy(_2869);
  }
}void mosek::fusion::ExprPermuteDims :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2872,monty::rc_ptr< ::mosek::fusion::WorkStack > _2873,monty::rc_ptr< ::mosek::fusion::WorkStack > _2874) { mosek::fusion::p_ExprPermuteDims::_get_impl(this)->eval(_2872,_2873,_2874); }void mosek::fusion::p_ExprPermuteDims::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2872,monty::rc_ptr< ::mosek::fusion::WorkStack > _2873,monty::rc_ptr< ::mosek::fusion::WorkStack > _2874){
  expr->eval(_2873,_2872,_2874);
  int _2875 = _2873->popi32();
  int _2876 = _2873->popi32(_2875);
  std::shared_ptr< monty::ndarray< long long,1 > > _2877 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2875)));
  _checked_ptr_1<long long> _ptr__2877(_2877 ? _2877->raw() : nullptr,_2877 ? _2877->size(0) : 0);
  _ptr__2877[(_2875 - (int)1)] = (int)1;
  int _8183 = (int)1;
  int _8184 = _2875;
  for (int _2878 = _8183; _2878 < _8184; ++_2878)
  {
    {
      _ptr__2877[((_2875 - _2878) - (int)1)] = safe_mul( _ptr__2877[(_2875 - _2878)],((*mosek::fusion::p_WorkStack::_get_impl(_2873)->i32)((safe_add( _2876,_2875 ) - _2878))) );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2879 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2875)));
  _checked_ptr_1<int> _ptr__2879(_2879 ? _2879->raw() : nullptr,_2879 ? _2879->size(0) : 0);
  _ptr__2879[(_2875 - (int)1)] = (int)1;
  int _8185 = (int)1;
  int _8186 = _2875;
  for (int _2880 = _8185; _2880 < _8186; ++_2880)
  {
    {
      _ptr__2879[((_2875 - _2880) - (int)1)] = safe_mul( _ptr__2879[(_2875 - _2880)],((*mosek::fusion::p_WorkStack::_get_impl(_2873)->i32)(safe_add( _2876,((*dperm)((_2875 - _2880))) ))) );
    }
  }
  int _2881 = _2873->popi32();
  int _2882 = _2873->popi32();
  bool _2883 = (_2873->popi32() != (int)0);
  int _2884 = _2873->popi32(safe_add( _2881,(int)1 ));
  int _8187;
  bool _8188 = (!_2883);
  if (_8188)
  {
    _8187 = (-(int)1);
  }
  else
  {
    _8187 = _2873->popi64(_2881);
  }
  int _2885 = _8187;
  int _2886 = _2873->popi64(_2882);
  int _2887 = _2873->popf64(_2881);
  int _2888 = _2873->popf64(_2882);
  std::shared_ptr< monty::ndarray< int,1 > > _2889 = mosek::fusion::p_WorkStack::_get_impl(_2873)->i32;
  _checked_ptr_1<int> _ptr__2889(_2889 ? _2889->raw() : nullptr,_2889 ? _2889->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2890 = mosek::fusion::p_WorkStack::_get_impl(_2873)->i64;
  _checked_ptr_1<long long> _ptr__2890(_2890 ? _2890->raw() : nullptr,_2890 ? _2890->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2891 = mosek::fusion::p_WorkStack::_get_impl(_2873)->f64;
  _checked_ptr_1<double> _ptr__2891(_2891 ? _2891->raw() : nullptr,_2891 ? _2891->size(0) : 0);
  if (_2883)
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2892 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2881)));
      _checked_ptr_1<long long> _ptr__2892(_2892 ? _2892->raw() : nullptr,_2892 ? _2892->size(0) : 0);
      {
        int _8189 = (int)0;
        int _8190 = _2881;
        for (int _2893 = _8189; _2893 < _8190; ++_2893)
        {
          {
            long long _2894 = (long long)0;
            int _8191 = (int)0;
            int _8192 = _2875;
            for (int _2895 = _8191; _2895 < _8192; ++_2895)
            {
              {
                _2894 += safe_mul( ((_ptr__2890[safe_add( _2885,_2893 )] / _ptr__2877[_2895]) % _ptr__2889[safe_add( _2876,_2895 )]),_ptr__2879[((*dperm)(_2895))] );
              }
            }
            _ptr__2892[_2893] = _2894;
          }
        }
      }
      std::vector<long long> _8193;
      for (int _2897 = (int)0, _8194 = _2881; _2897 < _8194 ; ++_2897)
      {
        _8193.push_back(_2897);
      }
      auto _8195 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_8193.size()),_8193.begin(),_8193.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _2896 = _8195;
      _checked_ptr_1<long long> _ptr__2896(_2896 ? _2896->raw() : nullptr,_2896 ? _2896->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_2896,_2892,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_2881));
      int _2898 = _2872->alloci32(safe_add( _2881,(int)1 ));
      int _2899 = _2872->alloci64(_2882);
      int _2900 = _2872->alloci64(_2881);
      int _2901 = _2872->allocf64(_2882);
      int _2902 = _2872->allocf64(_2881);
      _2872->pushi32((int)1);
      _2872->pushi32(_2882);
      _2872->pushi32(_2881);
      int _8196 = (int)0;
      int _8197 = _2875;
      for (int _2903 = _8196; _2903 < _8197; ++_2903)
      {
        {
          _2872->pushi32(_ptr__2889[safe_add( _2876,((*dperm)(_2903)) )]);
        }
      }
      _2872->pushi32(_2875);
      std::shared_ptr< monty::ndarray< int,1 > > _2904 = mosek::fusion::p_WorkStack::_get_impl(_2872)->i32;
      _checked_ptr_1<int> _ptr__2904(_2904 ? _2904->raw() : nullptr,_2904 ? _2904->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2905 = mosek::fusion::p_WorkStack::_get_impl(_2872)->i64;
      _checked_ptr_1<long long> _ptr__2905(_2905 ? _2905->raw() : nullptr,_2905 ? _2905->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2906 = mosek::fusion::p_WorkStack::_get_impl(_2872)->f64;
      _checked_ptr_1<double> _ptr__2906(_2906 ? _2906->raw() : nullptr,_2906 ? _2906->size(0) : 0);
      _ptr__2904[_2898] = (int)0;
      int _2907 = (int)0;
      int _2908 = (int)0;
      int _8198 = (int)0;
      int _8199 = _2881;
      for (int _2909 = _8198; _2909 < _8199; ++_2909)
      {
        {
          long long _2910 = _ptr__2896[_2909];
          int _8200 = _ptr__2889[safe_add( _2884,_2910 )];
          int _8201 = _ptr__2889[safe_add( safe_add( _2884,_2910 ),(int)1 )];
          for (int _2911 = _8200; _2911 < _8201; ++_2911)
          {
            {
              _ptr__2905[safe_add( _2899,_2908 )] = _ptr__2890[safe_add( _2886,_2911 )];
              _ptr__2906[safe_add( _2901,_2908 )] = _ptr__2891[safe_add( _2888,_2911 )];
              ++ _2908;
            }
          }
          _ptr__2905[safe_add( _2900,_2909 )] = _ptr__2892[_2910];
          _ptr__2906[safe_add( _2902,_2909 )] = _ptr__2891[safe_add( _2887,_2910 )];
          ++ _2907;
          _ptr__2904[safe_add( safe_add( _2898,_2909 ),(int)1 )] = _2908;
        }
      }
    }
  }
  else
  {
    {
      int _2912 = _2872->alloci32(safe_add( _2881,(int)1 ));
      int _2913 = _2872->alloci64(_2882);
      int _2914 = _2872->allocf64(_2882);
      int _2915 = _2872->allocf64(_2881);
      _2872->pushi32((int)0);
      _2872->pushi32(_2882);
      _2872->pushi32(_2881);
      int _8202 = (int)0;
      int _8203 = _2875;
      for (int _2916 = _8202; _2916 < _8203; ++_2916)
      {
        {
          _2872->pushi32(_ptr__2889[safe_add( _2876,((*dperm)(_2916)) )]);
        }
      }
      _2872->pushi32(_2875);
      std::shared_ptr< monty::ndarray< int,1 > > _2917 = mosek::fusion::p_WorkStack::_get_impl(_2872)->i32;
      _checked_ptr_1<int> _ptr__2917(_2917 ? _2917->raw() : nullptr,_2917 ? _2917->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2918 = mosek::fusion::p_WorkStack::_get_impl(_2872)->i64;
      _checked_ptr_1<long long> _ptr__2918(_2918 ? _2918->raw() : nullptr,_2918 ? _2918->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2919 = mosek::fusion::p_WorkStack::_get_impl(_2872)->f64;
      _checked_ptr_1<double> _ptr__2919(_2919 ? _2919->raw() : nullptr,_2919 ? _2919->size(0) : 0);
      _ptr__2917[_2912] = (int)0;
      int _2920 = (int)0;
      int _2921 = (int)0;
      int _8204 = (int)0;
      int _8205 = _2881;
      for (int _2922 = _8204; _2922 < _8205; ++_2922)
      {
        {
          long long _2923 = (long long)0;
          int _8206 = (int)0;
          int _8207 = _2875;
          for (int _2924 = _8206; _2924 < _8207; ++_2924)
          {
            {
              _2923 += safe_mul( ((_2922 / _ptr__2877[((*dperm)(_2924))]) % _ptr__2889[safe_add( _2876,((*dperm)(_2924)) )]),_ptr__2879[_2924] );
            }
          }
          int _8208 = _ptr__2889[safe_add( _2884,_2923 )];
          int _8209 = _ptr__2889[safe_add( safe_add( _2884,_2923 ),(int)1 )];
          for (int _2925 = _8208; _2925 < _8209; ++_2925)
          {
            {
              _ptr__2918[safe_add( _2913,_2921 )] = _ptr__2890[safe_add( _2886,_2925 )];
              _ptr__2919[safe_add( _2914,_2921 )] = _ptr__2891[safe_add( _2888,_2925 )];
              ++ _2921;
            }
          }
          _ptr__2919[safe_add( _2915,_2920 )] = _ptr__2891[safe_add( _2887,_2923 )];
          ++ _2920;
          _ptr__2917[safe_add( _2912,_2920 )] = _2921;
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprPermuteDims::computeshape(std::shared_ptr< monty::ndarray< int,1 > > _2926,std::shared_ptr< monty::ndarray< int,1 > > _2927){
  _checked_ptr_1<int> _ptr__2926(_2926 ? _2926->raw() : nullptr, _2926 ? _2926->size(0) : 0);
  _checked_ptr_1<int> _ptr__2927(_2927 ? _2927->raw() : nullptr, _2927 ? _2927->size(0) : 0);
  std::vector<int> _8210;
  for (int _2928 = (int)0, _8211 = (int)((_2926)->size(0)); _2928 < _8211 ; ++_2928)
  {
    _8210.push_back(_ptr__2927[_ptr__2926[_2928]]);
  }
  auto _8212 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8210.size()),_8210.begin(),_8210.end()));
  return _8212;
}
void mosek::fusion::p_ExprPermuteDims::destroy(){dperm.reset();expr.reset();}void mosek::fusion::ExprPermuteDims::destroy() { mosek::fusion::p_ExprPermuteDims::_get_impl(this)->destroy(); }mosek::fusion::ExprTranspose::ExprTranspose(mosek::fusion::p_ExprTranspose *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprTranspose()" << this << std::endl; */ }mosek::fusion::ExprTranspose::~ExprTranspose() {  /* std::cout << "~ExprTranspose()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprTranspose::p_ExprTranspose  (::mosek::fusion::ExprTranspose * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprTranspose::t mosek::fusion::p_ExprTranspose::_new_ExprTranspose  (monty::rc_ptr< ::mosek::fusion::Expression > _2929){ return new mosek::fusion::ExprTranspose(_2929); }mosek::fusion::ExprTranspose::ExprTranspose  (monty::rc_ptr< ::mosek::fusion::Expression > _2929) :    ExprTranspose(new mosek::fusion::p_ExprTranspose(this)){ mosek::fusion::p_ExprTranspose::_get_impl(this)->_initialize(_2929); }void mosek::fusion::p_ExprTranspose::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2929){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprTranspose::transposeShape(_2929->getShape()));
    mosek::fusion::p_ExprTranspose::_get_impl(::mosek::fusion::ExprTranspose::t(_pubthis))->expr = _2929;
  }
}void mosek::fusion::ExprTranspose :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2930,monty::rc_ptr< ::mosek::fusion::WorkStack > _2931,monty::rc_ptr< ::mosek::fusion::WorkStack > _2932) { mosek::fusion::p_ExprTranspose::_get_impl(this)->eval(_2930,_2931,_2932); }void mosek::fusion::p_ExprTranspose::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2930,monty::rc_ptr< ::mosek::fusion::WorkStack > _2931,monty::rc_ptr< ::mosek::fusion::WorkStack > _2932){
  expr->eval(_2931,_2930,_2932);
  _2931->pop_expr();
  if ((mosek::fusion::p_WorkStack::_get_impl(_2931)->nd != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  else
  {
    {
      int _2933 = mosek::fusion::p_WorkStack::_get_impl(_2931)->shape_base;
      int _2934 = mosek::fusion::p_WorkStack::_get_impl(_2931)->nelem;
      int _2935 = mosek::fusion::p_WorkStack::_get_impl(_2931)->nnz;
      bool _2936 = mosek::fusion::p_WorkStack::_get_impl(_2931)->hassp;
      int _2937 = mosek::fusion::p_WorkStack::_get_impl(_2931)->ptr_base;
      int _2938 = mosek::fusion::p_WorkStack::_get_impl(_2931)->sp_base;
      int _2939 = mosek::fusion::p_WorkStack::_get_impl(_2931)->nidxs_base;
      int _2940 = mosek::fusion::p_WorkStack::_get_impl(_2931)->bfix_base;
      int _2941 = mosek::fusion::p_WorkStack::_get_impl(_2931)->cof_base;
      int _2942 = ((*mosek::fusion::p_WorkStack::_get_impl(_2931)->i32)(_2933));
      int _2943 = ((*mosek::fusion::p_WorkStack::_get_impl(_2931)->i32)(safe_add( _2933,(int)1 )));
      std::shared_ptr< monty::ndarray< int,1 > > _2944 = mosek::fusion::p_WorkStack::_get_impl(_2931)->i32;
      _checked_ptr_1<int> _ptr__2944(_2944 ? _2944->raw() : nullptr,_2944 ? _2944->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2945 = mosek::fusion::p_WorkStack::_get_impl(_2931)->i64;
      _checked_ptr_1<long long> _ptr__2945(_2945 ? _2945->raw() : nullptr,_2945 ? _2945->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2946 = mosek::fusion::p_WorkStack::_get_impl(_2931)->f64;
      _checked_ptr_1<double> _ptr__2946(_2946 ? _2946->raw() : nullptr,_2946 ? _2946->size(0) : 0);
      _2930->alloc_expr((int)2,_2934,_2935,_2936);
      int _2947 = mosek::fusion::p_WorkStack::_get_impl(_2930)->ptr_base;
      int _2948 = mosek::fusion::p_WorkStack::_get_impl(_2930)->nidxs_base;
      int _2949 = mosek::fusion::p_WorkStack::_get_impl(_2930)->sp_base;
      int _2950 = mosek::fusion::p_WorkStack::_get_impl(_2930)->cof_base;
      int _2951 = mosek::fusion::p_WorkStack::_get_impl(_2930)->bfix_base;
      int _2952 = mosek::fusion::p_WorkStack::_get_impl(_2930)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _2953 = mosek::fusion::p_WorkStack::_get_impl(_2930)->i32;
      _checked_ptr_1<int> _ptr__2953(_2953 ? _2953->raw() : nullptr,_2953 ? _2953->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2954 = mosek::fusion::p_WorkStack::_get_impl(_2930)->i64;
      _checked_ptr_1<long long> _ptr__2954(_2954 ? _2954->raw() : nullptr,_2954 ? _2954->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2955 = mosek::fusion::p_WorkStack::_get_impl(_2930)->f64;
      _checked_ptr_1<double> _ptr__2955(_2955 ? _2955->raw() : nullptr,_2955 ? _2955->size(0) : 0);
      _ptr__2953[_2952] = _2943;
      _ptr__2953[safe_add( _2952,(int)1 )] = _2942;
      if (_2936)
      {
        {
          int _2956 = _2932->alloci32(_2934);
          int _2957 = _2932->alloci32(safe_add( _2943,(int)1 ));
          std::shared_ptr< monty::ndarray< int,1 > > _2958 = mosek::fusion::p_WorkStack::_get_impl(_2932)->i32;
          _checked_ptr_1<int> _ptr__2958(_2958 ? _2958->raw() : nullptr,_2958 ? _2958->size(0) : 0);
          {
            int _8213 = (int)0;
            int _8214 = safe_add( _2943,(int)1 );
            for (int _2959 = _8213; _2959 < _8214; ++_2959)
            {
              {
                _ptr__2958[safe_add( _2957,_2959 )] = (int)0;
              }
            }
            int _8215 = (int)0;
            int _8216 = _2934;
            for (int _2960 = _8215; _2960 < _8216; ++_2960)
            {
              {
                ++ _ptr__2958[safe_add( safe_add( _2957,(_ptr__2945[safe_add( _2938,_2960 )] % _2943) ),(int)1 )];
              }
            }
            int _8217 = (int)0;
            int _8218 = _2943;
            for (int _2961 = _8217; _2961 < _8218; ++_2961)
            {
              {
                _ptr__2958[safe_add( safe_add( _2957,_2961 ),(int)1 )] += _ptr__2958[safe_add( _2957,_2961 )];
              }
            }
            int _8219 = (int)0;
            int _8220 = _2934;
            for (int _2962 = _8219; _2962 < _8220; ++_2962)
            {
              {
                long long _2963 = (_ptr__2945[safe_add( _2938,_2962 )] % _2943);
                _ptr__2958[safe_add( _2956,_ptr__2958[safe_add( _2957,_2963 )] )] = _2962;
                ++ _ptr__2958[safe_add( _2957,_2963 )];
              }
            }
            _ptr__2953[_2947] = (int)0;
            int _2964 = (int)0;
            int _8221 = (int)0;
            int _8222 = _2934;
            for (int _2965 = _8221; _2965 < _8222; ++_2965)
            {
              {
                int _2966 = _ptr__2958[safe_add( _2956,_2965 )];
                int _8223 = _ptr__2944[safe_add( _2937,_2966 )];
                int _8224 = _ptr__2944[safe_add( safe_add( _2937,_2966 ),(int)1 )];
                for (int _2967 = _8223; _2967 < _8224; ++_2967)
                {
                  {
                    _ptr__2954[safe_add( _2948,_2964 )] = _ptr__2945[safe_add( _2939,_2967 )];
                    _ptr__2955[safe_add( _2950,_2964 )] = _ptr__2946[safe_add( _2941,_2967 )];
                    ++ _2964;
                  }
                }
                long long _2968 = (_ptr__2945[safe_add( _2938,_2966 )] / _2943);
                long long _2969 = (_ptr__2945[safe_add( _2938,_2966 )] % _2943);
                _ptr__2953[safe_add( safe_add( _2947,_2965 ),(int)1 )] = _2964;
                _ptr__2954[safe_add( _2949,_2965 )] = safe_add( safe_mul( _2969,_2942 ),_2968 );
                _ptr__2955[safe_add( _2951,_2965 )] = _ptr__2946[safe_add( _2940,_2966 )];
              }
            }
          }
        }
      }
      else
      {
        {
          _ptr__2953[_2947] = (int)0;
          int _2970 = (int)0;
          int _2971 = (int)0;
          int _8225 = (int)0;
          int _8226 = _2943;
          for (int _2972 = _8225; _2972 < _8226; ++_2972)
          {
            {
              int _8227 = (int)0;
              int _8228 = _2942;
              for (int _2973 = _8227; _2973 < _8228; ++_2973)
              {
                {
                  int _2974 = safe_add( safe_mul( _2973,_2943 ),_2972 );
                  int _8229 = _ptr__2944[safe_add( _2937,_2974 )];
                  int _8230 = _ptr__2944[safe_add( safe_add( _2937,_2974 ),(int)1 )];
                  for (int _2975 = _8229; _2975 < _8230; ++_2975)
                  {
                    {
                      _ptr__2954[safe_add( _2948,_2970 )] = _ptr__2945[safe_add( _2939,_2975 )];
                      _ptr__2955[safe_add( _2950,_2970 )] = _ptr__2946[safe_add( _2941,_2975 )];
                      ++ _2970;
                    }
                  }
                  _ptr__2955[safe_add( _2951,_2971 )] = _ptr__2946[safe_add( _2940,_2974 )];
                  _ptr__2953[safe_add( safe_add( _2947,_2971 ),(int)1 )] = _2970;
                  ++ _2971;
                }
              }
            }
          }
        }
      }
      _2932->clear();
    }
  }
}
std::string mosek::fusion::ExprTranspose :: toString() { return mosek::fusion::p_ExprTranspose::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprTranspose::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprTranspose("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprTranspose::transposeShape(std::shared_ptr< monty::ndarray< int,1 > > _2976){
  _checked_ptr_1<int> _ptr__2976(_2976 ? _2976->raw() : nullptr, _2976 ? _2976->size(0) : 0);
  if (((int)((_2976)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  else
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__2976[(int)1]),(int)(_ptr__2976[(int)0])});
    }
  }
}
void mosek::fusion::p_ExprTranspose::destroy(){expr.reset();}void mosek::fusion::ExprTranspose::destroy() { mosek::fusion::p_ExprTranspose::_get_impl(this)->destroy(); }mosek::fusion::ExprStack::ExprStack(mosek::fusion::p_ExprStack *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprStack()" << this << std::endl; */ }mosek::fusion::ExprStack::~ExprStack() {  /* std::cout << "~ExprStack()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprStack::p_ExprStack  (::mosek::fusion::ExprStack * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprStack::t mosek::fusion::p_ExprStack::_new_ExprStack  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2977,    int _2978){ return new mosek::fusion::ExprStack(_2977,_2978); }mosek::fusion::ExprStack::ExprStack  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2977,    int _2978) :    ExprStack(new mosek::fusion::p_ExprStack(this)){ mosek::fusion::p_ExprStack::_get_impl(this)->_initialize(_2977,_2978); }void mosek::fusion::p_ExprStack::_initialize  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2977,    int _2978){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprStack::getshape(_2977,_2978));
    std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _8231;
    for (int _2979 = (int)0, _8232 = (int)((_2977)->size(0)); _2979 < _8232 ; ++_2979)
    {
      _8231.push_back(((*_2977)(_2979)));
    }
    auto _8233 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_8231.size()),_8231.begin(),_8231.end()));
    mosek::fusion::p_ExprStack::_get_impl(::mosek::fusion::ExprStack::t(_pubthis))->exprs = _8233;
    mosek::fusion::p_ExprStack::_get_impl(::mosek::fusion::ExprStack::t(_pubthis))->dim = _2978;
  }
}void mosek::fusion::ExprStack :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2980,monty::rc_ptr< ::mosek::fusion::WorkStack > _2981,monty::rc_ptr< ::mosek::fusion::WorkStack > _2982) { mosek::fusion::p_ExprStack::_get_impl(this)->eval(_2980,_2981,_2982); }void mosek::fusion::p_ExprStack::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2980,monty::rc_ptr< ::mosek::fusion::WorkStack > _2981,monty::rc_ptr< ::mosek::fusion::WorkStack > _2982){
  int _2983 = (int)((exprs)->size(0));
  if ((_2983 == (int)1))
  {
    {
      ((*exprs)((int)0))->eval(_2980,_2981,_2982);
    }
  }
  else
  {
    {
      int _8234 = (int)0;
      int _8235 = _2983;
      for (int _2984 = _8234; _2984 < _8235; ++_2984)
      {
        {
          ((*exprs)(((_2983 - _2984) - (int)1)))->eval(_2981,_2980,_2982);
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2985 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2983)));
      _checked_ptr_1<int> _ptr__2985(_2985 ? _2985->raw() : nullptr,_2985 ? _2985->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2986 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2983)));
      _checked_ptr_1<int> _ptr__2986(_2986 ? _2986->raw() : nullptr,_2986 ? _2986->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2987 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2983)));
      _checked_ptr_1<int> _ptr__2987(_2987 ? _2987->raw() : nullptr,_2987 ? _2987->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2988 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2983)));
      _checked_ptr_1<int> _ptr__2988(_2988 ? _2988->raw() : nullptr,_2988 ? _2988->size(0) : 0);
      std::shared_ptr< monty::ndarray< bool,1 > > _2989 = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape(_2983)));
      std::shared_ptr< monty::ndarray< int,1 > > _2990 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2983)));
      _checked_ptr_1<int> _ptr__2990(_2990 ? _2990->raw() : nullptr,_2990 ? _2990->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2991 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2983)));
      _checked_ptr_1<int> _ptr__2991(_2991 ? _2991->raw() : nullptr,_2991 ? _2991->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2992 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2983)));
      _checked_ptr_1<int> _ptr__2992(_2992 ? _2992->raw() : nullptr,_2992 ? _2992->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2993 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2983)));
      _checked_ptr_1<int> _ptr__2993(_2993 ? _2993->raw() : nullptr,_2993 ? _2993->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2994 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2983)));
      _checked_ptr_1<int> _ptr__2994(_2994 ? _2994->raw() : nullptr,_2994 ? _2994->size(0) : 0);
      int _8236 = (int)0;
      int _8237 = _2983;
      for (int _2995 = _8236; _2995 < _8237; ++_2995)
      {
        {
          _2981->pop_expr();
          _ptr__2985[_2995] = mosek::fusion::p_WorkStack::_get_impl(_2981)->nd;
          _ptr__2986[_2995] = mosek::fusion::p_WorkStack::_get_impl(_2981)->shape_base;
          _ptr__2987[_2995] = mosek::fusion::p_WorkStack::_get_impl(_2981)->nelem;
          _ptr__2988[_2995] = mosek::fusion::p_WorkStack::_get_impl(_2981)->nnz;
          ((*_2989)(_2995)) = mosek::fusion::p_WorkStack::_get_impl(_2981)->hassp;
          _ptr__2990[_2995] = mosek::fusion::p_WorkStack::_get_impl(_2981)->ptr_base;
          _ptr__2992[_2995] = mosek::fusion::p_WorkStack::_get_impl(_2981)->sp_base;
          _ptr__2991[_2995] = mosek::fusion::p_WorkStack::_get_impl(_2981)->nidxs_base;
          _ptr__2994[_2995] = mosek::fusion::p_WorkStack::_get_impl(_2981)->bfix_base;
          _ptr__2993[_2995] = mosek::fusion::p_WorkStack::_get_impl(_2981)->cof_base;
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2996 = mosek::fusion::p_WorkStack::_get_impl(_2981)->i32;
      _checked_ptr_1<int> _ptr__2996(_2996 ? _2996->raw() : nullptr,_2996 ? _2996->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2997 = mosek::fusion::p_WorkStack::_get_impl(_2981)->i64;
      _checked_ptr_1<long long> _ptr__2997(_2997 ? _2997->raw() : nullptr,_2997 ? _2997->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2998 = mosek::fusion::p_WorkStack::_get_impl(_2981)->f64;
      _checked_ptr_1<double> _ptr__2998(_2998 ? _2998->raw() : nullptr,_2998 ? _2998->size(0) : 0);
      int _2999 = _ptr__2985[(int)0];
      int _3000 = _ptr__2986[(int)0];
      bool _3001 = (!((*_2989)((int)0)));
      bool _3002 = false;
      int _8238 = (int)1;
      int _8239 = _2983;
      for (int _3003 = _8238; _3003 < _8239; ++_3003)
      {
        {
          {
            _3002 = (_3002 || ((dim != _3003) && (_ptr__2985[_3003] != _2999)));
            if ((!_3002))
            {
              {
                int _8240 = (int)0;
                int _8241 = dim;
                for (int _3004 = _8240; _3004 < _8241; ++_3004)
                {
                  {
                    _3002 = (_3002 || (_ptr__2996[safe_add( _3000,_3004 )] != _ptr__2996[safe_add( _ptr__2986[_3003],_3004 )]));
                  }
                }
              }
            }
            {}
            if ((!_3002))
            {
              {
                int _8242 = safe_add( dim,(int)1 );
                int _8243 = _2999;
                for (int _3005 = _8242; _3005 < _8243; ++_3005)
                {
                  {
                    _3002 = (_3002 || (_ptr__2996[safe_add( _3000,_3005 )] != _ptr__2996[safe_add( _ptr__2986[_3003],_3005 )]));
                  }
                }
              }
            }
            {}
          }
          _3001 = (_3001 && (!((*_2989)(_3003))));
        }
      }
      if (_3002)
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression dimensions"));
        }
      }
      {}
      int _3006 = (int)0;
      if ((dim < _2999))
      {
        {
          int _8244 = (int)0;
          int _8245 = _2983;
          for (int _3007 = _8244; _3007 < _8245; ++_3007)
          {
            {
              _3006 += _ptr__2996[safe_add( _ptr__2986[_3007],dim )];
            }
          }
        }
      }
      else
      {
        {
          _3006 = _2983;
        }
      }
      int _8246;
      bool _8247 = (dim < _2999);
      if (_8247)
      {
        _8246 = _2999;
      }
      else
      {
        _8246 = safe_add( _2999,(int)1 );
      }
      int _3008 = _8246;
      if ((_3008 != _pubthis->getND()))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Oops!!"));
        }
      }
      {}
      int _3009 = (int)0;
      int _3010 = (int)0;
      {
        int _8248 = (int)0;
        int _8249 = _2983;
        for (int _3011 = _8248; _3011 < _8249; ++_3011)
        {
          {
            _3010 += _ptr__2988[_3011];
          }
        }
        int _8250 = (int)0;
        int _8251 = _2983;
        for (int _3012 = _8250; _3012 < _8251; ++_3012)
        {
          {
            _3009 += _ptr__2987[_3012];
          }
        }
      }
      int _3013 = (int)1;
      int _8252 = (int)0;
      int _8253 = dim;
      for (int _3014 = _8252; _3014 < _8253; ++_3014)
      {
        {
          _3013 *= _ptr__2996[safe_add( _3000,_3014 )];
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _8254;
      bool _8255 = (dim < _2999);
      if (_8255)
      {
        std::vector<int> _8256;
        for (int _3016 = (int)0, _8257 = _2983; _3016 < _8257 ; ++_3016)
        {
          _8256.push_back(_ptr__2996[safe_add( _ptr__2986[_3016],dim )]);
        }
        auto _8258 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8256.size()),_8256.begin(),_8256.end()));
        _8254 = _8258;
      }
      else
      {
        std::vector<int> _8259;
        for (int _3017 = (int)0, _8260 = _2983; _3017 < _8260 ; ++_3017)
        {
          _8259.push_back((int)1);
        }
        auto _8261 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8259.size()),_8259.begin(),_8259.end()));
        _8254 = _8261;
      }
      std::shared_ptr< monty::ndarray< int,1 > > _3015 = _8254;
      _checked_ptr_1<int> _ptr__3015(_3015 ? _3015->raw() : nullptr,_3015 ? _3015->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _3018 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2983)));
      _checked_ptr_1<int> _ptr__3018(_3018 ? _3018->raw() : nullptr,_3018 ? _3018->size(0) : 0);
      _ptr__3018[(int)0] = (int)0;
      int _8262 = (int)1;
      int _8263 = _2983;
      for (int _3019 = _8262; _3019 < _8263; ++_3019)
      {
        {
          _ptr__3018[_3019] = safe_add( _ptr__3018[(_3019 - (int)1)],_ptr__3015[(_3019 - (int)1)] );
        }
      }
      int _3020 = (int)0;
      int _8264 = (int)0;
      int _8265 = _2983;
      for (int _3021 = _8264; _3021 < _8265; ++_3021)
      {
        {
          _3020 += _ptr__3015[_3021];
        }
      }
      int _3022 = (int)1;
      int _8266 = safe_add( dim,(int)1 );
      int _8267 = _2999;
      for (int _3023 = _8266; _3023 < _8267; ++_3023)
      {
        {
          _3022 *= _ptr__2996[safe_add( _3000,_3023 )];
        }
      }
      if (_3001)
      {
        {
          _2980->alloc_expr(_3008,_3009,_3010,false);
          int _3024 = mosek::fusion::p_WorkStack::_get_impl(_2980)->ptr_base;
          int _3025 = mosek::fusion::p_WorkStack::_get_impl(_2980)->shape_base;
          int _3026 = mosek::fusion::p_WorkStack::_get_impl(_2980)->nidxs_base;
          int _3027 = mosek::fusion::p_WorkStack::_get_impl(_2980)->cof_base;
          int _3028 = mosek::fusion::p_WorkStack::_get_impl(_2980)->bfix_base;
          std::shared_ptr< monty::ndarray< int,1 > > _3029 = mosek::fusion::p_WorkStack::_get_impl(_2980)->i32;
          _checked_ptr_1<int> _ptr__3029(_3029 ? _3029->raw() : nullptr,_3029 ? _3029->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3030 = mosek::fusion::p_WorkStack::_get_impl(_2980)->i64;
          _checked_ptr_1<long long> _ptr__3030(_3030 ? _3030->raw() : nullptr,_3030 ? _3030->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3031 = mosek::fusion::p_WorkStack::_get_impl(_2980)->f64;
          _checked_ptr_1<double> _ptr__3031(_3031 ? _3031->raw() : nullptr,_3031 ? _3031->size(0) : 0);
          int _8268 = (int)0;
          int _8269 = _2999;
          for (int _3032 = _8268; _3032 < _8269; ++_3032)
          {
            {
              _ptr__3029[safe_add( _3025,_3032 )] = _ptr__2996[safe_add( _3000,_3032 )];
            }
          }
          _ptr__3029[safe_add( _3025,dim )] = _3006;
          {
            _ptr__3029[_3024] = (int)0;
            {
              int _3033 = (int)0;
              int _8270 = (int)0;
              int _8271 = _2983;
              for (int _3034 = _8270; _3034 < _8271; ++_3034)
              {
                {
                  int _3035 = _ptr__2990[_3034];
                  int _3036 = (int)0;
                  int _8272 = (int)0;
                  int _8273 = _3013;
                  for (int _3037 = _8272; _3037 < _8273; ++_3037)
                  {
                    {
                      int _8274 = (int)0;
                      int _8275 = _ptr__3015[_3034];
                      for (int _3038 = _8274; _3038 < _8275; ++_3038)
                      {
                        {
                          int _8276 = (int)0;
                          int _8277 = _3022;
                          for (int _3039 = _8276; _3039 < _8277; ++_3039)
                          {
                            {
                              int _3040 = safe_add( safe_add( _3039,safe_mul( safe_add( _3038,_3033 ),_3022 ) ),safe_mul( safe_mul( _3037,_3020 ),_3022 ) );
                              int _3041 = (_ptr__2996[safe_add( safe_add( _3035,_3036 ),(int)1 )] - _ptr__2996[safe_add( _3035,_3036 )]);
                              _ptr__3029[safe_add( safe_add( _3024,_3040 ),(int)1 )] = _3041;
                              _ptr__3031[safe_add( _3028,_3040 )] = _ptr__2998[safe_add( _ptr__2994[_3034],_3036 )];
                              ++ _3036;
                            }
                          }
                        }
                      }
                    }
                  }
                  _3033 += _ptr__3015[_3034];
                }
              }
              int _8278 = (int)0;
              int _8279 = _3009;
              for (int _3042 = _8278; _3042 < _8279; ++_3042)
              {
                {
                  _ptr__3029[safe_add( safe_add( _3024,_3042 ),(int)1 )] += _ptr__3029[safe_add( _3024,_3042 )];
                }
              }
            }
            {
              int _3043 = (int)0;
              int _8280 = (int)0;
              int _8281 = _2983;
              for (int _3044 = _8280; _3044 < _8281; ++_3044)
              {
                {
                  int _3045 = _ptr__2990[_3044];
                  int _3046 = (int)0;
                  int _8282 = (int)0;
                  int _8283 = _3013;
                  for (int _3047 = _8282; _3047 < _8283; ++_3047)
                  {
                    {
                      int _8284 = (int)0;
                      int _8285 = _ptr__3015[_3044];
                      for (int _3048 = _8284; _3048 < _8285; ++_3048)
                      {
                        {
                          int _8286 = (int)0;
                          int _8287 = _3022;
                          for (int _3049 = _8286; _3049 < _8287; ++_3049)
                          {
                            {
                              int _3050 = safe_add( safe_add( _3049,safe_mul( safe_add( _3048,_3043 ),_3022 ) ),safe_mul( safe_mul( _3047,_3020 ),_3022 ) );
                              int _3051 = _ptr__2996[safe_add( _3045,_3046 )];
                              int _3052 = (_ptr__2996[safe_add( safe_add( _3045,_3046 ),(int)1 )] - _3051);
                              int _8288 = (int)0;
                              int _8289 = _3052;
                              for (int _3053 = _8288; _3053 < _8289; ++_3053)
                              {
                                {
                                  _ptr__3030[safe_add( safe_add( _3026,_ptr__3029[safe_add( _3024,_3050 )] ),_3053 )] = _ptr__2997[safe_add( safe_add( _ptr__2991[_3044],_3051 ),_3053 )];
                                }
                              }
                              int _8290 = (int)0;
                              int _8291 = _3052;
                              for (int _3054 = _8290; _3054 < _8291; ++_3054)
                              {
                                {
                                  _ptr__3031[safe_add( safe_add( _3027,_ptr__3029[safe_add( _3024,_3050 )] ),_3054 )] = _ptr__2998[safe_add( safe_add( _ptr__2993[_3044],_3051 ),_3054 )];
                                }
                              }
                              ++ _3046;
                            }
                          }
                        }
                      }
                    }
                  }
                  _3043 += _ptr__3015[_3044];
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _3055 = (int)1;
          int _8292 = (int)0;
          int _8293 = dim;
          for (int _3056 = _8292; _3056 < _8293; ++_3056)
          {
            {
              _3055 *= _ptr__2996[safe_add( _3000,_3056 )];
            }
          }
          _3055 *= _3006;
          int _8294 = safe_add( dim,(int)1 );
          int _8295 = _2999;
          for (int _3057 = _8294; _3057 < _8295; ++_3057)
          {
            {
              _3055 *= _ptr__2996[safe_add( _3000,_3057 )];
            }
          }
          bool _3058 = (_3009 < _3055);
          _2980->alloc_expr(_3008,_3009,_3010,_3058);
          int _3059 = mosek::fusion::p_WorkStack::_get_impl(_2980)->ptr_base;
          int _3060 = mosek::fusion::p_WorkStack::_get_impl(_2980)->nidxs_base;
          int _8296;
          bool _8297 = _3058;
          if (_8297)
          {
            _8296 = mosek::fusion::p_WorkStack::_get_impl(_2980)->sp_base;
          }
          else
          {
            _8296 = _2980->alloci64(_3009);
          }
          int _3061 = _8296;
          int _3062 = mosek::fusion::p_WorkStack::_get_impl(_2980)->cof_base;
          int _3063 = mosek::fusion::p_WorkStack::_get_impl(_2980)->bfix_base;
          int _3064 = mosek::fusion::p_WorkStack::_get_impl(_2980)->shape_base;
          int _8298 = (int)0;
          int _8299 = _2999;
          for (int _3065 = _8298; _3065 < _8299; ++_3065)
          {
            {
              ((*mosek::fusion::p_WorkStack::_get_impl(_2980)->i32)(safe_add( _3064,_3065 ))) = _ptr__2996[safe_add( _3000,_3065 )];
            }
          }
          ((*mosek::fusion::p_WorkStack::_get_impl(_2980)->i32)(safe_add( _3064,dim ))) = _3006;
          int _3066 = _2982->alloci32(safe_add( _3009,(int)1 ));
          int _3067 = _2982->alloci64(_3010);
          int _3068 = _2982->alloci64(_3009);
          int _3069 = _2982->allocf64(_3010);
          int _3070 = _2982->allocf64(_3009);
          std::shared_ptr< monty::ndarray< int,1 > > _3071 = mosek::fusion::p_WorkStack::_get_impl(_2980)->i32;
          _checked_ptr_1<int> _ptr__3071(_3071 ? _3071->raw() : nullptr,_3071 ? _3071->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3072 = mosek::fusion::p_WorkStack::_get_impl(_2980)->i64;
          _checked_ptr_1<long long> _ptr__3072(_3072 ? _3072->raw() : nullptr,_3072 ? _3072->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3073 = mosek::fusion::p_WorkStack::_get_impl(_2980)->f64;
          _checked_ptr_1<double> _ptr__3073(_3073 ? _3073->raw() : nullptr,_3073 ? _3073->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _3074 = mosek::fusion::p_WorkStack::_get_impl(_2982)->i32;
          _checked_ptr_1<int> _ptr__3074(_3074 ? _3074->raw() : nullptr,_3074 ? _3074->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3075 = mosek::fusion::p_WorkStack::_get_impl(_2982)->i64;
          _checked_ptr_1<long long> _ptr__3075(_3075 ? _3075->raw() : nullptr,_3075 ? _3075->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3076 = mosek::fusion::p_WorkStack::_get_impl(_2982)->f64;
          _checked_ptr_1<double> _ptr__3076(_3076 ? _3076->raw() : nullptr,_3076 ? _3076->size(0) : 0);
          {
            int _3077 = (int)0;
            int _3078 = (int)0;
            int _8300 = (int)0;
            int _8301 = _2983;
            for (int _3079 = _8300; _3079 < _8301; ++_3079)
            {
              {
                ::mosek::fusion::Utils::Tools::arraycopy(_2997,_ptr__2991[_3079],_3075,safe_add( _3067,_3078 ),_ptr__2988[_3079]);
                ::mosek::fusion::Utils::Tools::arraycopy(_2998,_ptr__2993[_3079],_3076,safe_add( _3069,_3078 ),_ptr__2988[_3079]);
                ::mosek::fusion::Utils::Tools::arraycopy(_2998,_ptr__2994[_3079],_3076,safe_add( _3070,_3077 ),_ptr__2987[_3079]);
                _3078 += _ptr__2988[_3079];
                _3077 += _ptr__2987[_3079];
              }
            }
          }
          {
            _ptr__3074[_3066] = (int)0;
            int _3080 = (int)0;
            int _3081 = (int)0;
            int _8302 = (int)0;
            int _8303 = _2983;
            for (int _3082 = _8302; _3082 < _8303; ++_3082)
            {
              {
                int _3083 = _ptr__3015[_3082];
                int _3084 = safe_mul( _3083,_3022 );
                int _3085 = _3022;
                if (((*_2989)(_3082)))
                {
                  {
                    int _8304 = (int)0;
                    int _8305 = _ptr__2987[_3082];
                    for (int _3086 = _8304; _3086 < _8305; ++_3086)
                    {
                      {
                        long long _3087 = (_ptr__2997[safe_add( _ptr__2992[_3082],_3086 )] / _3084);
                        long long _3088 = ((_ptr__2997[safe_add( _ptr__2992[_3082],_3086 )] / _3085) % _3083);
                        long long _3089 = (_ptr__2997[safe_add( _ptr__2992[_3082],_3086 )] % _3022);
                        _ptr__3075[safe_add( _3068,_3081 )] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _3087,_3006 ),_3088 ),_ptr__3018[_3082] ),_3022 ),_3089 );
                        _ptr__3074[safe_add( safe_add( _3066,_3081 ),(int)1 )] = safe_add( _3080,_ptr__2996[safe_add( safe_add( _ptr__2990[_3082],_3086 ),(int)1 )] );
                        ++ _3081;
                      }
                    }
                  }
                }
                else
                {
                  {
                    int _3090 = (int)0;
                    int _8306 = (int)0;
                    int _8307 = _3013;
                    for (int _3091 = _8306; _3091 < _8307; ++_3091)
                    {
                      {
                        int _8308 = (int)0;
                        int _8309 = _3083;
                        for (int _3092 = _8308; _3092 < _8309; ++_3092)
                        {
                          {
                            int _8310 = (int)0;
                            int _8311 = _3022;
                            for (int _3093 = _8310; _3093 < _8311; ++_3093)
                            {
                              {
                                _ptr__3075[safe_add( _3068,_3081 )] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _3091,_3006 ),_3092 ),_ptr__3018[_3082] ),_3022 ),_3093 );
                                _ptr__3074[safe_add( safe_add( _3066,_3081 ),(int)1 )] = safe_add( _3080,_ptr__2996[safe_add( safe_add( _ptr__2990[_3082],_3090 ),(int)1 )] );
                                ++ _3081;
                                ++ _3090;
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
                _3080 += _ptr__2988[_3082];
              }
            }
          }
          if ((dim > (int)0))
          {
            {
              int _3094 = (int)0;
              int _8312 = (int)0;
              int _8313 = _3008;
              for (int _3095 = _8312; _3095 < _8313; ++_3095)
              {
                {
                  if ((_3094 < _ptr__3071[safe_add( _3064,_3095 )]))
                  {
                    {
                      _3094 = _ptr__3071[safe_add( _3064,_3095 )];
                    }
                  }
                  {}
                }
              }
              std::shared_ptr< monty::ndarray< long long,1 > > _3096 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_3008)));
              _checked_ptr_1<long long> _ptr__3096(_3096 ? _3096->raw() : nullptr,_3096 ? _3096->size(0) : 0);
              _ptr__3096[(_3008 - (int)1)] = (int)1;
              int _8314 = (int)1;
              int _8315 = _3008;
              for (int _3097 = _8314; _3097 < _8315; ++_3097)
              {
                {
                  _ptr__3096[((_3008 - _3097) - (int)1)] = safe_mul( _ptr__3096[(_3008 - _3097)],_ptr__3071[(safe_add( _3064,_3008 ) - _3097)] );
                }
              }
              int _3098 = _2982->alloci32(_3009);
              int _3099 = _2982->alloci32(_3009);
              int _3100 = _2982->alloci32(safe_add( _3094,(int)1 ));
              std::shared_ptr< monty::ndarray< int,1 > > _3101 = mosek::fusion::p_WorkStack::_get_impl(_2982)->i32;
              _checked_ptr_1<int> _ptr__3101(_3101 ? _3101->raw() : nullptr,_3101 ? _3101->size(0) : 0);
              std::shared_ptr< monty::ndarray< long long,1 > > _3102 = mosek::fusion::p_WorkStack::_get_impl(_2982)->i64;
              _checked_ptr_1<long long> _ptr__3102(_3102 ? _3102->raw() : nullptr,_3102 ? _3102->size(0) : 0);
              std::shared_ptr< monty::ndarray< double,1 > > _3103 = mosek::fusion::p_WorkStack::_get_impl(_2982)->f64;
              _checked_ptr_1<double> _ptr__3103(_3103 ? _3103->raw() : nullptr,_3103 ? _3103->size(0) : 0);
              {
                int _8316 = (int)0;
                int _8317 = _3009;
                for (int _3104 = _8316; _3104 < _8317; ++_3104)
                {
                  {
                    _ptr__3101[safe_add( _3098,_3104 )] = _3104;
                  }
                }
                int _8318 = (int)0;
                int _8319 = _3008;
                for (int _3105 = _8318; _3105 < _8319; ++_3105)
                {
                  {
                    int _3106 = ((_3008 - _3105) - (int)1);
                    int _3107 = _ptr__3071[safe_add( _3064,_3106 )];
                    int _8320 = (int)0;
                    int _8321 = safe_add( _3107,(int)1 );
                    for (int _3108 = _8320; _3108 < _8321; ++_3108)
                    {
                      {
                        _ptr__3101[safe_add( _3100,_3108 )] = (int)0;
                      }
                    }
                    int _8322 = (int)0;
                    int _8323 = _3009;
                    for (int _3109 = _8322; _3109 < _8323; ++_3109)
                    {
                      {
                        int _3110 = _ptr__3101[safe_add( _3098,_3109 )];
                        long long _3111 = ((_ptr__3102[safe_add( _3068,_3110 )] / _ptr__3096[_3106]) % _3107);
                        ++ _ptr__3101[safe_add( safe_add( _3100,_3111 ),(int)1 )];
                      }
                    }
                    {
                      int _8324 = (int)0;
                      int _8325 = _3107;
                      for (int _3112 = _8324; _3112 < _8325; ++_3112)
                      {
                        {
                          _ptr__3101[safe_add( safe_add( _3100,_3112 ),(int)1 )] += _ptr__3101[safe_add( _3100,_3112 )];
                        }
                      }
                      int _8326 = (int)0;
                      int _8327 = _3009;
                      for (int _3113 = _8326; _3113 < _8327; ++_3113)
                      {
                        {
                          int _3114 = _ptr__3101[safe_add( _3098,_3113 )];
                          long long _3115 = ((_ptr__3102[safe_add( _3068,_3114 )] / _ptr__3096[_3106]) % _3107);
                          _ptr__3101[safe_add( _3099,_ptr__3101[safe_add( _3100,_3115 )] )] = _3114;
                          ++ _ptr__3101[safe_add( _3100,_3115 )];
                        }
                      }
                    }
                    int _3116 = _3098;
                    _3098 = _3099;
                    _3099 = _3116;
                  }
                }
                int _3117 = (int)0;
                _ptr__3071[_3059] = (int)0;
                int _8328 = (int)0;
                int _8329 = _3009;
                for (int _3118 = _8328; _3118 < _8329; ++_3118)
                {
                  {
                    int _3119 = _ptr__3101[safe_add( _3098,_3118 )];
                    int _3120 = _ptr__3101[safe_add( _3066,_3119 )];
                    int _3121 = _ptr__3101[safe_add( safe_add( _3066,_3119 ),(int)1 )];
                    int _3122 = (_3121 - _3120);
                    _ptr__3071[safe_add( safe_add( _3059,_3118 ),(int)1 )] = safe_add( _ptr__3071[safe_add( _3059,_3118 )],_3122 );
                    _ptr__3073[safe_add( _3063,_3118 )] = _ptr__3103[safe_add( _3070,_3119 )];
                    _ptr__3072[safe_add( _3061,_3118 )] = _ptr__3102[safe_add( _3068,_3119 )];
                    int _8330 = _3120;
                    int _8331 = _3121;
                    for (int _3123 = _8330; _3123 < _8331; ++_3123)
                    {
                      {
                        _ptr__3072[safe_add( _3060,_3117 )] = _ptr__3102[safe_add( _3067,_3123 )];
                        _ptr__3073[safe_add( _3062,_3117 )] = _ptr__3103[safe_add( _3069,_3123 )];
                        ++ _3117;
                      }
                    }
                  }
                }
              }
            }
          }
          else
          {
            {
              int _3124 = (int)0;
              _ptr__3071[_3059] = (int)0;
              int _8332 = (int)0;
              int _8333 = _3009;
              for (int _3125 = _8332; _3125 < _8333; ++_3125)
              {
                {
                  int _3126 = _ptr__3074[safe_add( _3066,_3125 )];
                  int _3127 = _ptr__3074[safe_add( safe_add( _3066,_3125 ),(int)1 )];
                  int _3128 = (_3127 - _3126);
                  _ptr__3071[safe_add( safe_add( _3059,_3125 ),(int)1 )] = safe_add( _ptr__3071[safe_add( _3059,_3125 )],_3128 );
                  _ptr__3073[safe_add( _3063,_3125 )] = _ptr__3076[safe_add( _3070,_3125 )];
                  _ptr__3072[safe_add( _3061,_3125 )] = _ptr__3075[safe_add( _3068,_3125 )];
                  int _8334 = _3126;
                  int _8335 = _3127;
                  for (int _3129 = _8334; _3129 < _8335; ++_3129)
                  {
                    {
                      _ptr__3072[safe_add( _3060,_3124 )] = _ptr__3075[safe_add( _3067,_3129 )];
                      _ptr__3073[safe_add( _3062,_3124 )] = _ptr__3076[safe_add( _3069,_3129 )];
                      ++ _3124;
                    }
                  }
                }
              }
            }
          }
          if ((!_3058))
          {
            {
              _2980->popi64(_3009);
            }
          }
          {}
          _2982->clear();
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprStack::getshape(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _3130,int _3131){
  if (((int)((_3130)->size(0)) == (int)0))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Cannot stack empty list"));
    }
  }
  else if(((int)((_3130)->size(0)) == (int)1))
  {
    {
      return ((*_3130)((int)0))->getShape();
    }
  }
  else
  {
    {
      std::vector<std::shared_ptr< monty::ndarray< int,1 > >> _8336;
      for (int _3133 = (int)0, _8337 = (int)((_3130)->size(0)); _3133 < _8337 ; ++_3133)
      {
        _8336.push_back(((*_3130)(_3133))->getShape());
      }
      auto _8338 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape(_8336.size()),_8336.begin(),_8336.end()));
      std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _3132 = _8338;
      std::shared_ptr< monty::ndarray< int,1 > > _3134 = ((*_3132)((int)0));
      _checked_ptr_1<int> _ptr__3134(_3134 ? _3134->raw() : nullptr,_3134 ? _3134->size(0) : 0);
      int _3135 = (int)((_3134)->size(0));
      int _8339 = (int)1;
      int _8340 = (int)((_3132)->size(0));
      for (int _3136 = _8339; _3136 < _8340; ++_3136)
      {
        {
          if ((_3135 != (int)((((*_3132)(_3136)))->size(0))))
          {
            {
              throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression dimensions"));
            }
          }
          {}
          int _8341 = (int)0;
          int _8342 = _3131;
          for (int _3137 = _8341; _3137 < _8342; ++_3137)
          {
            {
              if ((_ptr__3134[_3137] != ((*((*_3132)(_3136)))(_3137))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("mismatching expression dimensions"));
                }
              }
              {}
            }
          }
          int _8343 = safe_add( _3131,(int)1 );
          int _8344 = _3135;
          for (int _3138 = _8343; _3138 < _8344; ++_3138)
          {
            {
              if ((_ptr__3134[_3138] != ((*((*_3132)(_3136)))(_3138))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("mismatching expression dimensions"));
                }
              }
              {}
            }
          }
        }
      }
      if ((_3131 == _3135))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _3139 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _3135,(int)1 ))));
          _checked_ptr_1<int> _ptr__3139(_3139 ? _3139->raw() : nullptr,_3139 ? _3139->size(0) : 0);
          int _8345 = (int)0;
          int _8346 = _3135;
          for (int _3140 = _8345; _3140 < _8346; ++_3140)
          {
            {
              _ptr__3139[_3140] = _ptr__3134[_3140];
            }
          }
          _ptr__3139[_3135] = (int)((_3132)->size(0));
          return _3139;
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _3141 = _3134;
          _checked_ptr_1<int> _ptr__3141(_3141 ? _3141->raw() : nullptr,_3141 ? _3141->size(0) : 0);
          int _8347 = (int)1;
          int _8348 = (int)((_3132)->size(0));
          for (int _3142 = _8347; _3142 < _8348; ++_3142)
          {
            {
              _ptr__3141[_3131] += ((*((*_3132)(_3142)))(_3131));
            }
          }
          return _3141;
        }
      }
    }
  }
}
std::string mosek::fusion::ExprStack :: toString() { return mosek::fusion::p_ExprStack::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprStack::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _3143 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprStack(dim="))->__mosek_2fusion_2Utils_2StringBuffer__a(dim)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",["))->__mosek_2fusion_2Utils_2StringBuffer__a(((*exprs)((int)0))->toString());
  int _8349 = (int)1;
  int _8350 = (int)((exprs)->size(0));
  for (int _3144 = _8349; _3144 < _8350; ++_3144)
  {
    {
      _3143->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*exprs)(_3144))->toString());
    }
  }
  _3143->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("])"));
  return _3143->toString();
}
void mosek::fusion::p_ExprStack::destroy(){exprs.reset();}void mosek::fusion::ExprStack::destroy() { mosek::fusion::p_ExprStack::_get_impl(this)->destroy(); }mosek::fusion::ExprInner::ExprInner(mosek::fusion::p_ExprInner *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprInner()" << this << std::endl; */ }mosek::fusion::ExprInner::~ExprInner() {  /* std::cout << "~ExprInner()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprInner::p_ExprInner  (::mosek::fusion::ExprInner * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprInner::t mosek::fusion::p_ExprInner::_new_ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3145,    std::shared_ptr< monty::ndarray< long long,1 > > _3146,    std::shared_ptr< monty::ndarray< double,1 > > _3147){ return new mosek::fusion::ExprInner(_3145,_3146,_3147); }mosek::fusion::ExprInner::ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3145,    std::shared_ptr< monty::ndarray< long long,1 > > _3146,    std::shared_ptr< monty::ndarray< double,1 > > _3147) :    ExprInner(new mosek::fusion::p_ExprInner(this)){ mosek::fusion::p_ExprInner::_get_impl(this)->_initialize(_3145,_3146,_3147); }void mosek::fusion::p_ExprInner::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _3145,    std::shared_ptr< monty::ndarray< long long,1 > > _3146,    std::shared_ptr< monty::ndarray< double,1 > > _3147){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__3146(_3146 ? _3146->raw() : nullptr, _3146 ? _3146->size(0) : 0);
    _checked_ptr_1<double> _ptr__3147(_3147 ? _3147->raw() : nullptr, _3147 ? _3147->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
    mosek::fusion::p_ExprInner::_get_impl(::mosek::fusion::ExprInner::t(_pubthis))->expr = _3145;
    mosek::fusion::p_ExprInner::_get_impl(::mosek::fusion::ExprInner::t(_pubthis))->vsub = _3146;
    mosek::fusion::p_ExprInner::_get_impl(::mosek::fusion::ExprInner::t(_pubthis))->vcof = _3147;
    if (((int)((_3146)->size(0)) != (int)((_3147)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching lengths of vcof and vsub"));
      }
    }
    {}
    std::shared_ptr< monty::ndarray< int,1 > > _3148 = _3145->getShape();
    _checked_ptr_1<int> _ptr__3148(_3148 ? _3148->raw() : nullptr,_3148 ? _3148->size(0) : 0);
    long long _3149 = ::mosek::fusion::p_Set::size(_3148);
    bool _3150 = false;
    bool _3151 = false;
    {
      int _8351 = (int)1;
      int _8352 = (int)((_3146)->size(0));
      for (int _3152 = _8351; _3152 < _8352; ++_3152)
      {
        {
          if ((_ptr__3146[_3152] <= _ptr__3146[(_3152 - (int)1)]))
          {
            {
              _3150 = true;
            }
          }
          {}
        }
      }
      if (((int)((_3146)->size(0)) > (int)0))
      {
        {
          if (((_ptr__3146[(int)0] < (int)0) || (_ptr__3146[((int)((_3146)->size(0)) - (int)1)] > _3149)))
          {
            {
              _3151 = true;
            }
          }
          {}
        }
      }
      {}
    }
    if (_3150)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Unordered coefficcient subscripts"));
      }
    }
    {}
    if (_3151)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Coefficient subscript out of bounds"));
      }
    }
    {}
  }
}mosek::fusion::ExprInner::t mosek::fusion::p_ExprInner::_new_ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3153,    std::shared_ptr< monty::ndarray< double,1 > > _3154){ return new mosek::fusion::ExprInner(_3153,_3154); }mosek::fusion::ExprInner::ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3153,    std::shared_ptr< monty::ndarray< double,1 > > _3154) :    ExprInner(new mosek::fusion::p_ExprInner(this)){ mosek::fusion::p_ExprInner::_get_impl(this)->_initialize(_3153,_3154); }void mosek::fusion::p_ExprInner::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _3153,    std::shared_ptr< monty::ndarray< double,1 > > _3154){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3154(_3154 ? _3154->raw() : nullptr, _3154 ? _3154->size(0) : 0);
    mosek::fusion::p_ExprInner::_initialize(_3153,::mosek::fusion::p_ExprInner::range((int)((_3154)->size(0))),_3154);
    std::shared_ptr< monty::ndarray< int,1 > > _3155 = _3153->getShape();
    _checked_ptr_1<int> _ptr__3155(_3155 ? _3155->raw() : nullptr,_3155 ? _3155->size(0) : 0);
    if ((((int)((_3155)->size(0)) != (int)1) || (_ptr__3155[(int)0] != (int)((_3154)->size(0)))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions of operands"));
      }
    }
    {}
  }
}mosek::fusion::ExprInner::t mosek::fusion::p_ExprInner::_new_ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3156,    std::shared_ptr< monty::ndarray< int,2 > > _3157,    std::shared_ptr< monty::ndarray< double,1 > > _3158){ return new mosek::fusion::ExprInner(_3156,_3157,_3158); }mosek::fusion::ExprInner::ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3156,    std::shared_ptr< monty::ndarray< int,2 > > _3157,    std::shared_ptr< monty::ndarray< double,1 > > _3158) :    ExprInner(new mosek::fusion::p_ExprInner(this)){ mosek::fusion::p_ExprInner::_get_impl(this)->_initialize(_3156,_3157,_3158); }void mosek::fusion::p_ExprInner::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _3156,    std::shared_ptr< monty::ndarray< int,2 > > _3157,    std::shared_ptr< monty::ndarray< double,1 > > _3158){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3158(_3158 ? _3158->raw() : nullptr, _3158 ? _3158->size(0) : 0);
    mosek::fusion::p_ExprInner::_initialize(_3156,::mosek::fusion::p_ExprInner::convert(_3156->getShape(),_3157),_3158);
  }
}void mosek::fusion::ExprInner :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3159,monty::rc_ptr< ::mosek::fusion::WorkStack > _3160,monty::rc_ptr< ::mosek::fusion::WorkStack > _3161) { mosek::fusion::p_ExprInner::_get_impl(this)->eval(_3159,_3160,_3161); }void mosek::fusion::p_ExprInner::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3159,monty::rc_ptr< ::mosek::fusion::WorkStack > _3160,monty::rc_ptr< ::mosek::fusion::WorkStack > _3161){
  expr->eval(_3160,_3159,_3161);
  int _3162 = _3160->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _3163 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_3162)));
  _checked_ptr_1<int> _ptr__3163(_3163 ? _3163->raw() : nullptr,_3163 ? _3163->size(0) : 0);
  _3160->popi32(_3162,_3163,(int)0);
  int _3164 = _3160->popi32();
  int _3165 = _3160->popi32();
  bool _3166 = (_3160->popi32() != (int)0);
  int _3167 = _3160->popi32(safe_add( _3164,(int)1 ));
  int _8353;
  bool _8354 = _3166;
  if (_8354)
  {
    _8353 = _3160->popi64(_3164);
  }
  else
  {
    _8353 = (int)0;
  }
  int _3168 = _8353;
  int _3169 = _3160->popi64(_3165);
  int _3170 = _3160->popf64(_3164);
  int _3171 = _3160->popf64(_3165);
  std::shared_ptr< monty::ndarray< int,1 > > _3172 = mosek::fusion::p_WorkStack::_get_impl(_3160)->i32;
  _checked_ptr_1<int> _ptr__3172(_3172 ? _3172->raw() : nullptr,_3172 ? _3172->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3173 = mosek::fusion::p_WorkStack::_get_impl(_3160)->i64;
  _checked_ptr_1<long long> _ptr__3173(_3173 ? _3173->raw() : nullptr,_3173 ? _3173->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3174 = mosek::fusion::p_WorkStack::_get_impl(_3160)->f64;
  _checked_ptr_1<double> _ptr__3174(_3174 ? _3174->raw() : nullptr,_3174 ? _3174->size(0) : 0);
  int _3175 = (int)0;
  if (_3166)
  {
    {
      int _3176 = (int)0;
      int _3177 = (int)0;
      while ( ((_3177 < (int)((vsub)->size(0))) && (_3176 < _3164)) )
      {
        {
          if ((_ptr__3173[safe_add( _3168,_3176 )] < ((*vsub)(_3177))))
          {
            {
              ++ _3176;
            }
          }
          else if((_ptr__3173[safe_add( _3168,_3176 )] > ((*vsub)(_3177))))
          {
            {
              ++ _3177;
            }
          }
          else
          {
            {
              _3175 += (_ptr__3172[safe_add( safe_add( _3167,_3176 ),(int)1 )] - _ptr__3172[safe_add( _3167,_3176 )]);
              ++ _3177;
              ++ _3176;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _8355 = (int)0;
      int _8356 = (int)((vsub)->size(0));
      for (int _3178 = _8355; _3178 < _8356; ++_3178)
      {
        {
          _3175 += (_ptr__3172[safe_add( safe_add( _3167,((*vsub)(_3178)) ),(int)1 )] - _ptr__3172[safe_add( _3167,((*vsub)(_3178)) )]);
        }
      }
    }
  }
  int _3179 = _3159->alloci32((int)2);
  int _3180 = _3159->alloci64(_3175);
  int _3181 = _3159->allocf64(_3175);
  int _3182 = _3159->allocf64((int)1);
  _3159->pushi32((int)0);
  _3159->pushi32(_3175);
  _3159->pushi32((int)1);
  _3159->pushi32((int)0);
  std::shared_ptr< monty::ndarray< int,1 > > _3183 = mosek::fusion::p_WorkStack::_get_impl(_3159)->i32;
  _checked_ptr_1<int> _ptr__3183(_3183 ? _3183->raw() : nullptr,_3183 ? _3183->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3184 = mosek::fusion::p_WorkStack::_get_impl(_3159)->i64;
  _checked_ptr_1<long long> _ptr__3184(_3184 ? _3184->raw() : nullptr,_3184 ? _3184->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3185 = mosek::fusion::p_WorkStack::_get_impl(_3159)->f64;
  _checked_ptr_1<double> _ptr__3185(_3185 ? _3185->raw() : nullptr,_3185 ? _3185->size(0) : 0);
  _ptr__3183[_3179] = (int)0;
  _ptr__3183[safe_add( _3179,(int)1 )] = _3175;
  int _3186 = (int)0;
  double _3187 = 0.0;
  if (_3166)
  {
    {
      int _3188 = (int)0;
      int _3189 = (int)0;
      while ( ((_3189 < (int)((vsub)->size(0))) && (_3188 < _3164)) )
      {
        {
          if ((_ptr__3173[safe_add( _3168,_3188 )] < ((*vsub)(_3189))))
          {
            {
              ++ _3188;
            }
          }
          else if((_ptr__3173[safe_add( _3168,_3188 )] > ((*vsub)(_3189))))
          {
            {
              ++ _3189;
            }
          }
          else
          {
            {
              int _3190 = _ptr__3172[safe_add( _3167,_3188 )];
              int _3191 = _ptr__3172[safe_add( safe_add( _3167,_3188 ),(int)1 )];
              int _8357 = _3190;
              int _8358 = _3191;
              for (int _3192 = _8357; _3192 < _8358; ++_3192)
              {
                {
                  _ptr__3184[safe_add( _3180,_3186 )] = _ptr__3173[safe_add( _3169,_3192 )];
                  _ptr__3185[safe_add( _3181,_3186 )] = (((*vcof)(_3189)) * _ptr__3174[safe_add( _3171,_3192 )]);
                  ++ _3186;
                }
              }
              _3187 += (((*vcof)(_3189)) * _ptr__3174[safe_add( _3170,_3188 )]);
              ++ _3189;
              ++ _3188;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _8359 = (int)0;
      int _8360 = (int)((vsub)->size(0));
      for (int _3193 = _8359; _3193 < _8360; ++_3193)
      {
        {
          int _3194 = _ptr__3172[safe_add( _3167,((*vsub)(_3193)) )];
          int _3195 = _ptr__3172[safe_add( safe_add( _3167,((*vsub)(_3193)) ),(int)1 )];
          int _8361 = _3194;
          int _8362 = _3195;
          for (int _3196 = _8361; _3196 < _8362; ++_3196)
          {
            {
              _ptr__3184[safe_add( _3180,_3186 )] = _ptr__3173[safe_add( _3169,_3196 )];
              _ptr__3185[safe_add( _3181,_3186 )] = (((*vcof)(_3193)) * _ptr__3174[safe_add( _3171,_3196 )]);
              ++ _3186;
            }
          }
          _3187 += (((*vcof)(_3193)) * _ptr__3174[safe_add( _3170,((*vsub)(_3193)) )]);
        }
      }
    }
  }
  _ptr__3185[_3182] = _3187;
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_ExprInner::range(int _3197){
  std::vector<long long> _8363;
  for (int _3198 = (int)0, _8364 = _3197; _3198 < _8364 ; ++_3198)
  {
    _8363.push_back(_3198);
  }
  auto _8365 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_8363.size()),_8363.begin(),_8363.end()));
  return _8365;
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_ExprInner::convert(std::shared_ptr< monty::ndarray< int,1 > > _3199,std::shared_ptr< monty::ndarray< int,2 > > _3200){
  _checked_ptr_1<int> _ptr__3199(_3199 ? _3199->raw() : nullptr, _3199 ? _3199->size(0) : 0);
  int _3201 = (int)((_3199)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _3202 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_3201)));
  _checked_ptr_1<long long> _ptr__3202(_3202 ? _3202->raw() : nullptr,_3202 ? _3202->size(0) : 0);
  _ptr__3202[(_3201 - (int)1)] = (int)1;
  int _8366 = (int)1;
  int _8367 = _3201;
  for (int _3203 = _8366; _3203 < _8367; ++_3203)
  {
    {
      _ptr__3202[((_3201 - _3203) - (int)1)] = safe_mul( _ptr__3202[(_3201 - _3203)],_ptr__3199[(_3201 - _3203)] );
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _3204 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_3200)->size(0)))));
  _checked_ptr_1<long long> _ptr__3204(_3204 ? _3204->raw() : nullptr,_3204 ? _3204->size(0) : 0);
  int _8368 = (int)0;
  int _8369 = (int)((_3200)->size(0));
  for (int _3205 = _8368; _3205 < _8369; ++_3205)
  {
    {
      int _8370 = (int)0;
      int _8371 = _3201;
      for (int _3206 = _8370; _3206 < _8371; ++_3206)
      {
        {
          _ptr__3204[_3205] += safe_mul( _ptr__3202[_3206],((*_3200)(_3205,_3206)) );
        }
      }
    }
  }
  return _3204;
}
std::string mosek::fusion::ExprInner :: toString() { return mosek::fusion::p_ExprInner::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprInner::toString(){
  return std::string ("ExprInner()");
}
void mosek::fusion::p_ExprInner::destroy(){vcof.reset();vsub.reset();expr.reset();}void mosek::fusion::ExprInner::destroy() { mosek::fusion::p_ExprInner::_get_impl(this)->destroy(); }mosek::fusion::ExprMulDiagRight::ExprMulDiagRight(mosek::fusion::p_ExprMulDiagRight *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulDiagRight()" << this << std::endl; */ }mosek::fusion::ExprMulDiagRight::~ExprMulDiagRight() {  /* std::cout << "~ExprMulDiagRight()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulDiagRight::p_ExprMulDiagRight  (::mosek::fusion::ExprMulDiagRight * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulDiagRight::t mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight  (int _3207,    int _3208,    std::shared_ptr< monty::ndarray< int,1 > > _3209,    std::shared_ptr< monty::ndarray< int,1 > > _3210,    std::shared_ptr< monty::ndarray< double,1 > > _3211,    monty::rc_ptr< ::mosek::fusion::Expression > _3212,    int _3213){ return new mosek::fusion::ExprMulDiagRight(_3207,_3208,_3209,_3210,_3211,_3212,_3213); }mosek::fusion::ExprMulDiagRight::ExprMulDiagRight  (int _3207,    int _3208,    std::shared_ptr< monty::ndarray< int,1 > > _3209,    std::shared_ptr< monty::ndarray< int,1 > > _3210,    std::shared_ptr< monty::ndarray< double,1 > > _3211,    monty::rc_ptr< ::mosek::fusion::Expression > _3212,    int _3213) :    ExprMulDiagRight(new mosek::fusion::p_ExprMulDiagRight(this)){ mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->_initialize(_3207,_3208,_3209,_3210,_3211,_3212,_3213); }void mosek::fusion::p_ExprMulDiagRight::_initialize  (int _3207,    int _3208,    std::shared_ptr< monty::ndarray< int,1 > > _3209,    std::shared_ptr< monty::ndarray< int,1 > > _3210,    std::shared_ptr< monty::ndarray< double,1 > > _3211,    monty::rc_ptr< ::mosek::fusion::Expression > _3212,    int _3213){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3209(_3209 ? _3209->raw() : nullptr, _3209 ? _3209->size(0) : 0);
    _checked_ptr_1<int> _ptr__3210(_3210 ? _3210->raw() : nullptr, _3210 ? _3210->size(0) : 0);
    _checked_ptr_1<double> _ptr__3211(_3211 ? _3211->raw() : nullptr, _3211 ? _3211->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3208)}));
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mdim0 = _3207;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mdim1 = _3208;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubi = _3209;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubj = _3210;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mval = _3211;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->expr = _3212;
  }
}mosek::fusion::ExprMulDiagRight::t mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight  (int _3214,    int _3215,    std::shared_ptr< monty::ndarray< int,1 > > _3216,    std::shared_ptr< monty::ndarray< int,1 > > _3217,    std::shared_ptr< monty::ndarray< double,1 > > _3218,    monty::rc_ptr< ::mosek::fusion::Expression > _3219){ return new mosek::fusion::ExprMulDiagRight(_3214,_3215,_3216,_3217,_3218,_3219); }mosek::fusion::ExprMulDiagRight::ExprMulDiagRight  (int _3214,    int _3215,    std::shared_ptr< monty::ndarray< int,1 > > _3216,    std::shared_ptr< monty::ndarray< int,1 > > _3217,    std::shared_ptr< monty::ndarray< double,1 > > _3218,    monty::rc_ptr< ::mosek::fusion::Expression > _3219) :    ExprMulDiagRight(new mosek::fusion::p_ExprMulDiagRight(this)){ mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->_initialize(_3214,_3215,_3216,_3217,_3218,_3219); }void mosek::fusion::p_ExprMulDiagRight::_initialize  (int _3214,    int _3215,    std::shared_ptr< monty::ndarray< int,1 > > _3216,    std::shared_ptr< monty::ndarray< int,1 > > _3217,    std::shared_ptr< monty::ndarray< double,1 > > _3218,    monty::rc_ptr< ::mosek::fusion::Expression > _3219){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3216(_3216 ? _3216->raw() : nullptr, _3216 ? _3216->size(0) : 0);
    _checked_ptr_1<int> _ptr__3217(_3217 ? _3217->raw() : nullptr, _3217 ? _3217->size(0) : 0);
    _checked_ptr_1<double> _ptr__3218(_3218 ? _3218->raw() : nullptr, _3218 ? _3218->size(0) : 0);
    mosek::fusion::p_ExprMulDiagRight::_initialize(_3214,_3215,_3216,_3217,_3218,_3219,::mosek::fusion::p_ExprMulDiagRight::validate(_3214,_3215,_3216,_3217,_3218,_3219));
  }
}void mosek::fusion::ExprMulDiagRight :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3220,monty::rc_ptr< ::mosek::fusion::WorkStack > _3221,monty::rc_ptr< ::mosek::fusion::WorkStack > _3222) { mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->eval(_3220,_3221,_3222); }void mosek::fusion::p_ExprMulDiagRight::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3220,monty::rc_ptr< ::mosek::fusion::WorkStack > _3221,monty::rc_ptr< ::mosek::fusion::WorkStack > _3222){
  mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->expr->eval(_3221,_3220,_3222);
  int _3223 = (int)0;
  int _3224 = (int)99999;
  int _3225 = (int)0;
  bool _3226 = (_3221->peeki32((int)5) != (int)0);
  if (_3226)
  {
    {
      _3225 = _3221->peeki32((int)2);
      _3224 = _3221->alloci32(safe_add( _3225,(int)1 ));
      _3223 += safe_add( _3225,(int)1 );
    }
  }
  {}
  int _3227 = (int)((mval)->size(0));
  int _3228 = _3221->alloci32(_3227);
  int _3229 = _3221->alloci32(safe_add( mdim1,(int)1 ));
  _3223 += safe_add( safe_add( _3227,mdim1 ),(int)1 );
  {
    std::shared_ptr< monty::ndarray< int,1 > > _3230 = mosek::fusion::p_WorkStack::_get_impl(_3221)->i32;
    _checked_ptr_1<int> _ptr__3230(_3230 ? _3230->raw() : nullptr,_3230 ? _3230->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _3231 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubj;
    _checked_ptr_1<int> _ptr__3231(_3231 ? _3231->raw() : nullptr,_3231 ? _3231->size(0) : 0);
    {
      int _8372 = (int)0;
      int _8373 = safe_add( mdim1,(int)1 );
      for (int _3232 = _8372; _3232 < _8373; ++_3232)
      {
        {
          _ptr__3230[safe_add( _3229,_3232 )] = (int)0;
        }
      }
      int _8374 = (int)0;
      int _8375 = _3227;
      for (int _3233 = _8374; _3233 < _8375; ++_3233)
      {
        {
          ++ _ptr__3230[safe_add( safe_add( _3229,_ptr__3231[_3233] ),(int)1 )];
        }
      }
      int _8376 = (int)0;
      int _8377 = mdim1;
      for (int _3234 = _8376; _3234 < _8377; ++_3234)
      {
        {
          _ptr__3230[safe_add( safe_add( _3229,_3234 ),(int)1 )] += _ptr__3230[safe_add( _3229,_3234 )];
        }
      }
      int _8378 = (int)0;
      int _8379 = _3227;
      for (int _3235 = _8378; _3235 < _8379; ++_3235)
      {
        {
          _ptr__3230[safe_add( _3228,_ptr__3230[safe_add( _3229,_ptr__3231[_3235] )] )] = _3235;
          ++ _ptr__3230[safe_add( _3229,_ptr__3231[_3235] )];
        }
      }
      int _8380 = (int)0;
      int _8381 = mdim1;
      for (int _3236 = _8380; _3236 < _8381; ++_3236)
      {
        {
          _ptr__3230[(safe_add( _3229,mdim1 ) - _3236)] = _ptr__3230[((safe_add( _3229,mdim1 ) - _3236) - (int)1)];
        }
      }
      _ptr__3230[_3229] = (int)0;
    }
  }
  _3221->popi32(_3223);
  int _3237 = _3221->popi32();
  if ((_3237 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _3238 = _3221->popi32();
  int _3239 = _3221->popi32();
  int _3240 = _3221->popi32();
  int _3241 = _3221->popi32();
  bool _3242 = (_3221->popi32() != (int)0);
  int _3243 = _3221->popi32(safe_add( _3240,(int)1 ));
  int _8382;
  bool _8383 = _3242;
  if (_8383)
  {
    _8382 = _3221->popi64(_3240);
  }
  else
  {
    _8382 = (int)9999;
  }
  int _3244 = _8382;
  int _3245 = _3221->popi64(_3241);
  int _3246 = _3221->popf64(_3240);
  int _3247 = _3221->popf64(_3241);
  std::shared_ptr< monty::ndarray< int,1 > > _3248 = mosek::fusion::p_WorkStack::_get_impl(_3221)->i32;
  _checked_ptr_1<int> _ptr__3248(_3248 ? _3248->raw() : nullptr,_3248 ? _3248->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3249 = mosek::fusion::p_WorkStack::_get_impl(_3221)->i64;
  _checked_ptr_1<long long> _ptr__3249(_3249 ? _3249->raw() : nullptr,_3249 ? _3249->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3250 = mosek::fusion::p_WorkStack::_get_impl(_3221)->f64;
  _checked_ptr_1<double> _ptr__3250(_3250 ? _3250->raw() : nullptr,_3250 ? _3250->size(0) : 0);
  if (_3242)
  {
    {
      int _8384 = (int)0;
      int _8385 = safe_add( _3239,(int)1 );
      for (int _3251 = _8384; _3251 < _8385; ++_3251)
      {
        {
          _ptr__3248[safe_add( _3224,_3251 )] = (int)0;
        }
      }
      int _8386 = (int)0;
      int _8387 = _3240;
      for (int _3252 = _8386; _3252 < _8387; ++_3252)
      {
        {
          ++ _ptr__3248[safe_add( safe_add( _3224,(_ptr__3249[safe_add( _3244,_3252 )] / _3238) ),(int)1 )];
        }
      }
      int _8388 = (int)0;
      int _8389 = _3239;
      for (int _3253 = _8388; _3253 < _8389; ++_3253)
      {
        {
          _ptr__3248[safe_add( safe_add( _3224,_3253 ),(int)1 )] += _ptr__3248[safe_add( _3224,_3253 )];
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _3254 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubi;
      _checked_ptr_1<int> _ptr__3254(_3254 ? _3254->raw() : nullptr,_3254 ? _3254->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3255 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mval;
      _checked_ptr_1<double> _ptr__3255(_3255 ? _3255->raw() : nullptr,_3255 ? _3255->size(0) : 0);
      int _3256 = (int)0;
      int _3257 = (int)0;
      {
        int _8390 = (int)0;
        int _8391 = _3239;
        for (int _3258 = _8390; _3258 < _8391; ++_3258)
        {
          {
            int _3259 = _ptr__3248[safe_add( safe_add( _3229,_3258 ),(int)1 )];
            int _3260 = _ptr__3248[safe_add( _3229,_3258 )];
            int _3261 = _ptr__3248[safe_add( safe_add( _3224,_3258 ),(int)1 )];
            int _3262 = _ptr__3248[safe_add( _3224,_3258 )];
            bool _3263 = false;
            while ( ((_3262 < _3261) && (_3260 < _3259)) )
            {
              {
                int _3264 = _ptr__3248[safe_add( _3228,_3260 )];
                long long _3265 = (_ptr__3249[safe_add( _3244,_3262 )] % _3238);
                if ((_ptr__3254[_3264] < _3265))
                {
                  {
                    ++ _3260;
                  }
                }
                else if((_ptr__3254[_3264] > _3265))
                {
                  {
                    ++ _3262;
                  }
                }
                else
                {
                  {
                    _3263 = true;
                    _3256 += (_ptr__3248[safe_add( safe_add( _3243,_3262 ),(int)1 )] - _ptr__3248[safe_add( _3243,_3262 )]);
                    ++ _3262;
                    ++ _3260;
                  }
                }
              }
            }
            if (_3263)
            {
              {
                ++ _3257;
              }
            }
            {}
          }
        }
      }
      bool _3266 = (_3257 < _3239);
      int _3267 = _3220->alloci32(safe_add( _3257,(int)1 ));
      int _3268 = _3220->alloci64(_3256);
      int _3269 = _3220->alloci64(_3257);
      int _3270 = _3220->allocf64(_3256);
      int _3271 = _3220->allocf64(_3257);
      int _8392;
      bool _8393 = _3266;
      if (_8393)
      {
        _8392 = (int)1;
      }
      else
      {
        _8392 = (int)0;
      }
      _3220->pushi32(_8392);
      _3220->pushi32(_3256);
      _3220->pushi32(_3257);
      _3220->pushi32(_3239);
      _3220->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3272 = mosek::fusion::p_WorkStack::_get_impl(_3220)->i32;
      _checked_ptr_1<int> _ptr__3272(_3272 ? _3272->raw() : nullptr,_3272 ? _3272->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3273 = mosek::fusion::p_WorkStack::_get_impl(_3220)->i64;
      _checked_ptr_1<long long> _ptr__3273(_3273 ? _3273->raw() : nullptr,_3273 ? _3273->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3274 = mosek::fusion::p_WorkStack::_get_impl(_3220)->f64;
      _checked_ptr_1<double> _ptr__3274(_3274 ? _3274->raw() : nullptr,_3274 ? _3274->size(0) : 0);
      {
        int _3275 = (int)0;
        int _3276 = (int)0;
        _ptr__3272[_3267] = (int)0;
        int _8394 = (int)0;
        int _8395 = _3239;
        for (int _3277 = _8394; _3277 < _8395; ++_3277)
        {
          {
            int _3278 = _ptr__3248[safe_add( safe_add( _3229,_3277 ),(int)1 )];
            int _3279 = _ptr__3248[safe_add( _3229,_3277 )];
            int _3280 = _ptr__3248[safe_add( safe_add( _3224,_3277 ),(int)1 )];
            int _3281 = _ptr__3248[safe_add( _3224,_3277 )];
            bool _3282 = false;
            double _3283 = 0.0;
            while ( ((_3281 < _3280) && (_3279 < _3278)) )
            {
              {
                int _3284 = _ptr__3248[safe_add( _3228,_3279 )];
                long long _3285 = (_ptr__3249[safe_add( _3244,_3281 )] % _3238);
                if ((_ptr__3254[_3284] < _3285))
                {
                  {
                    ++ _3279;
                  }
                }
                else if((_ptr__3254[_3284] > _3285))
                {
                  {
                    ++ _3281;
                  }
                }
                else
                {
                  {
                    _3282 = true;
                    int _8396 = _ptr__3248[safe_add( _3243,_3281 )];
                    int _8397 = _ptr__3248[safe_add( safe_add( _3243,_3281 ),(int)1 )];
                    for (int _3286 = _8396; _3286 < _8397; ++_3286)
                    {
                      {
                        _ptr__3273[safe_add( _3268,_3276 )] = _ptr__3249[safe_add( _3245,_3286 )];
                        _ptr__3274[safe_add( _3270,_3276 )] = (_ptr__3250[safe_add( _3247,_3286 )] * _ptr__3255[_3284]);
                        ++ _3276;
                      }
                    }
                    _3283 += (_ptr__3250[safe_add( _3246,_3281 )] * _ptr__3255[_3284]);
                    ++ _3281;
                    ++ _3279;
                  }
                }
              }
            }
            if (_3282)
            {
              {
                _ptr__3272[safe_add( safe_add( _3267,_3275 ),(int)1 )] = _3276;
                _ptr__3273[safe_add( _3269,_3275 )] = _3277;
                _ptr__3274[safe_add( _3271,_3275 )] = _3283;
                ++ _3275;
              }
            }
            {}
          }
        }
      }
      if ((!_3266))
      {
        {
          _3220->popi64(_3257);
        }
      }
      {}
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _3287 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubi;
      _checked_ptr_1<int> _ptr__3287(_3287 ? _3287->raw() : nullptr,_3287 ? _3287->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3288 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mval;
      _checked_ptr_1<double> _ptr__3288(_3288 ? _3288->raw() : nullptr,_3288 ? _3288->size(0) : 0);
      int _3289 = (int)0;
      int _3290 = (int)0;
      {
        int _8398 = (int)0;
        int _8399 = _3239;
        for (int _3291 = _8398; _3291 < _8399; ++_3291)
        {
          {
            bool _3292 = false;
            int _8400 = _ptr__3248[safe_add( _3229,_3291 )];
            int _8401 = _ptr__3248[safe_add( safe_add( _3229,_3291 ),(int)1 )];
            for (int _3293 = _8400; _3293 < _8401; ++_3293)
            {
              {
                int _3294 = _ptr__3248[safe_add( _3228,_3293 )];
                int _3295 = safe_add( safe_mul( _3291,_3238 ),_ptr__3287[_3294] );
                _3290 += (_ptr__3248[safe_add( safe_add( _3243,_3295 ),(int)1 )] - _ptr__3248[safe_add( _3243,_3295 )]);
                if ((_ptr__3248[safe_add( safe_add( _3243,_3295 ),(int)1 )] > _ptr__3248[safe_add( _3243,_3295 )]))
                {
                  {
                    _3292 = true;
                  }
                }
                {}
              }
            }
            if (_3292)
            {
              {
                ++ _3289;
              }
            }
            {}
          }
        }
      }
      bool _3296 = (_3289 < _3239);
      int _3297 = _3220->alloci32(safe_add( _3289,(int)1 ));
      int _3298 = _3220->alloci64(_3290);
      int _3299 = _3220->alloci64(_3289);
      int _3300 = _3220->allocf64(_3290);
      int _3301 = _3220->allocf64(_3289);
      int _8402;
      bool _8403 = _3296;
      if (_8403)
      {
        _8402 = (int)1;
      }
      else
      {
        _8402 = (int)0;
      }
      _3220->pushi32(_8402);
      _3220->pushi32(_3290);
      _3220->pushi32(_3289);
      _3220->pushi32(_3239);
      _3220->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3302 = mosek::fusion::p_WorkStack::_get_impl(_3220)->i32;
      _checked_ptr_1<int> _ptr__3302(_3302 ? _3302->raw() : nullptr,_3302 ? _3302->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3303 = mosek::fusion::p_WorkStack::_get_impl(_3220)->i64;
      _checked_ptr_1<long long> _ptr__3303(_3303 ? _3303->raw() : nullptr,_3303 ? _3303->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3304 = mosek::fusion::p_WorkStack::_get_impl(_3220)->f64;
      _checked_ptr_1<double> _ptr__3304(_3304 ? _3304->raw() : nullptr,_3304 ? _3304->size(0) : 0);
      {
        int _3305 = (int)0;
        int _3306 = (int)0;
        _ptr__3302[_3297] = (int)0;
        int _8404 = (int)0;
        int _8405 = _3239;
        for (int _3307 = _8404; _3307 < _8405; ++_3307)
        {
          {
            bool _3308 = false;
            double _3309 = 0.0;
            int _8406 = _ptr__3248[safe_add( _3229,_3307 )];
            int _8407 = _ptr__3248[safe_add( safe_add( _3229,_3307 ),(int)1 )];
            for (int _3310 = _8406; _3310 < _8407; ++_3310)
            {
              {
                int _3311 = _ptr__3248[safe_add( _3228,_3310 )];
                int _3312 = safe_add( safe_mul( _3307,_3238 ),_ptr__3287[_3311] );
                int _8408 = _ptr__3248[safe_add( _3243,_3312 )];
                int _8409 = _ptr__3248[safe_add( safe_add( _3243,_3312 ),(int)1 )];
                for (int _3313 = _8408; _3313 < _8409; ++_3313)
                {
                  {
                    _3308 = true;
                    _ptr__3303[safe_add( _3298,_3306 )] = _ptr__3249[safe_add( _3245,_3313 )];
                    _ptr__3304[safe_add( _3300,_3306 )] = (_ptr__3250[safe_add( _3247,_3313 )] * _ptr__3288[_3311]);
                    ++ _3306;
                  }
                }
                _3309 += (_ptr__3250[safe_add( _3246,_3312 )] * _ptr__3288[_3311]);
              }
            }
            if (_3308)
            {
              {
                _ptr__3304[safe_add( _3301,_3305 )] = _3309;
                _ptr__3303[safe_add( _3299,_3305 )] = _3307;
                _ptr__3302[safe_add( safe_add( _3297,_3305 ),(int)1 )] = _3306;
                ++ _3305;
              }
            }
            {}
          }
        }
      }
      if ((!_3296))
      {
        {
          _3220->popi64(_3289);
        }
      }
      {}
    }
  }
}
int mosek::fusion::p_ExprMulDiagRight::validate(int _3314,int _3315,std::shared_ptr< monty::ndarray< int,1 > > _3316,std::shared_ptr< monty::ndarray< int,1 > > _3317,std::shared_ptr< monty::ndarray< double,1 > > _3318,monty::rc_ptr< ::mosek::fusion::Expression > _3319){
  _checked_ptr_1<int> _ptr__3316(_3316 ? _3316->raw() : nullptr, _3316 ? _3316->size(0) : 0);
  _checked_ptr_1<int> _ptr__3317(_3317 ? _3317->raw() : nullptr, _3317 ? _3317->size(0) : 0);
  _checked_ptr_1<double> _ptr__3318(_3318 ? _3318->raw() : nullptr, _3318 ? _3318->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3320 = _3319->getShape();
  _checked_ptr_1<int> _ptr__3320(_3320 ? _3320->raw() : nullptr,_3320 ? _3320->size(0) : 0);
  if (((int)((_3320)->size(0)) > (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3321 = _ptr__3320[(int)0];
  int _3322 = _ptr__3320[(int)1];
  if (((_3314 < (int)0) || ((_3315 < (int)0) || ((_3321 < (int)0) || (_3322 < (int)0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if (((_3314 != _3322) || (_3315 != _3321)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3316)->size(0)) != (int)((_3317)->size(0))) || ((int)((_3316)->size(0)) != (int)((_3318)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3323 = (int)((_3316)->size(0));
  bool _3324 = false;
  bool _3325 = false;
  {
    int _8410 = (int)0;
    int _8411 = _3323;
    for (int _3326 = _8410; _3326 < _8411; ++_3326)
    {
      {
        if (((_ptr__3316[_3326] < (int)0) || ((_ptr__3316[_3326] >= _3314) || ((_ptr__3317[_3326] < (int)0) || (_ptr__3317[_3326] >= _3315)))))
        {
          {
            _3324 = true;
          }
        }
        {}
      }
    }
    int _8412 = (int)0;
    int _8413 = (_3323 - (int)1);
    for (int _3327 = _8412; _3327 < _8413; ++_3327)
    {
      {
        if (((_ptr__3316[_3327] > _ptr__3316[safe_add( _3327,(int)1 )]) || ((_ptr__3316[_3327] == _ptr__3316[safe_add( _3327,(int)1 )]) && (_ptr__3317[_3327] >= _ptr__3317[safe_add( _3327,(int)1 )]))))
        {
          {
            _3325 = true;
          }
        }
        {}
      }
    }
  }
  if (_3324)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  if (_3325)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
    }
  }
  {}
  return (int)1;
}
std::string mosek::fusion::ExprMulDiagRight :: toString() { return mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulDiagRight::toString(){
  return std::string ("ExprMulDiagRight()");
}
void mosek::fusion::p_ExprMulDiagRight::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulDiagRight::destroy() { mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->destroy(); }mosek::fusion::ExprMulDiagLeft::ExprMulDiagLeft(mosek::fusion::p_ExprMulDiagLeft *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulDiagLeft()" << this << std::endl; */ }mosek::fusion::ExprMulDiagLeft::~ExprMulDiagLeft() {  /* std::cout << "~ExprMulDiagLeft()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulDiagLeft::p_ExprMulDiagLeft  (::mosek::fusion::ExprMulDiagLeft * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulDiagLeft::t mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft  (int _3328,    int _3329,    std::shared_ptr< monty::ndarray< int,1 > > _3330,    std::shared_ptr< monty::ndarray< int,1 > > _3331,    std::shared_ptr< monty::ndarray< double,1 > > _3332,    monty::rc_ptr< ::mosek::fusion::Expression > _3333,    int _3334){ return new mosek::fusion::ExprMulDiagLeft(_3328,_3329,_3330,_3331,_3332,_3333,_3334); }mosek::fusion::ExprMulDiagLeft::ExprMulDiagLeft  (int _3328,    int _3329,    std::shared_ptr< monty::ndarray< int,1 > > _3330,    std::shared_ptr< monty::ndarray< int,1 > > _3331,    std::shared_ptr< monty::ndarray< double,1 > > _3332,    monty::rc_ptr< ::mosek::fusion::Expression > _3333,    int _3334) :    ExprMulDiagLeft(new mosek::fusion::p_ExprMulDiagLeft(this)){ mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->_initialize(_3328,_3329,_3330,_3331,_3332,_3333,_3334); }void mosek::fusion::p_ExprMulDiagLeft::_initialize  (int _3328,    int _3329,    std::shared_ptr< monty::ndarray< int,1 > > _3330,    std::shared_ptr< monty::ndarray< int,1 > > _3331,    std::shared_ptr< monty::ndarray< double,1 > > _3332,    monty::rc_ptr< ::mosek::fusion::Expression > _3333,    int _3334){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3330(_3330 ? _3330->raw() : nullptr, _3330 ? _3330->size(0) : 0);
    _checked_ptr_1<int> _ptr__3331(_3331 ? _3331->raw() : nullptr, _3331 ? _3331->size(0) : 0);
    _checked_ptr_1<double> _ptr__3332(_3332 ? _3332->raw() : nullptr, _3332 ? _3332->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3328)}));
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->mdim0 = _3328;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->mdim1 = _3329;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->msubi = _3330;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->msubj = _3331;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->mval = _3332;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->expr = _3333;
  }
}mosek::fusion::ExprMulDiagLeft::t mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft  (int _3335,    int _3336,    std::shared_ptr< monty::ndarray< int,1 > > _3337,    std::shared_ptr< monty::ndarray< int,1 > > _3338,    std::shared_ptr< monty::ndarray< double,1 > > _3339,    monty::rc_ptr< ::mosek::fusion::Expression > _3340){ return new mosek::fusion::ExprMulDiagLeft(_3335,_3336,_3337,_3338,_3339,_3340); }mosek::fusion::ExprMulDiagLeft::ExprMulDiagLeft  (int _3335,    int _3336,    std::shared_ptr< monty::ndarray< int,1 > > _3337,    std::shared_ptr< monty::ndarray< int,1 > > _3338,    std::shared_ptr< monty::ndarray< double,1 > > _3339,    monty::rc_ptr< ::mosek::fusion::Expression > _3340) :    ExprMulDiagLeft(new mosek::fusion::p_ExprMulDiagLeft(this)){ mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->_initialize(_3335,_3336,_3337,_3338,_3339,_3340); }void mosek::fusion::p_ExprMulDiagLeft::_initialize  (int _3335,    int _3336,    std::shared_ptr< monty::ndarray< int,1 > > _3337,    std::shared_ptr< monty::ndarray< int,1 > > _3338,    std::shared_ptr< monty::ndarray< double,1 > > _3339,    monty::rc_ptr< ::mosek::fusion::Expression > _3340){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3337(_3337 ? _3337->raw() : nullptr, _3337 ? _3337->size(0) : 0);
    _checked_ptr_1<int> _ptr__3338(_3338 ? _3338->raw() : nullptr, _3338 ? _3338->size(0) : 0);
    _checked_ptr_1<double> _ptr__3339(_3339 ? _3339->raw() : nullptr, _3339 ? _3339->size(0) : 0);
    mosek::fusion::p_ExprMulDiagLeft::_initialize(_3335,_3336,_3337,_3338,_3339,_3340,::mosek::fusion::p_ExprMulDiagLeft::validate(_3335,_3336,_3337,_3338,_3339,_3340));
  }
}void mosek::fusion::ExprMulDiagLeft :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3341,monty::rc_ptr< ::mosek::fusion::WorkStack > _3342,monty::rc_ptr< ::mosek::fusion::WorkStack > _3343) { mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->eval(_3341,_3342,_3343); }void mosek::fusion::p_ExprMulDiagLeft::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3341,monty::rc_ptr< ::mosek::fusion::WorkStack > _3342,monty::rc_ptr< ::mosek::fusion::WorkStack > _3343){
  mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->expr->eval(_3342,_3341,_3343);
  if ((_3342->peeki32() != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _3344 = (int)((msubi)->size(0));
  int _3345 = (int)9999;
  int _3346 = (int)9999;
  int _3347 = (int)0;
  int _3348 = _3342->peeki32((int)5);
  if ((_3348 != (int)0))
  {
    {
      int _3349 = _3342->peeki32((int)1);
      int _3350 = _3342->peeki32((int)3);
      _3345 = _3342->alloci32(safe_add( _3349,(int)1 ));
      _3346 = _3342->alloci32(_3350);
      _3347 += safe_add( safe_add( _3350,_3349 ),(int)1 );
    }
  }
  {}
  int _3351 = _3342->alloci32(safe_add( mdim0,(int)1 ));
  _3347 += safe_add( mdim0,(int)1 );
  _3342->popi32(_3347);
  std::shared_ptr< monty::ndarray< int,1 > > _3352 = mosek::fusion::p_WorkStack::_get_impl(_3342)->i32;
  _checked_ptr_1<int> _ptr__3352(_3352 ? _3352->raw() : nullptr,_3352 ? _3352->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3353 = mosek::fusion::p_WorkStack::_get_impl(_3342)->i64;
  _checked_ptr_1<long long> _ptr__3353(_3353 ? _3353->raw() : nullptr,_3353 ? _3353->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3354 = mosek::fusion::p_WorkStack::_get_impl(_3342)->f64;
  _checked_ptr_1<double> _ptr__3354(_3354 ? _3354->raw() : nullptr,_3354 ? _3354->size(0) : 0);
  int _8414 = (int)0;
  int _8415 = safe_add( mdim0,(int)1 );
  for (int _3355 = _8414; _3355 < _8415; ++_3355)
  {
    {
      _ptr__3352[safe_add( _3351,_3355 )] = (int)0;
    }
  }
  int _8416 = (int)0;
  int _8417 = _3344;
  for (int _3356 = _8416; _3356 < _8417; ++_3356)
  {
    {
      ++ _ptr__3352[safe_add( safe_add( _3351,((*msubi)(_3356)) ),(int)1 )];
    }
  }
  int _8418 = (int)0;
  int _8419 = mdim0;
  for (int _3357 = _8418; _3357 < _8419; ++_3357)
  {
    {
      _ptr__3352[safe_add( safe_add( _3351,_3357 ),(int)1 )] += _ptr__3352[safe_add( _3351,_3357 )];
    }
  }
  int _3358 = _3342->popi32();
  int _3359 = _3342->popi32();
  int _3360 = _3342->popi32();
  int _3361 = _3342->popi32();
  int _3362 = _3342->popi32();
  bool _3363 = (_3342->popi32() != (int)0);
  int _3364 = _3342->popi32(safe_add( _3361,(int)1 ));
  int _8420;
  bool _8421 = _3363;
  if (_8421)
  {
    _8420 = _3342->popi64(_3361);
  }
  else
  {
    _8420 = (int)9999;
  }
  int _3365 = _8420;
  int _3366 = _3342->popi64(_3362);
  int _3367 = _3342->popf64(_3361);
  int _3368 = _3342->popf64(_3362);
  if ((!_3363))
  {
    {
      int _3369 = (int)((msubi)->size(0));
      int _3370 = (int)0;
      int _8422 = (int)0;
      int _8423 = mdim0;
      for (int _3371 = _8422; _3371 < _8423; ++_3371)
      {
        {
          if ((_ptr__3352[safe_add( _3351,_3371 )] < _ptr__3352[safe_add( safe_add( _3351,_3371 ),(int)1 )]))
          {
            {
              ++ _3370;
            }
          }
          {}
        }
      }
      bool _3372 = (_3370 < mdim0);
      int _3373 = _3341->alloci32(safe_add( _3370,(int)1 ));
      int _3374 = _3341->alloci64(_3369);
      int _3375 = _3341->alloci64(_3370);
      int _3376 = _3341->allocf64(_3369);
      int _3377 = _3341->allocf64(_3370);
      int _8424;
      bool _8425 = _3372;
      if (_8425)
      {
        _8424 = (int)1;
      }
      else
      {
        _8424 = (int)0;
      }
      _3341->pushi32(_8424);
      _3341->pushi32(_3369);
      _3341->pushi32(_3370);
      _3341->pushi32(mdim0);
      _3341->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3378 = mosek::fusion::p_WorkStack::_get_impl(_3341)->i32;
      _checked_ptr_1<int> _ptr__3378(_3378 ? _3378->raw() : nullptr,_3378 ? _3378->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3379 = mosek::fusion::p_WorkStack::_get_impl(_3341)->i64;
      _checked_ptr_1<long long> _ptr__3379(_3379 ? _3379->raw() : nullptr,_3379 ? _3379->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3380 = mosek::fusion::p_WorkStack::_get_impl(_3341)->f64;
      _checked_ptr_1<double> _ptr__3380(_3380 ? _3380->raw() : nullptr,_3380 ? _3380->size(0) : 0);
      {
        _ptr__3378[_3373] = (int)0;
        int _3381 = (int)0;
        int _3382 = (int)0;
        int _8426 = (int)0;
        int _8427 = mdim0;
        for (int _3383 = _8426; _3383 < _8427; ++_3383)
        {
          {
            if ((_ptr__3352[safe_add( _3351,_3383 )] < _ptr__3352[safe_add( safe_add( _3351,_3383 ),(int)1 )]))
            {
              {
                int _3384 = (int)0;
                int _8428 = _ptr__3352[safe_add( _3351,_3383 )];
                int _8429 = _ptr__3352[safe_add( safe_add( _3351,_3383 ),(int)1 )];
                for (int _3385 = _8428; _3385 < _8429; ++_3385)
                {
                  {
                    int _3386 = ((*msubj)(_3385));
                    int _3387 = safe_add( safe_mul( _3386,_3359 ),_3383 );
                    int _8430 = _ptr__3352[safe_add( _3364,_3387 )];
                    int _8431 = _ptr__3352[safe_add( safe_add( _3364,_3387 ),(int)1 )];
                    for (int _3388 = _8430; _3388 < _8431; ++_3388)
                    {
                      {
                        _ptr__3379[safe_add( _3374,_3382 )] = _ptr__3353[safe_add( _3366,_3388 )];
                        _ptr__3380[safe_add( _3376,_3382 )] = (_ptr__3354[safe_add( _3368,_3388 )] * ((*mval)(_3385)));
                        ++ _3382;
                      }
                    }
                  }
                }
                _ptr__3380[safe_add( _3377,_3381 )] = _3384;
                _ptr__3379[safe_add( _3375,_3381 )] = _3383;
                _ptr__3378[safe_add( safe_add( _3373,_3381 ),(int)1 )] = _3382;
                ++ _3381;
              }
            }
            {}
          }
        }
      }
      if ((!_3372))
      {
        {
          _3341->popi64(_3370);
        }
      }
      {}
    }
  }
  else
  {
    {
      int _8432 = (int)0;
      int _8433 = safe_add( _3359,(int)1 );
      for (int _3389 = _8432; _3389 < _8433; ++_3389)
      {
        {
          _ptr__3352[safe_add( _3345,_3389 )] = (int)0;
        }
      }
      int _8434 = (int)0;
      int _8435 = _3361;
      for (int _3390 = _8434; _3390 < _8435; ++_3390)
      {
        {
          ++ _ptr__3352[safe_add( safe_add( _3345,(_ptr__3353[safe_add( _3365,_3390 )] % _3359) ),(int)1 )];
        }
      }
      int _8436 = (int)0;
      int _8437 = _3359;
      for (int _3391 = _8436; _3391 < _8437; ++_3391)
      {
        {
          _ptr__3352[safe_add( safe_add( _3345,_3391 ),(int)1 )] += _ptr__3352[safe_add( _3345,_3391 )];
        }
      }
      int _8438 = (int)0;
      int _8439 = _3361;
      for (int _3392 = _8438; _3392 < _8439; ++_3392)
      {
        {
          long long _3393 = (_ptr__3353[safe_add( _3365,_3392 )] % _3359);
          _ptr__3352[safe_add( _3346,_ptr__3352[safe_add( _3345,_3393 )] )] = _3392;
          ++ _ptr__3352[safe_add( _3345,_3393 )];
        }
      }
      int _8440 = (int)0;
      int _8441 = _3359;
      for (int _3394 = _8440; _3394 < _8441; ++_3394)
      {
        {
          _ptr__3352[(safe_add( _3345,_3359 ) - _3394)] = _ptr__3352[((safe_add( _3345,_3359 ) - _3394) - (int)1)];
        }
      }
      _ptr__3352[_3345] = (int)0;
      int _3395 = (int)0;
      int _3396 = (int)0;
      {
        int _8442 = (int)0;
        int _8443 = mdim0;
        for (int _3397 = _8442; _3397 < _8443; ++_3397)
        {
          {
            int _3398 = _ptr__3352[safe_add( safe_add( _3345,_3397 ),(int)1 )];
            int _3399 = _ptr__3352[safe_add( _3345,_3397 )];
            int _3400 = _ptr__3352[safe_add( safe_add( _3351,_3397 ),(int)1 )];
            int _3401 = _ptr__3352[safe_add( _3351,_3397 )];
            bool _3402 = false;
            while ( ((_3401 < _3400) && (_3399 < _3398)) )
            {
              {
                int _3403 = _ptr__3352[safe_add( _3346,_3399 )];
                long long _3404 = (_ptr__3353[safe_add( _3365,_3403 )] / _3359);
                if ((((*msubj)(_3401)) < _3404))
                {
                  {
                    ++ _3401;
                  }
                }
                else if((((*msubj)(_3401)) > _3404))
                {
                  {
                    ++ _3399;
                  }
                }
                else
                {
                  {
                    _3402 = true;
                    _3396 += (_ptr__3352[safe_add( safe_add( _3364,_3403 ),(int)1 )] - _ptr__3352[safe_add( _3364,_3403 )]);
                    ++ _3401;
                    ++ _3399;
                  }
                }
              }
            }
            if (_3402)
            {
              {
                ++ _3395;
              }
            }
            {}
          }
        }
      }
      int _3405 = _3395;
      int _3406 = _3396;
      bool _3407 = (_3405 < mdim0);
      int _3408 = _3341->alloci32(safe_add( _3405,(int)1 ));
      int _3409 = _3341->alloci64(_3406);
      int _3410 = _3341->alloci64(_3405);
      int _3411 = _3341->allocf64(_3406);
      int _3412 = _3341->allocf64(_3405);
      int _8444;
      bool _8445 = _3407;
      if (_8445)
      {
        _8444 = (int)1;
      }
      else
      {
        _8444 = (int)0;
      }
      _3341->pushi32(_8444);
      _3341->pushi32(_3406);
      _3341->pushi32(_3405);
      _3341->pushi32(mdim0);
      _3341->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3413 = mosek::fusion::p_WorkStack::_get_impl(_3341)->i32;
      _checked_ptr_1<int> _ptr__3413(_3413 ? _3413->raw() : nullptr,_3413 ? _3413->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3414 = mosek::fusion::p_WorkStack::_get_impl(_3341)->i64;
      _checked_ptr_1<long long> _ptr__3414(_3414 ? _3414->raw() : nullptr,_3414 ? _3414->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3415 = mosek::fusion::p_WorkStack::_get_impl(_3341)->f64;
      _checked_ptr_1<double> _ptr__3415(_3415 ? _3415->raw() : nullptr,_3415 ? _3415->size(0) : 0);
      {
        _ptr__3413[_3408] = (int)0;
        int _3416 = (int)0;
        int _3417 = (int)0;
        int _8446 = (int)0;
        int _8447 = mdim0;
        for (int _3418 = _8446; _3418 < _8447; ++_3418)
        {
          {
            int _3419 = _ptr__3352[safe_add( safe_add( _3345,_3418 ),(int)1 )];
            int _3420 = _ptr__3352[safe_add( _3345,_3418 )];
            int _3421 = _ptr__3352[safe_add( safe_add( _3351,_3418 ),(int)1 )];
            int _3422 = _ptr__3352[safe_add( _3351,_3418 )];
            bool _3423 = false;
            double _3424 = 0.0;
            while ( ((_3422 < _3421) && (_3420 < _3419)) )
            {
              {
                int _3425 = _ptr__3352[safe_add( _3346,_3420 )];
                long long _3426 = (_ptr__3353[safe_add( _3365,_3425 )] / _3359);
                if ((((*msubj)(_3422)) < _3426))
                {
                  {
                    ++ _3422;
                  }
                }
                else if((((*msubj)(_3422)) > _3426))
                {
                  {
                    ++ _3420;
                  }
                }
                else
                {
                  {
                    _3423 = true;
                    int _8448 = _ptr__3352[safe_add( _3364,_3425 )];
                    int _8449 = _ptr__3352[safe_add( safe_add( _3364,_3425 ),(int)1 )];
                    for (int _3427 = _8448; _3427 < _8449; ++_3427)
                    {
                      {
                        _ptr__3414[safe_add( _3409,_3417 )] = _ptr__3353[safe_add( _3366,_3427 )];
                        _ptr__3415[safe_add( _3411,_3417 )] = (_ptr__3354[safe_add( _3368,_3427 )] * ((*mval)(_3422)));
                        ++ _3417;
                      }
                    }
                    _3424 += _ptr__3354[safe_add( _3367,_3425 )];
                    ++ _3422;
                    ++ _3420;
                  }
                }
              }
            }
            if (_3423)
            {
              {
                _ptr__3414[safe_add( _3410,_3416 )] = _3418;
                _ptr__3415[safe_add( _3412,_3416 )] = (_3424 * ((*mval)(_3422)));
                _ptr__3413[safe_add( safe_add( _3408,_3416 ),(int)1 )] = _3417;
                ++ _3416;
              }
            }
            {}
          }
        }
      }
      if ((!_3407))
      {
        {
          _3341->popi64(_3405);
        }
      }
      {}
    }
  }
}
int mosek::fusion::p_ExprMulDiagLeft::validate(int _3428,int _3429,std::shared_ptr< monty::ndarray< int,1 > > _3430,std::shared_ptr< monty::ndarray< int,1 > > _3431,std::shared_ptr< monty::ndarray< double,1 > > _3432,monty::rc_ptr< ::mosek::fusion::Expression > _3433){
  _checked_ptr_1<int> _ptr__3430(_3430 ? _3430->raw() : nullptr, _3430 ? _3430->size(0) : 0);
  _checked_ptr_1<int> _ptr__3431(_3431 ? _3431->raw() : nullptr, _3431 ? _3431->size(0) : 0);
  _checked_ptr_1<double> _ptr__3432(_3432 ? _3432->raw() : nullptr, _3432 ? _3432->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3434 = _3433->getShape();
  _checked_ptr_1<int> _ptr__3434(_3434 ? _3434->raw() : nullptr,_3434 ? _3434->size(0) : 0);
  if (((int)((_3434)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3435 = _ptr__3434[(int)0];
  int _3436 = _ptr__3434[(int)1];
  if (((_3428 < (int)0) || (_3429 < (int)0)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if (((_3429 != _3435) || (_3428 != _3436)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3430)->size(0)) != (int)((_3431)->size(0))) || ((int)((_3430)->size(0)) != (int)((_3432)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3437 = (int)((_3430)->size(0));
  bool _3438 = false;
  bool _3439 = false;
  {
    int _8450 = (int)0;
    int _8451 = _3437;
    for (int _3440 = _8450; _3440 < _8451; ++_3440)
    {
      {
        if (((_ptr__3430[_3440] < (int)0) || ((_ptr__3430[_3440] >= _3428) || ((_ptr__3431[_3440] < (int)0) || (_ptr__3431[_3440] >= _3429)))))
        {
          {
            _3438 = true;
          }
        }
        {}
      }
    }
    int _8452 = (int)0;
    int _8453 = (_3437 - (int)1);
    for (int _3441 = _8452; _3441 < _8453; ++_3441)
    {
      {
        if (((_ptr__3430[_3441] > _ptr__3430[safe_add( _3441,(int)1 )]) || ((_ptr__3430[_3441] == _ptr__3430[safe_add( _3441,(int)1 )]) && (_ptr__3431[_3441] >= _ptr__3431[safe_add( _3441,(int)1 )]))))
        {
          {
            _3439 = true;
          }
        }
        {}
      }
    }
  }
  if (_3438)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  if (_3439)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
    }
  }
  {}
  return (int)1;
}
std::string mosek::fusion::ExprMulDiagLeft :: toString() { return mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulDiagLeft::toString(){
  return std::string ("ExprMulDiagLeft()");
}
void mosek::fusion::p_ExprMulDiagLeft::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulDiagLeft::destroy() { mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->destroy(); }mosek::fusion::ExprMulElement::ExprMulElement(mosek::fusion::p_ExprMulElement *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulElement()" << this << std::endl; */ }mosek::fusion::ExprMulElement::~ExprMulElement() {  /* std::cout << "~ExprMulElement()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulElement::p_ExprMulElement  (::mosek::fusion::ExprMulElement * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulElement::t mosek::fusion::p_ExprMulElement::_new_ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3442,    std::shared_ptr< monty::ndarray< long long,1 > > _3443,    monty::rc_ptr< ::mosek::fusion::Expression > _3444){ return new mosek::fusion::ExprMulElement(_3442,_3443,_3444); }mosek::fusion::ExprMulElement::ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3442,    std::shared_ptr< monty::ndarray< long long,1 > > _3443,    monty::rc_ptr< ::mosek::fusion::Expression > _3444) :    ExprMulElement(new mosek::fusion::p_ExprMulElement(this)){ mosek::fusion::p_ExprMulElement::_get_impl(this)->_initialize(_3442,_3443,_3444); }void mosek::fusion::p_ExprMulElement::_initialize  (std::shared_ptr< monty::ndarray< double,1 > > _3442,    std::shared_ptr< monty::ndarray< long long,1 > > _3443,    monty::rc_ptr< ::mosek::fusion::Expression > _3444){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3442(_3442 ? _3442->raw() : nullptr, _3442 ? _3442->size(0) : 0);
    _checked_ptr_1<long long> _ptr__3443(_3443 ? _3443->raw() : nullptr, _3443 ? _3443->size(0) : 0);
    mosek::fusion::p_ExprMulElement::_initialize(_3442,_3443,_3444,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _3445 = _3444->getShape();
    _checked_ptr_1<int> _ptr__3445(_3445 ? _3445->raw() : nullptr,_3445 ? _3445->size(0) : 0);
    if (((int)((_3442)->size(0)) != (int)((_3443)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid matrix specification"));
      }
    }
    {}
    long long _3446 = ::mosek::fusion::p_Set::size(_3445);
    bool _3447 = false;
    bool _3448 = false;
    {
      int _8454 = (int)0;
      int _8455 = (int)((_3443)->size(0));
      for (int _3449 = _8454; _3449 < _8455; ++_3449)
      {
        {
          if (((_ptr__3443[_3449] < (int)0) || (_ptr__3443[_3449] >= _3446)))
          {
            {
              _3447 = true;
            }
          }
          {}
        }
      }
      int _8456 = (int)0;
      int _8457 = ((int)((_3443)->size(0)) - (int)1);
      for (int _3450 = _8456; _3450 < _8457; ++_3450)
      {
        {
          if ((_ptr__3443[_3450] >= _ptr__3443[safe_add( _3450,(int)1 )]))
          {
            {
              _3448 = true;
            }
          }
          {}
        }
      }
    }
    if (_3447)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Invalid matrix data"));
      }
    }
    {}
    if (_3448)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Matrix data not sorted"));
      }
    }
    {}
  }
}mosek::fusion::ExprMulElement::t mosek::fusion::p_ExprMulElement::_new_ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3451,    std::shared_ptr< monty::ndarray< long long,1 > > _3452,    monty::rc_ptr< ::mosek::fusion::Expression > _3453,    int _3454){ return new mosek::fusion::ExprMulElement(_3451,_3452,_3453,_3454); }mosek::fusion::ExprMulElement::ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3451,    std::shared_ptr< monty::ndarray< long long,1 > > _3452,    monty::rc_ptr< ::mosek::fusion::Expression > _3453,    int _3454) :    ExprMulElement(new mosek::fusion::p_ExprMulElement(this)){ mosek::fusion::p_ExprMulElement::_get_impl(this)->_initialize(_3451,_3452,_3453,_3454); }void mosek::fusion::p_ExprMulElement::_initialize  (std::shared_ptr< monty::ndarray< double,1 > > _3451,    std::shared_ptr< monty::ndarray< long long,1 > > _3452,    monty::rc_ptr< ::mosek::fusion::Expression > _3453,    int _3454){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3451(_3451 ? _3451->raw() : nullptr, _3451 ? _3451->size(0) : 0);
    _checked_ptr_1<long long> _ptr__3452(_3452 ? _3452->raw() : nullptr, _3452 ? _3452->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_3453->getShape());
    mosek::fusion::p_ExprMulElement::_get_impl(::mosek::fusion::ExprMulElement::t(_pubthis))->expr = _3453;
    mosek::fusion::p_ExprMulElement::_get_impl(::mosek::fusion::ExprMulElement::t(_pubthis))->mcof = _3451;
    mosek::fusion::p_ExprMulElement::_get_impl(::mosek::fusion::ExprMulElement::t(_pubthis))->msp = _3452;
  }
}void mosek::fusion::ExprMulElement :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3455,monty::rc_ptr< ::mosek::fusion::WorkStack > _3456,monty::rc_ptr< ::mosek::fusion::WorkStack > _3457) { mosek::fusion::p_ExprMulElement::_get_impl(this)->eval(_3455,_3456,_3457); }void mosek::fusion::p_ExprMulElement::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3455,monty::rc_ptr< ::mosek::fusion::WorkStack > _3456,monty::rc_ptr< ::mosek::fusion::WorkStack > _3457){
  expr->eval(_3456,_3455,_3457);
  int _3458 = _3456->popi32();
  int _3459 = _3456->popi32(_3458);
  int _3460 = _3456->popi32();
  int _3461 = _3456->popi32();
  bool _3462 = (_3456->popi32() != (int)0);
  int _3463 = _3456->popi32(safe_add( _3460,(int)1 ));
  int _8458;
  bool _8459 = _3462;
  if (_8459)
  {
    _8458 = _3456->popi64(_3460);
  }
  else
  {
    _8458 = (-(int)1);
  }
  int _3464 = _8458;
  int _3465 = _3456->popi64(_3461);
  int _3466 = _3456->popf64(_3460);
  int _3467 = _3456->popf64(_3461);
  std::shared_ptr< monty::ndarray< int,1 > > _3468 = mosek::fusion::p_WorkStack::_get_impl(_3456)->i32;
  _checked_ptr_1<int> _ptr__3468(_3468 ? _3468->raw() : nullptr,_3468 ? _3468->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3469 = mosek::fusion::p_WorkStack::_get_impl(_3456)->i64;
  _checked_ptr_1<long long> _ptr__3469(_3469 ? _3469->raw() : nullptr,_3469 ? _3469->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3470 = mosek::fusion::p_WorkStack::_get_impl(_3456)->f64;
  _checked_ptr_1<double> _ptr__3470(_3470 ? _3470->raw() : nullptr,_3470 ? _3470->size(0) : 0);
  int _3471 = (int)0;
  int _3472 = (int)0;
  if ((!_3462))
  {
    {
      _3472 = (int)((msp)->size(0));
      int _8460 = (int)0;
      int _8461 = (int)((msp)->size(0));
      for (int _3473 = _8460; _3473 < _8461; ++_3473)
      {
        {
          _3471 += (_ptr__3468[safe_add( safe_add( _3463,((*msp)(_3473)) ),(int)1 )] - _ptr__3468[safe_add( _3463,((*msp)(_3473)) )]);
        }
      }
    }
  }
  else
  {
    {
      int _3474 = (int)((msp)->size(0));
      int _3475 = (int)0;
      int _3476 = _3460;
      int _3477 = (int)0;
      while ( ((_3475 < _3474) && (_3477 < _3476)) )
      {
        {
          if ((((*msp)(_3475)) < _ptr__3469[safe_add( _3464,_3477 )]))
          {
            {
              ++ _3475;
            }
          }
          else if((((*msp)(_3475)) > _ptr__3469[safe_add( _3464,_3477 )]))
          {
            {
              ++ _3477;
            }
          }
          else
          {
            {
              _3471 += (_ptr__3468[safe_add( safe_add( _3463,_3477 ),(int)1 )] - _ptr__3468[safe_add( _3463,_3477 )]);
              ++ _3475;
              ++ _3477;
              ++ _3472;
            }
          }
        }
      }
    }
  }
  int _3478 = _3455->alloci32(safe_add( _3472,(int)1 ));
  int _3479 = _3455->alloci64(_3471);
  int _3480 = _3455->alloci64(_3472);
  int _3481 = _3455->allocf64(_3471);
  int _3482 = _3455->allocf64(_3472);
  int _3483 = (int)1;
  int _8462 = (int)0;
  int _8463 = _3458;
  for (int _3484 = _8462; _3484 < _8463; ++_3484)
  {
    {
      _3483 *= _ptr__3468[safe_add( _3459,_3484 )];
    }
  }
  bool _3485 = (_3472 < _3483);
  int _8464;
  bool _8465 = _3485;
  if (_8465)
  {
    _8464 = (int)1;
  }
  else
  {
    _8464 = (int)0;
  }
  _3455->pushi32(_8464);
  _3455->pushi32(_3471);
  _3455->pushi32(_3472);
  int _3486 = _3455->alloci32(_3458);
  _3455->pushi32(_3458);
  std::shared_ptr< monty::ndarray< int,1 > > _3487 = mosek::fusion::p_WorkStack::_get_impl(_3455)->i32;
  _checked_ptr_1<int> _ptr__3487(_3487 ? _3487->raw() : nullptr,_3487 ? _3487->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3488 = mosek::fusion::p_WorkStack::_get_impl(_3455)->i64;
  _checked_ptr_1<long long> _ptr__3488(_3488 ? _3488->raw() : nullptr,_3488 ? _3488->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3489 = mosek::fusion::p_WorkStack::_get_impl(_3455)->f64;
  _checked_ptr_1<double> _ptr__3489(_3489 ? _3489->raw() : nullptr,_3489 ? _3489->size(0) : 0);
  {
    int _3490 = (int)0;
    int _3491 = (int)0;
    _ptr__3487[_3478] = (int)0;
    int _8466 = (int)0;
    int _8467 = _3458;
    for (int _3492 = _8466; _3492 < _8467; ++_3492)
    {
      {
        _ptr__3487[safe_add( _3486,_3492 )] = _ptr__3468[safe_add( _3459,_3492 )];
      }
    }
    if ((!_3462))
    {
      {
        int _8468 = (int)0;
        int _8469 = (int)((msp)->size(0));
        for (int _3493 = _8468; _3493 < _8469; ++_3493)
        {
          {
            int _3494 = _ptr__3468[safe_add( _3463,((*msp)(_3493)) )];
            int _3495 = _ptr__3468[safe_add( safe_add( _3463,((*msp)(_3493)) ),(int)1 )];
            int _8470 = _3494;
            int _8471 = _3495;
            for (int _3496 = _8470; _3496 < _8471; ++_3496)
            {
              {
                _ptr__3488[safe_add( _3479,_3491 )] = _ptr__3469[safe_add( _3465,_3496 )];
                _ptr__3489[safe_add( _3481,_3491 )] = (_ptr__3470[safe_add( _3467,_3496 )] * ((*mcof)(_3493)));
                ++ _3491;
              }
            }
            _ptr__3487[safe_add( safe_add( _3478,_3493 ),(int)1 )] = _3491;
            _ptr__3489[safe_add( _3482,_3493 )] = (_ptr__3470[safe_add( _3466,((*msp)(_3493)) )] * ((*mcof)(_3493)));
            _ptr__3488[safe_add( _3480,_3493 )] = ((*msp)(_3493));
          }
        }
      }
    }
    else
    {
      {
        int _3497 = (int)((msp)->size(0));
        int _3498 = (int)0;
        int _3499 = _3460;
        int _3500 = (int)0;
        while ( ((_3498 < _3497) && (_3500 < _3499)) )
        {
          {
            if ((((*msp)(_3498)) < _ptr__3469[safe_add( _3464,_3500 )]))
            {
              {
                ++ _3498;
              }
            }
            else if((((*msp)(_3498)) > _ptr__3469[safe_add( _3464,_3500 )]))
            {
              {
                ++ _3500;
              }
            }
            else
            {
              {
                int _3501 = _ptr__3468[safe_add( _3463,_3500 )];
                int _3502 = _ptr__3468[safe_add( safe_add( _3463,_3500 ),(int)1 )];
                int _8472 = _3501;
                int _8473 = _3502;
                for (int _3503 = _8472; _3503 < _8473; ++_3503)
                {
                  {
                    _ptr__3488[safe_add( _3479,_3491 )] = _ptr__3469[safe_add( _3465,_3503 )];
                    _ptr__3489[safe_add( _3479,_3491 )] = (_ptr__3470[safe_add( _3465,_3503 )] * ((*mcof)(_3498)));
                    ++ _3491;
                  }
                }
                _ptr__3487[safe_add( safe_add( _3478,_3490 ),(int)1 )] = _3491;
                _ptr__3489[safe_add( _3482,_3490 )] = (_ptr__3470[safe_add( _3466,_3500 )] * ((*mcof)(_3498)));
                _ptr__3488[safe_add( _3480,_3490 )] = ((*msp)(_3498));
                ++ _3490;
                ++ _3498;
                ++ _3500;
              }
            }
          }
        }
      }
    }
  }
  if ((!_3485))
  {
    {
      _3455->popi64(_3472);
    }
  }
  {}
}
std::string mosek::fusion::ExprMulElement :: toString() { return mosek::fusion::p_ExprMulElement::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulElement::toString(){
  return std::string ("ExprMulElement()");
}
void mosek::fusion::p_ExprMulElement::destroy(){expr.reset();msp.reset();mcof.reset();}void mosek::fusion::ExprMulElement::destroy() { mosek::fusion::p_ExprMulElement::_get_impl(this)->destroy(); }mosek::fusion::ExprMulScalarConst::ExprMulScalarConst(mosek::fusion::p_ExprMulScalarConst *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulScalarConst()" << this << std::endl; */ }mosek::fusion::ExprMulScalarConst::~ExprMulScalarConst() {  /* std::cout << "~ExprMulScalarConst()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulScalarConst::p_ExprMulScalarConst  (::mosek::fusion::ExprMulScalarConst * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulScalarConst::t mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst  (double _3504,    monty::rc_ptr< ::mosek::fusion::Expression > _3505){ return new mosek::fusion::ExprMulScalarConst(_3504,_3505); }mosek::fusion::ExprMulScalarConst::ExprMulScalarConst  (double _3504,    monty::rc_ptr< ::mosek::fusion::Expression > _3505) :    ExprMulScalarConst(new mosek::fusion::p_ExprMulScalarConst(this)){ mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->_initialize(_3504,_3505); }void mosek::fusion::p_ExprMulScalarConst::_initialize  (double _3504,    monty::rc_ptr< ::mosek::fusion::Expression > _3505){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_3505->getShape());
    mosek::fusion::p_ExprMulScalarConst::_get_impl(::mosek::fusion::ExprMulScalarConst::t(_pubthis))->c = _3504;
    mosek::fusion::p_ExprMulScalarConst::_get_impl(::mosek::fusion::ExprMulScalarConst::t(_pubthis))->expr = _3505;
  }
}void mosek::fusion::ExprMulScalarConst :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3506,monty::rc_ptr< ::mosek::fusion::WorkStack > _3507,monty::rc_ptr< ::mosek::fusion::WorkStack > _3508) { mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->eval(_3506,_3507,_3508); }void mosek::fusion::p_ExprMulScalarConst::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3506,monty::rc_ptr< ::mosek::fusion::WorkStack > _3507,monty::rc_ptr< ::mosek::fusion::WorkStack > _3508){
  expr->eval(_3506,_3507,_3508);
  int _3509 = _3506->peeki32((int)0);
  int _3510 = _3506->peeki32(safe_add( _3509,(int)1 ));
  int _3511 = _3506->peeki32(safe_add( _3509,(int)2 ));
  int _3512 = (mosek::fusion::p_WorkStack::_get_impl(_3506)->pf64 - _3510);
  int _3513 = (_3512 - _3511);
  std::shared_ptr< monty::ndarray< double,1 > > _3514 = mosek::fusion::p_WorkStack::_get_impl(_3506)->f64;
  _checked_ptr_1<double> _ptr__3514(_3514 ? _3514->raw() : nullptr,_3514 ? _3514->size(0) : 0);
  int _8474 = (int)0;
  int _8475 = safe_add( _3511,_3510 );
  for (int _3515 = _8474; _3515 < _8475; ++_3515)
  {
    {
      _ptr__3514[safe_add( _3513,_3515 )] *= c;
    }
  }
}
std::string mosek::fusion::ExprMulScalarConst :: toString() { return mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulScalarConst::toString(){
  return std::string ("ExprMulScalarConst()");
}
void mosek::fusion::p_ExprMulScalarConst::destroy(){expr.reset();}void mosek::fusion::ExprMulScalarConst::destroy() { mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->destroy(); }mosek::fusion::ExprScalarMul::ExprScalarMul(mosek::fusion::p_ExprScalarMul *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprScalarMul()" << this << std::endl; */ }mosek::fusion::ExprScalarMul::~ExprScalarMul() {  /* std::cout << "~ExprScalarMul()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprScalarMul::p_ExprScalarMul  (::mosek::fusion::ExprScalarMul * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprScalarMul::t mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul  (int _3516,    int _3517,    std::shared_ptr< monty::ndarray< int,1 > > _3518,    std::shared_ptr< monty::ndarray< int,1 > > _3519,    std::shared_ptr< monty::ndarray< double,1 > > _3520,    monty::rc_ptr< ::mosek::fusion::Expression > _3521,    int _3522){ return new mosek::fusion::ExprScalarMul(_3516,_3517,_3518,_3519,_3520,_3521,_3522); }mosek::fusion::ExprScalarMul::ExprScalarMul  (int _3516,    int _3517,    std::shared_ptr< monty::ndarray< int,1 > > _3518,    std::shared_ptr< monty::ndarray< int,1 > > _3519,    std::shared_ptr< monty::ndarray< double,1 > > _3520,    monty::rc_ptr< ::mosek::fusion::Expression > _3521,    int _3522) :    ExprScalarMul(new mosek::fusion::p_ExprScalarMul(this)){ mosek::fusion::p_ExprScalarMul::_get_impl(this)->_initialize(_3516,_3517,_3518,_3519,_3520,_3521,_3522); }void mosek::fusion::p_ExprScalarMul::_initialize  (int _3516,    int _3517,    std::shared_ptr< monty::ndarray< int,1 > > _3518,    std::shared_ptr< monty::ndarray< int,1 > > _3519,    std::shared_ptr< monty::ndarray< double,1 > > _3520,    monty::rc_ptr< ::mosek::fusion::Expression > _3521,    int _3522){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3518(_3518 ? _3518->raw() : nullptr, _3518 ? _3518->size(0) : 0);
    _checked_ptr_1<int> _ptr__3519(_3519 ? _3519->raw() : nullptr, _3519 ? _3519->size(0) : 0);
    _checked_ptr_1<double> _ptr__3520(_3520 ? _3520->raw() : nullptr, _3520 ? _3520->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3516),(int)(_3517)}));
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->mdim0 = _3516;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->mdim1 = _3517;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->msubi = _3518;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->msubj = _3519;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->mval = _3520;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->expr = _3521;
  }
}mosek::fusion::ExprScalarMul::t mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul  (int _3523,    int _3524,    std::shared_ptr< monty::ndarray< int,1 > > _3525,    std::shared_ptr< monty::ndarray< int,1 > > _3526,    std::shared_ptr< monty::ndarray< double,1 > > _3527,    monty::rc_ptr< ::mosek::fusion::Expression > _3528){ return new mosek::fusion::ExprScalarMul(_3523,_3524,_3525,_3526,_3527,_3528); }mosek::fusion::ExprScalarMul::ExprScalarMul  (int _3523,    int _3524,    std::shared_ptr< monty::ndarray< int,1 > > _3525,    std::shared_ptr< monty::ndarray< int,1 > > _3526,    std::shared_ptr< monty::ndarray< double,1 > > _3527,    monty::rc_ptr< ::mosek::fusion::Expression > _3528) :    ExprScalarMul(new mosek::fusion::p_ExprScalarMul(this)){ mosek::fusion::p_ExprScalarMul::_get_impl(this)->_initialize(_3523,_3524,_3525,_3526,_3527,_3528); }void mosek::fusion::p_ExprScalarMul::_initialize  (int _3523,    int _3524,    std::shared_ptr< monty::ndarray< int,1 > > _3525,    std::shared_ptr< monty::ndarray< int,1 > > _3526,    std::shared_ptr< monty::ndarray< double,1 > > _3527,    monty::rc_ptr< ::mosek::fusion::Expression > _3528){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3525(_3525 ? _3525->raw() : nullptr, _3525 ? _3525->size(0) : 0);
    _checked_ptr_1<int> _ptr__3526(_3526 ? _3526->raw() : nullptr, _3526 ? _3526->size(0) : 0);
    _checked_ptr_1<double> _ptr__3527(_3527 ? _3527->raw() : nullptr, _3527 ? _3527->size(0) : 0);
    mosek::fusion::p_ExprScalarMul::_initialize(_3523,_3524,_3525,_3526,_3527,_3528,::mosek::fusion::p_ExprScalarMul::validate(_3523,_3524,_3525,_3526,_3527,_3528));
  }
}void mosek::fusion::ExprScalarMul :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3529,monty::rc_ptr< ::mosek::fusion::WorkStack > _3530,monty::rc_ptr< ::mosek::fusion::WorkStack > _3531) { mosek::fusion::p_ExprScalarMul::_get_impl(this)->eval(_3529,_3530,_3531); }void mosek::fusion::p_ExprScalarMul::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3529,monty::rc_ptr< ::mosek::fusion::WorkStack > _3530,monty::rc_ptr< ::mosek::fusion::WorkStack > _3531){
  mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->expr->eval(_3530,_3529,_3531);
  _3530->pop_expr();
  int _3532 = mosek::fusion::p_WorkStack::_get_impl(_3530)->nd;
  int _3533 = mosek::fusion::p_WorkStack::_get_impl(_3530)->nelem;
  int _3534 = mosek::fusion::p_WorkStack::_get_impl(_3530)->nnz;
  bool _3535 = mosek::fusion::p_WorkStack::_get_impl(_3530)->hassp;
  int _3536 = mosek::fusion::p_WorkStack::_get_impl(_3530)->ptr_base;
  int _3537 = mosek::fusion::p_WorkStack::_get_impl(_3530)->sp_base;
  int _3538 = mosek::fusion::p_WorkStack::_get_impl(_3530)->nidxs_base;
  int _3539 = mosek::fusion::p_WorkStack::_get_impl(_3530)->bfix_base;
  int _3540 = mosek::fusion::p_WorkStack::_get_impl(_3530)->cof_base;
  std::shared_ptr< monty::ndarray< long long,1 > > _3541 = mosek::fusion::p_WorkStack::_get_impl(_3530)->i64;
  _checked_ptr_1<long long> _ptr__3541(_3541 ? _3541->raw() : nullptr,_3541 ? _3541->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3542 = mosek::fusion::p_WorkStack::_get_impl(_3530)->f64;
  _checked_ptr_1<double> _ptr__3542(_3542 ? _3542->raw() : nullptr,_3542 ? _3542->size(0) : 0);
  int _3543 = (int)((mval)->size(0));
  if ((_3532 != (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid expression shape"));
    }
  }
  {}
  if ((_3533 == (int)0))
  {
    {
      _3529->alloc_expr((int)2,(int)0,(int)0,true);
      ((*mosek::fusion::p_WorkStack::_get_impl(_3529)->i32)(mosek::fusion::p_WorkStack::_get_impl(_3529)->shape_base)) = mdim0;
      ((*mosek::fusion::p_WorkStack::_get_impl(_3529)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_3529)->shape_base,(int)1 ))) = mdim1;
    }
  }
  else
  {
    {
      _3529->alloc_expr((int)2,_3543,safe_mul( _3543,_3534 ),true);
      int _3544 = mosek::fusion::p_WorkStack::_get_impl(_3529)->ptr_base;
      int _3545 = mosek::fusion::p_WorkStack::_get_impl(_3529)->nidxs_base;
      int _3546 = mosek::fusion::p_WorkStack::_get_impl(_3529)->sp_base;
      int _3547 = mosek::fusion::p_WorkStack::_get_impl(_3529)->cof_base;
      int _3548 = mosek::fusion::p_WorkStack::_get_impl(_3529)->bfix_base;
      int _3549 = mosek::fusion::p_WorkStack::_get_impl(_3529)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _3550 = mosek::fusion::p_WorkStack::_get_impl(_3529)->i32;
      _checked_ptr_1<int> _ptr__3550(_3550 ? _3550->raw() : nullptr,_3550 ? _3550->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3551 = mosek::fusion::p_WorkStack::_get_impl(_3529)->i64;
      _checked_ptr_1<long long> _ptr__3551(_3551 ? _3551->raw() : nullptr,_3551 ? _3551->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3552 = mosek::fusion::p_WorkStack::_get_impl(_3529)->f64;
      _checked_ptr_1<double> _ptr__3552(_3552 ? _3552->raw() : nullptr,_3552 ? _3552->size(0) : 0);
      _ptr__3550[_3549] = mdim0;
      _ptr__3550[safe_add( _3549,(int)1 )] = mdim1;
      int _3553 = (int)0;
      _ptr__3550[_3544] = (int)0;
      int _8476 = (int)0;
      int _8477 = _3543;
      for (int _3554 = _8476; _3554 < _8477; ++_3554)
      {
        {
          int _8478 = (int)0;
          int _8479 = _3534;
          for (int _3555 = _8478; _3555 < _8479; ++_3555)
          {
            {
              _ptr__3551[safe_add( _3545,_3553 )] = _ptr__3541[safe_add( _3538,_3555 )];
              _ptr__3552[safe_add( _3547,_3553 )] = (_ptr__3542[safe_add( _3540,_3555 )] * ((*mval)(_3554)));
              ++ _3553;
            }
          }
          _ptr__3551[safe_add( _3546,_3554 )] = safe_add( safe_mul( ((*msubi)(_3554)),mdim1 ),((*msubj)(_3554)) );
          _ptr__3552[safe_add( _3548,_3554 )] = (((*mval)(_3554)) * _ptr__3542[_3539]);
          _ptr__3550[safe_add( safe_add( _3544,_3554 ),(int)1 )] = _3553;
        }
      }
    }
  }
}
int mosek::fusion::p_ExprScalarMul::validate(int _3556,int _3557,std::shared_ptr< monty::ndarray< int,1 > > _3558,std::shared_ptr< monty::ndarray< int,1 > > _3559,std::shared_ptr< monty::ndarray< double,1 > > _3560,monty::rc_ptr< ::mosek::fusion::Expression > _3561){
  _checked_ptr_1<int> _ptr__3558(_3558 ? _3558->raw() : nullptr, _3558 ? _3558->size(0) : 0);
  _checked_ptr_1<int> _ptr__3559(_3559 ? _3559->raw() : nullptr, _3559 ? _3559->size(0) : 0);
  _checked_ptr_1<double> _ptr__3560(_3560 ? _3560->raw() : nullptr, _3560 ? _3560->size(0) : 0);
  int _3562 = _3561->getND();
  if ((_3562 != (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if (((_3556 < (int)0) || (_3557 < (int)0)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if ((((int)((_3558)->size(0)) != (int)((_3559)->size(0))) || ((int)((_3558)->size(0)) != (int)((_3560)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3563 = (int)((_3558)->size(0));
  bool _3564 = false;
  bool _3565 = false;
  {
    int _8480 = (int)0;
    int _8481 = _3563;
    for (int _3566 = _8480; _3566 < _8481; ++_3566)
    {
      {
        if (((_ptr__3558[_3566] < (int)0) || ((_ptr__3558[_3566] >= _3556) || ((_ptr__3559[_3566] < (int)0) || (_ptr__3559[_3566] >= _3557)))))
        {
          {
            _3564 = true;
          }
        }
        {}
      }
    }
    int _8482 = (int)0;
    int _8483 = (_3563 - (int)1);
    for (int _3567 = _8482; _3567 < _8483; ++_3567)
    {
      {
        if (((_ptr__3558[_3567] > _ptr__3558[safe_add( _3567,(int)1 )]) || ((_ptr__3558[_3567] == _ptr__3558[safe_add( _3567,(int)1 )]) && (_ptr__3559[_3567] >= _ptr__3559[safe_add( _3567,(int)1 )]))))
        {
          {
            _3565 = true;
          }
        }
        {}
      }
    }
  }
  if (_3564)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  if (_3565)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
    }
  }
  {}
  return (int)1;
}
std::string mosek::fusion::ExprScalarMul :: toString() { return mosek::fusion::p_ExprScalarMul::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprScalarMul::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprScalarMul(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprScalarMul::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprScalarMul::destroy() { mosek::fusion::p_ExprScalarMul::_get_impl(this)->destroy(); }mosek::fusion::ExprMulRight::ExprMulRight(mosek::fusion::p_ExprMulRight *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulRight()" << this << std::endl; */ }mosek::fusion::ExprMulRight::~ExprMulRight() {  /* std::cout << "~ExprMulRight()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulRight::p_ExprMulRight  (::mosek::fusion::ExprMulRight * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulRight::t mosek::fusion::p_ExprMulRight::_new_ExprMulRight  (int _3568,    int _3569,    std::shared_ptr< monty::ndarray< int,1 > > _3570,    std::shared_ptr< monty::ndarray< int,1 > > _3571,    std::shared_ptr< monty::ndarray< double,1 > > _3572,    monty::rc_ptr< ::mosek::fusion::Expression > _3573,    int _3574){ return new mosek::fusion::ExprMulRight(_3568,_3569,_3570,_3571,_3572,_3573,_3574); }mosek::fusion::ExprMulRight::ExprMulRight  (int _3568,    int _3569,    std::shared_ptr< monty::ndarray< int,1 > > _3570,    std::shared_ptr< monty::ndarray< int,1 > > _3571,    std::shared_ptr< monty::ndarray< double,1 > > _3572,    monty::rc_ptr< ::mosek::fusion::Expression > _3573,    int _3574) :    ExprMulRight(new mosek::fusion::p_ExprMulRight(this)){ mosek::fusion::p_ExprMulRight::_get_impl(this)->_initialize(_3568,_3569,_3570,_3571,_3572,_3573,_3574); }void mosek::fusion::p_ExprMulRight::_initialize  (int _3568,    int _3569,    std::shared_ptr< monty::ndarray< int,1 > > _3570,    std::shared_ptr< monty::ndarray< int,1 > > _3571,    std::shared_ptr< monty::ndarray< double,1 > > _3572,    monty::rc_ptr< ::mosek::fusion::Expression > _3573,    int _3574){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3570(_3570 ? _3570->raw() : nullptr, _3570 ? _3570->size(0) : 0);
    _checked_ptr_1<int> _ptr__3571(_3571 ? _3571->raw() : nullptr, _3571 ? _3571->size(0) : 0);
    _checked_ptr_1<double> _ptr__3572(_3572 ? _3572->raw() : nullptr, _3572 ? _3572->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprMulRight::computeshape(_3569,_3573->getShape()));
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->mdim0 = _3568;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->mdim1 = _3569;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->msubi = _3570;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->msubj = _3571;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->mval = _3572;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->expr = _3573;
  }
}mosek::fusion::ExprMulRight::t mosek::fusion::p_ExprMulRight::_new_ExprMulRight  (int _3575,    int _3576,    std::shared_ptr< monty::ndarray< int,1 > > _3577,    std::shared_ptr< monty::ndarray< int,1 > > _3578,    std::shared_ptr< monty::ndarray< double,1 > > _3579,    monty::rc_ptr< ::mosek::fusion::Expression > _3580){ return new mosek::fusion::ExprMulRight(_3575,_3576,_3577,_3578,_3579,_3580); }mosek::fusion::ExprMulRight::ExprMulRight  (int _3575,    int _3576,    std::shared_ptr< monty::ndarray< int,1 > > _3577,    std::shared_ptr< monty::ndarray< int,1 > > _3578,    std::shared_ptr< monty::ndarray< double,1 > > _3579,    monty::rc_ptr< ::mosek::fusion::Expression > _3580) :    ExprMulRight(new mosek::fusion::p_ExprMulRight(this)){ mosek::fusion::p_ExprMulRight::_get_impl(this)->_initialize(_3575,_3576,_3577,_3578,_3579,_3580); }void mosek::fusion::p_ExprMulRight::_initialize  (int _3575,    int _3576,    std::shared_ptr< monty::ndarray< int,1 > > _3577,    std::shared_ptr< monty::ndarray< int,1 > > _3578,    std::shared_ptr< monty::ndarray< double,1 > > _3579,    monty::rc_ptr< ::mosek::fusion::Expression > _3580){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3577(_3577 ? _3577->raw() : nullptr, _3577 ? _3577->size(0) : 0);
    _checked_ptr_1<int> _ptr__3578(_3578 ? _3578->raw() : nullptr, _3578 ? _3578->size(0) : 0);
    _checked_ptr_1<double> _ptr__3579(_3579 ? _3579->raw() : nullptr, _3579 ? _3579->size(0) : 0);
    mosek::fusion::p_ExprMulRight::_initialize(_3575,_3576,_3577,_3578,_3579,_3580,::mosek::fusion::p_ExprMulRight::validate(_3575,_3576,_3577,_3578,_3579,_3580));
  }
}void mosek::fusion::ExprMulRight :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3581,monty::rc_ptr< ::mosek::fusion::WorkStack > _3582,monty::rc_ptr< ::mosek::fusion::WorkStack > _3583) { mosek::fusion::p_ExprMulRight::_get_impl(this)->eval(_3581,_3582,_3583); }void mosek::fusion::p_ExprMulRight::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3581,monty::rc_ptr< ::mosek::fusion::WorkStack > _3582,monty::rc_ptr< ::mosek::fusion::WorkStack > _3583){
  mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->expr->eval(_3582,_3581,_3583);
  _3582->peek_expr();
  int _3584 = mosek::fusion::p_WorkStack::_get_impl(_3582)->nd;
  bool _3585 = mosek::fusion::p_WorkStack::_get_impl(_3582)->hassp;
  int _3586 = (int)((mval)->size(0));
  bool _3587 = (_3586 < safe_mul( (long long)mdim0,(long long)mdim1 ));
  int _3588 = ((*mosek::fusion::p_WorkStack::_get_impl(_3582)->i32)(mosek::fusion::p_WorkStack::_get_impl(_3582)->shape_base));
  if (_3587)
  {
    {
      int _3589 = _3582->alloci32(safe_add( mdim1,(int)1 ));
      int _3590 = _3582->alloci32(_3586);
      int _3591 = _3582->alloci32(safe_add( _3588,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _3592 = mosek::fusion::p_WorkStack::_get_impl(_3582)->i32;
      _checked_ptr_1<int> _ptr__3592(_3592 ? _3592->raw() : nullptr,_3592 ? _3592->size(0) : 0);
      int _8484 = (int)0;
      int _8485 = safe_add( mdim1,(int)1 );
      for (int _3593 = _8484; _3593 < _8485; ++_3593)
      {
        {
          _ptr__3592[safe_add( _3589,_3593 )] = (int)0;
        }
      }
      int _8486 = (int)0;
      int _8487 = _3586;
      for (int _3594 = _8486; _3594 < _8487; ++_3594)
      {
        {
          ++ _ptr__3592[safe_add( safe_add( _3589,((*msubj)(_3594)) ),(int)1 )];
        }
      }
      int _8488 = (int)0;
      int _8489 = mdim1;
      for (int _3595 = _8488; _3595 < _8489; ++_3595)
      {
        {
          _ptr__3592[safe_add( safe_add( _3589,_3595 ),(int)1 )] += _ptr__3592[safe_add( _3589,_3595 )];
        }
      }
      int _8490 = (int)0;
      int _8491 = _3586;
      for (int _3596 = _8490; _3596 < _8491; ++_3596)
      {
        {
          _ptr__3592[safe_add( _3590,_3596 )] = _ptr__3592[safe_add( _3589,((*msubj)(_3596)) )];
          ++ _ptr__3592[safe_add( _3589,((*msubj)(_3596)) )];
        }
      }
      int _8492 = (int)0;
      int _8493 = mdim1;
      for (int _3597 = _8492; _3597 < _8493; ++_3597)
      {
        {
          _ptr__3592[(safe_add( _3589,mdim1 ) - _3597)] = _ptr__3592[((safe_add( _3589,mdim1 ) - _3597) - (int)1)];
        }
      }
      _ptr__3592[_3589] = (int)0;
      int _8494 = (int)0;
      int _8495 = safe_add( _3588,(int)1 );
      for (int _3598 = _8494; _3598 < _8495; ++_3598)
      {
        {
          _ptr__3592[safe_add( _3591,_3598 )] = (int)0;
        }
      }
      _3582->popi32(safe_add( safe_add( safe_add( _3588,mdim1 ),(int)2 ),_3586 ));
      int _3599 = _3582->popi32();
      if ((_3599 != (int)2))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
        }
      }
      {}
      int _3600 = _3582->popi32();
      int _3601 = _3582->popi32();
      int _3602 = _3582->popi32();
      int _3603 = _3582->popi32();
      bool _3604 = (_3582->popi32() != (int)0);
      int _3605 = _3582->popi32(safe_add( _3602,(int)1 ));
      int _8496;
      bool _8497 = _3604;
      if (_8497)
      {
        _8496 = _3582->popi64(_3602);
      }
      else
      {
        _8496 = (int)999999;
      }
      int _3606 = _8496;
      int _3607 = _3582->popi64(_3603);
      int _3608 = _3582->popf64(_3602);
      int _3609 = _3582->popf64(_3603);
      std::shared_ptr< monty::ndarray< int,1 > > _3610 = mosek::fusion::p_WorkStack::_get_impl(_3582)->i32;
      _checked_ptr_1<int> _ptr__3610(_3610 ? _3610->raw() : nullptr,_3610 ? _3610->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3611 = mosek::fusion::p_WorkStack::_get_impl(_3582)->i64;
      _checked_ptr_1<long long> _ptr__3611(_3611 ? _3611->raw() : nullptr,_3611 ? _3611->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3612 = mosek::fusion::p_WorkStack::_get_impl(_3582)->f64;
      _checked_ptr_1<double> _ptr__3612(_3612 ? _3612->raw() : nullptr,_3612 ? _3612->size(0) : 0);
      if (_3604)
      {
        {
          int _8498 = (int)0;
          int _8499 = _3602;
          for (int _3613 = _8498; _3613 < _8499; ++_3613)
          {
            {
              ++ _ptr__3610[safe_add( safe_add( _3591,(_ptr__3611[safe_add( _3606,_3613 )] / _3600) ),(int)1 )];
            }
          }
          int _8500 = (int)0;
          int _8501 = _3601;
          for (int _3614 = _8500; _3614 < _8501; ++_3614)
          {
            {
              _ptr__3610[safe_add( safe_add( _3591,_3614 ),(int)1 )] += _ptr__3610[safe_add( _3591,_3614 )];
            }
          }
          int _3615 = (int)0;
          int _3616 = (int)0;
          int _8502 = (int)0;
          int _8503 = _3601;
          for (int _3617 = _8502; _3617 < _8503; ++_3617)
          {
            {
              int _8504 = (int)0;
              int _8505 = mdim1;
              for (int _3618 = _8504; _3618 < _8505; ++_3618)
              {
                {
                  bool _3619 = false;
                  int _3620 = _ptr__3610[safe_add( safe_add( _3591,_3617 ),(int)1 )];
                  int _3621 = _ptr__3610[safe_add( _3591,_3617 )];
                  int _3622 = _ptr__3610[safe_add( safe_add( _3589,_3618 ),(int)1 )];
                  int _3623 = _ptr__3610[safe_add( _3589,_3618 )];
                  while ( ((_3621 < _3620) && (_3623 < _3622)) )
                  {
                    {
                      int _3624 = _ptr__3610[safe_add( _3590,_3623 )];
                      if (((_ptr__3611[safe_add( _3606,_3621 )] % _3600) < ((*msubi)(_3624))))
                      {
                        {
                          ++ _3621;
                        }
                      }
                      else if(((_ptr__3611[safe_add( _3606,_3621 )] % _3600) > ((*msubi)(_3624))))
                      {
                        {
                          ++ _3623;
                        }
                      }
                      else
                      {
                        {
                          _3616 += (_ptr__3610[safe_add( safe_add( _3605,_3621 ),(int)1 )] - _ptr__3610[safe_add( _3605,_3621 )]);
                          ++ _3621;
                          ++ _3623;
                          _3619 = true;
                        }
                      }
                    }
                  }
                  if (_3619)
                  {
                    {
                      ++ _3615;
                    }
                  }
                  {}
                }
              }
            }
          }
          bool _3625 = (_3615 < safe_mul( _3601,mdim1 ));
          _3581->alloc_expr((int)2,_3615,_3616,_3625);
          int _3626 = mosek::fusion::p_WorkStack::_get_impl(_3581)->ptr_base;
          int _3627 = mosek::fusion::p_WorkStack::_get_impl(_3581)->nidxs_base;
          int _8506;
          bool _8507 = _3625;
          if (_8507)
          {
            _8506 = mosek::fusion::p_WorkStack::_get_impl(_3581)->sp_base;
          }
          else
          {
            _8506 = _3581->alloci64(_3615);
          }
          int _3628 = _8506;
          int _3629 = mosek::fusion::p_WorkStack::_get_impl(_3581)->cof_base;
          int _3630 = mosek::fusion::p_WorkStack::_get_impl(_3581)->bfix_base;
          int _3631 = mosek::fusion::p_WorkStack::_get_impl(_3581)->shape_base;
          std::shared_ptr< monty::ndarray< int,1 > > _3632 = mosek::fusion::p_WorkStack::_get_impl(_3581)->i32;
          _checked_ptr_1<int> _ptr__3632(_3632 ? _3632->raw() : nullptr,_3632 ? _3632->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3633 = mosek::fusion::p_WorkStack::_get_impl(_3581)->i64;
          _checked_ptr_1<long long> _ptr__3633(_3633 ? _3633->raw() : nullptr,_3633 ? _3633->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3634 = mosek::fusion::p_WorkStack::_get_impl(_3581)->f64;
          _checked_ptr_1<double> _ptr__3634(_3634 ? _3634->raw() : nullptr,_3634 ? _3634->size(0) : 0);
          _ptr__3632[_3631] = _3601;
          _ptr__3632[safe_add( _3631,(int)1 )] = mdim1;
          int _3635 = (int)0;
          int _3636 = (int)0;
          _ptr__3632[_3626] = (int)0;
          int _8508 = (int)0;
          int _8509 = _3601;
          for (int _3637 = _8508; _3637 < _8509; ++_3637)
          {
            {
              int _8510 = (int)0;
              int _8511 = mdim1;
              for (int _3638 = _8510; _3638 < _8511; ++_3638)
              {
                {
                  bool _3639 = false;
                  double _3640 = 0.0;
                  int _3641 = _ptr__3610[safe_add( safe_add( _3591,_3637 ),(int)1 )];
                  int _3642 = _ptr__3610[safe_add( _3591,_3637 )];
                  int _3643 = _ptr__3610[safe_add( safe_add( _3589,_3638 ),(int)1 )];
                  int _3644 = _ptr__3610[safe_add( _3589,_3638 )];
                  while ( ((_3642 < _3641) && (_3644 < _3643)) )
                  {
                    {
                      int _3645 = _ptr__3610[safe_add( _3590,_3644 )];
                      if (((_ptr__3611[safe_add( _3606,_3642 )] % _3600) < ((*msubi)(_3645))))
                      {
                        {
                          ++ _3642;
                        }
                      }
                      else if(((_ptr__3611[safe_add( _3606,_3642 )] % _3600) > ((*msubi)(_3645))))
                      {
                        {
                          ++ _3644;
                        }
                      }
                      else
                      {
                        {
                          int _3646 = (_ptr__3610[safe_add( safe_add( _3605,_3642 ),(int)1 )] - _ptr__3610[safe_add( _3605,_3642 )]);
                          _3640 += (((*mval)(_3645)) * _ptr__3612[safe_add( _3608,_3642 )]);
                          int _8512 = (int)0;
                          int _8513 = _3646;
                          for (int _3647 = _8512; _3647 < _8513; ++_3647)
                          {
                            {
                              _ptr__3633[safe_add( safe_add( _3627,_3636 ),_3647 )] = _ptr__3611[safe_add( safe_add( _3607,_ptr__3610[safe_add( _3605,_3642 )] ),_3647 )];
                            }
                          }
                          int _8514 = (int)0;
                          int _8515 = _3646;
                          for (int _3648 = _8514; _3648 < _8515; ++_3648)
                          {
                            {
                              _ptr__3634[safe_add( safe_add( _3629,_3636 ),_3648 )] = (_ptr__3612[safe_add( safe_add( _3609,_ptr__3610[safe_add( _3605,_3642 )] ),_3648 )] * ((*mval)(_3645)));
                            }
                          }
                          _3636 += _3646;
                          ++ _3642;
                          ++ _3644;
                          _3639 = true;
                        }
                      }
                      if (_3639)
                      {
                        {
                          _ptr__3632[safe_add( safe_add( _3626,_3635 ),(int)1 )] = _3636;
                          _ptr__3634[safe_add( _3630,_3635 )] = _3640;
                          _ptr__3633[safe_add( _3628,_3635 )] = safe_add( safe_mul( _3637,mdim1 ),_3638 );
                          ++ _3635;
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
          if ((!_3625))
          {
            {
              _3581->popi64(_3615);
            }
          }
          {}
        }
      }
      else
      {
        {
          int _3649 = safe_mul( _3601,mdim1 );
          int _3650 = (int)0;
          int _8516 = (int)0;
          int _8517 = _3601;
          for (int _3651 = _8516; _3651 < _8517; ++_3651)
          {
            {
              int _8518 = (int)0;
              int _8519 = mdim1;
              for (int _3652 = _8518; _3652 < _8519; ++_3652)
              {
                {
                  int _8520 = _ptr__3610[safe_add( _3589,_3652 )];
                  int _8521 = _ptr__3610[safe_add( safe_add( _3589,_3652 ),(int)1 )];
                  for (int _3653 = _8520; _3653 < _8521; ++_3653)
                  {
                    {
                      int _3654 = _ptr__3610[safe_add( _3590,_3653 )];
                      int _3655 = safe_add( safe_mul( _3651,_3600 ),((*msubi)(_3654)) );
                      _3650 += (_ptr__3610[safe_add( safe_add( _3605,_3655 ),(int)1 )] - _ptr__3610[safe_add( _3605,_3655 )]);
                    }
                  }
                }
              }
            }
          }
          bool _3656 = (_3649 < safe_mul( _3601,mdim1 ));
          int _3657 = _3581->alloci32(safe_add( _3649,(int)1 ));
          int _8522;
          bool _8523 = _3656;
          if (_8523)
          {
            _8522 = (int)1;
          }
          else
          {
            _8522 = (int)0;
          }
          _3581->pushi32(_8522);
          _3581->pushi32(_3650);
          _3581->pushi32(_3649);
          _3581->pushi32(_3601);
          _3581->pushi32(mdim1);
          _3581->pushi32((int)2);
          int _3658 = _3581->alloci64(_3650);
          int _3659 = _3581->alloci64(_3649);
          int _3660 = _3581->allocf64(_3650);
          int _3661 = _3581->allocf64(_3649);
          std::shared_ptr< monty::ndarray< int,1 > > _3662 = mosek::fusion::p_WorkStack::_get_impl(_3581)->i32;
          _checked_ptr_1<int> _ptr__3662(_3662 ? _3662->raw() : nullptr,_3662 ? _3662->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3663 = mosek::fusion::p_WorkStack::_get_impl(_3581)->i64;
          _checked_ptr_1<long long> _ptr__3663(_3663 ? _3663->raw() : nullptr,_3663 ? _3663->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3664 = mosek::fusion::p_WorkStack::_get_impl(_3581)->f64;
          _checked_ptr_1<double> _ptr__3664(_3664 ? _3664->raw() : nullptr,_3664 ? _3664->size(0) : 0);
          int _3665 = (int)0;
          int _3666 = (int)0;
          _ptr__3662[_3657] = (int)0;
          int _8524 = (int)0;
          int _8525 = _3601;
          for (int _3667 = _8524; _3667 < _8525; ++_3667)
          {
            {
              int _8526 = (int)0;
              int _8527 = mdim1;
              for (int _3668 = _8526; _3668 < _8527; ++_3668)
              {
                {
                  int _3669 = safe_mul( _3667,_3600 );
                  double _3670 = 0.0;
                  int _8528 = _ptr__3610[safe_add( _3589,_3668 )];
                  int _8529 = _ptr__3610[safe_add( safe_add( _3589,_3668 ),(int)1 )];
                  for (int _3671 = _8528; _3671 < _8529; ++_3671)
                  {
                    {
                      int _3672 = _ptr__3610[safe_add( _3590,_3671 )];
                      int _3673 = safe_add( _3669,((*msubi)(_3672)) );
                      int _3674 = _ptr__3610[safe_add( _3605,_3673 )];
                      int _3675 = (_ptr__3610[safe_add( safe_add( _3605,_3673 ),(int)1 )] - _ptr__3610[safe_add( _3605,_3673 )]);
                      int _8530 = (int)0;
                      int _8531 = _3675;
                      for (int _3676 = _8530; _3676 < _8531; ++_3676)
                      {
                        {
                          _ptr__3663[safe_add( safe_add( _3658,_3666 ),_3676 )] = _ptr__3611[safe_add( safe_add( _3607,_3674 ),_3676 )];
                        }
                      }
                      int _8532 = (int)0;
                      int _8533 = _3675;
                      for (int _3677 = _8532; _3677 < _8533; ++_3677)
                      {
                        {
                          _ptr__3664[safe_add( safe_add( _3660,_3666 ),_3677 )] = (_ptr__3612[safe_add( safe_add( _3609,_3674 ),_3677 )] * ((*mval)(_3672)));
                        }
                      }
                      _3670 += (_ptr__3612[safe_add( safe_add( _3608,_3669 ),((*msubi)(_3672)) )] * ((*mval)(_3672)));
                      _3666 += _3675;
                    }
                  }
                  _ptr__3662[safe_add( safe_add( _3657,_3665 ),(int)1 )] = _3666;
                  _ptr__3664[safe_add( _3661,_3665 )] = _3670;
                  _ptr__3663[safe_add( _3659,_3665 )] = safe_add( safe_mul( _3667,mdim1 ),_3668 );
                  ++ _3665;
                }
              }
            }
          }
          if ((!_3656))
          {
            {
              _3581->popi64(_3649);
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      int _3678 = _3583->alloci32(safe_add( _3588,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _3679 = mosek::fusion::p_WorkStack::_get_impl(_3583)->i32;
      _checked_ptr_1<int> _ptr__3679(_3679 ? _3679->raw() : nullptr,_3679 ? _3679->size(0) : 0);
      int _8534 = (int)0;
      int _8535 = safe_add( _3588,(int)1 );
      for (int _3680 = _8534; _3680 < _8535; ++_3680)
      {
        {
          _ptr__3679[safe_add( _3678,_3680 )] = (int)0;
        }
      }
      _3582->pop_expr();
      std::shared_ptr< monty::ndarray< int,1 > > _3681 = mosek::fusion::p_WorkStack::_get_impl(_3582)->i32;
      _checked_ptr_1<int> _ptr__3681(_3681 ? _3681->raw() : nullptr,_3681 ? _3681->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3682 = mosek::fusion::p_WorkStack::_get_impl(_3582)->i64;
      _checked_ptr_1<long long> _ptr__3682(_3682 ? _3682->raw() : nullptr,_3682 ? _3682->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3683 = mosek::fusion::p_WorkStack::_get_impl(_3582)->f64;
      _checked_ptr_1<double> _ptr__3683(_3683 ? _3683->raw() : nullptr,_3683 ? _3683->size(0) : 0);
      int _3684 = mosek::fusion::p_WorkStack::_get_impl(_3582)->nd;
      int _3685 = mosek::fusion::p_WorkStack::_get_impl(_3582)->nelem;
      int _3686 = mosek::fusion::p_WorkStack::_get_impl(_3582)->nnz;
      bool _3687 = mosek::fusion::p_WorkStack::_get_impl(_3582)->hassp;
      int _3688 = _3686;
      int _3689 = _3685;
      int _3690 = mosek::fusion::p_WorkStack::_get_impl(_3582)->shape_base;
      int _3691 = mosek::fusion::p_WorkStack::_get_impl(_3582)->ptr_base;
      int _3692 = mosek::fusion::p_WorkStack::_get_impl(_3582)->sp_base;
      int _3693 = mosek::fusion::p_WorkStack::_get_impl(_3582)->nidxs_base;
      int _3694 = mosek::fusion::p_WorkStack::_get_impl(_3582)->bfix_base;
      int _3695 = mosek::fusion::p_WorkStack::_get_impl(_3582)->cof_base;
      int _3696 = _ptr__3681[_3690];
      int _3697 = _ptr__3681[safe_add( _3690,(int)1 )];
      if ((_3684 != (int)2))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
        }
      }
      {}
      std::shared_ptr< monty::ndarray< int,1 > > _3698 = mosek::fusion::p_WorkStack::_get_impl(_3582)->i32;
      _checked_ptr_1<int> _ptr__3698(_3698 ? _3698->raw() : nullptr,_3698 ? _3698->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3699 = mosek::fusion::p_WorkStack::_get_impl(_3582)->i64;
      _checked_ptr_1<long long> _ptr__3699(_3699 ? _3699->raw() : nullptr,_3699 ? _3699->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3700 = mosek::fusion::p_WorkStack::_get_impl(_3582)->f64;
      _checked_ptr_1<double> _ptr__3700(_3700 ? _3700->raw() : nullptr,_3700 ? _3700->size(0) : 0);
      int _3701 = safe_mul( _3696,mdim1 );
      int _3702 = safe_mul( _3686,mdim1 );
      bool _3703 = false;
      int _3704 = (int)2;
      _3581->alloc_expr(_3704,_3701,_3702,_3703);
      std::shared_ptr< monty::ndarray< int,1 > > _3705 = mosek::fusion::p_WorkStack::_get_impl(_3581)->i32;
      _checked_ptr_1<int> _ptr__3705(_3705 ? _3705->raw() : nullptr,_3705 ? _3705->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3706 = mosek::fusion::p_WorkStack::_get_impl(_3581)->i64;
      _checked_ptr_1<long long> _ptr__3706(_3706 ? _3706->raw() : nullptr,_3706 ? _3706->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3707 = mosek::fusion::p_WorkStack::_get_impl(_3581)->f64;
      _checked_ptr_1<double> _ptr__3707(_3707 ? _3707->raw() : nullptr,_3707 ? _3707->size(0) : 0);
      int _3708 = mosek::fusion::p_WorkStack::_get_impl(_3581)->shape_base;
      int _3709 = mosek::fusion::p_WorkStack::_get_impl(_3581)->ptr_base;
      int _3710 = mosek::fusion::p_WorkStack::_get_impl(_3581)->nidxs_base;
      int _3711 = mosek::fusion::p_WorkStack::_get_impl(_3581)->sp_base;
      int _3712 = mosek::fusion::p_WorkStack::_get_impl(_3581)->cof_base;
      int _3713 = mosek::fusion::p_WorkStack::_get_impl(_3581)->bfix_base;
      _ptr__3705[_3708] = _3696;
      _ptr__3705[safe_add( _3708,(int)1 )] = mdim1;
      int _3714 = (int)0;
      int _3715 = (int)0;
      _ptr__3705[_3709] = (int)0;
      if (_3687)
      {
        {
          int _8536 = (int)0;
          int _8537 = _3685;
          for (int _3716 = _8536; _3716 < _8537; ++_3716)
          {
            {
              ++ _ptr__3679[safe_add( safe_add( _3678,(_ptr__3699[safe_add( _3692,_3716 )] / _3697) ),(int)1 )];
            }
          }
          int _8538 = (int)0;
          int _8539 = _3696;
          for (int _3717 = _8538; _3717 < _8539; ++_3717)
          {
            {
              _ptr__3679[safe_add( safe_add( _3678,_3717 ),(int)1 )] += _ptr__3679[safe_add( _3678,_3717 )];
            }
          }
          int _8540 = (int)0;
          int _8541 = _3696;
          for (int _3718 = _8540; _3718 < _8541; ++_3718)
          {
            {
              int _8542 = (int)0;
              int _8543 = mdim1;
              for (int _3719 = _8542; _3719 < _8543; ++_3719)
              {
                {
                  double _3720 = 0.0;
                  int _3721 = (int)0;
                  int _8544 = _ptr__3679[safe_add( _3678,_3718 )];
                  int _8545 = _ptr__3679[safe_add( safe_add( _3678,_3718 ),(int)1 )];
                  for (int _3722 = _8544; _3722 < _8545; ++_3722)
                  {
                    {
                      long long _3723 = safe_add( _3719,safe_mul( (_ptr__3699[safe_add( _3692,_3722 )] % _3697),mdim1 ) );
                      _3720 += (_ptr__3700[safe_add( _3694,_3722 )] * ((*mval)(_3723)));
                      int _8546 = _ptr__3698[safe_add( _3691,_3722 )];
                      int _8547 = _ptr__3698[safe_add( safe_add( _3691,_3722 ),(int)1 )];
                      for (int _3724 = _8546; _3724 < _8547; ++_3724)
                      {
                        {
                          _ptr__3706[safe_add( safe_add( _3710,_3714 ),_3721 )] = _ptr__3699[safe_add( _3693,_3724 )];
                          _ptr__3707[safe_add( safe_add( _3712,_3714 ),_3721 )] = (_ptr__3700[safe_add( _3695,_3724 )] * ((*mval)(_3723)));
                          ++ _3721;
                        }
                      }
                    }
                  }
                  _3714 += _3721;
                  _ptr__3705[safe_add( safe_add( _3709,_3715 ),(int)1 )] = _3714;
                  _ptr__3707[safe_add( _3713,_3715 )] = _3720;
                  ++ _3715;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _8548 = (int)0;
          int _8549 = _3696;
          for (int _3725 = _8548; _3725 < _8549; ++_3725)
          {
            {
              int _8550 = (int)0;
              int _8551 = mdim1;
              for (int _3726 = _8550; _3726 < _8551; ++_3726)
              {
                {
                  double _3727 = 0.0;
                  int _3728 = (int)0;
                  int _8552 = (int)0;
                  int _8553 = _3697;
                  for (int _3729 = _8552; _3729 < _8553; ++_3729)
                  {
                    {
                      int _3730 = safe_add( safe_mul( _3725,_3697 ),_3729 );
                      int _3731 = safe_add( _3726,safe_mul( _3729,mdim1 ) );
                      _3727 += (_ptr__3700[safe_add( _3694,_3730 )] * ((*mval)(_3731)));
                      int _8554 = _ptr__3698[safe_add( _3691,_3730 )];
                      int _8555 = _ptr__3698[safe_add( safe_add( _3691,_3730 ),(int)1 )];
                      for (int _3732 = _8554; _3732 < _8555; ++_3732)
                      {
                        {
                          _ptr__3706[safe_add( safe_add( _3710,_3714 ),_3728 )] = _ptr__3699[safe_add( _3693,_3732 )];
                          _ptr__3707[safe_add( safe_add( _3712,_3714 ),_3728 )] = (_ptr__3700[safe_add( _3695,_3732 )] * ((*mval)(_3731)));
                          ++ _3728;
                        }
                      }
                    }
                  }
                  _3714 += _3728;
                  _ptr__3705[safe_add( safe_add( _3709,_3715 ),(int)1 )] = _3714;
                  _ptr__3707[safe_add( _3713,_3715 )] = _3727;
                  ++ _3715;
                }
              }
            }
          }
        }
      }
      _3583->clear();
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprMulRight::computeshape(int _3733,std::shared_ptr< monty::ndarray< int,1 > > _3734){
  _checked_ptr_1<int> _ptr__3734(_3734 ? _3734->raw() : nullptr, _3734 ? _3734->size(0) : 0);
  if (((int)((_3734)->size(0)) == (int)1))
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_3733)});
    }
  }
  else
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__3734[(int)0]),(int)(_3733)});
    }
  }
}
int mosek::fusion::p_ExprMulRight::validate(int _3735,int _3736,std::shared_ptr< monty::ndarray< int,1 > > _3737,std::shared_ptr< monty::ndarray< int,1 > > _3738,std::shared_ptr< monty::ndarray< double,1 > > _3739,monty::rc_ptr< ::mosek::fusion::Expression > _3740){
  _checked_ptr_1<int> _ptr__3737(_3737 ? _3737->raw() : nullptr, _3737 ? _3737->size(0) : 0);
  _checked_ptr_1<int> _ptr__3738(_3738 ? _3738->raw() : nullptr, _3738 ? _3738->size(0) : 0);
  _checked_ptr_1<double> _ptr__3739(_3739 ? _3739->raw() : nullptr, _3739 ? _3739->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3741 = _3740->getShape();
  _checked_ptr_1<int> _ptr__3741(_3741 ? _3741->raw() : nullptr,_3741 ? _3741->size(0) : 0);
  if (((int)((_3741)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3742 = _ptr__3741[(int)0];
  int _3743 = _ptr__3741[(int)1];
  if (((_3735 < (int)0) || ((_3736 < (int)0) || ((_3742 < (int)0) || (_3743 < (int)0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if ((_3735 != _3743))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3737)->size(0)) != (int)((_3738)->size(0))) || ((int)((_3737)->size(0)) != (int)((_3739)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3744 = (int)((_3737)->size(0));
  {
    bool _3745 = false;
    int _8556 = (int)0;
    int _8557 = _3744;
    for (int _3746 = _8556; _3746 < _8557; ++_3746)
    {
      {
        _3745 = (_3745 || ((_ptr__3737[_3746] < (int)0) || ((_ptr__3737[_3746] >= _3735) || ((_ptr__3738[_3746] < (int)0) || (_ptr__3738[_3746] >= _3736)))));
      }
    }
    if (_3745)
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
      }
    }
    {}
  }
  {
    bool _3747 = false;
    int _8558 = (int)0;
    int _8559 = (_3744 - (int)1);
    for (int _3748 = _8558; _3748 < _8559; ++_3748)
    {
      {
        _3747 = (_3747 || ((_ptr__3737[_3748] > _ptr__3737[safe_add( _3748,(int)1 )]) || ((_ptr__3737[_3748] == _ptr__3737[safe_add( _3748,(int)1 )]) && (_ptr__3738[_3748] >= _ptr__3738[safe_add( _3748,(int)1 )]))));
      }
    }
    if (_3747)
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
      }
    }
    {}
  }
  return (int)1;
}
std::string mosek::fusion::ExprMulRight :: toString() { return mosek::fusion::p_ExprMulRight::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulRight::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulRight(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulRight::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulRight::destroy() { mosek::fusion::p_ExprMulRight::_get_impl(this)->destroy(); }mosek::fusion::ExprMulLeft::ExprMulLeft(mosek::fusion::p_ExprMulLeft *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulLeft()" << this << std::endl; */ }mosek::fusion::ExprMulLeft::~ExprMulLeft() {  /* std::cout << "~ExprMulLeft()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulLeft::p_ExprMulLeft  (::mosek::fusion::ExprMulLeft * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulLeft::t mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft  (int _3749,    int _3750,    std::shared_ptr< monty::ndarray< int,1 > > _3751,    std::shared_ptr< monty::ndarray< int,1 > > _3752,    std::shared_ptr< monty::ndarray< double,1 > > _3753,    monty::rc_ptr< ::mosek::fusion::Expression > _3754,    int _3755){ return new mosek::fusion::ExprMulLeft(_3749,_3750,_3751,_3752,_3753,_3754,_3755); }mosek::fusion::ExprMulLeft::ExprMulLeft  (int _3749,    int _3750,    std::shared_ptr< monty::ndarray< int,1 > > _3751,    std::shared_ptr< monty::ndarray< int,1 > > _3752,    std::shared_ptr< monty::ndarray< double,1 > > _3753,    monty::rc_ptr< ::mosek::fusion::Expression > _3754,    int _3755) :    ExprMulLeft(new mosek::fusion::p_ExprMulLeft(this)){ mosek::fusion::p_ExprMulLeft::_get_impl(this)->_initialize(_3749,_3750,_3751,_3752,_3753,_3754,_3755); }void mosek::fusion::p_ExprMulLeft::_initialize  (int _3749,    int _3750,    std::shared_ptr< monty::ndarray< int,1 > > _3751,    std::shared_ptr< monty::ndarray< int,1 > > _3752,    std::shared_ptr< monty::ndarray< double,1 > > _3753,    monty::rc_ptr< ::mosek::fusion::Expression > _3754,    int _3755){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3751(_3751 ? _3751->raw() : nullptr, _3751 ? _3751->size(0) : 0);
    _checked_ptr_1<int> _ptr__3752(_3752 ? _3752->raw() : nullptr, _3752 ? _3752->size(0) : 0);
    _checked_ptr_1<double> _ptr__3753(_3753 ? _3753->raw() : nullptr, _3753 ? _3753->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprMulLeft::computeshape(_3749,_3750,_3754->getShape()));
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->mdim0 = _3749;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->mdim1 = _3750;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->msubi = _3751;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->msubj = _3752;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->mval = _3753;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->expr = _3754;
  }
}mosek::fusion::ExprMulLeft::t mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft  (int _3756,    int _3757,    std::shared_ptr< monty::ndarray< int,1 > > _3758,    std::shared_ptr< monty::ndarray< int,1 > > _3759,    std::shared_ptr< monty::ndarray< double,1 > > _3760,    monty::rc_ptr< ::mosek::fusion::Expression > _3761){ return new mosek::fusion::ExprMulLeft(_3756,_3757,_3758,_3759,_3760,_3761); }mosek::fusion::ExprMulLeft::ExprMulLeft  (int _3756,    int _3757,    std::shared_ptr< monty::ndarray< int,1 > > _3758,    std::shared_ptr< monty::ndarray< int,1 > > _3759,    std::shared_ptr< monty::ndarray< double,1 > > _3760,    monty::rc_ptr< ::mosek::fusion::Expression > _3761) :    ExprMulLeft(new mosek::fusion::p_ExprMulLeft(this)){ mosek::fusion::p_ExprMulLeft::_get_impl(this)->_initialize(_3756,_3757,_3758,_3759,_3760,_3761); }void mosek::fusion::p_ExprMulLeft::_initialize  (int _3756,    int _3757,    std::shared_ptr< monty::ndarray< int,1 > > _3758,    std::shared_ptr< monty::ndarray< int,1 > > _3759,    std::shared_ptr< monty::ndarray< double,1 > > _3760,    monty::rc_ptr< ::mosek::fusion::Expression > _3761){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3758(_3758 ? _3758->raw() : nullptr, _3758 ? _3758->size(0) : 0);
    _checked_ptr_1<int> _ptr__3759(_3759 ? _3759->raw() : nullptr, _3759 ? _3759->size(0) : 0);
    _checked_ptr_1<double> _ptr__3760(_3760 ? _3760->raw() : nullptr, _3760 ? _3760->size(0) : 0);
    mosek::fusion::p_ExprMulLeft::_initialize(_3756,_3757,_3758,_3759,_3760,_3761,::mosek::fusion::p_ExprMulLeft::validate(_3756,_3757,_3758,_3759,_3760,_3761));
  }
}void mosek::fusion::ExprMulLeft :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3762,monty::rc_ptr< ::mosek::fusion::WorkStack > _3763,monty::rc_ptr< ::mosek::fusion::WorkStack > _3764) { mosek::fusion::p_ExprMulLeft::_get_impl(this)->eval(_3762,_3763,_3764); }void mosek::fusion::p_ExprMulLeft::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3762,monty::rc_ptr< ::mosek::fusion::WorkStack > _3763,monty::rc_ptr< ::mosek::fusion::WorkStack > _3764){
  mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->expr->eval(_3763,_3762,_3764);
  _3763->pop_expr();
  int _3765 = mosek::fusion::p_WorkStack::_get_impl(_3763)->nd;
  int _3766 = mosek::fusion::p_WorkStack::_get_impl(_3763)->nnz;
  int _3767 = mosek::fusion::p_WorkStack::_get_impl(_3763)->nelem;
  bool _3768 = mosek::fusion::p_WorkStack::_get_impl(_3763)->hassp;
  int _3769 = mosek::fusion::p_WorkStack::_get_impl(_3763)->shape_base;
  int _3770 = mosek::fusion::p_WorkStack::_get_impl(_3763)->ptr_base;
  int _3771 = mosek::fusion::p_WorkStack::_get_impl(_3763)->sp_base;
  int _3772 = mosek::fusion::p_WorkStack::_get_impl(_3763)->nidxs_base;
  int _3773 = mosek::fusion::p_WorkStack::_get_impl(_3763)->bfix_base;
  int _3774 = mosek::fusion::p_WorkStack::_get_impl(_3763)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _3775 = mosek::fusion::p_WorkStack::_get_impl(_3763)->i32;
  _checked_ptr_1<int> _ptr__3775(_3775 ? _3775->raw() : nullptr,_3775 ? _3775->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3776 = mosek::fusion::p_WorkStack::_get_impl(_3763)->i64;
  _checked_ptr_1<long long> _ptr__3776(_3776 ? _3776->raw() : nullptr,_3776 ? _3776->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3777 = mosek::fusion::p_WorkStack::_get_impl(_3763)->f64;
  _checked_ptr_1<double> _ptr__3777(_3777 ? _3777->raw() : nullptr,_3777 ? _3777->size(0) : 0);
  if ((_3765 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _3778 = (int)9999;
  int _3779 = (int)9999;
  int _3780 = (int)9999;
  int _3781 = _ptr__3775[_3769];
  int _3782 = _ptr__3775[safe_add( _3769,(int)1 )];
  int _3783 = (int)((msubi)->size(0));
  bool _3784 = (_3783 < safe_mul( (long long)mdim0,(long long)mdim1 ));
  bool _3785 = false;
  int _3786 = (int)0;
  int _3787 = (int)0;
  if (_3768)
  {
    {
      _3778 = _3764->alloci32(_3767);
      _3779 = _3764->alloci32(_3767);
      _3780 = _3764->alloci32(safe_add( _3782,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _3788 = mosek::fusion::p_WorkStack::_get_impl(_3764)->i32;
      _checked_ptr_1<int> _ptr__3788(_3788 ? _3788->raw() : nullptr,_3788 ? _3788->size(0) : 0);
      int _8560 = (int)0;
      int _8561 = safe_add( _3782,(int)1 );
      for (int _3789 = _8560; _3789 < _8561; ++_3789)
      {
        {
          _ptr__3788[safe_add( _3780,_3789 )] = (int)0;
        }
      }
      int _8562 = (int)0;
      int _8563 = _3767;
      for (int _3790 = _8562; _3790 < _8563; ++_3790)
      {
        {
          ++ _ptr__3788[safe_add( safe_add( _3780,(_ptr__3776[safe_add( _3771,_3790 )] % _3782) ),(int)1 )];
        }
      }
      int _8564 = (int)0;
      int _8565 = _3782;
      for (int _3791 = _8564; _3791 < _8565; ++_3791)
      {
        {
          _ptr__3788[safe_add( safe_add( _3780,_3791 ),(int)1 )] += _ptr__3788[safe_add( _3780,_3791 )];
        }
      }
      int _8566 = (int)0;
      int _8567 = _3767;
      for (int _3792 = _8566; _3792 < _8567; ++_3792)
      {
        {
          long long _3793 = (_ptr__3776[safe_add( _3771,_3792 )] % _3782);
          _ptr__3788[safe_add( _3778,_ptr__3788[safe_add( _3780,_3793 )] )] = _3792;
          ++ _ptr__3788[safe_add( _3780,_3793 )];
        }
      }
      int _8568 = (int)0;
      int _8569 = _3782;
      for (int _3794 = _8568; _3794 < _8569; ++_3794)
      {
        {
          _ptr__3788[(safe_add( _3780,_3782 ) - _3794)] = _ptr__3788[((safe_add( _3780,_3782 ) - _3794) - (int)1)];
        }
      }
      _ptr__3788[_3780] = (int)0;
      if (_3784)
      {
        {
          int _3795 = (int)0;
          while ( (_3795 < _3783) )
          {
            {
              int _3796 = ((*msubi)(_3795));
              int _3797 = safe_add( _3795,(int)1 );
              while ( ((_3797 < _3783) && (((*msubi)(_3797)) == ((*msubi)(_3795)))) )
              {
                {
                  ++ _3797;
                }
              }
              int _8570 = (int)0;
              int _8571 = _3782;
              for (int _3798 = _8570; _3798 < _8571; ++_3798)
              {
                {
                  bool _3799 = false;
                  int _3800 = _3797;
                  int _3801 = _3795;
                  int _3802 = _ptr__3788[safe_add( safe_add( _3780,_3798 ),(int)1 )];
                  int _3803 = _ptr__3788[safe_add( _3780,_3798 )];
                  while ( ((_3801 < _3800) && (_3803 < _3802)) )
                  {
                    {
                      int _3804 = _ptr__3788[safe_add( _3778,_3803 )];
                      if ((((*msubj)(_3801)) < (_ptr__3776[safe_add( _3771,_3804 )] / _3782)))
                      {
                        {
                          ++ _3801;
                        }
                      }
                      else if((((*msubj)(_3801)) > (_ptr__3776[safe_add( _3771,_3804 )] / _3782)))
                      {
                        {
                          ++ _3803;
                        }
                      }
                      else
                      {
                        {
                          _3799 = true;
                          _3787 += (_ptr__3775[safe_add( safe_add( _3770,_3804 ),(int)1 )] - _ptr__3775[safe_add( _3770,_3804 )]);
                          ++ _3803;
                          ++ _3801;
                        }
                      }
                    }
                  }
                  if (_3799)
                  {
                    {
                      ++ _3786;
                    }
                  }
                  {}
                }
              }
              _3795 = _3797;
            }
          }
        }
      }
      else
      {
        {
          _3786 = safe_mul( mdim0,_3782 );
          _3787 = safe_mul( _3766,mdim0 );
        }
      }
    }
  }
  else
  {
    {
      if (_3784)
      {
        {
          int _3805 = (int)0;
          while ( (_3805 < _3783) )
          {
            {
              int _3806 = safe_add( _3805,(int)1 );
              while ( ((_3806 < _3783) && (((*msubi)(_3805)) == ((*msubi)(_3806)))) )
              {
                {
                  ++ _3806;
                }
              }
              int _3807 = ((*msubi)(_3805));
              int _8572 = (int)0;
              int _8573 = _3782;
              for (int _3808 = _8572; _3808 < _8573; ++_3808)
              {
                {
                  bool _3809 = false;
                  int _8574 = _3805;
                  int _8575 = _3806;
                  for (int _3810 = _8574; _3810 < _8575; ++_3810)
                  {
                    {
                      int _3811 = safe_add( safe_mul( ((*msubj)(_3810)),_3782 ),_3808 );
                      _3787 += (_ptr__3775[safe_add( safe_add( _3770,_3811 ),(int)1 )] - _ptr__3775[safe_add( _3770,_3811 )]);
                      _3809 = true;
                    }
                  }
                  if (_3809)
                  {
                    {
                      ++ _3786;
                    }
                  }
                  {}
                }
              }
              _3805 = _3806;
            }
          }
        }
      }
      else
      {
        {
          _3787 = safe_mul( _3766,mdim0 );
          _3786 = safe_mul( mdim0,_3782 );
        }
      }
    }
  }
  _3785 = (_3786 < safe_mul( mdim0,_3782 ));
  int _3812 = (int)2;
  _3762->alloc_expr(_3812,_3786,_3787,_3785);
  int _3813 = mosek::fusion::p_WorkStack::_get_impl(_3762)->ptr_base;
  int _3814 = mosek::fusion::p_WorkStack::_get_impl(_3762)->nidxs_base;
  int _8576;
  bool _8577 = _3785;
  if (_8577)
  {
    _8576 = mosek::fusion::p_WorkStack::_get_impl(_3762)->sp_base;
  }
  else
  {
    _8576 = _3762->alloci64(_3786);
  }
  int _3815 = _8576;
  int _3816 = mosek::fusion::p_WorkStack::_get_impl(_3762)->cof_base;
  int _3817 = mosek::fusion::p_WorkStack::_get_impl(_3762)->bfix_base;
  int _3818 = mosek::fusion::p_WorkStack::_get_impl(_3762)->shape_base;
  std::shared_ptr< monty::ndarray< long long,1 > > _3819 = mosek::fusion::p_WorkStack::_get_impl(_3762)->i64;
  _checked_ptr_1<long long> _ptr__3819(_3819 ? _3819->raw() : nullptr,_3819 ? _3819->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3820 = mosek::fusion::p_WorkStack::_get_impl(_3762)->f64;
  _checked_ptr_1<double> _ptr__3820(_3820 ? _3820->raw() : nullptr,_3820 ? _3820->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3821 = mosek::fusion::p_WorkStack::_get_impl(_3762)->i32;
  _checked_ptr_1<int> _ptr__3821(_3821 ? _3821->raw() : nullptr,_3821 ? _3821->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3822 = mosek::fusion::p_WorkStack::_get_impl(_3764)->i32;
  _checked_ptr_1<int> _ptr__3822(_3822 ? _3822->raw() : nullptr,_3822 ? _3822->size(0) : 0);
  _ptr__3821[_3818] = mdim0;
  _ptr__3821[safe_add( _3818,(int)1 )] = _3782;
  if (_3768)
  {
    {
      _ptr__3821[_3813] = (int)0;
      if (_3784)
      {
        {
          int _3823 = (int)0;
          int _3824 = (int)0;
          int _3825 = (int)0;
          while ( (_3825 < _3783) )
          {
            {
              int _3826 = ((*msubi)(_3825));
              int _3827 = safe_add( _3825,(int)1 );
              while ( ((_3827 < _3783) && (((*msubi)(_3827)) == ((*msubi)(_3825)))) )
              {
                {
                  ++ _3827;
                }
              }
              int _8578 = (int)0;
              int _8579 = _3782;
              for (int _3828 = _8578; _3828 < _8579; ++_3828)
              {
                {
                  bool _3829 = false;
                  double _3830 = 0.0;
                  int _3831 = _3827;
                  int _3832 = _3825;
                  int _3833 = _ptr__3822[safe_add( safe_add( _3780,_3828 ),(int)1 )];
                  int _3834 = _ptr__3822[safe_add( _3780,_3828 )];
                  while ( ((_3832 < _3831) && (_3834 < _3833)) )
                  {
                    {
                      int _3835 = _ptr__3822[safe_add( _3778,_3834 )];
                      if ((((*msubj)(_3832)) < (_ptr__3776[safe_add( _3771,_3835 )] / _3782)))
                      {
                        {
                          ++ _3832;
                        }
                      }
                      else if((((*msubj)(_3832)) > (_ptr__3776[safe_add( _3771,_3835 )] / _3782)))
                      {
                        {
                          ++ _3834;
                        }
                      }
                      else
                      {
                        {
                          _3829 = true;
                          _3830 += (_ptr__3777[safe_add( _3773,_3835 )] * ((*mval)(_3832)));
                          int _3836 = (_ptr__3775[safe_add( safe_add( _3770,_3835 ),(int)1 )] - _ptr__3775[safe_add( _3770,_3835 )]);
                          int _8580 = (int)0;
                          int _8581 = _3836;
                          for (int _3837 = _8580; _3837 < _8581; ++_3837)
                          {
                            {
                              _ptr__3819[safe_add( safe_add( _3814,_3824 ),_3837 )] = _ptr__3776[safe_add( safe_add( _3772,_ptr__3775[safe_add( _3770,_3835 )] ),_3837 )];
                            }
                          }
                          int _8582 = (int)0;
                          int _8583 = _3836;
                          for (int _3838 = _8582; _3838 < _8583; ++_3838)
                          {
                            {
                              _ptr__3820[safe_add( safe_add( _3816,_3824 ),_3838 )] = (_ptr__3777[safe_add( safe_add( _3774,_ptr__3775[safe_add( _3770,_3835 )] ),_3838 )] * ((*mval)(_3832)));
                            }
                          }
                          ++ _3832;
                          ++ _3834;
                          _3824 += _3836;
                        }
                      }
                    }
                  }
                  if (_3829)
                  {
                    {
                      _ptr__3821[safe_add( safe_add( _3813,_3823 ),(int)1 )] = _3824;
                      _ptr__3819[safe_add( _3815,_3823 )] = safe_add( safe_mul( _3826,_3782 ),_3828 );
                      _ptr__3820[safe_add( _3817,_3823 )] = _3830;
                      ++ _3823;
                    }
                  }
                  {}
                }
              }
              _3825 = _3827;
            }
          }
        }
      }
      else
      {
        {
          int _3839 = (int)0;
          int _3840 = (int)0;
          int _8584 = (int)0;
          int _8585 = mdim0;
          for (int _3841 = _8584; _3841 < _8585; ++_3841)
          {
            {
              int _8586 = (int)0;
              int _8587 = _3782;
              for (int _3842 = _8586; _3842 < _8587; ++_3842)
              {
                {
                  double _3843 = 0.0;
                  int _8588 = _ptr__3822[safe_add( _3780,_3842 )];
                  int _8589 = _ptr__3822[safe_add( safe_add( _3780,_3842 ),(int)1 )];
                  for (int _3844 = _8588; _3844 < _8589; ++_3844)
                  {
                    {
                      int _3845 = _ptr__3822[safe_add( _3778,_3844 )];
                      long long _3846 = safe_add( safe_mul( _3841,mdim1 ),(_ptr__3776[safe_add( _3771,_3845 )] / _3782) );
                      _3843 += (_ptr__3777[safe_add( _3773,_3845 )] * ((*mval)(_3846)));
                      int _3847 = (_ptr__3775[safe_add( safe_add( _3770,_3845 ),(int)1 )] - _ptr__3775[safe_add( _3770,_3845 )]);
                      int _8590 = (int)0;
                      int _8591 = _3847;
                      for (int _3848 = _8590; _3848 < _8591; ++_3848)
                      {
                        {
                          _ptr__3819[safe_add( safe_add( _3814,_3840 ),_3848 )] = _ptr__3776[safe_add( safe_add( _3772,_ptr__3775[safe_add( _3770,_3845 )] ),_3848 )];
                          _ptr__3820[safe_add( safe_add( _3816,_3840 ),_3848 )] = (_ptr__3777[safe_add( safe_add( _3774,_ptr__3775[safe_add( _3770,_3845 )] ),_3848 )] * ((*mval)(_3846)));
                        }
                      }
                      _3840 += _3847;
                    }
                  }
                  _ptr__3821[safe_add( safe_add( _3813,_3839 ),(int)1 )] = _3840;
                  _ptr__3820[safe_add( _3817,_3839 )] = _3843;
                  ++ _3839;
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      _ptr__3821[_3813] = (int)0;
      int _3849 = (int)0;
      int _3850 = (int)0;
      int _3851 = (int)0;
      while ( (_3849 < _3783) )
      {
        {
          int _3852 = safe_add( _3849,(int)1 );
          while ( ((_3852 < _3783) && (((*msubi)(_3849)) == ((*msubi)(_3852)))) )
          {
            {
              ++ _3852;
            }
          }
          int _3853 = ((*msubi)(_3849));
          int _8592 = (int)0;
          int _8593 = _3782;
          for (int _3854 = _8592; _3854 < _8593; ++_3854)
          {
            {
              double _3855 = 0.0;
              bool _3856 = false;
              int _8594 = _3849;
              int _8595 = _3852;
              for (int _3857 = _8594; _3857 < _8595; ++_3857)
              {
                {
                  int _3858 = safe_add( safe_mul( ((*msubj)(_3857)),_3782 ),_3854 );
                  int _3859 = (_ptr__3775[safe_add( safe_add( _3770,_3858 ),(int)1 )] - _ptr__3775[safe_add( _3770,_3858 )]);
                  int _8596 = (int)0;
                  int _8597 = _3859;
                  for (int _3860 = _8596; _3860 < _8597; ++_3860)
                  {
                    {
                      _ptr__3819[safe_add( safe_add( _3814,_3851 ),_3860 )] = _ptr__3776[safe_add( safe_add( _3772,_ptr__3775[safe_add( _3770,_3858 )] ),_3860 )];
                    }
                  }
                  int _8598 = (int)0;
                  int _8599 = _3859;
                  for (int _3861 = _8598; _3861 < _8599; ++_3861)
                  {
                    {
                      _ptr__3820[safe_add( safe_add( _3816,_3851 ),_3861 )] = (_ptr__3777[safe_add( safe_add( _3774,_ptr__3775[safe_add( _3770,_3858 )] ),_3861 )] * ((*mval)(_3857)));
                    }
                  }
                  _3855 += (_ptr__3777[safe_add( _3773,_3858 )] * ((*mval)(_3857)));
                  _3856 = true;
                  _3851 += _3859;
                }
              }
              if (_3856)
              {
                {
                  _ptr__3819[safe_add( _3815,_3850 )] = safe_add( safe_mul( _3853,_3782 ),_3854 );
                  _ptr__3820[safe_add( _3817,_3850 )] = _3855;
                  _ptr__3821[safe_add( safe_add( _3813,_3850 ),(int)1 )] = _3851;
                  ++ _3850;
                }
              }
              {}
            }
          }
          _3849 = _3852;
        }
      }
    }
  }
  _3762->peek_expr();
  if ((!_3785))
  {
    {
      _3762->popi64(_3786);
    }
  }
  {}
  _3764->clear();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprMulLeft::computeshape(int _3862,int _3863,std::shared_ptr< monty::ndarray< int,1 > > _3864){
  _checked_ptr_1<int> _ptr__3864(_3864 ? _3864->raw() : nullptr, _3864 ? _3864->size(0) : 0);
  if (((int)((_3864)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions"));
    }
  }
  else if((_3863 != _ptr__3864[(int)0]))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions"));
    }
  }
  {}
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3862),(int)(_ptr__3864[(int)1])});
}
int mosek::fusion::p_ExprMulLeft::validate(int _3865,int _3866,std::shared_ptr< monty::ndarray< int,1 > > _3867,std::shared_ptr< monty::ndarray< int,1 > > _3868,std::shared_ptr< monty::ndarray< double,1 > > _3869,monty::rc_ptr< ::mosek::fusion::Expression > _3870){
  _checked_ptr_1<int> _ptr__3867(_3867 ? _3867->raw() : nullptr, _3867 ? _3867->size(0) : 0);
  _checked_ptr_1<int> _ptr__3868(_3868 ? _3868->raw() : nullptr, _3868 ? _3868->size(0) : 0);
  _checked_ptr_1<double> _ptr__3869(_3869 ? _3869->raw() : nullptr, _3869 ? _3869->size(0) : 0);
  if ((_3870->getND() != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3871 = _3870->getDim((int)0);
  int _3872 = _3870->getDim((int)0);
  if (((_3865 < (int)0) || (_3866 < (int)0)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if ((_3866 != _3871))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3867)->size(0)) != (int)((_3868)->size(0))) || ((int)((_3867)->size(0)) != (int)((_3869)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3873 = (int)((_3867)->size(0));
  bool _3874 = false;
  bool _3875 = false;
  {
    int _8600 = (int)0;
    int _8601 = _3873;
    for (int _3876 = _8600; _3876 < _8601; ++_3876)
    {
      {
        _3874 = (_3874 || ((_ptr__3867[_3876] < (int)0) || ((_ptr__3867[_3876] >= _3865) || ((_ptr__3868[_3876] < (int)0) || (_ptr__3868[_3876] >= _3866)))));
      }
    }
    if ((!_3874))
    {
      {
        int _8602 = (int)0;
        int _8603 = (_3873 - (int)1);
        for (int _3877 = _8602; _3877 < _8603; ++_3877)
        {
          {
            _3875 = (_3875 || ((_ptr__3867[_3877] > _ptr__3867[safe_add( _3877,(int)1 )]) || ((_ptr__3867[_3877] == _ptr__3867[safe_add( _3877,(int)1 )]) && (_ptr__3868[_3877] >= _ptr__3868[safe_add( _3877,(int)1 )]))));
          }
        }
      }
    }
    {}
  }
  if (_3874)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  if (_3875)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
    }
  }
  {}
  return (int)1;
}
std::string mosek::fusion::ExprMulLeft :: toString() { return mosek::fusion::p_ExprMulLeft::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulLeft::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulLeft(M("))->__mosek_2fusion_2Utils_2StringBuffer__a(mdim0)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(mdim1)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("),"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulLeft::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulLeft::destroy() { mosek::fusion::p_ExprMulLeft::_get_impl(this)->destroy(); }mosek::fusion::ExprMulVar::ExprMulVar(mosek::fusion::p_ExprMulVar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulVar()" << this << std::endl; */ }mosek::fusion::ExprMulVar::~ExprMulVar() {  /* std::cout << "~ExprMulVar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulVar::p_ExprMulVar  (::mosek::fusion::ExprMulVar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulVar::t mosek::fusion::p_ExprMulVar::_new_ExprMulVar  (bool _3878,    int _3879,    int _3880,    std::shared_ptr< monty::ndarray< int,1 > > _3881,    std::shared_ptr< monty::ndarray< int,1 > > _3882,    std::shared_ptr< monty::ndarray< double,1 > > _3883,    monty::rc_ptr< ::mosek::fusion::Variable > _3884){ return new mosek::fusion::ExprMulVar(_3878,_3879,_3880,_3881,_3882,_3883,_3884); }mosek::fusion::ExprMulVar::ExprMulVar  (bool _3878,    int _3879,    int _3880,    std::shared_ptr< monty::ndarray< int,1 > > _3881,    std::shared_ptr< monty::ndarray< int,1 > > _3882,    std::shared_ptr< monty::ndarray< double,1 > > _3883,    monty::rc_ptr< ::mosek::fusion::Variable > _3884) :    ExprMulVar(new mosek::fusion::p_ExprMulVar(this)){ mosek::fusion::p_ExprMulVar::_get_impl(this)->_initialize(_3878,_3879,_3880,_3881,_3882,_3883,_3884); }void mosek::fusion::p_ExprMulVar::_initialize  (bool _3878,    int _3879,    int _3880,    std::shared_ptr< monty::ndarray< int,1 > > _3881,    std::shared_ptr< monty::ndarray< int,1 > > _3882,    std::shared_ptr< monty::ndarray< double,1 > > _3883,    monty::rc_ptr< ::mosek::fusion::Variable > _3884){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3881(_3881 ? _3881->raw() : nullptr, _3881 ? _3881->size(0) : 0);
    _checked_ptr_1<int> _ptr__3882(_3882 ? _3882->raw() : nullptr, _3882 ? _3882->size(0) : 0);
    _checked_ptr_1<double> _ptr__3883(_3883 ? _3883->raw() : nullptr, _3883 ? _3883->size(0) : 0);
    mosek::fusion::p_ExprMulVar::_initialize(_3878,_3879,_3880,_3881,_3882,_3883,_3884,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _3885 = _3884->getShape();
    _checked_ptr_1<int> _ptr__3885(_3885 ? _3885->raw() : nullptr,_3885 ? _3885->size(0) : 0);
    int _3886 = (int)((_3885)->size(0));
    if ((_3886 != (int)2))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    else if((_3878 && (_ptr__3885[(int)0] != _3880)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    else if(((!_3878) && (_ptr__3885[(int)1] != _3879)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    {}
    if ((((int)((_3881)->size(0)) != (int)((_3882)->size(0))) || ((int)((_3881)->size(0)) != (int)((_3883)->size(0)))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching matrix data lengths"));
      }
    }
    {}
    validate(_3879,_3880,_3881,_3882,_3883);
  }
}mosek::fusion::ExprMulVar::t mosek::fusion::p_ExprMulVar::_new_ExprMulVar  (bool _3887,    int _3888,    int _3889,    std::shared_ptr< monty::ndarray< int,1 > > _3890,    std::shared_ptr< monty::ndarray< int,1 > > _3891,    std::shared_ptr< monty::ndarray< double,1 > > _3892,    monty::rc_ptr< ::mosek::fusion::Variable > _3893,    int _3894){ return new mosek::fusion::ExprMulVar(_3887,_3888,_3889,_3890,_3891,_3892,_3893,_3894); }mosek::fusion::ExprMulVar::ExprMulVar  (bool _3887,    int _3888,    int _3889,    std::shared_ptr< monty::ndarray< int,1 > > _3890,    std::shared_ptr< monty::ndarray< int,1 > > _3891,    std::shared_ptr< monty::ndarray< double,1 > > _3892,    monty::rc_ptr< ::mosek::fusion::Variable > _3893,    int _3894) :    ExprMulVar(new mosek::fusion::p_ExprMulVar(this)){ mosek::fusion::p_ExprMulVar::_get_impl(this)->_initialize(_3887,_3888,_3889,_3890,_3891,_3892,_3893,_3894); }void mosek::fusion::p_ExprMulVar::_initialize  (bool _3887,    int _3888,    int _3889,    std::shared_ptr< monty::ndarray< int,1 > > _3890,    std::shared_ptr< monty::ndarray< int,1 > > _3891,    std::shared_ptr< monty::ndarray< double,1 > > _3892,    monty::rc_ptr< ::mosek::fusion::Variable > _3893,    int _3894){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3890(_3890 ? _3890->raw() : nullptr, _3890 ? _3890->size(0) : 0);
    _checked_ptr_1<int> _ptr__3891(_3891 ? _3891->raw() : nullptr, _3891 ? _3891->size(0) : 0);
    _checked_ptr_1<double> _ptr__3892(_3892 ? _3892->raw() : nullptr, _3892 ? _3892->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprMulVar::resshape(_3888,_3889,_3893->getShape(),_3887));
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->left = _3887;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->x = _3893;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimi = _3888;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimj = _3889;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi = ::mosek::fusion::Utils::Tools::arraycopy(_3890);
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubj = ::mosek::fusion::Utils::Tools::arraycopy(_3891);
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mcof = ::mosek::fusion::Utils::Tools::arraycopy(_3892);
  }
}void mosek::fusion::ExprMulVar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3895,monty::rc_ptr< ::mosek::fusion::WorkStack > _3896,monty::rc_ptr< ::mosek::fusion::WorkStack > _3897) { mosek::fusion::p_ExprMulVar::_get_impl(this)->eval(_3895,_3896,_3897); }void mosek::fusion::p_ExprMulVar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3895,monty::rc_ptr< ::mosek::fusion::WorkStack > _3896,monty::rc_ptr< ::mosek::fusion::WorkStack > _3897){
  if (left)
  {
    {
      _pubthis->eval_left(_3895,_3896,_3897);
    }
  }
  else
  {
    {
      _pubthis->eval_right(_3895,_3896,_3897);
    }
  }
}
void mosek::fusion::ExprMulVar :: eval_right(monty::rc_ptr< ::mosek::fusion::WorkStack > _3898,monty::rc_ptr< ::mosek::fusion::WorkStack > _3899,monty::rc_ptr< ::mosek::fusion::WorkStack > _3900) { mosek::fusion::p_ExprMulVar::_get_impl(this)->eval_right(_3898,_3899,_3900); }void mosek::fusion::p_ExprMulVar::eval_right(monty::rc_ptr< ::mosek::fusion::WorkStack > _3898,monty::rc_ptr< ::mosek::fusion::WorkStack > _3899,monty::rc_ptr< ::mosek::fusion::WorkStack > _3900){
  int _3901 = mosek::fusion::p_WorkStack::_get_impl(_3899)->pi32;
  int _3902 = mosek::fusion::p_WorkStack::_get_impl(_3899)->pi64;
  int _3903 = x->numInst();
  int _3904 = _3899->alloci64(_3903);
  int _3905 = _3899->alloci64(_3903);
  int _3906 = _3899->alloci32(_3903);
  int _3907 = _3899->alloci32(_3903);
  std::shared_ptr< monty::ndarray< int,1 > > _3908 = x->getShape();
  _checked_ptr_1<int> _ptr__3908(_3908 ? _3908->raw() : nullptr,_3908 ? _3908->size(0) : 0);
  int _3909 = (int)((_3908)->size(0));
  long long _3910 = safe_mul( _ptr__3908[(int)0],_ptr__3908[(int)1] );
  int _3911 = _ptr__3908[(int)1];
  int _3912 = _ptr__3908[(int)0];
  int _3913 = _3899->alloci32(safe_add( _3912,(int)1 ));
  int _3914 = (int)((mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _3915 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi;
  _checked_ptr_1<int> _ptr__3915(_3915 ? _3915->raw() : nullptr,_3915 ? _3915->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3916 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubj;
  _checked_ptr_1<int> _ptr__3916(_3916 ? _3916->raw() : nullptr,_3916 ? _3916->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3917 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mcof;
  _checked_ptr_1<double> _ptr__3917(_3917 ? _3917->raw() : nullptr,_3917 ? _3917->size(0) : 0);
  int _3918 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimi;
  int _3919 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimj;
  bool _3920 = ((_3914 / _3918) == _3919);
  int _3921 = _3899->alloci32(_3914);
  int _3922 = _3899->alloci32(safe_add( mdimj,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _3923 = mosek::fusion::p_WorkStack::_get_impl(_3899)->i32;
  _checked_ptr_1<int> _ptr__3923(_3923 ? _3923->raw() : nullptr,_3923 ? _3923->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3924 = mosek::fusion::p_WorkStack::_get_impl(_3899)->i64;
  _checked_ptr_1<long long> _ptr__3924(_3924 ? _3924->raw() : nullptr,_3924 ? _3924->size(0) : 0);
  int _3925 = (int)0;
  int _3926 = (int)0;
  x->inst(_3905,_3924,_3904,_3924);
  if (_3920)
  {
    {
      int _3927 = (int)0;
      if ((_3903 > (int)0))
      {
        {
          _3927 = (int)1;
          if ((_3912 > (int)1))
          {
            {
              if ((_3911 == (int)1))
              {
                {
                  int _8604 = (int)1;
                  int _8605 = _3903;
                  for (int _3928 = _8604; _3928 < _8605; ++_3928)
                  {
                    {
                      if ((_ptr__3924[safe_add( _3905,_3928 )] > _ptr__3924[(safe_add( _3905,_3928 ) - (int)1)]))
                      {
                        {
                          ++ _3927;
                        }
                      }
                      {}
                    }
                  }
                }
              }
              else
              {
                {
                  int _8606 = (int)1;
                  int _8607 = _3903;
                  for (int _3929 = _8606; _3929 < _8607; ++_3929)
                  {
                    {
                      if (((_ptr__3924[safe_add( _3905,_3929 )] / _3911) > (_ptr__3924[(safe_add( _3905,_3929 ) - (int)1)] / _3911)))
                      {
                        {
                          ++ _3927;
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
          {}
        }
      }
      {}
      _3926 = safe_mul( _3927,_3919 );
      _3925 = safe_mul( _3903,_3919 );
      bool _3930 = (_3927 < _3912);
      int _3931 = _3898->alloci32(safe_add( _3926,(int)1 ));
      int _8608;
      bool _8609 = _3930;
      if (_8609)
      {
        _8608 = (int)1;
      }
      else
      {
        _8608 = (int)0;
      }
      _3898->pushi32(_8608);
      _3898->pushi32(_3925);
      _3898->pushi32(_3926);
      _3898->pushi32(_3912);
      _3898->pushi32(_3919);
      _3898->pushi32((int)2);
      int _3932 = _3898->alloci64(_3925);
      int _3933 = _3898->alloci64(_3926);
      int _3934 = _3898->allocf64(_3925);
      int _3935 = _3898->allocf64(_3926);
      std::shared_ptr< monty::ndarray< int,1 > > _3936 = mosek::fusion::p_WorkStack::_get_impl(_3898)->i32;
      _checked_ptr_1<int> _ptr__3936(_3936 ? _3936->raw() : nullptr,_3936 ? _3936->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3937 = mosek::fusion::p_WorkStack::_get_impl(_3898)->i64;
      _checked_ptr_1<long long> _ptr__3937(_3937 ? _3937->raw() : nullptr,_3937 ? _3937->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3938 = mosek::fusion::p_WorkStack::_get_impl(_3898)->f64;
      _checked_ptr_1<double> _ptr__3938(_3938 ? _3938->raw() : nullptr,_3938 ? _3938->size(0) : 0);
      {
        int _3939 = (int)0;
        int _3940 = (int)0;
        int _3941 = (int)0;
        _ptr__3936[_3931] = (int)0;
        while ( (_3939 < _3903) )
        {
          {
            int _3942 = _3939;
            ++ _3939;
            while ( ((_3939 < _3903) && ((_ptr__3924[safe_add( _3905,_3939 )] / _3911) == (_ptr__3924[safe_add( _3905,_3942 )] / _3911))) )
            {
              {
                ++ _3939;
              }
            }
            long long _3943 = (_ptr__3924[safe_add( _3905,_3942 )] / _3911);
            int _8610 = (int)0;
            int _8611 = _3919;
            for (int _3944 = _8610; _3944 < _8611; ++_3944)
            {
              {
                int _8612 = _3942;
                int _8613 = _3939;
                for (int _3945 = _8612; _3945 < _8613; ++_3945)
                {
                  {
                    long long _3946 = (_ptr__3924[safe_add( _3905,_3945 )] % _3911);
                    _ptr__3937[safe_add( _3932,_3941 )] = _ptr__3924[safe_add( _3904,_3945 )];
                    _ptr__3938[safe_add( _3934,_3941 )] = _ptr__3917[safe_add( safe_mul( _3946,_3919 ),_3944 )];
                    ++ _3941;
                  }
                }
                _ptr__3936[safe_add( safe_add( _3931,_3940 ),(int)1 )] = _3941;
                _ptr__3938[safe_add( _3935,_3940 )] = 0.0;
                _ptr__3937[safe_add( _3933,_3940 )] = safe_add( safe_mul( _3943,_3919 ),_3944 );
                ++ _3940;
              }
            }
          }
        }
      }
      if ((!_3930))
      {
        {
          _3898->popi64(_3926);
        }
      }
      {}
    }
  }
  else
  {
    {
      {
        if ((_3919 == (int)1))
        {
          {
            int _8614 = (int)0;
            int _8615 = _3914;
            for (int _3947 = _8614; _3947 < _8615; ++_3947)
            {
              {
                _ptr__3923[safe_add( _3921,_3947 )] = _3947;
              }
            }
            _ptr__3923[_3922] = (int)0;
            _ptr__3923[safe_add( _3922,(int)1 )] = _3914;
          }
        }
        else
        {
          {
            _ptr__3923[_3922] = (int)0;
            int _8616 = (int)0;
            int _8617 = safe_add( _3919,(int)1 );
            for (int _3948 = _8616; _3948 < _8617; ++_3948)
            {
              {
                _ptr__3923[safe_add( _3922,_3948 )] = (int)0;
              }
            }
            int _8618 = (int)0;
            int _8619 = _3914;
            for (int _3949 = _8618; _3949 < _8619; ++_3949)
            {
              {
                ++ _ptr__3923[safe_add( safe_add( _3922,_ptr__3916[_3949] ),(int)1 )];
              }
            }
            int _8620 = (int)0;
            int _8621 = mdimj;
            for (int _3950 = _8620; _3950 < _8621; ++_3950)
            {
              {
                _ptr__3923[safe_add( safe_add( _3922,_3950 ),(int)1 )] += _ptr__3923[safe_add( _3922,_3950 )];
              }
            }
            int _8622 = (int)0;
            int _8623 = _3914;
            for (int _3951 = _8622; _3951 < _8623; ++_3951)
            {
              {
                _ptr__3923[safe_add( _3921,_ptr__3923[safe_add( _3922,_ptr__3916[_3951] )] )] = _3951;
                ++ _ptr__3923[safe_add( _3922,_ptr__3916[_3951] )];
              }
            }
            int _8624 = (int)0;
            int _8625 = _3919;
            for (int _3952 = _8624; _3952 < _8625; ++_3952)
            {
              {
                _ptr__3923[(safe_add( _3922,_3919 ) - _3952)] = _ptr__3923[((safe_add( _3922,_3919 ) - _3952) - (int)1)];
              }
            }
            _ptr__3923[_3922] = (int)0;
          }
        }
      }
      if (((_3903 / _3912) == _3911))
      {
        {
          int _3953 = (int)0;
          {
            int _3954 = (int)0;
            while ( (_3954 < _3914) )
            {
              {
                ++ _3954;
                while ( ((_3954 < _3914) && (_ptr__3916[_ptr__3923[(safe_add( _3921,_3954 ) - (int)1)]] == _ptr__3916[_ptr__3923[safe_add( _3921,_3954 )]])) )
                {
                  {
                    ++ _3954;
                  }
                }
                ++ _3953;
              }
            }
          }
          _3926 = safe_mul( _3953,_3912 );
          _3925 = safe_mul( _3914,_3912 );
          bool _3955 = (_3953 < _3919);
          int _3956 = _3898->alloci32(safe_add( _3926,(int)1 ));
          int _8626;
          bool _8627 = _3955;
          if (_8627)
          {
            _8626 = (int)1;
          }
          else
          {
            _8626 = (int)0;
          }
          _3898->pushi32(_8626);
          _3898->pushi32(_3925);
          _3898->pushi32(_3926);
          _3898->pushi32(_3912);
          _3898->pushi32(_3919);
          _3898->pushi32((int)2);
          int _3957 = _3898->alloci64(_3925);
          int _3958 = _3898->alloci64(_3926);
          int _3959 = _3898->allocf64(_3925);
          int _3960 = _3898->allocf64(_3926);
          std::shared_ptr< monty::ndarray< int,1 > > _3961 = mosek::fusion::p_WorkStack::_get_impl(_3898)->i32;
          _checked_ptr_1<int> _ptr__3961(_3961 ? _3961->raw() : nullptr,_3961 ? _3961->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3962 = mosek::fusion::p_WorkStack::_get_impl(_3898)->i64;
          _checked_ptr_1<long long> _ptr__3962(_3962 ? _3962->raw() : nullptr,_3962 ? _3962->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3963 = mosek::fusion::p_WorkStack::_get_impl(_3898)->f64;
          _checked_ptr_1<double> _ptr__3963(_3963 ? _3963->raw() : nullptr,_3963 ? _3963->size(0) : 0);
          _ptr__3961[_3956] = (int)0;
          int _3964 = (int)0;
          int _3965 = (int)0;
          int _8628 = (int)0;
          int _8629 = _3912;
          for (int _3966 = _8628; _3966 < _8629; ++_3966)
          {
            {
              int _3967 = (int)0;
              while ( (_3967 < _3914) )
              {
                {
                  int _3968 = _3967;
                  ++ _3967;
                  while ( ((_3967 < _3914) && (_ptr__3916[_ptr__3923[safe_add( _3921,_3968 )]] == _ptr__3916[_ptr__3923[safe_add( _3921,_3967 )]])) )
                  {
                    {
                      ++ _3967;
                    }
                  }
                  int _3969 = _ptr__3916[_ptr__3923[safe_add( _3921,_3968 )]];
                  int _8630 = _3968;
                  int _8631 = _3967;
                  for (int _3970 = _8630; _3970 < _8631; ++_3970)
                  {
                    {
                      int _3971 = _ptr__3915[_ptr__3923[safe_add( _3921,_3970 )]];
                      _ptr__3962[safe_add( _3957,_3965 )] = _ptr__3924[safe_add( safe_add( _3904,safe_mul( _3966,_3911 ) ),_3971 )];
                      _ptr__3963[safe_add( _3959,_3965 )] = _ptr__3917[_ptr__3923[safe_add( _3921,_3970 )]];
                      ++ _3965;
                    }
                  }
                  _ptr__3963[safe_add( _3960,_3964 )] = 0.0;
                  _ptr__3962[safe_add( _3958,_3964 )] = safe_add( safe_mul( _3966,_3919 ),_3969 );
                  _ptr__3961[safe_add( safe_add( _3956,_3964 ),(int)1 )] = _3965;
                  ++ _3964;
                }
              }
            }
          }
          if ((!_3955))
          {
            {
              _3898->popi64(_3926);
            }
          }
          {}
        }
      }
      else
      {
        {
          int _8632 = (int)0;
          int _8633 = safe_add( _3912,(int)1 );
          for (int _3972 = _8632; _3972 < _8633; ++_3972)
          {
            {
              _ptr__3923[safe_add( _3913,_3972 )] = (int)0;
            }
          }
          if ((_3909 == (int)1))
          {
            {
              int _8634 = (int)0;
              int _8635 = _3903;
              for (int _3973 = _8634; _3973 < _8635; ++_3973)
              {
                {
                  _ptr__3923[safe_add( _3906,_3973 )] = (int)0;
                }
              }
              int _8636 = (int)0;
              int _8637 = _3903;
              for (int _3974 = _8636; _3974 < _8637; ++_3974)
              {
                {
                  _ptr__3923[safe_add( _3907,_3974 )] = (int)_ptr__3924[safe_add( _3905,_3974 )];
                }
              }
              _ptr__3923[_3913] = (int)0;
              _ptr__3923[safe_add( _3913,(int)1 )] = _3903;
            }
          }
          else
          {
            {
              int _8638 = (int)0;
              int _8639 = _3903;
              for (int _3975 = _8638; _3975 < _8639; ++_3975)
              {
                {
                  _ptr__3923[safe_add( _3906,_3975 )] = (int)(_ptr__3924[safe_add( _3905,_3975 )] / _ptr__3908[(int)1]);
                }
              }
              int _8640 = (int)0;
              int _8641 = _3903;
              for (int _3976 = _8640; _3976 < _8641; ++_3976)
              {
                {
                  _ptr__3923[safe_add( _3907,_3976 )] = (int)(_ptr__3924[safe_add( _3905,_3976 )] % _ptr__3908[(int)1]);
                }
              }
              _ptr__3923[_3913] = (int)0;
              int _8642 = (int)0;
              int _8643 = _3903;
              for (int _3977 = _8642; _3977 < _8643; ++_3977)
              {
                {
                  ++ _ptr__3923[safe_add( safe_add( _3913,_ptr__3923[safe_add( _3906,_3977 )] ),(int)1 )];
                }
              }
              int _8644 = (int)0;
              int _8645 = _3912;
              for (int _3978 = _8644; _3978 < _8645; ++_3978)
              {
                {
                  _ptr__3923[safe_add( safe_add( _3913,_3978 ),(int)1 )] += _ptr__3923[safe_add( _3913,_3978 )];
                }
              }
            }
          }
          int _8646 = (int)0;
          int _8647 = _3912;
          for (int _3979 = _8646; _3979 < _8647; ++_3979)
          {
            {
              int _8648 = (int)0;
              int _8649 = mdimj;
              for (int _3980 = _8648; _3980 < _8649; ++_3980)
              {
                {
                  int _3981 = (int)0;
                  int _3982 = _ptr__3923[safe_add( safe_add( _3913,_3979 ),(int)1 )];
                  int _3983 = _ptr__3923[safe_add( safe_add( _3922,_3980 ),(int)1 )];
                  int _3984 = _ptr__3923[safe_add( _3913,_3979 )];
                  int _3985 = _ptr__3923[safe_add( _3922,_3980 )];
                  while ( ((_3985 < _3983) && (_3984 < _3982)) )
                  {
                    {
                      if ((_ptr__3915[_ptr__3923[safe_add( _3921,_3985 )]] < _ptr__3923[safe_add( _3907,_3984 )]))
                      {
                        {
                          ++ _3985;
                        }
                      }
                      else if((_ptr__3915[_ptr__3923[safe_add( _3921,_3985 )]] > _ptr__3923[safe_add( _3907,_3984 )]))
                      {
                        {
                          ++ _3984;
                        }
                      }
                      else
                      {
                        {
                          ++ _3981;
                          ++ _3985;
                          ++ _3984;
                        }
                      }
                    }
                  }
                  if ((_3981 > (int)0))
                  {
                    {
                      _3925 += _3981;
                      ++ _3926;
                    }
                  }
                  {}
                }
              }
            }
          }
          int _3986 = _3898->alloci32(safe_add( _3926,(int)1 ));
          bool _8650;
          bool _8651 = (_3926 < safe_mul( _3911,mdimi ));
          if (_8651)
          {
            _8650 = true;
          }
          else
          {
            _8650 = false;
          }
          bool _3987 = _8650;
          int _8652;
          bool _8653 = _3987;
          if (_8653)
          {
            _8652 = (int)1;
          }
          else
          {
            _8652 = (int)0;
          }
          _3898->pushi32(_8652);
          _3898->pushi32(_3925);
          _3898->pushi32(_3926);
          _3898->pushi32(_3912);
          _3898->pushi32(mdimj);
          _3898->pushi32((int)2);
          int _3988 = _3898->alloci64(_3925);
          int _3989 = _3898->alloci64(_3926);
          int _3990 = _3898->allocf64(_3925);
          int _3991 = _3898->allocf64(_3926);
          std::shared_ptr< monty::ndarray< int,1 > > _3992 = mosek::fusion::p_WorkStack::_get_impl(_3898)->i32;
          _checked_ptr_1<int> _ptr__3992(_3992 ? _3992->raw() : nullptr,_3992 ? _3992->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3993 = mosek::fusion::p_WorkStack::_get_impl(_3898)->i64;
          _checked_ptr_1<long long> _ptr__3993(_3993 ? _3993->raw() : nullptr,_3993 ? _3993->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3994 = mosek::fusion::p_WorkStack::_get_impl(_3898)->f64;
          _checked_ptr_1<double> _ptr__3994(_3994 ? _3994->raw() : nullptr,_3994 ? _3994->size(0) : 0);
          {
            int _3995 = (int)0;
            int _3996 = (int)0;
            int _3997 = (int)0;
            _ptr__3992[_3986] = (int)0;
            int _8654 = (int)0;
            int _8655 = _3926;
            for (int _3998 = _8654; _3998 < _8655; ++_3998)
            {
              {
                _ptr__3994[safe_add( _3991,_3998 )] = 0.0;
              }
            }
            int _8656 = (int)0;
            int _8657 = _3912;
            for (int _3999 = _8656; _3999 < _8657; ++_3999)
            {
              {
                int _8658 = (int)0;
                int _8659 = mdimj;
                for (int _4000 = _8658; _4000 < _8659; ++_4000)
                {
                  {
                    int _4001 = (int)0;
                    int _4002 = _ptr__3923[safe_add( safe_add( _3913,_3999 ),(int)1 )];
                    int _4003 = _ptr__3923[safe_add( safe_add( _3922,_4000 ),(int)1 )];
                    int _4004 = _ptr__3923[safe_add( _3913,_3999 )];
                    int _4005 = _ptr__3923[safe_add( _3922,_4000 )];
                    while ( ((_4005 < _4003) && (_4004 < _4002)) )
                    {
                      {
                        if ((_ptr__3915[_ptr__3923[safe_add( _3921,_4005 )]] < _ptr__3923[safe_add( _3907,_4004 )]))
                        {
                          {
                            ++ _4005;
                          }
                        }
                        else if((_ptr__3915[_ptr__3923[safe_add( _3921,_4005 )]] > _ptr__3923[safe_add( _3907,_4004 )]))
                        {
                          {
                            ++ _4004;
                          }
                        }
                        else
                        {
                          {
                            _ptr__3993[safe_add( _3988,_3997 )] = _ptr__3924[safe_add( _3904,_4004 )];
                            _ptr__3994[safe_add( _3990,_3997 )] = _ptr__3917[_ptr__3923[safe_add( _3921,_4005 )]];
                            ++ _4001;
                            ++ _3997;
                            ++ _4005;
                            ++ _4004;
                          }
                        }
                      }
                    }
                    if ((_4001 > (int)0))
                    {
                      {
                        _ptr__3992[safe_add( safe_add( _3986,_3996 ),(int)1 )] = _3997;
                        _ptr__3993[safe_add( _3989,_3996 )] = _3995;
                        ++ _3996;
                      }
                    }
                    {}
                    ++ _3995;
                  }
                }
              }
            }
          }
          if ((!_3987))
          {
            {
              _3898->popi64(_3926);
            }
          }
          {}
        }
      }
    }
  }
  mosek::fusion::p_WorkStack::_get_impl(_3899)->pi32 = _3901;
  mosek::fusion::p_WorkStack::_get_impl(_3899)->pi64 = _3902;
}
void mosek::fusion::ExprMulVar :: eval_left(monty::rc_ptr< ::mosek::fusion::WorkStack > _4006,monty::rc_ptr< ::mosek::fusion::WorkStack > _4007,monty::rc_ptr< ::mosek::fusion::WorkStack > _4008) { mosek::fusion::p_ExprMulVar::_get_impl(this)->eval_left(_4006,_4007,_4008); }void mosek::fusion::p_ExprMulVar::eval_left(monty::rc_ptr< ::mosek::fusion::WorkStack > _4006,monty::rc_ptr< ::mosek::fusion::WorkStack > _4007,monty::rc_ptr< ::mosek::fusion::WorkStack > _4008){
  int _4009 = x->numInst();
  std::shared_ptr< monty::ndarray< int,1 > > _4010 = x->getShape();
  _checked_ptr_1<int> _ptr__4010(_4010 ? _4010->raw() : nullptr,_4010 ? _4010->size(0) : 0);
  int _4011 = (int)((_4010)->size(0));
  int _4012 = _4008->alloci64(_4009);
  int _4013 = _4008->alloci64(_4009);
  int _4014 = _4008->alloci32(_4009);
  int _4015 = _4008->alloci32(_4009);
  int _4016 = _4008->alloci32(_4009);
  int _4017 = _4008->alloci32(safe_add( mdimi,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _4018 = x->getShape();
  _checked_ptr_1<int> _ptr__4018(_4018 ? _4018->raw() : nullptr,_4018 ? _4018->size(0) : 0);
  int _4019 = (int)((_4018)->size(0));
  int _8660;
  bool _8661 = (_4019 == (int)1);
  if (_8661)
  {
    _8660 = (int)1;
  }
  else
  {
    _8660 = _ptr__4018[(int)1];
  }
  int _4020 = _8660;
  int _4021 = _ptr__4018[(int)0];
  int _4022 = _4008->alloci32(safe_add( _4020,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _4023 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi;
  _checked_ptr_1<int> _ptr__4023(_4023 ? _4023->raw() : nullptr,_4023 ? _4023->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4024 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubj;
  _checked_ptr_1<int> _ptr__4024(_4024 ? _4024->raw() : nullptr,_4024 ? _4024->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4025 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mcof;
  _checked_ptr_1<double> _ptr__4025(_4025 ? _4025->raw() : nullptr,_4025 ? _4025->size(0) : 0);
  int _4026 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimi;
  int _4027 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimj;
  int _4028 = (int)0;
  int _4029 = (int)0;
  std::shared_ptr< monty::ndarray< int,1 > > _4030 = mosek::fusion::p_WorkStack::_get_impl(_4008)->i32;
  _checked_ptr_1<int> _ptr__4030(_4030 ? _4030->raw() : nullptr,_4030 ? _4030->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4031 = mosek::fusion::p_WorkStack::_get_impl(_4008)->i64;
  _checked_ptr_1<long long> _ptr__4031(_4031 ? _4031->raw() : nullptr,_4031 ? _4031->size(0) : 0);
  int _4032 = (int)((_4025)->size(0));
  x->inst(_4013,_4031,_4012,_4031);
  if ((x->numInst() < x->getSize()))
  {
    {
      {
        int _8662 = (int)0;
        int _8663 = safe_add( _4026,(int)1 );
        for (int _4033 = _8662; _4033 < _8663; ++_4033)
        {
          {
            _ptr__4030[safe_add( _4017,_4033 )] = (int)0;
          }
        }
        int _8664 = (int)0;
        int _8665 = (int)((_4023)->size(0));
        for (int _4034 = _8664; _4034 < _8665; ++_4034)
        {
          {
            ++ _ptr__4030[safe_add( safe_add( _4017,_ptr__4023[_4034] ),(int)1 )];
          }
        }
        int _8666 = (int)0;
        int _8667 = _4026;
        for (int _4035 = _8666; _4035 < _8667; ++_4035)
        {
          {
            _ptr__4030[safe_add( safe_add( _4017,_4035 ),(int)1 )] += _ptr__4030[safe_add( _4017,_4035 )];
          }
        }
        if ((_4019 == (int)1))
        {
          {
            int _8668 = (int)0;
            int _8669 = _4009;
            for (int _4036 = _8668; _4036 < _8669; ++_4036)
            {
              {
                _ptr__4030[safe_add( _4014,_4036 )] = (int)_ptr__4031[safe_add( _4013,_4036 )];
              }
            }
            int _8670 = (int)0;
            int _8671 = _4009;
            for (int _4037 = _8670; _4037 < _8671; ++_4037)
            {
              {
                _ptr__4030[safe_add( _4015,_4037 )] = (int)0;
              }
            }
          }
        }
        else
        {
          {
            int _8672 = (int)0;
            int _8673 = _4009;
            for (int _4038 = _8672; _4038 < _8673; ++_4038)
            {
              {
                _ptr__4030[safe_add( _4014,_4038 )] = (int)(_ptr__4031[safe_add( _4013,_4038 )] / _4020);
              }
            }
            int _8674 = (int)0;
            int _8675 = _4009;
            for (int _4039 = _8674; _4039 < _8675; ++_4039)
            {
              {
                _ptr__4030[safe_add( _4015,_4039 )] = (int)(_ptr__4031[safe_add( _4013,_4039 )] % _4020);
              }
            }
          }
        }
        if ((_4019 > (int)1))
        {
          {
            int _8676 = (int)0;
            int _8677 = safe_add( _4020,(int)1 );
            for (int _4040 = _8676; _4040 < _8677; ++_4040)
            {
              {
                _ptr__4030[safe_add( _4022,_4040 )] = (int)0;
              }
            }
            int _8678 = (int)0;
            int _8679 = _4009;
            for (int _4041 = _8678; _4041 < _8679; ++_4041)
            {
              {
                ++ _ptr__4030[safe_add( safe_add( _4022,_ptr__4030[safe_add( _4015,_4041 )] ),(int)1 )];
              }
            }
            int _8680 = (int)0;
            int _8681 = _4020;
            for (int _4042 = _8680; _4042 < _8681; ++_4042)
            {
              {
                _ptr__4030[safe_add( safe_add( _4022,_4042 ),(int)1 )] += _ptr__4030[safe_add( _4022,_4042 )];
              }
            }
            int _8682 = (int)0;
            int _8683 = _4009;
            for (int _4043 = _8682; _4043 < _8683; ++_4043)
            {
              {
                _ptr__4030[safe_add( _4016,_ptr__4030[safe_add( _4022,_ptr__4030[safe_add( _4015,_4043 )] )] )] = _4043;
                ++ _ptr__4030[safe_add( _4022,_ptr__4030[safe_add( _4015,_4043 )] )];
              }
            }
            int _8684 = (int)0;
            int _8685 = _4020;
            for (int _4044 = _8684; _4044 < _8685; ++_4044)
            {
              {
                _ptr__4030[(safe_add( _4022,_4020 ) - _4044)] = _ptr__4030[((safe_add( _4022,_4020 ) - _4044) - (int)1)];
              }
            }
            _ptr__4030[_4022] = (int)0;
          }
        }
        else
        {
          {
            _ptr__4030[_4022] = (int)0;
            _ptr__4030[safe_add( _4022,(int)1 )] = _4009;
            int _8686 = (int)0;
            int _8687 = _4009;
            for (int _4045 = _8686; _4045 < _8687; ++_4045)
            {
              {
                _ptr__4030[safe_add( _4016,_4045 )] = _4045;
              }
            }
          }
        }
        int _8688 = (int)0;
        int _8689 = _4026;
        for (int _4046 = _8688; _4046 < _8689; ++_4046)
        {
          {
            int _8690 = (int)0;
            int _8691 = _4020;
            for (int _4047 = _8690; _4047 < _8691; ++_4047)
            {
              {
                int _4048 = (int)0;
                int _4049 = _ptr__4030[safe_add( safe_add( _4022,_4047 ),(int)1 )];
                int _4050 = _ptr__4030[safe_add( safe_add( _4017,_4046 ),(int)1 )];
                int _4051 = _ptr__4030[safe_add( _4022,_4047 )];
                int _4052 = _ptr__4030[safe_add( _4017,_4046 )];
                while ( ((_4052 < _4050) && (_4051 < _4049)) )
                {
                  {
                    if ((_ptr__4024[_4052] < _ptr__4030[safe_add( _4014,_ptr__4030[safe_add( _4016,_4051 )] )]))
                    {
                      {
                        ++ _4052;
                      }
                    }
                    else if((_ptr__4024[_4052] > _ptr__4030[safe_add( _4014,_ptr__4030[safe_add( _4016,_4051 )] )]))
                    {
                      {
                        ++ _4051;
                      }
                    }
                    else
                    {
                      {
                        ++ _4048;
                        ++ _4052;
                        ++ _4051;
                      }
                    }
                  }
                }
                if ((_4048 > (int)0))
                {
                  {
                    _4028 += _4048;
                    ++ _4029;
                  }
                }
                {}
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      _4028 = safe_mul( _4032,_4020 );
      int _4053 = (int)0;
      while ( (_4053 < _4032) )
      {
        {
          int _4054 = safe_add( _4053,(int)1 );
          while ( ((_4054 < _4032) && (_ptr__4023[_4053] == _ptr__4023[_4054])) )
          {
            {
              ++ _4054;
            }
          }
          ++ _4029;
          _4053 = _4054;
        }
      }
      _4029 *= _4020;
    }
  }
  bool _8692;
  bool _8693 = (_4029 < safe_mul( _4020,_4026 ));
  if (_8693)
  {
    _8692 = true;
  }
  else
  {
    _8692 = false;
  }
  bool _4055 = _8692;
  int _4056 = _4019;
  _4006->alloc_expr(_4056,_4029,_4028,_4055);
  int _4057 = mosek::fusion::p_WorkStack::_get_impl(_4006)->ptr_base;
  int _4058 = mosek::fusion::p_WorkStack::_get_impl(_4006)->shape_base;
  int _4059 = mosek::fusion::p_WorkStack::_get_impl(_4006)->nidxs_base;
  int _8694;
  bool _8695 = _4055;
  if (_8695)
  {
    _8694 = mosek::fusion::p_WorkStack::_get_impl(_4006)->sp_base;
  }
  else
  {
    _8694 = _4006->alloci64(_4029);
  }
  int _4060 = _8694;
  int _4061 = mosek::fusion::p_WorkStack::_get_impl(_4006)->cof_base;
  int _4062 = mosek::fusion::p_WorkStack::_get_impl(_4006)->bfix_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4063 = mosek::fusion::p_WorkStack::_get_impl(_4006)->i32;
  _checked_ptr_1<int> _ptr__4063(_4063 ? _4063->raw() : nullptr,_4063 ? _4063->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4064 = mosek::fusion::p_WorkStack::_get_impl(_4006)->i64;
  _checked_ptr_1<long long> _ptr__4064(_4064 ? _4064->raw() : nullptr,_4064 ? _4064->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4065 = mosek::fusion::p_WorkStack::_get_impl(_4006)->f64;
  _checked_ptr_1<double> _ptr__4065(_4065 ? _4065->raw() : nullptr,_4065 ? _4065->size(0) : 0);
  _ptr__4063[_4058] = _4026;
  if ((_4019 > (int)1))
  {
    {
      _ptr__4063[safe_add( _4058,(int)1 )] = _4020;
    }
  }
  {}
  if ((x->numInst() < x->getSize()))
  {
    {
      int _4066 = (int)0;
      int _4067 = (int)0;
      int _4068 = (int)0;
      _ptr__4063[_4057] = (int)0;
      int _8696 = (int)0;
      int _8697 = _4029;
      for (int _4069 = _8696; _4069 < _8697; ++_4069)
      {
        {
          _ptr__4065[safe_add( _4062,_4069 )] = 0.0;
        }
      }
      int _8698 = (int)0;
      int _8699 = _4026;
      for (int _4070 = _8698; _4070 < _8699; ++_4070)
      {
        {
          int _8700 = (int)0;
          int _8701 = _4020;
          for (int _4071 = _8700; _4071 < _8701; ++_4071)
          {
            {
              int _4072 = (int)0;
              int _4073 = _ptr__4030[safe_add( safe_add( _4022,_4071 ),(int)1 )];
              int _4074 = _ptr__4030[safe_add( safe_add( _4017,_4070 ),(int)1 )];
              int _4075 = _ptr__4030[safe_add( _4022,_4071 )];
              int _4076 = _ptr__4030[safe_add( _4017,_4070 )];
              while ( ((_4076 < _4074) && (_4075 < _4073)) )
              {
                {
                  if ((_ptr__4024[_4076] < _ptr__4030[safe_add( _4014,_ptr__4030[safe_add( _4016,_4075 )] )]))
                  {
                    {
                      ++ _4076;
                    }
                  }
                  else if((_ptr__4024[_4076] > _ptr__4030[safe_add( _4014,_ptr__4030[safe_add( _4016,_4075 )] )]))
                  {
                    {
                      ++ _4075;
                    }
                  }
                  else
                  {
                    {
                      _ptr__4064[safe_add( _4059,_4068 )] = _ptr__4031[safe_add( _4012,_ptr__4030[safe_add( _4016,_4075 )] )];
                      _ptr__4065[safe_add( _4061,_4068 )] = _ptr__4025[_4076];
                      ++ _4072;
                      ++ _4068;
                      ++ _4076;
                      ++ _4075;
                    }
                  }
                }
              }
              if ((_4072 > (int)0))
              {
                {
                  _ptr__4063[safe_add( safe_add( _4057,_4067 ),(int)1 )] = _4068;
                  _ptr__4064[safe_add( _4060,_4067 )] = _4066;
                  ++ _4067;
                }
              }
              {}
              ++ _4066;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _4077 = (int)0;
      int _4078 = (int)0;
      _ptr__4063[_4057] = (int)0;
      int _4079 = (int)0;
      while ( (_4079 < _4032) )
      {
        {
          int _4080 = safe_add( _4079,(int)1 );
          while ( ((_4080 < _4032) && (_ptr__4023[_4080] == _ptr__4023[_4079])) )
          {
            {
              ++ _4080;
            }
          }
          int _8702 = (int)0;
          int _8703 = _4020;
          for (int _4081 = _8702; _4081 < _8703; ++_4081)
          {
            {
              int _8704 = _4079;
              int _8705 = _4080;
              for (int _4082 = _8704; _4082 < _8705; ++_4082)
              {
                {
                  _ptr__4064[safe_add( _4059,_4077 )] = _ptr__4031[safe_add( safe_add( _4012,safe_mul( _ptr__4024[_4082],_4020 ) ),_4081 )];
                  _ptr__4065[safe_add( _4061,_4077 )] = _ptr__4025[_4082];
                  ++ _4077;
                }
              }
              _ptr__4063[safe_add( safe_add( _4057,_4078 ),(int)1 )] = _4077;
              _ptr__4064[safe_add( _4060,_4078 )] = safe_add( safe_mul( _ptr__4023[_4079],_4020 ),_4081 );
              _ptr__4065[safe_add( _4062,_4078 )] = (int)0;
              ++ _4078;
            }
          }
          _4079 = _4080;
        }
      }
    }
  }
  if ((!_4055))
  {
    {
      _4006->popi64(_4029);
    }
  }
  {}
  _4008->clear();
}
void mosek::fusion::p_ExprMulVar::validate(int _4083,int _4084,std::shared_ptr< monty::ndarray< int,1 > > _4085,std::shared_ptr< monty::ndarray< int,1 > > _4086,std::shared_ptr< monty::ndarray< double,1 > > _4087){
  _checked_ptr_1<int> _ptr__4085(_4085 ? _4085->raw() : nullptr, _4085 ? _4085->size(0) : 0);
  _checked_ptr_1<int> _ptr__4086(_4086 ? _4086->raw() : nullptr, _4086 ? _4086->size(0) : 0);
  _checked_ptr_1<double> _ptr__4087(_4087 ? _4087->raw() : nullptr, _4087 ? _4087->size(0) : 0);
  bool _4088 = true;
  {
    int _8706 = (int)0;
    int _8707 = (int)((_4085)->size(0));
    for (int _4089 = _8706; _4089 < _8707; ++_4089)
    {
      {
        if (((_ptr__4085[_4089] < (int)0) || ((_ptr__4085[_4089] >= _4083) || ((_ptr__4086[_4089] < (int)0) || (_ptr__4086[_4089] >= _4084)))))
        {
          {
            _4088 = false;
          }
        }
        {}
      }
    }
    int _8708 = (int)1;
    int _8709 = (int)((_4085)->size(0));
    for (int _4090 = _8708; _4090 < _8709; ++_4090)
    {
      {
        if (((_ptr__4085[(_4090 - (int)1)] > _ptr__4085[_4090]) || ((_ptr__4085[(_4090 - (int)1)] == _ptr__4085[_4090]) && (_ptr__4086[(_4090 - (int)1)] >= _ptr__4086[_4090]))))
        {
          {
            _4088 = false;
          }
        }
        {}
      }
    }
  }
  if ((!_4088))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid matrix data"));
    }
  }
  {}
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprMulVar::resshape(int _4091,int _4092,std::shared_ptr< monty::ndarray< int,1 > > _4093,bool _4094){
  _checked_ptr_1<int> _ptr__4093(_4093 ? _4093->raw() : nullptr, _4093 ? _4093->size(0) : 0);
  if (_4094)
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4091),(int)(_ptr__4093[(int)1])});
    }
  }
  else
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__4093[(int)0]),(int)(_4092)});
    }
  }
}
std::string mosek::fusion::ExprMulVar :: toString() { return mosek::fusion::p_ExprMulVar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulVar::toString(){
  if (left)
  {
    {
      return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulVar(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
    }
  }
  else
  {
    {
      return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulVar("))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",M)"))->toString();
    }
  }
}
void mosek::fusion::p_ExprMulVar::destroy(){x.reset();mcof.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulVar::destroy() { mosek::fusion::p_ExprMulVar::_get_impl(this)->destroy(); }mosek::fusion::ExprMulScalarVar::ExprMulScalarVar(mosek::fusion::p_ExprMulScalarVar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulScalarVar()" << this << std::endl; */ }mosek::fusion::ExprMulScalarVar::~ExprMulScalarVar() {  /* std::cout << "~ExprMulScalarVar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulScalarVar::p_ExprMulScalarVar  (::mosek::fusion::ExprMulScalarVar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulScalarVar::t mosek::fusion::p_ExprMulScalarVar::_new_ExprMulScalarVar  (int _4095,    int _4096,    std::shared_ptr< monty::ndarray< int,1 > > _4097,    std::shared_ptr< monty::ndarray< int,1 > > _4098,    std::shared_ptr< monty::ndarray< double,1 > > _4099,    monty::rc_ptr< ::mosek::fusion::Variable > _4100){ return new mosek::fusion::ExprMulScalarVar(_4095,_4096,_4097,_4098,_4099,_4100); }mosek::fusion::ExprMulScalarVar::ExprMulScalarVar  (int _4095,    int _4096,    std::shared_ptr< monty::ndarray< int,1 > > _4097,    std::shared_ptr< monty::ndarray< int,1 > > _4098,    std::shared_ptr< monty::ndarray< double,1 > > _4099,    monty::rc_ptr< ::mosek::fusion::Variable > _4100) :    ExprMulScalarVar(new mosek::fusion::p_ExprMulScalarVar(this)){ mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->_initialize(_4095,_4096,_4097,_4098,_4099,_4100); }void mosek::fusion::p_ExprMulScalarVar::_initialize  (int _4095,    int _4096,    std::shared_ptr< monty::ndarray< int,1 > > _4097,    std::shared_ptr< monty::ndarray< int,1 > > _4098,    std::shared_ptr< monty::ndarray< double,1 > > _4099,    monty::rc_ptr< ::mosek::fusion::Variable > _4100){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4097(_4097 ? _4097->raw() : nullptr, _4097 ? _4097->size(0) : 0);
    _checked_ptr_1<int> _ptr__4098(_4098 ? _4098->raw() : nullptr, _4098 ? _4098->size(0) : 0);
    _checked_ptr_1<double> _ptr__4099(_4099 ? _4099->raw() : nullptr, _4099 ? _4099->size(0) : 0);
    mosek::fusion::p_ExprMulScalarVar::_initialize(_4095,_4096,::mosek::fusion::Utils::Tools::arraycopy(_4097),::mosek::fusion::Utils::Tools::arraycopy(_4098),::mosek::fusion::Utils::Tools::arraycopy(_4099),_4100,(int)1);
    if ((_4100->getND() != (int)0))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid Variable size"));
      }
    }
    {}
    if (((_4095 < (int)0) || ((_4096 < (int)0) || (((int)((_4097)->size(0)) != (int)((_4098)->size(0))) || ((int)((_4097)->size(0)) != (int)((_4099)->size(0)))))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid Matrix data"));
      }
    }
    {}
    bool _4101 = false;
    int _8710 = (int)0;
    int _8711 = (int)((_4097)->size(0));
    for (int _4102 = _8710; _4102 < _8711; ++_4102)
    {
      {
        if (((_ptr__4097[_4102] < (int)0) || ((_ptr__4097[_4102] >= _4095) || ((_ptr__4098[_4102] < (int)0) || (_ptr__4098[_4102] >= _4096)))))
        {
          {
            _4101 = true;
          }
        }
        {}
      }
    }
    if (_4101)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Invalid Matrix data"));
      }
    }
    {}
    bool _4103 = false;
    int _8712 = (int)1;
    int _8713 = (int)((_4097)->size(0));
    for (int _4104 = _8712; _4104 < _8713; ++_4104)
    {
      {
        if (((_ptr__4097[_4104] < _ptr__4097[(_4104 - (int)1)]) || ((_ptr__4097[_4104] == _ptr__4097[(_4104 - (int)1)]) && (_ptr__4098[_4104] <= _ptr__4098[(_4104 - (int)1)]))))
        {
          {
            _4103 = true;
          }
        }
        {}
      }
    }
    if (_4103)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Matrix data not correctly sorted"));
      }
    }
    {}
  }
}mosek::fusion::ExprMulScalarVar::t mosek::fusion::p_ExprMulScalarVar::_new_ExprMulScalarVar  (int _4105,    int _4106,    std::shared_ptr< monty::ndarray< int,1 > > _4107,    std::shared_ptr< monty::ndarray< int,1 > > _4108,    std::shared_ptr< monty::ndarray< double,1 > > _4109,    monty::rc_ptr< ::mosek::fusion::Variable > _4110,    int _4111){ return new mosek::fusion::ExprMulScalarVar(_4105,_4106,_4107,_4108,_4109,_4110,_4111); }mosek::fusion::ExprMulScalarVar::ExprMulScalarVar  (int _4105,    int _4106,    std::shared_ptr< monty::ndarray< int,1 > > _4107,    std::shared_ptr< monty::ndarray< int,1 > > _4108,    std::shared_ptr< monty::ndarray< double,1 > > _4109,    monty::rc_ptr< ::mosek::fusion::Variable > _4110,    int _4111) :    ExprMulScalarVar(new mosek::fusion::p_ExprMulScalarVar(this)){ mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->_initialize(_4105,_4106,_4107,_4108,_4109,_4110,_4111); }void mosek::fusion::p_ExprMulScalarVar::_initialize  (int _4105,    int _4106,    std::shared_ptr< monty::ndarray< int,1 > > _4107,    std::shared_ptr< monty::ndarray< int,1 > > _4108,    std::shared_ptr< monty::ndarray< double,1 > > _4109,    monty::rc_ptr< ::mosek::fusion::Variable > _4110,    int _4111){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4107(_4107 ? _4107->raw() : nullptr, _4107 ? _4107->size(0) : 0);
    _checked_ptr_1<int> _ptr__4108(_4108 ? _4108->raw() : nullptr, _4108 ? _4108->size(0) : 0);
    _checked_ptr_1<double> _ptr__4109(_4109 ? _4109->raw() : nullptr, _4109 ? _4109->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4105),(int)(_4106)}));
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->mdimi = _4105;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->mdimj = _4106;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->msubi = _4107;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->msubj = _4108;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->mcof = _4109;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->x = _4110;
  }
}void mosek::fusion::ExprMulScalarVar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4112,monty::rc_ptr< ::mosek::fusion::WorkStack > _4113,monty::rc_ptr< ::mosek::fusion::WorkStack > _4114) { mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->eval(_4112,_4113,_4114); }void mosek::fusion::p_ExprMulScalarVar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4112,monty::rc_ptr< ::mosek::fusion::WorkStack > _4113,monty::rc_ptr< ::mosek::fusion::WorkStack > _4114){
  if ((x->numInst() == (int)0))
  {
    {
      _4112->alloc_expr((int)2,(int)0,(int)0,false);
      ((*mosek::fusion::p_WorkStack::_get_impl(_4112)->i32)(mosek::fusion::p_WorkStack::_get_impl(_4112)->shape_base)) = mdimi;
      ((*mosek::fusion::p_WorkStack::_get_impl(_4112)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_4112)->shape_base,(int)1 ))) = mdimj;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _4115 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)1)));
      _checked_ptr_1<long long> _ptr__4115(_4115 ? _4115->raw() : nullptr,_4115 ? _4115->size(0) : 0);
      x->inst((int)0,_4115);
      long long _4116 = _ptr__4115[(int)0];
      int _4117 = (int)((msubi)->size(0));
      int _4118 = _4117;
      bool _4119 = (_4117 < safe_mul( mdimi,mdimj ));
      _4112->alloc_expr((int)2,_4117,_4118,_4119);
      int _4120 = mosek::fusion::p_WorkStack::_get_impl(_4112)->ptr_base;
      ((*mosek::fusion::p_WorkStack::_get_impl(_4112)->i32)(mosek::fusion::p_WorkStack::_get_impl(_4112)->shape_base)) = mdimi;
      ((*mosek::fusion::p_WorkStack::_get_impl(_4112)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_4112)->shape_base,(int)1 ))) = mdimj;
      int _4121 = mosek::fusion::p_WorkStack::_get_impl(_4112)->nidxs_base;
      int _4122 = mosek::fusion::p_WorkStack::_get_impl(_4112)->sp_base;
      int _4123 = mosek::fusion::p_WorkStack::_get_impl(_4112)->cof_base;
      int _4124 = mosek::fusion::p_WorkStack::_get_impl(_4112)->bfix_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4125 = mosek::fusion::p_WorkStack::_get_impl(_4112)->i32;
      _checked_ptr_1<int> _ptr__4125(_4125 ? _4125->raw() : nullptr,_4125 ? _4125->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4126 = mosek::fusion::p_WorkStack::_get_impl(_4112)->i64;
      _checked_ptr_1<long long> _ptr__4126(_4126 ? _4126->raw() : nullptr,_4126 ? _4126->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4127 = mosek::fusion::p_WorkStack::_get_impl(_4112)->f64;
      _checked_ptr_1<double> _ptr__4127(_4127 ? _4127->raw() : nullptr,_4127 ? _4127->size(0) : 0);
      {
        int _8714 = (int)0;
        int _8715 = _4117;
        for (int _4128 = _8714; _4128 < _8715; ++_4128)
        {
          {
            _ptr__4127[safe_add( _4124,_4128 )] = (int)0;
          }
        }
        int _8716 = (int)0;
        int _8717 = _4118;
        for (int _4129 = _8716; _4129 < _8717; ++_4129)
        {
          {
            _ptr__4127[safe_add( _4123,_4129 )] = ((*mcof)(_4129));
          }
        }
        int _8718 = (int)0;
        int _8719 = _4118;
        for (int _4130 = _8718; _4130 < _8719; ++_4130)
        {
          {
            _ptr__4126[safe_add( _4121,_4130 )] = _4116;
          }
        }
        if (_4119)
        {
          {
            int _8720 = (int)0;
            int _8721 = _4117;
            for (int _4131 = _8720; _4131 < _8721; ++_4131)
            {
              {
                _ptr__4126[safe_add( _4122,_4131 )] = safe_add( safe_mul( ((*msubi)(_4131)),mdimj ),((*msubj)(_4131)) );
              }
            }
          }
        }
        {}
        int _8722 = (int)0;
        int _8723 = safe_add( _4117,(int)1 );
        for (int _4132 = _8722; _4132 < _8723; ++_4132)
        {
          {
            _ptr__4125[safe_add( _4120,_4132 )] = _4132;
          }
        }
      }
    }
  }
}
std::string mosek::fusion::ExprMulScalarVar :: toString() { return mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulScalarVar::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulScalarVar(M("))->__mosek_2fusion_2Utils_2StringBuffer__a(mdimi)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(mdimj)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("), "))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulScalarVar::destroy(){x.reset();mcof.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulScalarVar::destroy() { mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->destroy(); }mosek::fusion::ExprMulVarScalarConst::ExprMulVarScalarConst(mosek::fusion::p_ExprMulVarScalarConst *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulVarScalarConst()" << this << std::endl; */ }mosek::fusion::ExprMulVarScalarConst::~ExprMulVarScalarConst() {  /* std::cout << "~ExprMulVarScalarConst()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulVarScalarConst::p_ExprMulVarScalarConst  (::mosek::fusion::ExprMulVarScalarConst * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulVarScalarConst::t mosek::fusion::p_ExprMulVarScalarConst::_new_ExprMulVarScalarConst  (monty::rc_ptr< ::mosek::fusion::Variable > _4133,    double _4134){ return new mosek::fusion::ExprMulVarScalarConst(_4133,_4134); }mosek::fusion::ExprMulVarScalarConst::ExprMulVarScalarConst  (monty::rc_ptr< ::mosek::fusion::Variable > _4133,    double _4134) :    ExprMulVarScalarConst(new mosek::fusion::p_ExprMulVarScalarConst(this)){ mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->_initialize(_4133,_4134); }void mosek::fusion::p_ExprMulVarScalarConst::_initialize  (monty::rc_ptr< ::mosek::fusion::Variable > _4133,    double _4134){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4133->getShape());
    mosek::fusion::p_ExprMulVarScalarConst::_get_impl(::mosek::fusion::ExprMulVarScalarConst::t(_pubthis))->x = _4133;
    mosek::fusion::p_ExprMulVarScalarConst::_get_impl(::mosek::fusion::ExprMulVarScalarConst::t(_pubthis))->c = _4134;
  }
}void mosek::fusion::ExprMulVarScalarConst :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4135,monty::rc_ptr< ::mosek::fusion::WorkStack > _4136,monty::rc_ptr< ::mosek::fusion::WorkStack > _4137) { mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->eval(_4135,_4136,_4137); }void mosek::fusion::p_ExprMulVarScalarConst::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4135,monty::rc_ptr< ::mosek::fusion::WorkStack > _4136,monty::rc_ptr< ::mosek::fusion::WorkStack > _4137){
  int _4138 = x->numInst();
  int _4139 = _4138;
  std::shared_ptr< monty::ndarray< int,1 > > _4140 = x->getShape();
  _checked_ptr_1<int> _ptr__4140(_4140 ? _4140->raw() : nullptr,_4140 ? _4140->size(0) : 0);
  int _4141 = (int)((_4140)->size(0));
  int _4142 = _4135->alloci32(safe_add( _4139,(int)1 ));
  int _4143 = _4135->alloci64(_4138);
  bool _4144 = (::mosek::fusion::p_Set::size(_4140) > _4139);
  int _8724;
  bool _8725 = _4144;
  if (_8725)
  {
    _8724 = _4135->alloci64(_4139);
  }
  else
  {
    _8724 = (int)0;
  }
  int _4145 = _8724;
  int _4146 = _4135->allocf64(_4138);
  int _4147 = _4135->allocf64(_4139);
  if (_4144)
  {
    {
      x->inst(_4145,mosek::fusion::p_WorkStack::_get_impl(_4135)->i64,_4143,mosek::fusion::p_WorkStack::_get_impl(_4135)->i64);
    }
  }
  else
  {
    {
      x->inst(_4143,mosek::fusion::p_WorkStack::_get_impl(_4135)->i64);
    }
  }
  int _8726;
  bool _8727 = _4144;
  if (_8727)
  {
    _8726 = (int)1;
  }
  else
  {
    _8726 = (int)0;
  }
  _4135->pushi32(_8726);
  _4135->pushi32(_4139);
  _4135->pushi32(_4138);
  int _8728 = (int)0;
  int _8729 = _4141;
  for (int _4148 = _8728; _4148 < _8729; ++_4148)
  {
    {
      _4135->pushi32(_ptr__4140[_4148]);
    }
  }
  _4135->pushi32(_4141);
  std::shared_ptr< monty::ndarray< int,1 > > _4149 = mosek::fusion::p_WorkStack::_get_impl(_4135)->i32;
  _checked_ptr_1<int> _ptr__4149(_4149 ? _4149->raw() : nullptr,_4149 ? _4149->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4150 = mosek::fusion::p_WorkStack::_get_impl(_4135)->i64;
  _checked_ptr_1<long long> _ptr__4150(_4150 ? _4150->raw() : nullptr,_4150 ? _4150->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4151 = mosek::fusion::p_WorkStack::_get_impl(_4135)->f64;
  _checked_ptr_1<double> _ptr__4151(_4151 ? _4151->raw() : nullptr,_4151 ? _4151->size(0) : 0);
  {
    int _8730 = (int)0;
    int _8731 = safe_add( _4139,(int)1 );
    for (int _4152 = _8730; _4152 < _8731; ++_4152)
    {
      {
        _ptr__4149[safe_add( _4142,_4152 )] = _4152;
      }
    }
    int _8732 = (int)0;
    int _8733 = _4138;
    for (int _4153 = _8732; _4153 < _8733; ++_4153)
    {
      {
        _ptr__4151[safe_add( _4146,_4153 )] = 1.0;
      }
    }
    int _8734 = (int)0;
    int _8735 = _4139;
    for (int _4154 = _8734; _4154 < _8735; ++_4154)
    {
      {
        _ptr__4151[safe_add( _4147,_4154 )] = 0.0;
      }
    }
  }
}
std::string mosek::fusion::ExprMulVarScalarConst :: toString() { return mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulVarScalarConst::toString(){
  return std::string ("ExprMulVarScalarConst()");
}
void mosek::fusion::p_ExprMulVarScalarConst::destroy(){x.reset();}void mosek::fusion::ExprMulVarScalarConst::destroy() { mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->destroy(); }mosek::fusion::ExprAdd::ExprAdd(mosek::fusion::p_ExprAdd *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprAdd()" << this << std::endl; */ }mosek::fusion::ExprAdd::~ExprAdd() {  /* std::cout << "~ExprAdd()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprAdd::p_ExprAdd  (::mosek::fusion::ExprAdd * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprAdd::t mosek::fusion::p_ExprAdd::_new_ExprAdd  (monty::rc_ptr< ::mosek::fusion::Expression > _4155,    monty::rc_ptr< ::mosek::fusion::Expression > _4156,    double _4157,    double _4158){ return new mosek::fusion::ExprAdd(_4155,_4156,_4157,_4158); }mosek::fusion::ExprAdd::ExprAdd  (monty::rc_ptr< ::mosek::fusion::Expression > _4155,    monty::rc_ptr< ::mosek::fusion::Expression > _4156,    double _4157,    double _4158) :    ExprAdd(new mosek::fusion::p_ExprAdd(this)){ mosek::fusion::p_ExprAdd::_get_impl(this)->_initialize(_4155,_4156,_4157,_4158); }void mosek::fusion::p_ExprAdd::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4155,    monty::rc_ptr< ::mosek::fusion::Expression > _4156,    double _4157,    double _4158){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4155->getShape());
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->e1 = _4155;
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->e2 = _4156;
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m1 = _4157;
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m2 = _4158;
    if ((_4155->getND() != _4156->getND()))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
      }
    }
    {}
    int _8736 = (int)0;
    int _8737 = _4155->getND();
    for (int _4159 = _8736; _4159 < _8737; ++_4159)
    {
      {
        if ((_4155->getDim(_4159) != _4156->getDim(_4159)))
        {
          {
            throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
          }
        }
        {}
      }
    }
  }
}void mosek::fusion::ExprAdd :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4160,monty::rc_ptr< ::mosek::fusion::WorkStack > _4161,monty::rc_ptr< ::mosek::fusion::WorkStack > _4162) { mosek::fusion::p_ExprAdd::_get_impl(this)->eval(_4160,_4161,_4162); }void mosek::fusion::p_ExprAdd::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4160,monty::rc_ptr< ::mosek::fusion::WorkStack > _4161,monty::rc_ptr< ::mosek::fusion::WorkStack > _4162){
  e1->eval(_4161,_4160,_4162);
  e2->eval(_4161,_4160,_4162);
  _4161->pop_expr();
  int _4163 = mosek::fusion::p_WorkStack::_get_impl(_4161)->nd;
  int _4164 = mosek::fusion::p_WorkStack::_get_impl(_4161)->shape_base;
  int _4165 = mosek::fusion::p_WorkStack::_get_impl(_4161)->nelem;
  int _4166 = mosek::fusion::p_WorkStack::_get_impl(_4161)->nnz;
  bool _4167 = mosek::fusion::p_WorkStack::_get_impl(_4161)->hassp;
  int _4168 = mosek::fusion::p_WorkStack::_get_impl(_4161)->ptr_base;
  int _4169 = mosek::fusion::p_WorkStack::_get_impl(_4161)->sp_base;
  int _4170 = mosek::fusion::p_WorkStack::_get_impl(_4161)->nidxs_base;
  int _4171 = mosek::fusion::p_WorkStack::_get_impl(_4161)->bfix_base;
  int _4172 = mosek::fusion::p_WorkStack::_get_impl(_4161)->cof_base;
  _4161->pop_expr();
  int _4173 = mosek::fusion::p_WorkStack::_get_impl(_4161)->nd;
  int _4174 = mosek::fusion::p_WorkStack::_get_impl(_4161)->shape_base;
  int _4175 = mosek::fusion::p_WorkStack::_get_impl(_4161)->nelem;
  int _4176 = mosek::fusion::p_WorkStack::_get_impl(_4161)->nnz;
  bool _4177 = mosek::fusion::p_WorkStack::_get_impl(_4161)->hassp;
  int _4178 = mosek::fusion::p_WorkStack::_get_impl(_4161)->ptr_base;
  int _4179 = mosek::fusion::p_WorkStack::_get_impl(_4161)->sp_base;
  int _4180 = mosek::fusion::p_WorkStack::_get_impl(_4161)->nidxs_base;
  int _4181 = mosek::fusion::p_WorkStack::_get_impl(_4161)->bfix_base;
  int _4182 = mosek::fusion::p_WorkStack::_get_impl(_4161)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4183 = mosek::fusion::p_WorkStack::_get_impl(_4161)->i32;
  _checked_ptr_1<int> _ptr__4183(_4183 ? _4183->raw() : nullptr,_4183 ? _4183->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4184 = mosek::fusion::p_WorkStack::_get_impl(_4161)->i64;
  _checked_ptr_1<long long> _ptr__4184(_4184 ? _4184->raw() : nullptr,_4184 ? _4184->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4185 = mosek::fusion::p_WorkStack::_get_impl(_4161)->f64;
  _checked_ptr_1<double> _ptr__4185(_4185 ? _4185->raw() : nullptr,_4185 ? _4185->size(0) : 0);
  if ((_4173 != _4163))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
    }
  }
  {}
  int _8738 = (int)0;
  int _8739 = _4173;
  for (int _4186 = _8738; _4186 < _8739; ++_4186)
  {
    {
      if ((_ptr__4183[safe_add( _4174,_4186 )] != _ptr__4183[safe_add( _4164,_4186 )]))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
      {}
    }
  }
  if (((!_4177) && (!_4167)))
  {
    {
      int _4187 = _4175;
      int _4188 = safe_add( _4176,_4166 );
      int _4189 = _4173;
      _4160->alloc_expr(_4189,_4187,_4188,false);
      int _4190 = mosek::fusion::p_WorkStack::_get_impl(_4160)->shape_base;
      int _4191 = mosek::fusion::p_WorkStack::_get_impl(_4160)->ptr_base;
      int _4192 = mosek::fusion::p_WorkStack::_get_impl(_4160)->sp_base;
      int _4193 = mosek::fusion::p_WorkStack::_get_impl(_4160)->nidxs_base;
      int _4194 = mosek::fusion::p_WorkStack::_get_impl(_4160)->bfix_base;
      int _4195 = mosek::fusion::p_WorkStack::_get_impl(_4160)->cof_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4196 = mosek::fusion::p_WorkStack::_get_impl(_4160)->i32;
      _checked_ptr_1<int> _ptr__4196(_4196 ? _4196->raw() : nullptr,_4196 ? _4196->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4197 = mosek::fusion::p_WorkStack::_get_impl(_4160)->i64;
      _checked_ptr_1<long long> _ptr__4197(_4197 ? _4197->raw() : nullptr,_4197 ? _4197->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4198 = mosek::fusion::p_WorkStack::_get_impl(_4160)->f64;
      _checked_ptr_1<double> _ptr__4198(_4198 ? _4198->raw() : nullptr,_4198 ? _4198->size(0) : 0);
      int _8740 = (int)0;
      int _8741 = _4189;
      for (int _4199 = _8740; _4199 < _8741; ++_4199)
      {
        {
          _ptr__4196[safe_add( _4190,_4199 )] = _ptr__4183[safe_add( _4174,_4199 )];
        }
      }
      int _4200 = (int)0;
      _ptr__4196[_4191] = (int)0;
      int _8742 = (int)0;
      int _8743 = _4187;
      for (int _4201 = _8742; _4201 < _8743; ++_4201)
      {
        {
          int _8744 = _ptr__4183[safe_add( _4178,_4201 )];
          int _8745 = _ptr__4183[safe_add( safe_add( _4178,_4201 ),(int)1 )];
          for (int _4202 = _8744; _4202 < _8745; ++_4202)
          {
            {
              _ptr__4197[safe_add( _4193,_4200 )] = _ptr__4184[safe_add( _4180,_4202 )];
              _ptr__4198[safe_add( _4195,_4200 )] = (_ptr__4185[safe_add( _4182,_4202 )] * m1);
              ++ _4200;
            }
          }
          int _8746 = _ptr__4183[safe_add( _4168,_4201 )];
          int _8747 = _ptr__4183[safe_add( safe_add( _4168,_4201 ),(int)1 )];
          for (int _4203 = _8746; _4203 < _8747; ++_4203)
          {
            {
              _ptr__4197[safe_add( _4193,_4200 )] = _ptr__4184[safe_add( _4170,_4203 )];
              _ptr__4198[safe_add( _4195,_4200 )] = (_ptr__4185[safe_add( _4172,_4203 )] * m2);
              ++ _4200;
            }
          }
          _ptr__4196[safe_add( safe_add( _4191,_4201 ),(int)1 )] = _4200;
          _ptr__4198[safe_add( _4194,_4201 )] = ((_ptr__4185[safe_add( _4181,_4201 )] * m1) + (_ptr__4185[safe_add( _4171,_4201 )] * m2));
        }
      }
    }
  }
  else if(((!_4177) || (!_4167)))
  {
    {
      if ((!_4167))
      {
        {
          int _4204 = _4165;
          int _4205 = _4166;
          int _4206 = _4168;
          int _4207 = _4169;
          int _4208 = _4170;
          int _4209 = _4171;
          int _4210 = _4172;
          _4165 = _4175;
          _4166 = _4176;
          _4168 = _4178;
          _4169 = _4179;
          _4170 = _4180;
          _4171 = _4181;
          _4172 = _4182;
          _4175 = _4204;
          _4176 = _4205;
          _4178 = _4206;
          _4179 = _4207;
          _4180 = _4208;
          _4181 = _4209;
          _4182 = _4210;
        }
      }
      {}
      double _8748;
      bool _8749 = (!_4177);
      if (_8749)
      {
        _8748 = mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m1;
      }
      else
      {
        _8748 = mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m2;
      }
      double _4211 = _8748;
      double _8750;
      bool _8751 = (!_4177);
      if (_8751)
      {
        _8750 = mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m2;
      }
      else
      {
        _8750 = mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m1;
      }
      double _4212 = _8750;
      int _4213 = _4175;
      int _4214 = safe_add( _4176,_4166 );
      int _4215 = _4173;
      _4160->alloc_expr(_4215,_4213,_4214,false);
      int _4216 = mosek::fusion::p_WorkStack::_get_impl(_4160)->shape_base;
      int _4217 = mosek::fusion::p_WorkStack::_get_impl(_4160)->ptr_base;
      int _4218 = mosek::fusion::p_WorkStack::_get_impl(_4160)->sp_base;
      int _4219 = mosek::fusion::p_WorkStack::_get_impl(_4160)->nidxs_base;
      int _4220 = mosek::fusion::p_WorkStack::_get_impl(_4160)->bfix_base;
      int _4221 = mosek::fusion::p_WorkStack::_get_impl(_4160)->cof_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4222 = mosek::fusion::p_WorkStack::_get_impl(_4160)->i32;
      _checked_ptr_1<int> _ptr__4222(_4222 ? _4222->raw() : nullptr,_4222 ? _4222->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4223 = mosek::fusion::p_WorkStack::_get_impl(_4160)->i64;
      _checked_ptr_1<long long> _ptr__4223(_4223 ? _4223->raw() : nullptr,_4223 ? _4223->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4224 = mosek::fusion::p_WorkStack::_get_impl(_4160)->f64;
      _checked_ptr_1<double> _ptr__4224(_4224 ? _4224->raw() : nullptr,_4224 ? _4224->size(0) : 0);
      {
        int _4225 = (int)0;
        int _8752 = (int)0;
        int _8753 = _4215;
        for (int _4226 = _8752; _4226 < _8753; ++_4226)
        {
          {
            _ptr__4222[safe_add( _4216,_4226 )] = _ptr__4183[safe_add( _4174,_4226 )];
          }
        }
        int _8754 = (int)0;
        int _8755 = safe_add( _4213,(int)1 );
        for (int _4227 = _8754; _4227 < _8755; ++_4227)
        {
          {
            _ptr__4222[safe_add( _4217,_4227 )] = (int)0;
          }
        }
        int _8756 = (int)0;
        int _8757 = _4175;
        for (int _4228 = _8756; _4228 < _8757; ++_4228)
        {
          {
            _ptr__4222[safe_add( safe_add( _4217,_4228 ),(int)1 )] += (_ptr__4183[safe_add( safe_add( _4178,_4228 ),(int)1 )] - _ptr__4183[safe_add( _4178,_4228 )]);
          }
        }
        int _8758 = (int)0;
        int _8759 = _4165;
        for (int _4229 = _8758; _4229 < _8759; ++_4229)
        {
          {
            long long _4230 = _ptr__4184[safe_add( _4169,_4229 )];
            _ptr__4222[safe_add( safe_add( _4217,_4230 ),(int)1 )] += (_ptr__4183[safe_add( safe_add( _4168,_4229 ),(int)1 )] - _ptr__4183[safe_add( _4168,_4229 )]);
          }
        }
        int _8760 = (int)0;
        int _8761 = _4213;
        for (int _4231 = _8760; _4231 < _8761; ++_4231)
        {
          {
            _ptr__4222[safe_add( safe_add( _4217,_4231 ),(int)1 )] += _ptr__4222[safe_add( _4217,_4231 )];
          }
        }
        int _8762 = (int)0;
        int _8763 = _4175;
        for (int _4232 = _8762; _4232 < _8763; ++_4232)
        {
          {
            int _4233 = _ptr__4222[safe_add( _4217,_4232 )];
            int _4234 = _ptr__4183[safe_add( _4178,_4232 )];
            int _4235 = (_ptr__4183[safe_add( safe_add( _4178,_4232 ),(int)1 )] - _ptr__4183[safe_add( _4178,_4232 )]);
            int _8764 = (int)0;
            int _8765 = _4235;
            for (int _4236 = _8764; _4236 < _8765; ++_4236)
            {
              {
                _ptr__4223[safe_add( safe_add( _4219,_4233 ),_4236 )] = _ptr__4184[safe_add( safe_add( _4180,_4234 ),_4236 )];
                _ptr__4224[safe_add( safe_add( _4221,_4233 ),_4236 )] = (_ptr__4185[safe_add( safe_add( _4182,_4234 ),_4236 )] * _4211);
              }
            }
            _ptr__4222[safe_add( _4217,_4232 )] += _4235;
            _ptr__4224[safe_add( _4220,_4232 )] = (_ptr__4185[safe_add( _4181,_4232 )] * _4211);
          }
        }
        int _8766 = (int)0;
        int _8767 = _4165;
        for (int _4237 = _8766; _4237 < _8767; ++_4237)
        {
          {
            long long _4238 = _ptr__4184[safe_add( _4169,_4237 )];
            int _4239 = _ptr__4222[safe_add( _4217,_4238 )];
            int _4240 = _ptr__4183[safe_add( _4168,_4237 )];
            int _4241 = (_ptr__4183[safe_add( safe_add( _4168,_4237 ),(int)1 )] - _ptr__4183[safe_add( _4168,_4237 )]);
            int _8768 = (int)0;
            int _8769 = _4241;
            for (int _4242 = _8768; _4242 < _8769; ++_4242)
            {
              {
                _ptr__4223[safe_add( safe_add( _4219,_4239 ),_4242 )] = _ptr__4184[safe_add( safe_add( _4170,_4240 ),_4242 )];
                _ptr__4224[safe_add( safe_add( _4221,_4239 ),_4242 )] = (_ptr__4185[safe_add( safe_add( _4172,_4240 ),_4242 )] * _4212);
              }
            }
            _ptr__4222[safe_add( _4217,_4238 )] += _4241;
            _ptr__4224[safe_add( _4220,_4238 )] += (_ptr__4185[safe_add( _4171,_4237 )] * _4212);
          }
        }
        int _8770 = (int)0;
        int _8771 = _4213;
        for (int _4243 = _8770; _4243 < _8771; ++_4243)
        {
          {
            _ptr__4222[(safe_add( _4217,_4213 ) - _4243)] = _ptr__4222[((safe_add( _4217,_4213 ) - _4243) - (int)1)];
          }
        }
        _ptr__4222[_4217] = (int)0;
      }
    }
  }
  else
  {
    {
      int _4244 = safe_add( _4176,_4166 );
      int _4245 = (int)0;
      int _4246 = _4173;
      long long _4247 = (long long)1;
      int _8772 = (int)0;
      int _8773 = _4246;
      for (int _4248 = _8772; _4248 < _8773; ++_4248)
      {
        {
          _4247 *= _ptr__4183[safe_add( _4174,_4248 )];
        }
      }
      {
        int _4249 = (int)0;
        int _4250 = (int)0;
        while ( ((_4250 < _4175) && (_4249 < _4165)) )
        {
          {
            if ((_ptr__4184[safe_add( _4179,_4250 )] < _ptr__4184[safe_add( _4169,_4249 )]))
            {
              {
                ++ _4245;
                ++ _4250;
              }
            }
            else if((_ptr__4184[safe_add( _4179,_4250 )] > _ptr__4184[safe_add( _4169,_4249 )]))
            {
              {
                ++ _4245;
                ++ _4249;
              }
            }
            else
            {
              {
                ++ _4245;
                ++ _4250;
                ++ _4249;
              }
            }
          }
        }
        _4245 += (safe_add( (_4175 - _4250),_4165 ) - _4249);
      }
      bool _4251 = (_4245 < _4247);
      _4160->alloc_expr(_4246,_4245,_4244,_4251);
      int _4252 = mosek::fusion::p_WorkStack::_get_impl(_4160)->shape_base;
      int _4253 = mosek::fusion::p_WorkStack::_get_impl(_4160)->ptr_base;
      int _8774;
      bool _8775 = _4251;
      if (_8775)
      {
        _8774 = mosek::fusion::p_WorkStack::_get_impl(_4160)->sp_base;
      }
      else
      {
        _8774 = _4160->alloci64(_4245);
      }
      int _4254 = _8774;
      int _4255 = mosek::fusion::p_WorkStack::_get_impl(_4160)->nidxs_base;
      int _4256 = mosek::fusion::p_WorkStack::_get_impl(_4160)->bfix_base;
      int _4257 = mosek::fusion::p_WorkStack::_get_impl(_4160)->cof_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4258 = mosek::fusion::p_WorkStack::_get_impl(_4160)->i32;
      _checked_ptr_1<int> _ptr__4258(_4258 ? _4258->raw() : nullptr,_4258 ? _4258->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4259 = mosek::fusion::p_WorkStack::_get_impl(_4160)->i64;
      _checked_ptr_1<long long> _ptr__4259(_4259 ? _4259->raw() : nullptr,_4259 ? _4259->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4260 = mosek::fusion::p_WorkStack::_get_impl(_4160)->f64;
      _checked_ptr_1<double> _ptr__4260(_4260 ? _4260->raw() : nullptr,_4260 ? _4260->size(0) : 0);
      int _8776 = (int)0;
      int _8777 = _4246;
      for (int _4261 = _8776; _4261 < _8777; ++_4261)
      {
        {
          _ptr__4258[safe_add( _4252,_4261 )] = _ptr__4183[safe_add( _4174,_4261 )];
        }
      }
      {
        _ptr__4258[_4253] = (int)0;
        int _4262 = (int)0;
        int _4263 = (int)0;
        int _4264 = (int)0;
        int _4265 = (int)0;
        while ( ((_4265 < _4175) && (_4264 < _4165)) )
        {
          {
            if ((_ptr__4184[safe_add( _4179,_4265 )] < _ptr__4184[safe_add( _4169,_4264 )]))
            {
              {
                int _8778 = _ptr__4183[safe_add( _4178,_4265 )];
                int _8779 = _ptr__4183[safe_add( safe_add( _4178,_4265 ),(int)1 )];
                for (int _4266 = _8778; _4266 < _8779; ++_4266)
                {
                  {
                    _ptr__4259[safe_add( _4255,_4263 )] = _ptr__4184[safe_add( _4180,_4266 )];
                    _ptr__4260[safe_add( _4257,_4263 )] = (m1 * _ptr__4185[safe_add( _4182,_4266 )]);
                    ++ _4263;
                  }
                }
                _ptr__4260[safe_add( _4256,_4262 )] = (m1 * _ptr__4185[safe_add( _4181,_4265 )]);
                _ptr__4259[safe_add( _4254,_4262 )] = _ptr__4184[safe_add( _4179,_4265 )];
                _ptr__4258[safe_add( safe_add( _4253,_4262 ),(int)1 )] = _4263;
                ++ _4262;
                ++ _4265;
              }
            }
            else if((_ptr__4184[safe_add( _4169,_4264 )] < _ptr__4184[safe_add( _4179,_4265 )]))
            {
              {
                int _8780 = _ptr__4183[safe_add( _4168,_4264 )];
                int _8781 = _ptr__4183[safe_add( safe_add( _4168,_4264 ),(int)1 )];
                for (int _4267 = _8780; _4267 < _8781; ++_4267)
                {
                  {
                    _ptr__4259[safe_add( _4255,_4263 )] = _ptr__4184[safe_add( _4170,_4267 )];
                    _ptr__4260[safe_add( _4257,_4263 )] = (m2 * _ptr__4185[safe_add( _4172,_4267 )]);
                    ++ _4263;
                  }
                }
                _ptr__4260[safe_add( _4256,_4262 )] = (m1 * _ptr__4185[safe_add( _4171,_4265 )]);
                _ptr__4259[safe_add( _4254,_4262 )] = _ptr__4184[safe_add( _4169,_4264 )];
                _ptr__4258[safe_add( safe_add( _4253,_4262 ),(int)1 )] = _4263;
                ++ _4262;
                ++ _4264;
              }
            }
            else
            {
              {
                int _8782 = _ptr__4183[safe_add( _4178,_4265 )];
                int _8783 = _ptr__4183[safe_add( safe_add( _4178,_4265 ),(int)1 )];
                for (int _4268 = _8782; _4268 < _8783; ++_4268)
                {
                  {
                    _ptr__4259[safe_add( _4255,_4263 )] = _ptr__4184[safe_add( _4180,_4268 )];
                    _ptr__4260[safe_add( _4257,_4263 )] = (m1 * _ptr__4185[safe_add( _4182,_4268 )]);
                    ++ _4263;
                  }
                }
                int _8784 = _ptr__4183[safe_add( _4168,_4264 )];
                int _8785 = _ptr__4183[safe_add( safe_add( _4168,_4264 ),(int)1 )];
                for (int _4269 = _8784; _4269 < _8785; ++_4269)
                {
                  {
                    _ptr__4259[safe_add( _4255,_4263 )] = _ptr__4184[safe_add( _4170,_4269 )];
                    _ptr__4260[safe_add( _4257,_4263 )] = (m2 * _ptr__4185[safe_add( _4172,_4269 )]);
                    ++ _4263;
                  }
                }
                _ptr__4260[safe_add( _4256,_4262 )] = ((m1 * _ptr__4185[safe_add( _4181,_4265 )]) + (m2 * _ptr__4185[safe_add( _4171,_4264 )]));
                _ptr__4259[safe_add( _4254,_4262 )] = _ptr__4184[safe_add( _4179,_4265 )];
                _ptr__4258[safe_add( safe_add( _4253,_4262 ),(int)1 )] = _4263;
                ++ _4262;
                ++ _4265;
                ++ _4264;
              }
            }
          }
        }
        while ( (_4265 < _4175) )
        {
          {
            int _8786 = _ptr__4183[safe_add( _4178,_4265 )];
            int _8787 = _ptr__4183[safe_add( safe_add( _4178,_4265 ),(int)1 )];
            for (int _4270 = _8786; _4270 < _8787; ++_4270)
            {
              {
                _ptr__4259[safe_add( _4255,_4263 )] = _ptr__4184[safe_add( _4180,_4270 )];
                _ptr__4260[safe_add( _4257,_4263 )] = (m1 * _ptr__4185[safe_add( _4182,_4270 )]);
                ++ _4263;
              }
            }
            _ptr__4260[safe_add( _4256,_4262 )] = (m1 * _ptr__4185[safe_add( _4181,_4265 )]);
            _ptr__4259[safe_add( _4254,_4262 )] = _ptr__4184[safe_add( _4179,_4265 )];
            _ptr__4258[safe_add( safe_add( _4253,_4262 ),(int)1 )] = _4263;
            ++ _4262;
            ++ _4265;
          }
        }
        while ( (_4264 < _4165) )
        {
          {
            int _8788 = _ptr__4183[safe_add( _4168,_4264 )];
            int _8789 = _ptr__4183[safe_add( safe_add( _4168,_4264 ),(int)1 )];
            for (int _4271 = _8788; _4271 < _8789; ++_4271)
            {
              {
                _ptr__4259[safe_add( _4255,_4263 )] = _ptr__4184[safe_add( _4170,_4271 )];
                _ptr__4260[safe_add( _4257,_4263 )] = (m2 * _ptr__4185[safe_add( _4172,_4271 )]);
                ++ _4263;
              }
            }
            _ptr__4260[safe_add( _4256,_4262 )] = (m1 * _ptr__4185[safe_add( _4171,_4264 )]);
            _ptr__4259[safe_add( _4254,_4262 )] = _ptr__4184[safe_add( _4169,_4264 )];
            _ptr__4258[safe_add( safe_add( _4253,_4262 ),(int)1 )] = _4263;
            ++ _4262;
            ++ _4264;
          }
        }
      }
      if ((!_4251))
      {
        {
          _4160->popi64(_4245);
        }
      }
      {}
    }
  }
}
std::string mosek::fusion::ExprAdd :: toString() { return mosek::fusion::p_ExprAdd::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprAdd::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprAdd("))->__mosek_2fusion_2Utils_2StringBuffer__a(e1->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(e2->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprAdd::destroy(){e2.reset();e1.reset();}void mosek::fusion::ExprAdd::destroy() { mosek::fusion::p_ExprAdd::_get_impl(this)->destroy(); }mosek::fusion::ExprWSum::ExprWSum(mosek::fusion::p_ExprWSum *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprWSum()" << this << std::endl; */ }mosek::fusion::ExprWSum::~ExprWSum() {  /* std::cout << "~ExprWSum()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprWSum::p_ExprWSum  (::mosek::fusion::ExprWSum * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprWSum::t mosek::fusion::p_ExprWSum::_new_ExprWSum  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4272,    std::shared_ptr< monty::ndarray< double,1 > > _4273){ return new mosek::fusion::ExprWSum(_4272,_4273); }mosek::fusion::ExprWSum::ExprWSum  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4272,    std::shared_ptr< monty::ndarray< double,1 > > _4273) :    ExprWSum(new mosek::fusion::p_ExprWSum(this)){ mosek::fusion::p_ExprWSum::_get_impl(this)->_initialize(_4272,_4273); }void mosek::fusion::p_ExprWSum::_initialize  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4272,    std::shared_ptr< monty::ndarray< double,1 > > _4273){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__4273(_4273 ? _4273->raw() : nullptr, _4273 ? _4273->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(((*_4272)((int)0))->getShape());
    if (((int)((_4273)->size(0)) != (int)((_4272)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching weights and expressions array lengths"));
      }
    }
    {}
    mosek::fusion::p_ExprWSum::_get_impl(::mosek::fusion::ExprWSum::t(_pubthis))->w = ::mosek::fusion::Utils::Tools::arraycopy(_4273);
    std::shared_ptr< monty::ndarray< int,1 > > _4274 = ((*_4272)((int)0))->getShape();
    _checked_ptr_1<int> _ptr__4274(_4274 ? _4274->raw() : nullptr,_4274 ? _4274->size(0) : 0);
    int _4275 = (int)((_4274)->size(0));
    int _8790 = (int)1;
    int _8791 = (int)((_4272)->size(0));
    for (int _4276 = _8790; _4276 < _8791; ++_4276)
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _4277 = ((*_4272)(_4276))->getShape();
        _checked_ptr_1<int> _ptr__4277(_4277 ? _4277->raw() : nullptr,_4277 ? _4277->size(0) : 0);
        if ((_4275 != (int)((_4277)->size(0))))
        {
          {
            throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression shapes"));
          }
        }
        else
        {
          {
            int _8792 = (int)0;
            int _8793 = _4275;
            for (int _4278 = _8792; _4278 < _8793; ++_4278)
            {
              {
                if ((_ptr__4274[_4278] != _ptr__4277[_4278]))
                {
                  {
                    throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression shapes"));
                  }
                }
                {}
              }
            }
          }
        }
      }
    }
    std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _8794;
    for (int _4279 = (int)0, _8795 = (int)((_4272)->size(0)); _4279 < _8795 ; ++_4279)
    {
      _8794.push_back(((*_4272)(_4279)));
    }
    auto _8796 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_8794.size()),_8794.begin(),_8794.end()));
    mosek::fusion::p_ExprWSum::_get_impl(::mosek::fusion::ExprWSum::t(_pubthis))->es = _8796;
  }
}void mosek::fusion::ExprWSum :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4280,monty::rc_ptr< ::mosek::fusion::WorkStack > _4281,monty::rc_ptr< ::mosek::fusion::WorkStack > _4282) { mosek::fusion::p_ExprWSum::_get_impl(this)->eval(_4280,_4281,_4282); }void mosek::fusion::p_ExprWSum::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4280,monty::rc_ptr< ::mosek::fusion::WorkStack > _4281,monty::rc_ptr< ::mosek::fusion::WorkStack > _4282){
  int _4283 = (int)((es)->size(0));
  int _8797 = (int)0;
  int _8798 = _4283;
  for (int _4284 = _8797; _4284 < _8798; ++_4284)
  {
    {
      ((*es)(_4284))->eval(_4281,_4280,_4282);
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _4285 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4283)));
  _checked_ptr_1<int> _ptr__4285(_4285 ? _4285->raw() : nullptr,_4285 ? _4285->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4286 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4283)));
  _checked_ptr_1<int> _ptr__4286(_4286 ? _4286->raw() : nullptr,_4286 ? _4286->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4287 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4283)));
  _checked_ptr_1<int> _ptr__4287(_4287 ? _4287->raw() : nullptr,_4287 ? _4287->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4288 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4283)));
  _checked_ptr_1<int> _ptr__4288(_4288 ? _4288->raw() : nullptr,_4288 ? _4288->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4289 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4283)));
  _checked_ptr_1<int> _ptr__4289(_4289 ? _4289->raw() : nullptr,_4289 ? _4289->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4290 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4283)));
  _checked_ptr_1<int> _ptr__4290(_4290 ? _4290->raw() : nullptr,_4290 ? _4290->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4291 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4283)));
  _checked_ptr_1<int> _ptr__4291(_4291 ? _4291->raw() : nullptr,_4291 ? _4291->size(0) : 0);
  int _4292 = _4281->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _4293 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4292)));
  _checked_ptr_1<int> _ptr__4293(_4293 ? _4293->raw() : nullptr,_4293 ? _4293->size(0) : 0);
  _4281->popi32(_4292,_4293,(int)0);
  {
    _ptr__4285[(_4283 - (int)1)] = _4281->popi32();
    _ptr__4286[(_4283 - (int)1)] = _4281->popi32();
    bool _4294 = (_4281->popi32() != (int)0);
    _ptr__4287[(_4283 - (int)1)] = _4281->popi32(safe_add( _ptr__4285[(_4283 - (int)1)],(int)1 ));
    int _8799;
    bool _8800 = _4294;
    if (_8800)
    {
      _8799 = _4281->popi64(_ptr__4285[(_4283 - (int)1)]);
    }
    else
    {
      _8799 = (-(int)1);
    }
    _ptr__4289[(_4283 - (int)1)] = _8799;
    _ptr__4288[(_4283 - (int)1)] = _4281->popi64(_ptr__4286[(_4283 - (int)1)]);
    _ptr__4291[(_4283 - (int)1)] = _4281->popf64(_ptr__4285[(_4283 - (int)1)]);
    _ptr__4290[(_4283 - (int)1)] = _4281->popf64(_ptr__4286[(_4283 - (int)1)]);
  }
  int _8801 = (int)1;
  int _8802 = _4283;
  for (int _4295 = _8801; _4295 < _8802; ++_4295)
  {
    {
      int _4296 = ((_4283 - _4295) - (int)1);
      _4281->popi32();
      _4281->popi32(_4292);
      _ptr__4285[_4296] = _4281->popi32();
      _ptr__4286[_4296] = _4281->popi32();
      bool _4297 = (_4281->popi32() != (int)0);
      _ptr__4287[_4296] = _4281->popi32(safe_add( _ptr__4285[_4296],(int)1 ));
      int _8803;
      bool _8804 = _4297;
      if (_8804)
      {
        _8803 = _4281->popi64(_ptr__4285[_4296]);
      }
      else
      {
        _8803 = (-(int)1);
      }
      _ptr__4289[_4296] = _8803;
      _ptr__4288[_4296] = _4281->popi64(_ptr__4286[_4296]);
      _ptr__4291[_4296] = _4281->popf64(_ptr__4285[_4296]);
      _ptr__4290[_4296] = _4281->popf64(_ptr__4286[_4296]);
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _4298 = mosek::fusion::p_WorkStack::_get_impl(_4281)->i32;
  _checked_ptr_1<int> _ptr__4298(_4298 ? _4298->raw() : nullptr,_4298 ? _4298->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4299 = mosek::fusion::p_WorkStack::_get_impl(_4281)->i64;
  _checked_ptr_1<long long> _ptr__4299(_4299 ? _4299->raw() : nullptr,_4299 ? _4299->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4300 = mosek::fusion::p_WorkStack::_get_impl(_4281)->f64;
  _checked_ptr_1<double> _ptr__4300(_4300 ? _4300->raw() : nullptr,_4300 ? _4300->size(0) : 0);
  bool _4301 = false;
  int _8805 = (int)0;
  int _8806 = _4283;
  for (int _4302 = _8805; _4302 < _8806; ++_4302)
  {
    {
      if ((_ptr__4289[_4302] < (int)0))
      {
        {
          _4301 = true;
        }
      }
      {}
    }
  }
  int _4303 = (int)0;
  int _4304 = (int)0;
  if (_4301)
  {
    {
      _4303 = (int)::mosek::fusion::p_Set::size(_4293);
      int _8807 = (int)0;
      int _8808 = _4283;
      for (int _4305 = _8807; _4305 < _8808; ++_4305)
      {
        {
          _4304 += _ptr__4286[_4305];
        }
      }
    }
  }
  else
  {
    {
      bool _4306 = false;
      std::shared_ptr< monty::ndarray< int,1 > > _4307 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4283)));
      _checked_ptr_1<int> _ptr__4307(_4307 ? _4307->raw() : nullptr,_4307 ? _4307->size(0) : 0);
      int _8809 = (int)0;
      int _8810 = _4283;
      for (int _4308 = _8809; _4308 < _8810; ++_4308)
      {
        {
          _4304 += _ptr__4286[_4308];
        }
      }
      while ( (!_4306) )
      {
        {
          long long _4309 = (-(int)1);
          int _8811 = (int)0;
          int _8812 = _4283;
          for (int _4310 = _8811; _4310 < _8812; ++_4310)
          {
            {
              if (((_ptr__4307[_4310] < _ptr__4285[_4310]) && ((_4309 < (int)0) || (_ptr__4299[safe_add( _ptr__4289[_4310],_ptr__4307[_4310] )] < _4309))))
              {
                {
                  _4309 = _ptr__4299[safe_add( _ptr__4289[_4310],_ptr__4307[_4310] )];
                }
              }
              {}
            }
          }
          if ((_4309 < (int)0))
          {
            {
              _4306 = true;
            }
          }
          else
          {
            {
              int _8813 = (int)0;
              int _8814 = _4283;
              for (int _4311 = _8813; _4311 < _8814; ++_4311)
              {
                {
                  if (((_ptr__4307[_4311] < _ptr__4285[_4311]) && (_4309 == _ptr__4299[safe_add( _ptr__4289[_4311],_ptr__4307[_4311] )])))
                  {
                    {
                      ++ _ptr__4307[_4311];
                    }
                  }
                  {}
                }
              }
              ++ _4303;
            }
          }
        }
      }
    }
  }
  int _4312 = _4280->alloci32(safe_add( _4303,(int)1 ));
  int _4313 = _4280->alloci64(_4304);
  int _8815;
  bool _8816 = (!_4301);
  if (_8816)
  {
    _8815 = _4280->alloci64(_4303);
  }
  else
  {
    _8815 = (-(int)1);
  }
  int _4314 = _8815;
  int _4315 = _4280->allocf64(_4304);
  int _4316 = _4280->allocf64(_4303);
  int _8817;
  bool _8818 = _4301;
  if (_8818)
  {
    _8817 = (int)0;
  }
  else
  {
    _8817 = (int)1;
  }
  _4280->pushi32(_8817);
  _4280->pushi32(_4304);
  _4280->pushi32(_4303);
  int _8819 = (int)0;
  int _8820 = _4292;
  for (int _4317 = _8819; _4317 < _8820; ++_4317)
  {
    {
      _4280->pushi32(_ptr__4293[_4317]);
    }
  }
  _4280->pushi32(_4292);
  std::shared_ptr< monty::ndarray< int,1 > > _4318 = mosek::fusion::p_WorkStack::_get_impl(_4280)->i32;
  _checked_ptr_1<int> _ptr__4318(_4318 ? _4318->raw() : nullptr,_4318 ? _4318->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4319 = mosek::fusion::p_WorkStack::_get_impl(_4280)->i64;
  _checked_ptr_1<long long> _ptr__4319(_4319 ? _4319->raw() : nullptr,_4319 ? _4319->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4320 = mosek::fusion::p_WorkStack::_get_impl(_4280)->f64;
  _checked_ptr_1<double> _ptr__4320(_4320 ? _4320->raw() : nullptr,_4320 ? _4320->size(0) : 0);
  _ptr__4318[_4312] = (int)0;
  int _8821 = (int)0;
  int _8822 = _4303;
  for (int _4321 = _8821; _4321 < _8822; ++_4321)
  {
    {
      _ptr__4320[safe_add( _4316,_4321 )] = 0.0;
    }
  }
  int _8823 = (int)0;
  int _8824 = safe_add( _4303,(int)1 );
  for (int _4322 = _8823; _4322 < _8824; ++_4322)
  {
    {
      _ptr__4318[safe_add( _4312,_4322 )] = (int)0;
    }
  }
  if (_4301)
  {
    {
      int _8825 = (int)0;
      int _8826 = _4283;
      for (int _4323 = _8825; _4323 < _8826; ++_4323)
      {
        {
          if ((_ptr__4289[_4323] >= (int)0))
          {
            {
              int _8827 = (int)0;
              int _8828 = _ptr__4285[_4323];
              for (int _4324 = _8827; _4324 < _8828; ++_4324)
              {
                {
                  _ptr__4318[safe_add( safe_add( _4312,_ptr__4299[safe_add( _ptr__4289[_4323],_4324 )] ),(int)1 )] += (_ptr__4298[safe_add( safe_add( _ptr__4287[_4323],_4324 ),(int)1 )] - _ptr__4298[safe_add( _ptr__4287[_4323],_4324 )]);
                }
              }
            }
          }
          else
          {
            {
              int _8829 = (int)0;
              int _8830 = _ptr__4285[_4323];
              for (int _4325 = _8829; _4325 < _8830; ++_4325)
              {
                {
                  _ptr__4318[safe_add( safe_add( _4312,_4325 ),(int)1 )] += (_ptr__4298[safe_add( safe_add( _ptr__4287[_4323],_4325 ),(int)1 )] - _ptr__4298[safe_add( _ptr__4287[_4323],_4325 )]);
                }
              }
            }
          }
        }
      }
      int _8831 = (int)0;
      int _8832 = _4303;
      for (int _4326 = _8831; _4326 < _8832; ++_4326)
      {
        {
          _ptr__4318[safe_add( safe_add( _4312,_4326 ),(int)1 )] += _ptr__4318[safe_add( _4312,_4326 )];
        }
      }
      int _8833 = (int)0;
      int _8834 = _4283;
      for (int _4327 = _8833; _4327 < _8834; ++_4327)
      {
        {
          if ((_ptr__4289[_4327] >= (int)0))
          {
            {
              int _8835 = (int)0;
              int _8836 = _ptr__4285[_4327];
              for (int _4328 = _8835; _4328 < _8836; ++_4328)
              {
                {
                  int _4329 = _ptr__4298[safe_add( _ptr__4287[_4327],_4328 )];
                  int _4330 = _ptr__4298[safe_add( safe_add( _ptr__4287[_4327],_4328 ),(int)1 )];
                  long long _4331 = _ptr__4299[safe_add( _ptr__4289[_4327],_4328 )];
                  int _4332 = _ptr__4318[safe_add( _4312,_4331 )];
                  int _8837 = _4329;
                  int _8838 = _4330;
                  for (int _4333 = _8837; _4333 < _8838; ++_4333)
                  {
                    {
                      _ptr__4319[safe_add( _4313,_4332 )] = _ptr__4299[safe_add( _ptr__4288[_4327],_4333 )];
                      _ptr__4320[safe_add( _4315,_4332 )] = (((*w)(_4327)) * _ptr__4300[safe_add( _ptr__4290[_4327],_4333 )]);
                      ++ _4332;
                    }
                  }
                  _ptr__4320[safe_add( _4316,_4331 )] += (((*w)(_4327)) * _ptr__4300[safe_add( _ptr__4291[_4327],_4328 )]);
                  _ptr__4318[safe_add( _4312,_4331 )] += (_4330 - _4329);
                }
              }
            }
          }
          else
          {
            {
              int _8839 = (int)0;
              int _8840 = _ptr__4285[_4327];
              for (int _4334 = _8839; _4334 < _8840; ++_4334)
              {
                {
                  int _4335 = _ptr__4298[safe_add( _ptr__4287[_4327],_4334 )];
                  int _4336 = _ptr__4298[safe_add( safe_add( _ptr__4287[_4327],_4334 ),(int)1 )];
                  int _4337 = _4334;
                  int _4338 = _ptr__4318[safe_add( _4312,_4337 )];
                  int _8841 = _4335;
                  int _8842 = _4336;
                  for (int _4339 = _8841; _4339 < _8842; ++_4339)
                  {
                    {
                      _ptr__4319[safe_add( _4313,_4338 )] = _ptr__4299[safe_add( _ptr__4288[_4327],_4339 )];
                      _ptr__4320[safe_add( _4315,_4338 )] = (((*w)(_4327)) * _ptr__4300[safe_add( _ptr__4290[_4327],_4339 )]);
                      ++ _4338;
                    }
                  }
                  _ptr__4320[safe_add( _4316,_4337 )] += (((*w)(_4327)) * _ptr__4300[safe_add( _ptr__4291[_4327],_4334 )]);
                  _ptr__4318[safe_add( _4312,_4337 )] += (_4336 - _4335);
                }
              }
            }
          }
        }
      }
      int _8843 = (int)0;
      int _8844 = _4303;
      for (int _4340 = _8843; _4340 < _8844; ++_4340)
      {
        {
          _ptr__4318[(safe_add( _4312,_4303 ) - _4340)] = _ptr__4318[((safe_add( _4312,_4303 ) - _4340) - (int)1)];
        }
      }
      _ptr__4318[_4312] = (int)0;
    }
  }
  else
  {
    {
      bool _4341 = false;
      std::shared_ptr< monty::ndarray< int,1 > > _4342 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4283)));
      _checked_ptr_1<int> _ptr__4342(_4342 ? _4342->raw() : nullptr,_4342 ? _4342->size(0) : 0);
      int _4343 = (int)0;
      int _4344 = (int)0;
      while ( (!_4341) )
      {
        {
          long long _4345 = (-(int)1);
          int _8845 = (int)0;
          int _8846 = _4283;
          for (int _4346 = _8845; _4346 < _8846; ++_4346)
          {
            {
              if (((_ptr__4342[_4346] < _ptr__4285[_4346]) && ((_4345 < (int)0) || (_ptr__4299[safe_add( _ptr__4289[_4346],_ptr__4342[_4346] )] < _4345))))
              {
                {
                  _4345 = _ptr__4299[safe_add( _ptr__4289[_4346],_ptr__4342[_4346] )];
                }
              }
              {}
            }
          }
          if ((_4345 < (int)0))
          {
            {
              _4341 = true;
            }
          }
          else
          {
            {
              int _8847 = (int)0;
              int _8848 = _4283;
              for (int _4347 = _8847; _4347 < _8848; ++_4347)
              {
                {
                  if (((_ptr__4342[_4347] < _ptr__4285[_4347]) && (_4345 == _ptr__4299[safe_add( _ptr__4289[_4347],_ptr__4342[_4347] )])))
                  {
                    {
                      int _8849 = _ptr__4298[safe_add( _ptr__4287[_4347],_ptr__4342[_4347] )];
                      int _8850 = _ptr__4298[safe_add( safe_add( _ptr__4287[_4347],_ptr__4342[_4347] ),(int)1 )];
                      for (int _4348 = _8849; _4348 < _8850; ++_4348)
                      {
                        {
                          _ptr__4319[safe_add( _4313,_4344 )] = _ptr__4299[safe_add( _ptr__4288[_4347],_4348 )];
                          _ptr__4320[safe_add( _4315,_4344 )] = (((*w)(_4347)) * _ptr__4300[safe_add( _ptr__4290[_4347],_4348 )]);
                          ++ _4344;
                        }
                      }
                      _ptr__4320[safe_add( _4316,_4343 )] += (((*w)(_4347)) * _ptr__4300[safe_add( _ptr__4291[_4347],_ptr__4342[_4347] )]);
                      ++ _ptr__4342[_4347];
                    }
                  }
                  {}
                }
              }
              _ptr__4318[safe_add( safe_add( _4312,_4343 ),(int)1 )] = _4344;
              _ptr__4319[safe_add( _4314,_4343 )] = _4345;
            }
          }
          ++ _4343;
        }
      }
    }
  }
}
std::string mosek::fusion::ExprWSum :: toString() { return mosek::fusion::p_ExprWSum::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprWSum::toString(){
  return std::string ("ExprWSum()");
}
void mosek::fusion::p_ExprWSum::destroy(){w.reset();es.reset();}void mosek::fusion::ExprWSum::destroy() { mosek::fusion::p_ExprWSum::_get_impl(this)->destroy(); }mosek::fusion::ExprSumReduce::ExprSumReduce(mosek::fusion::p_ExprSumReduce *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprSumReduce()" << this << std::endl; */ }mosek::fusion::ExprSumReduce::~ExprSumReduce() {  /* std::cout << "~ExprSumReduce()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprSumReduce::p_ExprSumReduce  (::mosek::fusion::ExprSumReduce * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprSumReduce::t mosek::fusion::p_ExprSumReduce::_new_ExprSumReduce  (int _4349,    monty::rc_ptr< ::mosek::fusion::Expression > _4350){ return new mosek::fusion::ExprSumReduce(_4349,_4350); }mosek::fusion::ExprSumReduce::ExprSumReduce  (int _4349,    monty::rc_ptr< ::mosek::fusion::Expression > _4350) :    ExprSumReduce(new mosek::fusion::p_ExprSumReduce(this)){ mosek::fusion::p_ExprSumReduce::_get_impl(this)->_initialize(_4349,_4350); }void mosek::fusion::p_ExprSumReduce::_initialize  (int _4349,    monty::rc_ptr< ::mosek::fusion::Expression > _4350){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprSumReduce::computeShape(_4349,_4350->getShape()));
    mosek::fusion::p_ExprSumReduce::_get_impl(::mosek::fusion::ExprSumReduce::t(_pubthis))->expr = _4350;
    mosek::fusion::p_ExprSumReduce::_get_impl(::mosek::fusion::ExprSumReduce::t(_pubthis))->dim = _4349;
    std::shared_ptr< monty::ndarray< int,1 > > _4351 = _4350->getShape();
    _checked_ptr_1<int> _ptr__4351(_4351 ? _4351->raw() : nullptr,_4351 ? _4351->size(0) : 0);
    if (((int)((_4351)->size(0)) <= _4349))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid summing dimension"));
      }
    }
    {}
  }
}void mosek::fusion::ExprSumReduce :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4352,monty::rc_ptr< ::mosek::fusion::WorkStack > _4353,monty::rc_ptr< ::mosek::fusion::WorkStack > _4354) { mosek::fusion::p_ExprSumReduce::_get_impl(this)->eval(_4352,_4353,_4354); }void mosek::fusion::p_ExprSumReduce::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4352,monty::rc_ptr< ::mosek::fusion::WorkStack > _4353,monty::rc_ptr< ::mosek::fusion::WorkStack > _4354){
  expr->eval(_4353,_4352,_4354);
  _4353->pop_expr();
  int _4355 = mosek::fusion::p_WorkStack::_get_impl(_4353)->nd;
  int _4356 = mosek::fusion::p_WorkStack::_get_impl(_4353)->shape_base;
  int _4357 = mosek::fusion::p_WorkStack::_get_impl(_4353)->nelem;
  int _4358 = mosek::fusion::p_WorkStack::_get_impl(_4353)->nnz;
  bool _4359 = mosek::fusion::p_WorkStack::_get_impl(_4353)->hassp;
  int _4360 = mosek::fusion::p_WorkStack::_get_impl(_4353)->ptr_base;
  int _4361 = mosek::fusion::p_WorkStack::_get_impl(_4353)->sp_base;
  int _4362 = mosek::fusion::p_WorkStack::_get_impl(_4353)->nidxs_base;
  int _4363 = mosek::fusion::p_WorkStack::_get_impl(_4353)->bfix_base;
  int _4364 = mosek::fusion::p_WorkStack::_get_impl(_4353)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4365 = mosek::fusion::p_WorkStack::_get_impl(_4353)->i32;
  _checked_ptr_1<int> _ptr__4365(_4365 ? _4365->raw() : nullptr,_4365 ? _4365->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4366 = mosek::fusion::p_WorkStack::_get_impl(_4353)->i64;
  _checked_ptr_1<long long> _ptr__4366(_4366 ? _4366->raw() : nullptr,_4366 ? _4366->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4367 = mosek::fusion::p_WorkStack::_get_impl(_4353)->f64;
  _checked_ptr_1<double> _ptr__4367(_4367 ? _4367->raw() : nullptr,_4367 ? _4367->size(0) : 0);
  int _4368 = (int)99999;
  int _4369 = (int)99999;
  int _4370 = (int)99999;
  if (_4359)
  {
    {
      int _4371 = (int)0;
      int _8851 = (int)0;
      int _8852 = _4355;
      for (int _4372 = _8851; _4372 < _8852; ++_4372)
      {
        {
          if ((_4371 < _ptr__4365[safe_add( _4356,_4372 )]))
          {
            {
              _4371 = _ptr__4365[safe_add( _4356,_4372 )];
            }
          }
          {}
        }
      }
      _4368 = _4354->alloci32(safe_add( _4371,(int)1 ));
      _4369 = _4354->alloci32(_4357);
      _4370 = _4354->alloci32(_4357);
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _4373 = mosek::fusion::p_WorkStack::_get_impl(_4354)->i32;
  _checked_ptr_1<int> _ptr__4373(_4373 ? _4373->raw() : nullptr,_4373 ? _4373->size(0) : 0);
  if (_4359)
  {
    {
      int _4374 = _4369;
      int _4375 = _4370;
      int _8853 = (int)0;
      int _8854 = _4357;
      for (int _4376 = _8853; _4376 < _8854; ++_4376)
      {
        {
          _ptr__4373[safe_add( _4374,_4376 )] = _4376;
        }
      }
      if ((dim < (_4355 - (int)1)))
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _4377 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4355)));
          _checked_ptr_1<long long> _ptr__4377(_4377 ? _4377->raw() : nullptr,_4377 ? _4377->size(0) : 0);
          _ptr__4377[(_4355 - (int)1)] = (int)1;
          int _8855 = (int)1;
          int _8856 = _4355;
          for (int _4378 = _8855; _4378 < _8856; ++_4378)
          {
            {
              _ptr__4377[((_4355 - _4378) - (int)1)] = safe_mul( _ptr__4377[(_4355 - _4378)],_ptr__4365[(safe_add( _4356,_4355 ) - _4378)] );
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _4379 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((_4355 - (int)1))));
          _checked_ptr_1<int> _ptr__4379(_4379 ? _4379->raw() : nullptr,_4379 ? _4379->size(0) : 0);
          int _8857 = (int)0;
          int _8858 = dim;
          for (int _4380 = _8857; _4380 < _8858; ++_4380)
          {
            {
              _ptr__4379[((_4355 - _4380) - (int)2)] = _4380;
            }
          }
          int _8859 = safe_add( dim,(int)1 );
          int _8860 = _4355;
          for (int _4381 = _8859; _4381 < _8860; ++_4381)
          {
            {
              _ptr__4379[((_4355 - _4381) - (int)1)] = _4381;
            }
          }
          int _8861 = (int)0;
          int _8862 = (_4355 - (int)1);
          for (int _4382 = _8861; _4382 < _8862; ++_4382)
          {
            {
              int _4383 = _ptr__4379[_4382];
              int _4384 = _ptr__4365[safe_add( _4356,_4383 )];
              int _8863 = (int)0;
              int _8864 = safe_add( _4384,(int)1 );
              for (int _4385 = _8863; _4385 < _8864; ++_4385)
              {
                {
                  _ptr__4373[safe_add( _4368,_4385 )] = (int)0;
                }
              }
              int _8865 = (int)0;
              int _8866 = _4357;
              for (int _4386 = _8865; _4386 < _8866; ++_4386)
              {
                {
                  ++ _ptr__4373[safe_add( safe_add( _4368,(int)1 ),((_ptr__4366[safe_add( _4361,_4386 )] / _ptr__4377[_4383]) % _4384) )];
                }
              }
              int _8867 = (int)0;
              int _8868 = _4384;
              for (int _4387 = _8867; _4387 < _8868; ++_4387)
              {
                {
                  _ptr__4373[safe_add( safe_add( _4368,_4387 ),(int)1 )] += _ptr__4373[safe_add( _4368,_4387 )];
                }
              }
              int _8869 = (int)0;
              int _8870 = _4357;
              for (int _4388 = _8869; _4388 < _8870; ++_4388)
              {
                {
                  int _4389 = _ptr__4373[safe_add( _4374,_4388 )];
                  long long _4390 = ((_ptr__4366[safe_add( _4361,_4389 )] / _ptr__4377[_4383]) % _4384);
                  _ptr__4373[safe_add( _4375,_ptr__4373[safe_add( _4368,_4390 )] )] = _4389;
                  ++ _ptr__4373[safe_add( _4368,_4390 )];
                }
              }
              int _4391 = _4375;
              _4375 = _4374;
              _4374 = _4391;
            }
          }
        }
      }
      {}
      int _4392 = (int)1;
      int _8871 = (int)0;
      int _8872 = dim;
      for (int _4393 = _8871; _4393 < _8872; ++_4393)
      {
        {
          _4392 *= _ptr__4365[safe_add( _4356,_4393 )];
        }
      }
      int _4394 = _ptr__4365[safe_add( _4356,dim )];
      int _4395 = (int)1;
      int _8873 = safe_add( dim,(int)1 );
      int _8874 = _4355;
      for (int _4396 = _8873; _4396 < _8874; ++_4396)
      {
        {
          _4395 *= _ptr__4365[safe_add( _4356,_4396 )];
        }
      }
      int _4397 = safe_mul( _4395,_4394 );
      int _4398 = _4395;
      int _4399 = (int)1;
      int _4400 = (int)0;
      long long _4401 = (-(int)1);
      long long _4402 = (-(int)1);
      int _8875 = (int)0;
      int _8876 = _4357;
      for (int _4403 = _8875; _4403 < _8876; ++_4403)
      {
        {
          int _4404 = _ptr__4373[safe_add( _4374,_4403 )];
          long long _4405 = ((_ptr__4366[safe_add( _4361,_4404 )] / _4397) % _4392);
          long long _4406 = (_ptr__4366[safe_add( _4361,_4404 )] % _4395);
          if (((_4402 != _4405) || (_4401 != _4406)))
          {
            {
              _4402 = _4405;
              _4401 = _4406;
              ++ _4400;
            }
          }
          {}
        }
      }
      int _4407 = (_4355 - (int)1);
      bool _4408 = (_4400 < safe_mul( _4392,_4395 ));
      int _4409 = _4358;
      _4352->alloc_expr(_4407,_4400,_4409,_4408);
      int _4410 = mosek::fusion::p_WorkStack::_get_impl(_4352)->ptr_base;
      int _4411 = mosek::fusion::p_WorkStack::_get_impl(_4352)->nidxs_base;
      int _8877;
      bool _8878 = _4408;
      if (_8878)
      {
        _8877 = mosek::fusion::p_WorkStack::_get_impl(_4352)->sp_base;
      }
      else
      {
        _8877 = _4352->alloci64(_4400);
      }
      int _4412 = _8877;
      int _4413 = mosek::fusion::p_WorkStack::_get_impl(_4352)->cof_base;
      int _4414 = mosek::fusion::p_WorkStack::_get_impl(_4352)->bfix_base;
      int _4415 = mosek::fusion::p_WorkStack::_get_impl(_4352)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4416 = mosek::fusion::p_WorkStack::_get_impl(_4352)->i32;
      _checked_ptr_1<int> _ptr__4416(_4416 ? _4416->raw() : nullptr,_4416 ? _4416->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4417 = mosek::fusion::p_WorkStack::_get_impl(_4352)->i64;
      _checked_ptr_1<long long> _ptr__4417(_4417 ? _4417->raw() : nullptr,_4417 ? _4417->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4418 = mosek::fusion::p_WorkStack::_get_impl(_4352)->f64;
      _checked_ptr_1<double> _ptr__4418(_4418 ? _4418->raw() : nullptr,_4418 ? _4418->size(0) : 0);
      int _8879 = (int)0;
      int _8880 = dim;
      for (int _4419 = _8879; _4419 < _8880; ++_4419)
      {
        {
          _ptr__4416[safe_add( _4415,_4419 )] = _ptr__4365[safe_add( _4356,_4419 )];
        }
      }
      int _8881 = safe_add( dim,(int)1 );
      int _8882 = _4355;
      for (int _4420 = _8881; _4420 < _8882; ++_4420)
      {
        {
          _ptr__4416[(safe_add( _4415,_4420 ) - (int)1)] = _ptr__4365[safe_add( _4356,_4420 )];
        }
      }
      _ptr__4416[_4410] = (int)0;
      int _4421 = (int)0;
      int _4422 = (int)0;
      int _4423 = (int)0;
      while ( (_4423 < _4357) )
      {
        {
          int _4424 = _4423;
          long long _4425 = ((_ptr__4366[safe_add( _4361,_ptr__4373[safe_add( _4374,_4424 )] )] / _4397) % _4392);
          long long _4426 = (_ptr__4366[safe_add( _4361,_ptr__4373[safe_add( _4374,_4424 )] )] % _4395);
          ++ _4423;
          while ( ((_4423 < _4357) && ((_4425 == ((_ptr__4366[safe_add( _4361,_ptr__4373[safe_add( _4374,_4423 )] )] / _4397) % _4392)) && (_4426 == (_ptr__4366[safe_add( _4361,_ptr__4373[safe_add( _4374,_4423 )] )] % _4395)))) )
          {
            {
              ++ _4423;
            }
          }
          double _4427 = 0.0;
          int _8883 = _4424;
          int _8884 = _4423;
          for (int _4428 = _8883; _4428 < _8884; ++_4428)
          {
            {
              int _4429 = _ptr__4373[safe_add( _4374,_4428 )];
              int _8885 = _ptr__4365[safe_add( _4360,_4429 )];
              int _8886 = _ptr__4365[safe_add( safe_add( _4360,_4429 ),(int)1 )];
              for (int _4430 = _8885; _4430 < _8886; ++_4430)
              {
                {
                  _ptr__4417[safe_add( _4411,_4422 )] = _ptr__4366[safe_add( _4362,_4430 )];
                  _ptr__4418[safe_add( _4413,_4422 )] = _ptr__4367[safe_add( _4364,_4430 )];
                  ++ _4422;
                }
              }
              _4427 += _ptr__4367[safe_add( _4363,_4429 )];
            }
          }
          _ptr__4417[safe_add( _4412,_4421 )] = safe_add( safe_mul( _4425,_4395 ),_4426 );
          _ptr__4416[safe_add( safe_add( _4410,_4421 ),(int)1 )] = _4422;
          _ptr__4418[safe_add( _4414,_4421 )] = _4427;
          ++ _4421;
        }
      }
      if ((!_4408))
      {
        {
          _4352->popi64(_4400);
        }
      }
      {}
    }
  }
  else
  {
    {
      int _4431 = (int)1;
      int _8887 = (int)0;
      int _8888 = dim;
      for (int _4432 = _8887; _4432 < _8888; ++_4432)
      {
        {
          _4431 *= _ptr__4365[safe_add( _4356,_4432 )];
        }
      }
      int _4433 = _ptr__4365[safe_add( _4356,dim )];
      int _4434 = (int)1;
      int _8889 = safe_add( dim,(int)1 );
      int _8890 = _4355;
      for (int _4435 = _8889; _4435 < _8890; ++_4435)
      {
        {
          _4434 *= _ptr__4365[safe_add( _4356,_4435 )];
        }
      }
      int _4436 = safe_mul( _4434,_4433 );
      int _4437 = _4434;
      int _4438 = (int)1;
      int _4439 = safe_mul( _4431,_4434 );
      int _4440 = _4352->alloci32(safe_add( _4439,(int)1 ));
      int _4441 = _4352->alloci64(_4358);
      int _4442 = _4352->allocf64(_4358);
      int _4443 = _4352->allocf64(_4439);
      _4352->pushi32((int)0);
      _4352->pushi32(_4358);
      _4352->pushi32(_4439);
      int _4444 = _4352->alloci32((_4355 - (int)1));
      _4352->pushi32((_4355 - (int)1));
      std::shared_ptr< monty::ndarray< int,1 > > _4445 = mosek::fusion::p_WorkStack::_get_impl(_4352)->i32;
      _checked_ptr_1<int> _ptr__4445(_4445 ? _4445->raw() : nullptr,_4445 ? _4445->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4446 = mosek::fusion::p_WorkStack::_get_impl(_4352)->i64;
      _checked_ptr_1<long long> _ptr__4446(_4446 ? _4446->raw() : nullptr,_4446 ? _4446->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4447 = mosek::fusion::p_WorkStack::_get_impl(_4352)->f64;
      _checked_ptr_1<double> _ptr__4447(_4447 ? _4447->raw() : nullptr,_4447 ? _4447->size(0) : 0);
      int _8891 = (int)0;
      int _8892 = dim;
      for (int _4448 = _8891; _4448 < _8892; ++_4448)
      {
        {
          _ptr__4445[safe_add( _4444,_4448 )] = _ptr__4365[safe_add( _4356,_4448 )];
        }
      }
      int _8893 = safe_add( dim,(int)1 );
      int _8894 = _4355;
      for (int _4449 = _8893; _4449 < _8894; ++_4449)
      {
        {
          _ptr__4445[(safe_add( _4444,_4449 ) - (int)1)] = _ptr__4365[safe_add( _4356,_4449 )];
        }
      }
      int _4450 = (int)0;
      int _4451 = (int)0;
      _ptr__4445[_4440] = (int)0;
      int _8895 = (int)0;
      int _8896 = _4431;
      for (int _4452 = _8895; _4452 < _8896; ++_4452)
      {
        {
          int _8897 = (int)0;
          int _8898 = _4434;
          for (int _4453 = _8897; _4453 < _8898; ++_4453)
          {
            {
              double _4454 = 0.0;
              int _8899 = (int)0;
              int _8900 = _4433;
              for (int _4455 = _8899; _4455 < _8900; ++_4455)
              {
                {
                  int _4456 = safe_add( safe_add( safe_mul( _4452,_4436 ),safe_mul( _4455,_4437 ) ),_4453 );
                  int _8901 = _ptr__4365[safe_add( _4360,_4456 )];
                  int _8902 = _ptr__4365[safe_add( safe_add( _4360,_4456 ),(int)1 )];
                  for (int _4457 = _8901; _4457 < _8902; ++_4457)
                  {
                    {
                      _ptr__4446[safe_add( _4441,_4451 )] = _ptr__4366[safe_add( _4362,_4457 )];
                      _ptr__4447[safe_add( _4442,_4451 )] = _ptr__4367[safe_add( _4364,_4457 )];
                      ++ _4451;
                    }
                  }
                  _4454 += _ptr__4367[safe_add( _4363,_4456 )];
                }
              }
              _ptr__4445[safe_add( safe_add( _4440,_4450 ),(int)1 )] = _4451;
              _ptr__4447[safe_add( _4443,_4450 )] = _4454;
              ++ _4450;
            }
          }
        }
      }
    }
  }
  _4354->clear();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprSumReduce::computeShape(int _4458,std::shared_ptr< monty::ndarray< int,1 > > _4459){
  _checked_ptr_1<int> _ptr__4459(_4459 ? _4459->raw() : nullptr, _4459 ? _4459->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4460 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(((int)((_4459)->size(0)) - (int)1))));
  _checked_ptr_1<int> _ptr__4460(_4460 ? _4460->raw() : nullptr,_4460 ? _4460->size(0) : 0);
  int _8903 = (int)0;
  int _8904 = _4458;
  for (int _4461 = _8903; _4461 < _8904; ++_4461)
  {
    {
      _ptr__4460[_4461] = _ptr__4459[_4461];
    }
  }
  int _8905 = safe_add( _4458,(int)1 );
  int _8906 = (int)((_4459)->size(0));
  for (int _4462 = _8905; _4462 < _8906; ++_4462)
  {
    {
      _ptr__4460[(_4462 - (int)1)] = _ptr__4459[_4462];
    }
  }
  return _4460;
}
std::string mosek::fusion::ExprSumReduce :: toString() { return mosek::fusion::p_ExprSumReduce::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprSumReduce::toString(){
  return std::string ("ExprSumReduce()");
}
void mosek::fusion::p_ExprSumReduce::destroy(){expr.reset();}void mosek::fusion::ExprSumReduce::destroy() { mosek::fusion::p_ExprSumReduce::_get_impl(this)->destroy(); }mosek::fusion::ExprDenseTril::ExprDenseTril(mosek::fusion::p_ExprDenseTril *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprDenseTril()" << this << std::endl; */ }mosek::fusion::ExprDenseTril::~ExprDenseTril() {  /* std::cout << "~ExprDenseTril()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprDenseTril::p_ExprDenseTril  (::mosek::fusion::ExprDenseTril * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprDenseTril::t mosek::fusion::p_ExprDenseTril::_new_ExprDenseTril  (int _4463,    int _4464,    monty::rc_ptr< ::mosek::fusion::Expression > _4465,    int _4466){ return new mosek::fusion::ExprDenseTril(_4463,_4464,_4465,_4466); }mosek::fusion::ExprDenseTril::ExprDenseTril  (int _4463,    int _4464,    monty::rc_ptr< ::mosek::fusion::Expression > _4465,    int _4466) :    ExprDenseTril(new mosek::fusion::p_ExprDenseTril(this)){ mosek::fusion::p_ExprDenseTril::_get_impl(this)->_initialize(_4463,_4464,_4465,_4466); }void mosek::fusion::p_ExprDenseTril::_initialize  (int _4463,    int _4464,    monty::rc_ptr< ::mosek::fusion::Expression > _4465,    int _4466){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4465->getShape());
    mosek::fusion::p_ExprDenseTril::_get_impl(::mosek::fusion::ExprDenseTril::t(_pubthis))->expr = _4465;
    mosek::fusion::p_ExprDenseTril::_get_impl(::mosek::fusion::ExprDenseTril::t(_pubthis))->dim0 = _4463;
    mosek::fusion::p_ExprDenseTril::_get_impl(::mosek::fusion::ExprDenseTril::t(_pubthis))->dim1 = _4464;
  }
}mosek::fusion::ExprDenseTril::t mosek::fusion::p_ExprDenseTril::_new_ExprDenseTril  (int _4467,    int _4468,    monty::rc_ptr< ::mosek::fusion::Expression > _4469){ return new mosek::fusion::ExprDenseTril(_4467,_4468,_4469); }mosek::fusion::ExprDenseTril::ExprDenseTril  (int _4467,    int _4468,    monty::rc_ptr< ::mosek::fusion::Expression > _4469) :    ExprDenseTril(new mosek::fusion::p_ExprDenseTril(this)){ mosek::fusion::p_ExprDenseTril::_get_impl(this)->_initialize(_4467,_4468,_4469); }void mosek::fusion::p_ExprDenseTril::_initialize  (int _4467,    int _4468,    monty::rc_ptr< ::mosek::fusion::Expression > _4469){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ExprDenseTril::_initialize(_4467,_4468,_4469,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _4470 = _4469->getShape();
    _checked_ptr_1<int> _ptr__4470(_4470 ? _4470->raw() : nullptr,_4470 ? _4470->size(0) : 0);
    if (((dim0 == dim1) || ((dim0 < (int)0) || ((dim0 >= (int)((_4470)->size(0))) || ((dim1 < (int)0) || ((dim1 >= (int)((_4470)->size(0))) || (_ptr__4470[dim0] != _ptr__4470[dim1])))))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid dimension definitions"));
      }
    }
    {}
  }
}void mosek::fusion::ExprDenseTril :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4471,monty::rc_ptr< ::mosek::fusion::WorkStack > _4472,monty::rc_ptr< ::mosek::fusion::WorkStack > _4473) { mosek::fusion::p_ExprDenseTril::_get_impl(this)->eval(_4471,_4472,_4473); }void mosek::fusion::p_ExprDenseTril::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4471,monty::rc_ptr< ::mosek::fusion::WorkStack > _4472,monty::rc_ptr< ::mosek::fusion::WorkStack > _4473){
  expr->eval(_4472,_4471,_4473);
  std::shared_ptr< monty::ndarray< int,1 > > _4474 = mosek::fusion::p_WorkStack::_get_impl(_4472)->i32;
  _checked_ptr_1<int> _ptr__4474(_4474 ? _4474->raw() : nullptr,_4474 ? _4474->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4475 = mosek::fusion::p_WorkStack::_get_impl(_4472)->i64;
  _checked_ptr_1<long long> _ptr__4475(_4475 ? _4475->raw() : nullptr,_4475 ? _4475->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4476 = mosek::fusion::p_WorkStack::_get_impl(_4472)->f64;
  _checked_ptr_1<double> _ptr__4476(_4476 ? _4476->raw() : nullptr,_4476 ? _4476->size(0) : 0);
  int _8907;
  bool _8908 = (dim0 < dim1);
  if (_8908)
  {
    _8907 = dim0;
  }
  else
  {
    _8907 = dim1;
  }
  int _4477 = _8907;
  int _8909;
  bool _8910 = (dim0 > dim1);
  if (_8910)
  {
    _8909 = dim0;
  }
  else
  {
    _8909 = dim1;
  }
  int _4478 = _8909;
  bool _4479 = (dim0 < dim1);
  int _4480 = _4472->popi32();
  int _4481 = _4472->popi32(_4480);
  int _4482 = _4472->popi32();
  int _4483 = _4472->popi32();
  bool _4484 = (_4472->popi32() != (int)0);
  int _4485 = _4472->popi32(safe_add( _4482,(int)1 ));
  int _8911;
  bool _8912 = _4484;
  if (_8912)
  {
    _8911 = _4472->popi64(_4482);
  }
  else
  {
    _8911 = (-(int)1);
  }
  int _4486 = _8911;
  int _4487 = _4472->popi64(_4483);
  int _4488 = _4472->popf64(_4482);
  int _4489 = _4472->popf64(_4483);
  std::vector<int> _8913;
  for (int _4491 = (int)0, _8914 = (int)5; _4491 < _8914 ; ++_4491)
  {
    _8913.push_back((int)1);
  }
  auto _8915 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8913.size()),_8913.begin(),_8913.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _4490 = _8915;
  _checked_ptr_1<int> _ptr__4490(_4490 ? _4490->raw() : nullptr,_4490 ? _4490->size(0) : 0);
  int _8916 = (int)0;
  int _8917 = _4477;
  for (int _4492 = _8916; _4492 < _8917; ++_4492)
  {
    {
      _ptr__4490[(int)0] *= _ptr__4474[safe_add( _4481,_4492 )];
    }
  }
  _ptr__4490[(int)1] = _ptr__4474[safe_add( _4481,_4477 )];
  int _8918 = safe_add( _4477,(int)1 );
  int _8919 = _4478;
  for (int _4493 = _8918; _4493 < _8919; ++_4493)
  {
    {
      _ptr__4490[(int)2] *= _ptr__4474[safe_add( _4481,_4493 )];
    }
  }
  _ptr__4490[(int)3] = _ptr__4474[safe_add( _4481,_4478 )];
  int _8920 = safe_add( _4478,(int)1 );
  int _8921 = _4480;
  for (int _4494 = _8920; _4494 < _8921; ++_4494)
  {
    {
      _ptr__4490[(int)4] *= _ptr__4474[safe_add( _4481,_4494 )];
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _4495 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)5)));
  _checked_ptr_1<int> _ptr__4495(_4495 ? _4495->raw() : nullptr,_4495 ? _4495->size(0) : 0);
  _ptr__4495[(int)4] = (int)1;
  int _8922 = (int)1;
  int _8923 = (int)5;
  for (int _4496 = _8922; _4496 < _8923; ++_4496)
  {
    {
      _ptr__4495[(((int)5 - _4496) - (int)1)] = safe_mul( _ptr__4495[((int)5 - _4496)],_ptr__4490[((int)5 - _4496)] );
    }
  }
  int _4497 = (int)0;
  int _4498 = (int)0;
  {
    if (_4484)
    {
      {
        if (_4479)
        {
          {
            int _8924 = (int)0;
            int _8925 = _4482;
            for (int _4499 = _8924; _4499 < _8925; ++_4499)
            {
              {
                long long _4500 = ((_ptr__4475[safe_add( _4486,_4499 )] / _ptr__4495[(int)1]) % _ptr__4490[(int)1]);
                long long _4501 = ((_ptr__4475[safe_add( _4486,_4499 )] / _ptr__4495[(int)3]) % _ptr__4490[(int)3]);
                if ((_4500 >= _4501))
                {
                  {
                    _4497 += (_ptr__4474[safe_add( safe_add( _4485,_4499 ),(int)1 )] - _ptr__4474[safe_add( _4485,_4499 )]);
                    ++ _4498;
                  }
                }
                {}
              }
            }
          }
        }
        else
        {
          {
            int _8926 = (int)0;
            int _8927 = _4482;
            for (int _4502 = _8926; _4502 < _8927; ++_4502)
            {
              {
                long long _4503 = ((_ptr__4475[safe_add( _4486,_4502 )] / _ptr__4495[(int)1]) % _ptr__4490[(int)1]);
                long long _4504 = ((_ptr__4475[safe_add( _4486,_4502 )] / _ptr__4495[(int)3]) % _ptr__4490[(int)3]);
                if ((_4503 <= _4504))
                {
                  {
                    _4497 += (_ptr__4474[safe_add( safe_add( _4485,_4502 ),(int)1 )] - _ptr__4474[safe_add( _4485,_4502 )]);
                    ++ _4498;
                  }
                }
                {}
              }
            }
          }
        }
      }
    }
    else
    {
      {
        _4498 = safe_mul( safe_mul( safe_mul( _ptr__4490[(int)0],_ptr__4490[(int)2] ),_ptr__4490[(int)4] ),(safe_mul( _ptr__4490[(int)1],safe_add( _ptr__4490[(int)1],(int)1 ) ) / (int)2) );
        if (_4479)
        {
          {
            int _8928 = (int)0;
            int _8929 = _ptr__4490[(int)0];
            for (int _4505 = _8928; _4505 < _8929; ++_4505)
            {
              {
                int _8930 = (int)0;
                int _8931 = _ptr__4490[(int)1];
                for (int _4506 = _8930; _4506 < _8931; ++_4506)
                {
                  {
                    int _8932 = (int)0;
                    int _8933 = _ptr__4490[(int)2];
                    for (int _4507 = _8932; _4507 < _8933; ++_4507)
                    {
                      {
                        int _8934 = (int)0;
                        int _8935 = safe_add( _4506,(int)1 );
                        for (int _4508 = _8934; _4508 < _8935; ++_4508)
                        {
                          {
                            int _8936 = (int)0;
                            int _8937 = _ptr__4490[(int)4];
                            for (int _4509 = _8936; _4509 < _8937; ++_4509)
                            {
                              {
                                int _4510 = safe_add( safe_add( safe_add( safe_add( safe_mul( _4505,_ptr__4495[(int)0] ),safe_mul( _4506,_ptr__4495[(int)1] ) ),safe_mul( _4507,_ptr__4495[(int)2] ) ),safe_mul( _4508,_ptr__4495[(int)3] ) ),safe_mul( _4509,_ptr__4495[(int)4] ) );
                                _4497 += (_ptr__4474[safe_add( safe_add( _4485,_4510 ),(int)1 )] - _ptr__4474[safe_add( _4485,_4510 )]);
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
        else
        {
          {
            int _8938 = (int)0;
            int _8939 = _ptr__4490[(int)0];
            for (int _4511 = _8938; _4511 < _8939; ++_4511)
            {
              {
                int _8940 = (int)0;
                int _8941 = _ptr__4490[(int)1];
                for (int _4512 = _8940; _4512 < _8941; ++_4512)
                {
                  {
                    int _8942 = (int)0;
                    int _8943 = _ptr__4490[(int)2];
                    for (int _4513 = _8942; _4513 < _8943; ++_4513)
                    {
                      {
                        int _8944 = _4512;
                        int _8945 = _ptr__4490[(int)3];
                        for (int _4514 = _8944; _4514 < _8945; ++_4514)
                        {
                          {
                            int _8946 = (int)0;
                            int _8947 = _ptr__4490[(int)4];
                            for (int _4515 = _8946; _4515 < _8947; ++_4515)
                            {
                              {
                                int _4516 = safe_add( safe_add( safe_add( safe_add( safe_mul( _4511,_ptr__4495[(int)0] ),safe_mul( _4512,_ptr__4495[(int)1] ) ),safe_mul( _4513,_ptr__4495[(int)2] ) ),safe_mul( _4514,_ptr__4495[(int)3] ) ),safe_mul( _4515,_ptr__4495[(int)4] ) );
                                _4497 += (_ptr__4474[safe_add( safe_add( _4485,_4516 ),(int)1 )] - _ptr__4474[safe_add( _4485,_4516 )]);
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  int _4517 = (safe_mul( safe_mul( safe_mul( safe_mul( _ptr__4490[(int)0],_ptr__4490[(int)2] ),_ptr__4490[(int)4] ),_ptr__4490[(int)1] ),safe_add( _ptr__4490[(int)1],(int)1 ) ) / (int)2);
  int _4518 = _4471->alloci32(safe_add( _4517,(int)1 ));
  _4471->pushi32((int)1);
  _4471->pushi32(_4497);
  _4471->pushi32(_4517);
  int _8948 = (int)0;
  int _8949 = _4480;
  for (int _4519 = _8948; _4519 < _8949; ++_4519)
  {
    {
      _4471->pushi32(_ptr__4474[safe_add( _4481,_4519 )]);
    }
  }
  _4471->pushi32(_4480);
  int _4520 = _4471->alloci64(_4497);
  int _4521 = _4471->alloci64(_4517);
  int _4522 = _4471->allocf64(_4497);
  int _4523 = _4471->allocf64(_4517);
  std::shared_ptr< monty::ndarray< int,1 > > _4524 = mosek::fusion::p_WorkStack::_get_impl(_4471)->i32;
  _checked_ptr_1<int> _ptr__4524(_4524 ? _4524->raw() : nullptr,_4524 ? _4524->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4525 = mosek::fusion::p_WorkStack::_get_impl(_4471)->i64;
  _checked_ptr_1<long long> _ptr__4525(_4525 ? _4525->raw() : nullptr,_4525 ? _4525->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4526 = mosek::fusion::p_WorkStack::_get_impl(_4471)->f64;
  _checked_ptr_1<double> _ptr__4526(_4526 ? _4526->raw() : nullptr,_4526 ? _4526->size(0) : 0);
  _ptr__4524[_4518] = (int)0;
  if (_4479)
  {
    {
      int _4527 = (int)0;
      int _8950 = (int)0;
      int _8951 = _ptr__4490[(int)0];
      for (int _4528 = _8950; _4528 < _8951; ++_4528)
      {
        {
          int _8952 = (int)0;
          int _8953 = _ptr__4490[(int)1];
          for (int _4529 = _8952; _4529 < _8953; ++_4529)
          {
            {
              int _8954 = (int)0;
              int _8955 = _ptr__4490[(int)2];
              for (int _4530 = _8954; _4530 < _8955; ++_4530)
              {
                {
                  int _8956 = (int)0;
                  int _8957 = safe_add( _4529,(int)1 );
                  for (int _4531 = _8956; _4531 < _8957; ++_4531)
                  {
                    {
                      int _8958 = (int)0;
                      int _8959 = _ptr__4490[(int)4];
                      for (int _4532 = _8958; _4532 < _8959; ++_4532)
                      {
                        {
                          _ptr__4525[safe_add( _4521,_4527 )] = safe_add( safe_add( safe_add( safe_add( safe_mul( _4528,_ptr__4495[(int)0] ),safe_mul( _4529,_ptr__4495[(int)1] ) ),safe_mul( _4530,_ptr__4495[(int)2] ) ),safe_mul( _4531,_ptr__4495[(int)3] ) ),safe_mul( _4532,_ptr__4495[(int)4] ) );
                          ++ _4527;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _4533 = (int)0;
      int _8960 = (int)0;
      int _8961 = _ptr__4490[(int)0];
      for (int _4534 = _8960; _4534 < _8961; ++_4534)
      {
        {
          int _8962 = (int)0;
          int _8963 = _ptr__4490[(int)1];
          for (int _4535 = _8962; _4535 < _8963; ++_4535)
          {
            {
              int _8964 = (int)0;
              int _8965 = _ptr__4490[(int)2];
              for (int _4536 = _8964; _4536 < _8965; ++_4536)
              {
                {
                  int _8966 = _4535;
                  int _8967 = _ptr__4490[(int)3];
                  for (int _4537 = _8966; _4537 < _8967; ++_4537)
                  {
                    {
                      int _8968 = (int)0;
                      int _8969 = _ptr__4490[(int)4];
                      for (int _4538 = _8968; _4538 < _8969; ++_4538)
                      {
                        {
                          _ptr__4525[safe_add( _4521,_4533 )] = safe_add( safe_add( safe_add( safe_add( safe_mul( _4534,_ptr__4495[(int)0] ),safe_mul( _4535,_ptr__4495[(int)1] ) ),safe_mul( _4536,_ptr__4495[(int)2] ) ),safe_mul( _4537,_ptr__4495[(int)3] ) ),safe_mul( _4538,_ptr__4495[(int)4] ) );
                          ++ _4533;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  {
    int _4539 = (int)0;
    if (_4484)
    {
      {
        int _4540 = (int)0;
        int _4541 = (int)0;
        while ( ((_4541 < _4482) && (_4540 < _4517)) )
        {
          {
            if ((_ptr__4475[safe_add( _4486,_4541 )] < _ptr__4525[safe_add( _4521,_4540 )]))
            {
              {
                ++ _4541;
              }
            }
            else if((_ptr__4475[safe_add( _4486,_4541 )] > _ptr__4525[safe_add( _4521,_4540 )]))
            {
              {
                _ptr__4526[safe_add( _4523,_4540 )] = 0.0;
                _ptr__4524[safe_add( safe_add( _4518,_4540 ),(int)1 )] = _4539;
                ++ _4540;
              }
            }
            else
            {
              {
                int _8970 = _ptr__4474[safe_add( _4485,_4541 )];
                int _8971 = _ptr__4474[safe_add( safe_add( _4485,_4541 ),(int)1 )];
                for (int _4542 = _8970; _4542 < _8971; ++_4542)
                {
                  {
                    _ptr__4525[safe_add( _4520,_4539 )] = _ptr__4475[safe_add( _4487,_4542 )];
                    _ptr__4526[safe_add( _4522,_4539 )] = _ptr__4476[safe_add( _4489,_4542 )];
                    ++ _4539;
                  }
                }
                _ptr__4526[safe_add( _4523,_4540 )] = _ptr__4476[safe_add( _4488,_4541 )];
                _ptr__4524[safe_add( safe_add( _4518,_4540 ),(int)1 )] = _4539;
                ++ _4541;
                ++ _4540;
              }
            }
          }
        }
        while ( (_4540 < _4517) )
        {
          {
            _ptr__4524[safe_add( safe_add( _4518,_4540 ),(int)1 )] = _4539;
            _ptr__4526[safe_add( _4523,_4540 )] = 0.0;
            ++ _4540;
          }
        }
      }
    }
    else
    {
      {
        int _8972 = (int)0;
        int _8973 = _4517;
        for (int _4543 = _8972; _4543 < _8973; ++_4543)
        {
          {
            long long _4544 = _ptr__4525[safe_add( _4521,_4543 )];
            _ptr__4526[safe_add( _4523,_4543 )] = _ptr__4476[safe_add( _4488,_4544 )];
            int _8974 = _ptr__4474[safe_add( _4485,_4544 )];
            int _8975 = _ptr__4474[safe_add( safe_add( _4485,_4544 ),(int)1 )];
            for (int _4545 = _8974; _4545 < _8975; ++_4545)
            {
              {
                _ptr__4525[safe_add( _4520,_4539 )] = _ptr__4475[safe_add( _4487,_4545 )];
                _ptr__4526[safe_add( _4522,_4539 )] = _ptr__4476[safe_add( _4489,_4545 )];
                ++ _4539;
              }
            }
            _ptr__4524[safe_add( safe_add( _4518,_4543 ),(int)1 )] = _4539;
          }
        }
      }
    }
  }
}
void mosek::fusion::p_ExprDenseTril::destroy(){expr.reset();}void mosek::fusion::ExprDenseTril::destroy() { mosek::fusion::p_ExprDenseTril::_get_impl(this)->destroy(); }mosek::fusion::ExprDense::ExprDense(mosek::fusion::p_ExprDense *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprDense()" << this << std::endl; */ }mosek::fusion::ExprDense::~ExprDense() {  /* std::cout << "~ExprDense()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprDense::p_ExprDense  (::mosek::fusion::ExprDense * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprDense::t mosek::fusion::p_ExprDense::_new_ExprDense  (monty::rc_ptr< ::mosek::fusion::Expression > _4546){ return new mosek::fusion::ExprDense(_4546); }mosek::fusion::ExprDense::ExprDense  (monty::rc_ptr< ::mosek::fusion::Expression > _4546) :    ExprDense(new mosek::fusion::p_ExprDense(this)){ mosek::fusion::p_ExprDense::_get_impl(this)->_initialize(_4546); }void mosek::fusion::p_ExprDense::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4546){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4546->getShape());
    mosek::fusion::p_ExprDense::_get_impl(::mosek::fusion::ExprDense::t(_pubthis))->expr = _4546;
  }
}void mosek::fusion::ExprDense :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4547,monty::rc_ptr< ::mosek::fusion::WorkStack > _4548,monty::rc_ptr< ::mosek::fusion::WorkStack > _4549) { mosek::fusion::p_ExprDense::_get_impl(this)->eval(_4547,_4548,_4549); }void mosek::fusion::p_ExprDense::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4547,monty::rc_ptr< ::mosek::fusion::WorkStack > _4548,monty::rc_ptr< ::mosek::fusion::WorkStack > _4549){
  expr->eval(_4547,_4548,_4549);
  _4547->peek_expr();
  if (mosek::fusion::p_WorkStack::_get_impl(_4547)->hassp)
  {
    {
      int _4550 = mosek::fusion::p_WorkStack::_get_impl(_4547)->nd;
      int _4551 = mosek::fusion::p_WorkStack::_get_impl(_4547)->nnz;
      int _4552 = mosek::fusion::p_WorkStack::_get_impl(_4547)->nelem;
      int _4553 = mosek::fusion::p_WorkStack::_get_impl(_4547)->sp_base;
      std::vector<int> _8976;
      for (int _4555 = (int)0, _8977 = _4550; _4555 < _8977 ; ++_4555)
      {
        _8976.push_back(((*mosek::fusion::p_WorkStack::_get_impl(_4547)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_4547)->shape_base,_4555 ))));
      }
      auto _8978 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8976.size()),_8976.begin(),_8976.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _4554 = _8978;
      _checked_ptr_1<int> _ptr__4554(_4554 ? _4554->raw() : nullptr,_4554 ? _4554->size(0) : 0);
      int _4556 = (int)::mosek::fusion::p_Set::size(_4554);
      _4547->popi32(safe_add( (int)4,_4550 ));
      if ((_4556 == _4552))
      {
        {
          _4547->popi64(_4552);
          _4547->pushi32((int)0);
          _4547->pushi32(_4551);
          _4547->pushi32(_4552);
          int _4557 = _4547->alloci32(_4550);
          int _8979 = (int)0;
          int _8980 = _4550;
          for (int _4558 = _8979; _4558 < _8980; ++_4558)
          {
            {
              ((*mosek::fusion::p_WorkStack::_get_impl(_4547)->i32)(safe_add( _4557,_4558 ))) = _ptr__4554[_4558];
            }
          }
          _4547->pushi32(_4550);
          _4547->peek_expr();
        }
      }
      else
      {
        {
          int _4559 = _4549->alloci32(safe_add( _4556,(int)1 ));
          int _4560 = _4549->allocf64(_4556);
          std::shared_ptr< monty::ndarray< int,1 > > _4561 = mosek::fusion::p_WorkStack::_get_impl(_4549)->i32;
          _checked_ptr_1<int> _ptr__4561(_4561 ? _4561->raw() : nullptr,_4561 ? _4561->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _4562 = mosek::fusion::p_WorkStack::_get_impl(_4549)->f64;
          _checked_ptr_1<double> _ptr__4562(_4562 ? _4562->raw() : nullptr,_4562 ? _4562->size(0) : 0);
          ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_WorkStack::_get_impl(_4547)->f64,mosek::fusion::p_WorkStack::_get_impl(_4547)->bfix_base,_4562,_4560,_4552);
          ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_WorkStack::_get_impl(_4547)->i32,mosek::fusion::p_WorkStack::_get_impl(_4547)->ptr_base,_4561,_4559,safe_add( _4552,(int)1 ));
          _4547->popi32(safe_add( _4552,(int)1 ));
          _4547->popf64(_4552);
          int _4563 = _4547->alloci32(safe_add( _4556,(int)1 ));
          int _4564 = _4547->allocf64(_4556);
          {
            std::shared_ptr< monty::ndarray< int,1 > > _4565 = mosek::fusion::p_WorkStack::_get_impl(_4547)->i32;
            _checked_ptr_1<int> _ptr__4565(_4565 ? _4565->raw() : nullptr,_4565 ? _4565->size(0) : 0);
            std::shared_ptr< monty::ndarray< long long,1 > > _4566 = mosek::fusion::p_WorkStack::_get_impl(_4547)->i64;
            _checked_ptr_1<long long> _ptr__4566(_4566 ? _4566->raw() : nullptr,_4566 ? _4566->size(0) : 0);
            std::shared_ptr< monty::ndarray< double,1 > > _4567 = mosek::fusion::p_WorkStack::_get_impl(_4547)->f64;
            _checked_ptr_1<double> _ptr__4567(_4567 ? _4567->raw() : nullptr,_4567 ? _4567->size(0) : 0);
            _ptr__4565[_4563] = (int)0;
            int _4568 = (int)0;
            if ((_4552 > (int)0))
            {
              {
                int _8981 = (int)0;
                int _8982 = _4556;
                for (int _4569 = _8981; _4569 < _8982; ++_4569)
                {
                  {
                    if ((_ptr__4566[safe_add( _4553,_4568 )] == _4569))
                    {
                      {
                        _ptr__4567[safe_add( _4564,_4569 )] = _ptr__4562[safe_add( _4560,_4568 )];
                        ++ _4568;
                      }
                    }
                    else
                    {
                      {
                        _ptr__4567[safe_add( _4564,_4569 )] = (int)0;
                      }
                    }
                    _ptr__4565[safe_add( safe_add( _4563,_4569 ),(int)1 )] = _ptr__4561[safe_add( _4559,_4568 )];
                  }
                }
              }
            }
            else
            {
              {
                int _8983 = (int)0;
                int _8984 = _4556;
                for (int _4570 = _8983; _4570 < _8984; ++_4570)
                {
                  {
                    _ptr__4567[safe_add( _4564,_4570 )] = (int)0;
                    _ptr__4565[safe_add( safe_add( _4563,_4570 ),(int)1 )] = (int)0;
                  }
                }
              }
            }
          }
          _4547->popi64(_4552);
          _4547->pushi32((int)0);
          _4547->pushi32(_4551);
          _4547->pushi32(_4556);
          int _8985 = (int)0;
          int _8986 = _4550;
          for (int _4571 = _8985; _4571 < _8986; ++_4571)
          {
            {
              _4547->pushi32(_ptr__4554[_4571]);
            }
          }
          _4547->pushi32(_4550);
        }
      }
      _4547->peek_expr();
    }
  }
  {}
  _4549->clear();
}
std::string mosek::fusion::ExprDense :: toString() { return mosek::fusion::p_ExprDense::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprDense::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprDense("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprDense::destroy(){expr.reset();}void mosek::fusion::ExprDense::destroy() { mosek::fusion::p_ExprDense::_get_impl(this)->destroy(); }mosek::fusion::ExprSymmetrize::ExprSymmetrize(mosek::fusion::p_ExprSymmetrize *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprSymmetrize()" << this << std::endl; */ }mosek::fusion::ExprSymmetrize::~ExprSymmetrize() {  /* std::cout << "~ExprSymmetrize()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprSymmetrize::p_ExprSymmetrize  (::mosek::fusion::ExprSymmetrize * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprSymmetrize::t mosek::fusion::p_ExprSymmetrize::_new_ExprSymmetrize  (int _4572,    int _4573,    monty::rc_ptr< ::mosek::fusion::Expression > _4574,    int _4575){ return new mosek::fusion::ExprSymmetrize(_4572,_4573,_4574,_4575); }mosek::fusion::ExprSymmetrize::ExprSymmetrize  (int _4572,    int _4573,    monty::rc_ptr< ::mosek::fusion::Expression > _4574,    int _4575) :    ExprSymmetrize(new mosek::fusion::p_ExprSymmetrize(this)){ mosek::fusion::p_ExprSymmetrize::_get_impl(this)->_initialize(_4572,_4573,_4574,_4575); }void mosek::fusion::p_ExprSymmetrize::_initialize  (int _4572,    int _4573,    monty::rc_ptr< ::mosek::fusion::Expression > _4574,    int _4575){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4574->getShape());
    mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->expr = _4574;
    if ((_4572 < _4573))
    {
      {
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim0 = _4572;
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim1 = _4573;
      }
    }
    else
    {
      {
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim0 = _4573;
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim1 = _4572;
      }
    }
  }
}mosek::fusion::ExprSymmetrize::t mosek::fusion::p_ExprSymmetrize::_new_ExprSymmetrize  (int _4576,    int _4577,    monty::rc_ptr< ::mosek::fusion::Expression > _4578){ return new mosek::fusion::ExprSymmetrize(_4576,_4577,_4578); }mosek::fusion::ExprSymmetrize::ExprSymmetrize  (int _4576,    int _4577,    monty::rc_ptr< ::mosek::fusion::Expression > _4578) :    ExprSymmetrize(new mosek::fusion::p_ExprSymmetrize(this)){ mosek::fusion::p_ExprSymmetrize::_get_impl(this)->_initialize(_4576,_4577,_4578); }void mosek::fusion::p_ExprSymmetrize::_initialize  (int _4576,    int _4577,    monty::rc_ptr< ::mosek::fusion::Expression > _4578){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ExprSymmetrize::_initialize(_4576,_4577,_4578,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _4579 = _4578->getShape();
    _checked_ptr_1<int> _ptr__4579(_4579 ? _4579->raw() : nullptr,_4579 ? _4579->size(0) : 0);
    if (((dim0 < (int)0) || ((dim0 == dim1) || ((dim1 >= (int)((_4579)->size(0))) || (_ptr__4579[dim0] != _ptr__4579[dim1])))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid dimension definitions"));
      }
    }
    {}
  }
}void mosek::fusion::ExprSymmetrize :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4580,monty::rc_ptr< ::mosek::fusion::WorkStack > _4581,monty::rc_ptr< ::mosek::fusion::WorkStack > _4582) { mosek::fusion::p_ExprSymmetrize::_get_impl(this)->eval(_4580,_4581,_4582); }void mosek::fusion::p_ExprSymmetrize::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4580,monty::rc_ptr< ::mosek::fusion::WorkStack > _4581,monty::rc_ptr< ::mosek::fusion::WorkStack > _4582){
  expr->eval(_4581,_4580,_4582);
  int _4583 = (int)0;
  int _4584 = _4581->peeki32();
  int _4585 = _4581->peeki32(safe_add( _4584,(int)3 ));
  int _4586 = _4581->peeki32(safe_add( _4584,(int)2 ));
  int _8987 = (int)0;
  int _8988 = _4584;
  for (int _4587 = _8987; _4587 < _8988; ++_4587)
  {
    {
      int _4588 = _4581->peeki32(safe_add( _4587,(int)1 ));
      if ((_4588 > _4583))
      {
        {
          _4588 = _4583;
        }
      }
      {}
    }
  }
  int _4589 = _4581->alloci32(_4586);
  int _4590 = _4581->alloci32(_4586);
  int _4591 = _4581->alloci32(safe_add( _4583,(int)1 ));
  int _4592 = _4581->alloci64(_4586);
  _4581->popi32(safe_add( safe_add( safe_mul( (int)2,_4586 ),_4583 ),(int)1 ));
  _4581->popi64(_4586);
  int _4593 = _4581->popi32();
  int _4594 = _4581->popi32(_4593);
  int _4595 = _4581->popi32();
  int _4596 = _4581->popi32();
  bool _4597 = (_4581->popi32() != (int)0);
  int _4598 = _4581->popi32(safe_add( _4595,(int)1 ));
  int _8989;
  bool _8990 = _4597;
  if (_8990)
  {
    _8989 = _4581->popi64(_4595);
  }
  else
  {
    _8989 = (-(int)1);
  }
  int _4599 = _8989;
  int _4600 = _4581->popi64(_4596);
  int _4601 = _4581->popf64(_4595);
  int _4602 = _4581->popf64(_4596);
  int _4603 = (int)0;
  int _4604 = (int)0;
  std::vector<int> _8991;
  for (int _4606 = (int)0, _8992 = (int)5; _4606 < _8992 ; ++_4606)
  {
    _8991.push_back((int)1);
  }
  auto _8993 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8991.size()),_8991.begin(),_8991.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _4605 = _8993;
  _checked_ptr_1<int> _ptr__4605(_4605 ? _4605->raw() : nullptr,_4605 ? _4605->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4607 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)5)));
  _checked_ptr_1<long long> _ptr__4607(_4607 ? _4607->raw() : nullptr,_4607 ? _4607->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4608 = mosek::fusion::p_WorkStack::_get_impl(_4581)->i32;
  _checked_ptr_1<int> _ptr__4608(_4608 ? _4608->raw() : nullptr,_4608 ? _4608->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4609 = mosek::fusion::p_WorkStack::_get_impl(_4581)->i64;
  _checked_ptr_1<long long> _ptr__4609(_4609 ? _4609->raw() : nullptr,_4609 ? _4609->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4610 = mosek::fusion::p_WorkStack::_get_impl(_4581)->f64;
  _checked_ptr_1<double> _ptr__4610(_4610 ? _4610->raw() : nullptr,_4610 ? _4610->size(0) : 0);
  int _8994 = (int)0;
  int _8995 = dim0;
  for (int _4611 = _8994; _4611 < _8995; ++_4611)
  {
    {
      _ptr__4605[(int)0] *= _ptr__4608[safe_add( _4594,_4611 )];
    }
  }
  _ptr__4605[(int)1] = _ptr__4608[safe_add( _4594,dim0 )];
  int _8996 = safe_add( dim0,(int)1 );
  int _8997 = dim1;
  for (int _4612 = _8996; _4612 < _8997; ++_4612)
  {
    {
      _ptr__4605[(int)2] *= _ptr__4608[safe_add( _4594,_4612 )];
    }
  }
  _ptr__4605[(int)3] = _ptr__4608[safe_add( _4594,dim1 )];
  int _8998 = safe_add( dim1,(int)1 );
  int _8999 = _4593;
  for (int _4613 = _8998; _4613 < _8999; ++_4613)
  {
    {
      _ptr__4605[(int)4] *= _ptr__4608[safe_add( _4594,_4613 )];
    }
  }
  _ptr__4607[(int)4] = (int)1;
  int _9000 = (int)1;
  int _9001 = (int)5;
  for (int _4614 = _9000; _4614 < _9001; ++_4614)
  {
    {
      _ptr__4607[(((int)5 - _4614) - (int)1)] = safe_mul( _ptr__4607[((int)5 - _4614)],_ptr__4605[((int)5 - _4614)] );
    }
  }
  if (_4597)
  {
    {
      int _4615 = _4589;
      int _9002 = (int)0;
      int _9003 = _4595;
      for (int _4616 = _9002; _4616 < _9003; ++_4616)
      {
        {
          _ptr__4608[safe_add( _4615,_4616 )] = _4616;
        }
      }
      int _4617 = _4590;
      std::shared_ptr< monty::ndarray< int,1 > > _4618 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)2),(int)((int)3),(int)((int)0)});
      _checked_ptr_1<int> _ptr__4618(_4618 ? _4618->raw() : nullptr,_4618 ? _4618->size(0) : 0);
      int _9004 = (int)0;
      int _9005 = (int)4;
      for (int _4619 = _9004; _4619 < _9005; ++_4619)
      {
        {
          long long _4620 = _ptr__4607[_ptr__4618[_4619]];
          int _4621 = _ptr__4605[_ptr__4618[_4619]];
          if ((_4621 > (int)1))
          {
            {
              int _9006 = (int)0;
              int _9007 = safe_add( _4621,(int)1 );
              for (int _4622 = _9006; _4622 < _9007; ++_4622)
              {
                {
                  _ptr__4608[safe_add( _4591,_4622 )] = (int)0;
                }
              }
              int _9008 = (int)0;
              int _9009 = _4595;
              for (int _4623 = _9008; _4623 < _9009; ++_4623)
              {
                {
                  ++ _ptr__4608[safe_add( safe_add( _4591,((_ptr__4609[safe_add( _4599,_ptr__4608[safe_add( _4615,_4623 )] )] / _4620) % _4621) ),(int)1 )];
                }
              }
              int _9010 = (int)0;
              int _9011 = _ptr__4605[(int)3];
              for (int _4624 = _9010; _4624 < _9011; ++_4624)
              {
                {
                  _ptr__4608[safe_add( safe_add( _4591,_4624 ),(int)1 )] += _ptr__4608[safe_add( _4591,_4624 )];
                }
              }
              int _9012 = (int)0;
              int _9013 = _4595;
              for (int _4625 = _9012; _4625 < _9013; ++_4625)
              {
                {
                  int _4626 = _ptr__4608[safe_add( _4615,_4625 )];
                  long long _4627 = ((_ptr__4609[safe_add( _4599,_4626 )] / _4620) % _4621);
                  _ptr__4608[safe_add( _4617,_ptr__4608[safe_add( _4591,_4627 )] )] = _4626;
                  ++ _ptr__4608[safe_add( _4591,_4627 )];
                }
              }
              int _4628 = _4615;
              _4615 = _4617;
              _4617 = _4628;
            }
          }
          {}
        }
      }
      int _9014 = (int)0;
      int _9015 = _4595;
      for (int _4629 = _9014; _4629 < _9015; ++_4629)
      {
        {
          _ptr__4609[safe_add( _4592,_4629 )] = safe_add( safe_add( safe_add( safe_add( safe_mul( ((_ptr__4609[safe_add( _4599,_4629 )] / _ptr__4607[(int)0]) % _ptr__4605[(int)0]),_ptr__4607[(int)0] ),safe_mul( ((_ptr__4609[safe_add( _4599,_4629 )] / _ptr__4607[(int)1]) % _ptr__4605[(int)1]),_ptr__4607[(int)3] ) ),safe_mul( ((_ptr__4609[safe_add( _4599,_4629 )] / _ptr__4607[(int)2]) % _ptr__4605[(int)2]),_ptr__4607[(int)2] ) ),safe_mul( ((_ptr__4609[safe_add( _4599,_4629 )] / _ptr__4607[(int)3]) % _ptr__4605[(int)3]),_ptr__4607[(int)1] ) ),safe_mul( ((_ptr__4609[safe_add( _4599,_4629 )] / _ptr__4607[(int)4]) % _ptr__4605[(int)4]),_ptr__4607[(int)4] ) );
        }
      }
      {
        int _4630 = (int)0;
        int _4631 = (int)0;
        while ( ((_4631 < _4595) && (_4630 < _4595)) )
        {
          {
            int _4632 = _ptr__4608[safe_add( _4615,_4630 )];
            if ((_ptr__4609[safe_add( _4599,_4631 )] < _ptr__4609[safe_add( _4592,_4632 )]))
            {
              {
                _4604 += (_ptr__4608[safe_add( safe_add( _4598,_4631 ),(int)1 )] - _ptr__4608[safe_add( _4598,_4631 )]);
                ++ _4603;
                ++ _4631;
              }
            }
            else if((_ptr__4609[safe_add( _4599,_4631 )] > _ptr__4609[safe_add( _4592,_4632 )]))
            {
              {
                _4604 += (_ptr__4608[safe_add( safe_add( _4598,_4632 ),(int)1 )] - _ptr__4608[safe_add( _4598,_4632 )]);
                ++ _4603;
                ++ _4630;
              }
            }
            else if((_ptr__4609[safe_add( _4599,_4631 )] != _ptr__4609[safe_add( _4599,_4632 )]))
            {
              {
                _4604 += (_ptr__4608[safe_add( safe_add( _4598,_4631 ),(int)1 )] - _ptr__4608[safe_add( _4598,_4631 )]);
                _4604 += (_ptr__4608[safe_add( safe_add( _4598,_4632 ),(int)1 )] - _ptr__4608[safe_add( _4598,_4632 )]);
                ++ _4603;
                ++ _4630;
                ++ _4631;
              }
            }
            else
            {
              {
                _4604 += (_ptr__4608[safe_add( safe_add( _4598,_4631 ),(int)1 )] - _ptr__4608[safe_add( _4598,_4631 )]);
                ++ _4603;
                ++ _4630;
                ++ _4631;
              }
            }
          }
        }
        while ( (_4631 < _4595) )
        {
          {
            _4604 += (_ptr__4608[safe_add( safe_add( _4598,_4631 ),(int)1 )] - _ptr__4608[safe_add( _4598,_4631 )]);
            ++ _4603;
            ++ _4631;
          }
        }
        while ( (_4630 < _4595) )
        {
          {
            int _4633 = _ptr__4608[safe_add( _4615,_4630 )];
            _4604 += (_ptr__4608[safe_add( safe_add( _4598,_4633 ),(int)1 )] - _ptr__4608[safe_add( _4598,_4633 )]);
            ++ _4603;
            ++ _4630;
          }
        }
      }
      int _4634 = _4580->alloci32(safe_add( _4603,(int)1 ));
      _4580->pushi32((int)1);
      _4580->pushi32(_4604);
      _4580->pushi32(_4603);
      int _9016 = (int)0;
      int _9017 = _4593;
      for (int _4635 = _9016; _4635 < _9017; ++_4635)
      {
        {
          _4580->pushi32(_ptr__4608[safe_add( _4594,_4635 )]);
        }
      }
      _4580->pushi32(_4593);
      int _4636 = _4580->alloci64(_4604);
      int _4637 = _4580->alloci64(_4603);
      int _4638 = _4580->allocf64(_4604);
      int _4639 = _4580->allocf64(_4603);
      std::shared_ptr< monty::ndarray< int,1 > > _4640 = mosek::fusion::p_WorkStack::_get_impl(_4580)->i32;
      _checked_ptr_1<int> _ptr__4640(_4640 ? _4640->raw() : nullptr,_4640 ? _4640->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4641 = mosek::fusion::p_WorkStack::_get_impl(_4580)->i64;
      _checked_ptr_1<long long> _ptr__4641(_4641 ? _4641->raw() : nullptr,_4641 ? _4641->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4642 = mosek::fusion::p_WorkStack::_get_impl(_4580)->f64;
      _checked_ptr_1<double> _ptr__4642(_4642 ? _4642->raw() : nullptr,_4642 ? _4642->size(0) : 0);
      _ptr__4640[_4634] = (int)0;
      {
        int _4643 = (int)0;
        int _4644 = (int)0;
        int _4645 = (int)0;
        int _4646 = (int)0;
        _ptr__4608[_4634] = (int)0;
        while ( ((_4646 < _4595) && (_4645 < _4595)) )
        {
          {
            int _4647 = _ptr__4608[safe_add( _4615,_4645 )];
            if ((_ptr__4609[safe_add( _4599,_4646 )] < _ptr__4609[safe_add( _4592,_4647 )]))
            {
              {
                int _9018 = _ptr__4608[safe_add( _4598,_4646 )];
                int _9019 = _ptr__4608[safe_add( safe_add( _4598,_4646 ),(int)1 )];
                for (int _4648 = _9018; _4648 < _9019; ++_4648)
                {
                  {
                    _ptr__4641[safe_add( _4636,_4643 )] = _ptr__4609[safe_add( _4600,_4648 )];
                    _ptr__4642[safe_add( _4638,_4643 )] = (_ptr__4610[safe_add( _4602,_4648 )] * 0.5);
                    ++ _4643;
                  }
                }
                _ptr__4642[safe_add( _4639,_4644 )] = (_ptr__4610[safe_add( _4601,_4646 )] * 0.5);
                _ptr__4641[safe_add( _4637,_4644 )] = _ptr__4609[safe_add( _4599,_4646 )];
                _ptr__4640[safe_add( safe_add( _4634,_4644 ),(int)1 )] = _4643;
                ++ _4644;
                ++ _4646;
              }
            }
            else if((_ptr__4609[safe_add( _4599,_4646 )] > _ptr__4609[safe_add( _4592,_4647 )]))
            {
              {
                int _9020 = _ptr__4608[safe_add( _4598,_4647 )];
                int _9021 = _ptr__4608[safe_add( safe_add( _4598,_4647 ),(int)1 )];
                for (int _4649 = _9020; _4649 < _9021; ++_4649)
                {
                  {
                    _ptr__4641[safe_add( _4636,_4643 )] = _ptr__4609[safe_add( _4600,_4649 )];
                    _ptr__4642[safe_add( _4638,_4643 )] = (_ptr__4610[safe_add( _4602,_4649 )] * 0.5);
                    ++ _4643;
                  }
                }
                _ptr__4642[safe_add( _4639,_4644 )] = (_ptr__4610[safe_add( _4601,_4647 )] * 0.5);
                _ptr__4641[safe_add( _4637,_4644 )] = _ptr__4609[safe_add( _4592,_4647 )];
                _ptr__4640[safe_add( safe_add( _4634,_4644 ),(int)1 )] = _4643;
                ++ _4644;
                ++ _4645;
              }
            }
            else if((_ptr__4609[safe_add( _4599,_4646 )] != _ptr__4609[safe_add( _4599,_4647 )]))
            {
              {
                int _9022 = _ptr__4608[safe_add( _4598,_4646 )];
                int _9023 = _ptr__4608[safe_add( safe_add( _4598,_4646 ),(int)1 )];
                for (int _4650 = _9022; _4650 < _9023; ++_4650)
                {
                  {
                    _ptr__4641[safe_add( _4636,_4643 )] = _ptr__4609[safe_add( _4600,_4650 )];
                    _ptr__4642[safe_add( _4638,_4643 )] = (_ptr__4610[safe_add( _4602,_4650 )] * 0.5);
                    ++ _4643;
                  }
                }
                int _9024 = _ptr__4608[safe_add( _4598,_4647 )];
                int _9025 = _ptr__4608[safe_add( safe_add( _4598,_4647 ),(int)1 )];
                for (int _4651 = _9024; _4651 < _9025; ++_4651)
                {
                  {
                    _ptr__4641[safe_add( _4636,_4643 )] = _ptr__4609[safe_add( _4600,_4651 )];
                    _ptr__4642[safe_add( _4638,_4643 )] = (_ptr__4610[safe_add( _4602,_4651 )] * 0.5);
                    ++ _4643;
                  }
                }
                _ptr__4642[safe_add( _4639,_4644 )] = (0.5 * (_ptr__4610[safe_add( _4601,_4646 )] + _ptr__4610[safe_add( _4601,_4647 )]));
                _ptr__4641[safe_add( _4637,_4644 )] = _ptr__4609[safe_add( _4599,_4646 )];
                _ptr__4640[safe_add( safe_add( _4634,_4644 ),(int)1 )] = _4643;
                ++ _4644;
                ++ _4645;
                ++ _4646;
              }
            }
            else
            {
              {
                int _9026 = _ptr__4608[safe_add( _4598,_4646 )];
                int _9027 = _ptr__4608[safe_add( safe_add( _4598,_4646 ),(int)1 )];
                for (int _4652 = _9026; _4652 < _9027; ++_4652)
                {
                  {
                    _ptr__4641[safe_add( _4636,_4643 )] = _ptr__4609[safe_add( _4600,_4652 )];
                    _ptr__4642[safe_add( _4638,_4643 )] = _ptr__4610[safe_add( _4602,_4652 )];
                    ++ _4643;
                  }
                }
                _ptr__4642[safe_add( _4639,_4644 )] = _ptr__4610[safe_add( _4601,_4646 )];
                _ptr__4641[safe_add( _4637,_4644 )] = _ptr__4609[safe_add( _4599,_4646 )];
                _ptr__4640[safe_add( safe_add( _4634,_4644 ),(int)1 )] = _4643;
                ++ _4644;
                ++ _4645;
                ++ _4646;
              }
            }
          }
        }
        while ( (_4646 < _4595) )
        {
          {
            int _9028 = _ptr__4608[safe_add( _4598,_4646 )];
            int _9029 = _ptr__4608[safe_add( safe_add( _4598,_4646 ),(int)1 )];
            for (int _4653 = _9028; _4653 < _9029; ++_4653)
            {
              {
                _ptr__4641[safe_add( _4636,_4643 )] = _ptr__4609[safe_add( _4600,_4653 )];
                _ptr__4642[safe_add( _4638,_4643 )] = (_ptr__4610[safe_add( _4602,_4653 )] * 0.5);
                ++ _4643;
              }
            }
            _ptr__4642[safe_add( _4639,_4644 )] = (_ptr__4610[safe_add( _4601,_4646 )] * 0.5);
            _ptr__4641[safe_add( _4637,_4644 )] = _ptr__4609[safe_add( _4599,_4646 )];
            _ptr__4640[safe_add( safe_add( _4634,_4644 ),(int)1 )] = _4643;
            ++ _4644;
            ++ _4646;
          }
        }
        while ( (_4645 < _4595) )
        {
          {
            int _4654 = _ptr__4608[safe_add( _4615,_4645 )];
            int _9030 = _ptr__4608[safe_add( _4598,_4654 )];
            int _9031 = _ptr__4608[safe_add( safe_add( _4598,_4654 ),(int)1 )];
            for (int _4655 = _9030; _4655 < _9031; ++_4655)
            {
              {
                _ptr__4641[safe_add( _4636,_4643 )] = _ptr__4609[safe_add( _4600,_4655 )];
                _ptr__4642[safe_add( _4638,_4643 )] = (_ptr__4610[safe_add( _4602,_4655 )] * 0.5);
                ++ _4643;
              }
            }
            _ptr__4642[safe_add( _4639,_4644 )] = (_ptr__4610[safe_add( _4601,_4654 )] * 0.5);
            _ptr__4641[safe_add( _4637,_4644 )] = _ptr__4609[safe_add( _4592,_4654 )];
            _ptr__4640[safe_add( safe_add( _4634,_4644 ),(int)1 )] = _4643;
            ++ _4644;
            ++ _4645;
          }
        }
      }
    }
  }
  else
  {
    {
      _4603 = _4595;
      _4604 = safe_mul( _4596,(int)2 );
      int _9032 = (int)0;
      int _9033 = _ptr__4605[(int)0];
      for (int _4656 = _9032; _4656 < _9033; ++_4656)
      {
        {
          int _9034 = (int)0;
          int _9035 = _ptr__4605[(int)2];
          for (int _4657 = _9034; _4657 < _9035; ++_4657)
          {
            {
              int _9036 = (int)0;
              int _9037 = _ptr__4605[(int)4];
              for (int _4658 = _9036; _4658 < _9037; ++_4658)
              {
                {
                  int _9038 = (int)0;
                  int _9039 = _ptr__4605[(int)1];
                  for (int _4659 = _9038; _4659 < _9039; ++_4659)
                  {
                    {
                      long long _4660 = safe_add( safe_add( safe_add( safe_add( safe_mul( _ptr__4607[(int)0],_4656 ),safe_mul( _ptr__4607[(int)1],_4659 ) ),safe_mul( _ptr__4607[(int)2],_4657 ) ),safe_mul( _ptr__4607[(int)3],_4659 ) ),safe_mul( _ptr__4607[(int)4],_4658 ) );
                      _4604 -= (_ptr__4608[safe_add( safe_add( _4598,_4660 ),(int)1 )] - _ptr__4608[safe_add( _4598,_4660 )]);
                    }
                  }
                }
              }
            }
          }
        }
      }
      int _4661 = _4580->alloci32(safe_add( _4603,(int)1 ));
      _4580->pushi32((int)0);
      _4580->pushi32(_4604);
      _4580->pushi32(_4603);
      int _9040 = (int)0;
      int _9041 = _4593;
      for (int _4662 = _9040; _4662 < _9041; ++_4662)
      {
        {
          _4580->pushi32(_ptr__4608[safe_add( _4594,_4662 )]);
        }
      }
      _4580->pushi32(_4593);
      int _4663 = _4580->alloci64(_4604);
      int _4664 = _4580->allocf64(_4604);
      int _4665 = _4580->allocf64(_4603);
      std::shared_ptr< monty::ndarray< int,1 > > _4666 = mosek::fusion::p_WorkStack::_get_impl(_4580)->i32;
      _checked_ptr_1<int> _ptr__4666(_4666 ? _4666->raw() : nullptr,_4666 ? _4666->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4667 = mosek::fusion::p_WorkStack::_get_impl(_4580)->i64;
      _checked_ptr_1<long long> _ptr__4667(_4667 ? _4667->raw() : nullptr,_4667 ? _4667->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4668 = mosek::fusion::p_WorkStack::_get_impl(_4580)->f64;
      _checked_ptr_1<double> _ptr__4668(_4668 ? _4668->raw() : nullptr,_4668 ? _4668->size(0) : 0);
      int _4669 = (int)0;
      int _4670 = (int)0;
      _ptr__4666[_4661] = (int)0;
      int _4671 = (int)0;
      int _9042 = (int)0;
      int _9043 = _ptr__4605[(int)0];
      for (int _4672 = _9042; _4672 < _9043; ++_4672)
      {
        {
          int _9044 = (int)0;
          int _9045 = _ptr__4605[(int)1];
          for (int _4673 = _9044; _4673 < _9045; ++_4673)
          {
            {
              int _9046 = (int)0;
              int _9047 = _ptr__4605[(int)2];
              for (int _4674 = _9046; _4674 < _9047; ++_4674)
              {
                {
                  int _9048 = (int)0;
                  int _9049 = _ptr__4605[(int)3];
                  for (int _4675 = _9048; _4675 < _9049; ++_4675)
                  {
                    {
                      int _9050 = (int)0;
                      int _9051 = _ptr__4605[(int)4];
                      for (int _4676 = _9050; _4676 < _9051; ++_4676)
                      {
                        {
                          if ((_4673 == _4675))
                          {
                            {
                              int _9052 = _ptr__4608[safe_add( _4598,_4671 )];
                              int _9053 = _ptr__4608[safe_add( safe_add( _4598,_4671 ),(int)1 )];
                              for (int _4677 = _9052; _4677 < _9053; ++_4677)
                              {
                                {
                                  _ptr__4667[safe_add( _4663,_4669 )] = _ptr__4609[safe_add( _4600,_4677 )];
                                  _ptr__4668[safe_add( _4664,_4669 )] = _ptr__4610[safe_add( _4602,_4677 )];
                                  ++ _4669;
                                }
                              }
                              _ptr__4668[safe_add( _4665,_4670 )] = _ptr__4610[safe_add( _4601,_4672 )];
                              _ptr__4666[safe_add( safe_add( _4661,_4670 ),(int)1 )] = _4669;
                              ++ _4671;
                            }
                          }
                          else
                          {
                            {
                              long long _4678 = safe_add( safe_add( safe_add( safe_add( safe_mul( _4672,_ptr__4607[(int)0] ),safe_mul( _4675,_ptr__4607[(int)1] ) ),safe_mul( _4674,_ptr__4607[(int)2] ) ),safe_mul( _4673,_ptr__4607[(int)3] ) ),_4676 );
                              int _9054 = _ptr__4608[safe_add( _4598,_4671 )];
                              int _9055 = _ptr__4608[safe_add( safe_add( _4598,_4671 ),(int)1 )];
                              for (int _4679 = _9054; _4679 < _9055; ++_4679)
                              {
                                {
                                  _ptr__4667[safe_add( _4663,_4669 )] = _ptr__4609[safe_add( _4600,_4679 )];
                                  _ptr__4668[safe_add( _4664,_4669 )] = (_ptr__4610[safe_add( _4602,_4679 )] * 0.5);
                                  ++ _4669;
                                }
                              }
                              int _9056 = _ptr__4608[safe_add( _4598,_4678 )];
                              int _9057 = _ptr__4608[safe_add( safe_add( _4598,_4678 ),(int)1 )];
                              for (int _4680 = _9056; _4680 < _9057; ++_4680)
                              {
                                {
                                  _ptr__4667[safe_add( _4663,_4669 )] = _ptr__4609[safe_add( _4600,_4680 )];
                                  _ptr__4668[safe_add( _4664,_4669 )] = (_ptr__4610[safe_add( _4602,_4680 )] * 0.5);
                                  ++ _4669;
                                }
                              }
                              _ptr__4668[safe_add( _4665,_4670 )] = (0.5 * (_ptr__4610[safe_add( _4601,_4671 )] + _ptr__4610[safe_add( _4601,_4678 )]));
                              _ptr__4666[safe_add( safe_add( _4661,_4670 ),(int)1 )] = _4669;
                              ++ _4671;
                            }
                          }
                          ++ _4670;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
}
void mosek::fusion::p_ExprSymmetrize::destroy(){expr.reset();}void mosek::fusion::ExprSymmetrize::destroy() { mosek::fusion::p_ExprSymmetrize::_get_impl(this)->destroy(); }mosek::fusion::ExprCompress::ExprCompress(mosek::fusion::p_ExprCompress *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprCompress()" << this << std::endl; */ }mosek::fusion::ExprCompress::~ExprCompress() {  /* std::cout << "~ExprCompress()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprCompress::p_ExprCompress  (::mosek::fusion::ExprCompress * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprCompress::t mosek::fusion::p_ExprCompress::_new_ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4681){ return new mosek::fusion::ExprCompress(_4681); }mosek::fusion::ExprCompress::ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4681) :    ExprCompress(new mosek::fusion::p_ExprCompress(this)){ mosek::fusion::p_ExprCompress::_get_impl(this)->_initialize(_4681); }void mosek::fusion::p_ExprCompress::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4681){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4681->getShape());
    eps = 0.0;
    mosek::fusion::p_ExprCompress::_get_impl(::mosek::fusion::ExprCompress::t(_pubthis))->expr = _4681;
  }
}mosek::fusion::ExprCompress::t mosek::fusion::p_ExprCompress::_new_ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4682,    double _4683){ return new mosek::fusion::ExprCompress(_4682,_4683); }mosek::fusion::ExprCompress::ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4682,    double _4683) :    ExprCompress(new mosek::fusion::p_ExprCompress(this)){ mosek::fusion::p_ExprCompress::_get_impl(this)->_initialize(_4682,_4683); }void mosek::fusion::p_ExprCompress::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4682,    double _4683){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4682->getShape());
    eps = _4683;
    mosek::fusion::p_ExprCompress::_get_impl(::mosek::fusion::ExprCompress::t(_pubthis))->expr = _4682;
  }
}void mosek::fusion::ExprCompress :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4684,monty::rc_ptr< ::mosek::fusion::WorkStack > _4685,monty::rc_ptr< ::mosek::fusion::WorkStack > _4686) { mosek::fusion::p_ExprCompress::_get_impl(this)->eval(_4684,_4685,_4686); }void mosek::fusion::p_ExprCompress::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4684,monty::rc_ptr< ::mosek::fusion::WorkStack > _4685,monty::rc_ptr< ::mosek::fusion::WorkStack > _4686){
  expr->eval(_4685,_4684,_4686);
  _4685->pop_expr();
  int _4687 = mosek::fusion::p_WorkStack::_get_impl(_4685)->nd;
  int _4688 = mosek::fusion::p_WorkStack::_get_impl(_4685)->shape_base;
  int _4689 = mosek::fusion::p_WorkStack::_get_impl(_4685)->nelem;
  int _4690 = mosek::fusion::p_WorkStack::_get_impl(_4685)->nnz;
  bool _4691 = mosek::fusion::p_WorkStack::_get_impl(_4685)->hassp;
  int _4692 = mosek::fusion::p_WorkStack::_get_impl(_4685)->ptr_base;
  int _4693 = mosek::fusion::p_WorkStack::_get_impl(_4685)->sp_base;
  int _4694 = mosek::fusion::p_WorkStack::_get_impl(_4685)->nidxs_base;
  int _4695 = mosek::fusion::p_WorkStack::_get_impl(_4685)->bfix_base;
  int _4696 = mosek::fusion::p_WorkStack::_get_impl(_4685)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4697 = mosek::fusion::p_WorkStack::_get_impl(_4685)->i32;
  _checked_ptr_1<int> _ptr__4697(_4697 ? _4697->raw() : nullptr,_4697 ? _4697->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4698 = mosek::fusion::p_WorkStack::_get_impl(_4685)->i64;
  _checked_ptr_1<long long> _ptr__4698(_4698 ? _4698->raw() : nullptr,_4698 ? _4698->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4699 = mosek::fusion::p_WorkStack::_get_impl(_4685)->f64;
  _checked_ptr_1<double> _ptr__4699(_4699 ? _4699->raw() : nullptr,_4699 ? _4699->size(0) : 0);
  std::vector<int> _9058;
  for (int _4701 = (int)0, _9059 = _4687; _4701 < _9059 ; ++_4701)
  {
    _9058.push_back(_ptr__4697[safe_add( _4688,_4701 )]);
  }
  auto _9060 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9058.size()),_9058.begin(),_9058.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _4700 = _9060;
  _checked_ptr_1<int> _ptr__4700(_4700 ? _4700->raw() : nullptr,_4700 ? _4700->size(0) : 0);
  bool _4702 = true;
  {
    int _9061 = (int)0;
    int _9062 = _4689;
    for (int _4703 = _9061; _4703 < _9062; ++_4703)
    {
      {
        int _9063 = safe_add( _ptr__4697[safe_add( _4692,_4703 )],(int)1 );
        int _9064 = _ptr__4697[safe_add( safe_add( _4692,_4703 ),(int)1 )];
        for (int _4704 = _9063; _4704 < _9064; ++_4704)
        {
          {
            _4702 = (_4702 && (_ptr__4698[(safe_add( _4694,_4704 ) - (int)1)] < _ptr__4698[safe_add( _4694,_4704 )]));
          }
        }
      }
    }
    if (_4702)
    {
      {
        int _9065 = (int)0;
        int _9066 = _4690;
        for (int _4705 = _9065; _4705 < _9066; ++_4705)
        {
          {
            _4702 = (_4702 && ((_ptr__4699[safe_add( _4696,_4705 )] <= (0.0 - eps)) || ((0.0 + eps) <= _ptr__4699[safe_add( _4696,_4705 )])));
          }
        }
      }
    }
    {}
  }
  if (_4702)
  {
    {
      _4684->alloc_expr(_4687,_4689,_4690,_4691);
      int _4706 = mosek::fusion::p_WorkStack::_get_impl(_4684)->ptr_base;
      int _4707 = mosek::fusion::p_WorkStack::_get_impl(_4684)->nidxs_base;
      int _4708 = mosek::fusion::p_WorkStack::_get_impl(_4684)->sp_base;
      int _4709 = mosek::fusion::p_WorkStack::_get_impl(_4684)->cof_base;
      int _4710 = mosek::fusion::p_WorkStack::_get_impl(_4684)->bfix_base;
      int _4711 = mosek::fusion::p_WorkStack::_get_impl(_4684)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4712 = mosek::fusion::p_WorkStack::_get_impl(_4684)->i32;
      _checked_ptr_1<int> _ptr__4712(_4712 ? _4712->raw() : nullptr,_4712 ? _4712->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4713 = mosek::fusion::p_WorkStack::_get_impl(_4684)->i64;
      _checked_ptr_1<long long> _ptr__4713(_4713 ? _4713->raw() : nullptr,_4713 ? _4713->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4714 = mosek::fusion::p_WorkStack::_get_impl(_4684)->f64;
      _checked_ptr_1<double> _ptr__4714(_4714 ? _4714->raw() : nullptr,_4714 ? _4714->size(0) : 0);
      {
        int _9067 = (int)0;
        int _9068 = _4687;
        for (int _4715 = _9067; _4715 < _9068; ++_4715)
        {
          {
            _ptr__4712[safe_add( _4711,_4715 )] = _ptr__4700[_4715];
          }
        }
        int _9069 = (int)0;
        int _9070 = safe_add( _4689,(int)1 );
        for (int _4716 = _9069; _4716 < _9070; ++_4716)
        {
          {
            _ptr__4712[safe_add( _4706,_4716 )] = _ptr__4697[safe_add( _4692,_4716 )];
          }
        }
        if (_4691)
        {
          {
            int _9071 = (int)0;
            int _9072 = _4689;
            for (int _4717 = _9071; _4717 < _9072; ++_4717)
            {
              {
                _ptr__4713[safe_add( _4708,_4717 )] = _ptr__4698[safe_add( _4693,_4717 )];
              }
            }
          }
        }
        {}
        int _9073 = (int)0;
        int _9074 = _4689;
        for (int _4718 = _9073; _4718 < _9074; ++_4718)
        {
          {
            _ptr__4714[safe_add( _4710,_4718 )] = _ptr__4699[safe_add( _4695,_4718 )];
          }
        }
        int _9075 = (int)0;
        int _9076 = _4690;
        for (int _4719 = _9075; _4719 < _9076; ++_4719)
        {
          {
            _ptr__4713[safe_add( _4707,_4719 )] = _ptr__4698[safe_add( _4694,_4719 )];
          }
        }
        int _9077 = (int)0;
        int _9078 = _4690;
        for (int _4720 = _9077; _4720 < _9078; ++_4720)
        {
          {
            _ptr__4714[safe_add( _4709,_4720 )] = _ptr__4699[safe_add( _4696,_4720 )];
          }
        }
      }
    }
  }
  else
  {
    {
      int _4721 = _4686->alloci32(_4690);
      ::mosek::fusion::p_ExprCompress::arg_sort(_4685,_4686,_4721,_4689,_4690,_4692,_4694);
      std::shared_ptr< monty::ndarray< int,1 > > _4722 = mosek::fusion::p_WorkStack::_get_impl(_4686)->i32;
      _checked_ptr_1<int> _ptr__4722(_4722 ? _4722->raw() : nullptr,_4722 ? _4722->size(0) : 0);
      int _4723 = (int)0;
      {
        std::shared_ptr< monty::ndarray< int,1 > > _4724 = mosek::fusion::p_WorkStack::_get_impl(_4684)->i32;
        _checked_ptr_1<int> _ptr__4724(_4724 ? _4724->raw() : nullptr,_4724 ? _4724->size(0) : 0);
        {
          int _9079 = (int)0;
          int _9080 = _4689;
          for (int _4725 = _9079; _4725 < _9080; ++_4725)
          {
            {
              int _4726 = _ptr__4697[safe_add( safe_add( _4692,_4725 ),(int)1 )];
              int _4727 = _ptr__4697[safe_add( _4692,_4725 )];
              if ((_4727 < _4726))
              {
                {
                  int _4728 = _4727;
                  while ( (_4728 < _4726) )
                  {
                    {
                      double _4729 = 0.0;
                      long long _4730 = _ptr__4698[safe_add( _4694,_ptr__4722[safe_add( _4721,_4728 )] )];
                      while ( ((_4728 < _4726) && (_ptr__4698[safe_add( _4694,_ptr__4722[safe_add( _4721,_4728 )] )] == _4730)) )
                      {
                        {
                          _4729 += _ptr__4699[safe_add( _4696,_ptr__4722[safe_add( _4721,_4728 )] )];
                          ++ _4728;
                        }
                      }
                      {
                      }
                      if (((_4730 != (int)0) && ((_4729 < (-eps)) || (eps < _4729))))
                      {
                        {
                          ++ _4723;
                        }
                      }
                      {}
                    }
                  }
                }
              }
              {}
            }
          }
        }
      }
      _4684->alloc_expr(_4687,_4689,_4723,_4691);
      int _4731 = mosek::fusion::p_WorkStack::_get_impl(_4684)->nidxs_base;
      int _4732 = mosek::fusion::p_WorkStack::_get_impl(_4684)->shape_base;
      int _4733 = mosek::fusion::p_WorkStack::_get_impl(_4684)->sp_base;
      int _4734 = mosek::fusion::p_WorkStack::_get_impl(_4684)->cof_base;
      int _4735 = mosek::fusion::p_WorkStack::_get_impl(_4684)->bfix_base;
      int _4736 = mosek::fusion::p_WorkStack::_get_impl(_4684)->ptr_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4737 = mosek::fusion::p_WorkStack::_get_impl(_4684)->i32;
      _checked_ptr_1<int> _ptr__4737(_4737 ? _4737->raw() : nullptr,_4737 ? _4737->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4738 = mosek::fusion::p_WorkStack::_get_impl(_4684)->i64;
      _checked_ptr_1<long long> _ptr__4738(_4738 ? _4738->raw() : nullptr,_4738 ? _4738->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4739 = mosek::fusion::p_WorkStack::_get_impl(_4684)->f64;
      _checked_ptr_1<double> _ptr__4739(_4739 ? _4739->raw() : nullptr,_4739 ? _4739->size(0) : 0);
      {
        int _9081 = (int)0;
        int _9082 = _4687;
        for (int _4740 = _9081; _4740 < _9082; ++_4740)
        {
          {
            _ptr__4737[safe_add( _4732,_4740 )] = _ptr__4700[_4740];
          }
        }
        int _9083 = (int)0;
        int _9084 = _4689;
        for (int _4741 = _9083; _4741 < _9084; ++_4741)
        {
          {
            _ptr__4739[safe_add( _4734,_4741 )] = 0.0;
          }
        }
        int _9085 = (int)0;
        int _9086 = _4689;
        for (int _4742 = _9085; _4742 < _9086; ++_4742)
        {
          {
            _ptr__4739[safe_add( _4735,_4742 )] = _ptr__4699[safe_add( _4695,_4742 )];
          }
        }
        if (_4691)
        {
          {
            int _9087 = (int)0;
            int _9088 = _4689;
            for (int _4743 = _9087; _4743 < _9088; ++_4743)
            {
              {
                _ptr__4738[safe_add( _4733,_4743 )] = _ptr__4698[safe_add( _4733,_4743 )];
              }
            }
          }
        }
        {}
        int _4744 = (int)0;
        {
          int _4745 = (_4734 - _4731);
          _ptr__4737[_4736] = (int)0;
          int _9089 = (int)0;
          int _9090 = _4689;
          for (int _4746 = _9089; _4746 < _9090; ++_4746)
          {
            {
              int _4747 = _ptr__4697[safe_add( safe_add( _4692,_4746 ),(int)1 )];
              int _4748 = _ptr__4697[safe_add( _4692,_4746 )];
              if ((_4748 < _4747))
              {
                {
                  int _4749 = _4748;
                  while ( (_4749 < _4747) )
                  {
                    {
                      double _4750 = 0.0;
                      long long _4751 = _ptr__4698[safe_add( _4694,_ptr__4722[safe_add( _4721,_4749 )] )];
                      while ( ((_4749 < _4747) && (_ptr__4698[safe_add( _4694,_ptr__4722[safe_add( _4721,_4749 )] )] == _4751)) )
                      {
                        {
                          _4750 += _ptr__4699[safe_add( _4696,_ptr__4722[safe_add( _4721,_4749 )] )];
                          ++ _4749;
                        }
                      }
                      {
                      }
                      if (((_4751 != (int)0) && ((_4750 < (-eps)) || (eps < _4750))))
                      {
                        {
                          _ptr__4738[safe_add( _4731,_4744 )] = _4751;
                          _ptr__4739[safe_add( _4734,_4744 )] = _4750;
                          ++ _4744;
                        }
                      }
                      {}
                    }
                  }
                }
              }
              {}
              _ptr__4737[safe_add( safe_add( _4736,_4746 ),(int)1 )] = _4744;
            }
          }
        }
      }
    }
  }
  _4686->clear();
}
void mosek::fusion::ExprCompress::arg_sort  ( monty::rc_ptr< ::mosek::fusion::WorkStack > _4752,    monty::rc_ptr< ::mosek::fusion::WorkStack > _4753,    int _4754,    int _4755,    int _4756,    int _4757,    int _4758) { mosek::fusion::p_ExprCompress::arg_sort(_4752,_4753,_4754,_4755,_4756,_4757,_4758); }void mosek::fusion::p_ExprCompress::arg_sort(monty::rc_ptr< ::mosek::fusion::WorkStack > _4752,monty::rc_ptr< ::mosek::fusion::WorkStack > _4753,int _4754,int _4755,int _4756,int _4757,int _4758){
  int _4759 = (int)0;
  std::shared_ptr< monty::ndarray< int,1 > > _4760 = mosek::fusion::p_WorkStack::_get_impl(_4752)->i32;
  _checked_ptr_1<int> _ptr__4760(_4760 ? _4760->raw() : nullptr,_4760 ? _4760->size(0) : 0);
  int _9091 = (int)0;
  int _9092 = _4755;
  for (int _4761 = _9091; _4761 < _9092; ++_4761)
  {
    {
      if (((_ptr__4760[safe_add( safe_add( _4757,_4761 ),(int)1 )] - _ptr__4760[safe_add( _4757,_4761 )]) > _4759))
      {
        {
          _4759 = (_ptr__4760[safe_add( safe_add( _4757,_4761 ),(int)1 )] - _ptr__4760[safe_add( _4757,_4761 )]);
        }
      }
      {}
    }
  }
  int _9093;
  bool _9094 = (_4759 > (int)2);
  if (_9094)
  {
    _9093 = _4753->alloci32(safe_mul( _4759,(int)2 ));
  }
  else
  {
    _9093 = (int)99999;
  }
  int _4762 = _9093;
  std::shared_ptr< monty::ndarray< int,1 > > _4763 = mosek::fusion::p_WorkStack::_get_impl(_4753)->i32;
  _checked_ptr_1<int> _ptr__4763(_4763 ? _4763->raw() : nullptr,_4763 ? _4763->size(0) : 0);
  _4760 = mosek::fusion::p_WorkStack::_get_impl(_4752)->i32;
  _ptr__4760.update(_4760 ? _4760->raw() : nullptr, _4760 ? _4760->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4764 = mosek::fusion::p_WorkStack::_get_impl(_4752)->i64;
  _checked_ptr_1<long long> _ptr__4764(_4764 ? _4764->raw() : nullptr,_4764 ? _4764->size(0) : 0);
  int _9095 = (int)0;
  int _9096 = _4755;
  for (int _4765 = _9095; _4765 < _9096; ++_4765)
  {
    {
      int _4766 = _ptr__4760[safe_add( _4757,_4765 )];
      int _4767 = _ptr__4760[safe_add( safe_add( _4757,_4765 ),(int)1 )];
      int _4768 = (_4767 - _4766);
      if ((_4768 == (int)0))
      {
        {
        }
      }
      else if((_4768 == (int)1))
      {
        {
          _ptr__4763[safe_add( _4754,_4766 )] = _4766;
        }
      }
      else if((_4768 == (int)2))
      {
        {
          if ((_ptr__4764[safe_add( _4758,_4766 )] <= _ptr__4764[safe_add( safe_add( _4758,_4766 ),(int)1 )]))
          {
            {
              _ptr__4763[safe_add( _4754,_4766 )] = _4766;
              _ptr__4763[safe_add( safe_add( _4754,_4766 ),(int)1 )] = safe_add( _4766,(int)1 );
            }
          }
          else
          {
            {
              _ptr__4763[safe_add( _4754,_4766 )] = safe_add( _4766,(int)1 );
              _ptr__4763[safe_add( safe_add( _4754,_4766 ),(int)1 )] = _4766;
            }
          }
        }
      }
      else
      {
        {
          long long _4769 = _ptr__4764[safe_add( _4758,_4766 )];
          long long _4770 = _ptr__4764[safe_add( _4758,_4766 )];
          bool _4771 = false;
          int _9097 = safe_add( _4766,(int)1 );
          int _9098 = _4767;
          for (int _4772 = _9097; _4772 < _9098; ++_4772)
          {
            {
              _4771 = (_4771 && (_ptr__4764[(safe_add( _4758,_4772 ) - (int)1)] <= _ptr__4764[safe_add( _4758,_4772 )]));
              if ((_4769 > _ptr__4764[safe_add( _4758,_4772 )]))
              {
                {
                  _4769 = _ptr__4764[safe_add( _4758,_4772 )];
                }
              }
              {}
              if ((_4770 < _ptr__4764[safe_add( _4758,_4772 )]))
              {
                {
                  _4770 = _ptr__4764[safe_add( _4758,_4772 )];
                }
              }
              {}
            }
          }
          if (_4771)
          {
            {
              int _9099 = _4766;
              int _9100 = _4767;
              for (int _4773 = _9099; _4773 < _9100; ++_4773)
              {
                {
                  _ptr__4763[safe_add( _4754,_4773 )] = _4773;
                }
              }
            }
          }
          else if((safe_add( (_4770 - _4769),(int)1 ) <= _4768))
          {
            {
              long long _4774 = safe_add( (_4770 - _4769),(int)1 );
              int _9101 = (int)0;
              long long _9102 = safe_add( _4774,(int)1 );
              for (long long _4775 = _9101; _4775 < _9102; ++_4775)
              {
                {
                  _ptr__4763[safe_add( _4762,_4775 )] = (int)0;
                }
              }
              int _9103 = _4766;
              int _9104 = _4767;
              for (int _4776 = _9103; _4776 < _9104; ++_4776)
              {
                {
                  ++ _ptr__4763[safe_add( (safe_add( _4762,_ptr__4764[safe_add( _4758,_4776 )] ) - _4769),(int)1 )];
                }
              }
              int _9105 = (int)0;
              long long _9106 = _4774;
              for (long long _4777 = _9105; _4777 < _9106; ++_4777)
              {
                {
                  _ptr__4763[safe_add( safe_add( _4762,_4777 ),(int)1 )] += _ptr__4763[safe_add( _4762,_4777 )];
                }
              }
              int _9107 = _4766;
              int _9108 = _4767;
              for (int _4778 = _9107; _4778 < _9108; ++_4778)
              {
                {
                  _ptr__4763[safe_add( safe_add( _4754,_4766 ),_ptr__4763[(safe_add( _4762,_ptr__4764[safe_add( _4758,_4778 )] ) - _4769)] )] = _4778;
                  ++ _ptr__4763[(safe_add( _4762,_ptr__4764[safe_add( _4758,_4778 )] ) - _4769)];
                }
              }
            }
          }
          else
          {
            {
              int _4779 = (int)1;
              int _4780 = _4762;
              int _4781 = safe_add( _4762,_4768 );
              int _9109 = (int)0;
              int _9110 = _4768;
              for (int _4782 = _9109; _4782 < _9110; ++_4782)
              {
                {
                  _ptr__4763[safe_add( _4780,_4782 )] = _4782;
                }
              }
              while ( (_4779 < _4768) )
              {
                {
                  int _4783 = safe_mul( _4779,(int)2 );
                  int _4784 = (_4768 / _4783);
                  if ((safe_add( safe_mul( _4784,_4783 ),_4779 ) < _4768))
                  {
                    {
                      ++ _4784;
                    }
                  }
                  {}
                  int _4785 = (int)0;
                  int _9111 = (int)0;
                  int _9112 = _4784;
                  for (int _4786 = _9111; _4786 < _9112; ++_4786)
                  {
                    {
                      int _4787 = safe_mul( _4786,_4783 );
                      int _4788 = safe_add( _4787,_4779 );
                      int _4789 = _4788;
                      int _4790 = safe_add( _4789,_4779 );
                      if ((_4790 > _4768))
                      {
                        {
                          _4790 = _4768;
                        }
                      }
                      {}
                      while ( ((_4787 < _4788) && (_4789 < _4790)) )
                      {
                        {
                          if ((_ptr__4764[safe_add( safe_add( _4758,_ptr__4763[safe_add( _4780,_4787 )] ),_4766 )] <= _ptr__4764[safe_add( safe_add( _4758,_ptr__4763[safe_add( _4780,_4789 )] ),_4766 )]))
                          {
                            {
                              _ptr__4763[safe_add( _4781,_4785 )] = _ptr__4763[safe_add( _4780,_4787 )];
                              ++ _4785;
                              ++ _4787;
                            }
                          }
                          else
                          {
                            {
                              _ptr__4763[safe_add( _4781,_4785 )] = _ptr__4763[safe_add( _4780,_4789 )];
                              ++ _4785;
                              ++ _4789;
                            }
                          }
                        }
                      }
                      while ( (_4787 < _4788) )
                      {
                        {
                          _ptr__4763[safe_add( _4781,_4785 )] = _ptr__4763[safe_add( _4780,_4787 )];
                          ++ _4785;
                          ++ _4787;
                        }
                      }
                      while ( (_4789 < _4790) )
                      {
                        {
                          _ptr__4763[safe_add( _4781,_4785 )] = _ptr__4763[safe_add( _4780,_4789 )];
                          ++ _4785;
                          ++ _4789;
                        }
                      }
                    }
                  }
                  if ((safe_mul( _4784,_4783 ) < _4768))
                  {
                    {
                      int _4791 = safe_mul( _4784,_4783 );
                      while ( (_4791 < _4768) )
                      {
                        {
                          _ptr__4763[safe_add( _4781,_4785 )] = _ptr__4763[safe_add( _4780,_4791 )];
                          ++ _4791;
                          ++ _4785;
                        }
                      }
                    }
                  }
                  {}
                  int _4792 = _4780;
                  _4780 = _4781;
                  _4781 = _4792;
                  _4779 *= (int)2;
                }
              }
              int _9113 = (int)0;
              int _9114 = _4768;
              for (int _4793 = _9113; _4793 < _9114; ++_4793)
              {
                {
                  _ptr__4763[safe_add( safe_add( _4754,_4766 ),_4793 )] = safe_add( _ptr__4763[safe_add( _4780,_4793 )],_4766 );
                }
              }
            }
          }
        }
      }
    }
  }
}
void mosek::fusion::ExprCompress::merge_sort  ( int _4794,    int _4795,    int _4796,    int _4797,    int _4798,    int _4799,    std::shared_ptr< monty::ndarray< int,1 > > _4800,    std::shared_ptr< monty::ndarray< long long,1 > > _4801) { mosek::fusion::p_ExprCompress::merge_sort(_4794,_4795,_4796,_4797,_4798,_4799,_4800,_4801); }void mosek::fusion::p_ExprCompress::merge_sort(int _4794,int _4795,int _4796,int _4797,int _4798,int _4799,std::shared_ptr< monty::ndarray< int,1 > > _4800,std::shared_ptr< monty::ndarray< long long,1 > > _4801){
  _checked_ptr_1<int> _ptr__4800(_4800 ? _4800->raw() : nullptr, _4800 ? _4800->size(0) : 0);
  _checked_ptr_1<long long> _ptr__4801(_4801 ? _4801->raw() : nullptr, _4801 ? _4801->size(0) : 0);
  int _4802 = _4794;
  int _4803 = _4795;
  int _9115 = (int)0;
  int _9116 = _4797;
  for (int _4804 = _9115; _4804 < _9116; ++_4804)
  {
    {
      _ptr__4800[safe_add( _4802,_4804 )] = _4804;
    }
  }
  int _9117 = (int)0;
  int _9118 = _4796;
  for (int _4805 = _9117; _4805 < _9118; ++_4805)
  {
    {
      _4802 = _4794;
      _4803 = _4795;
      int _4806 = _ptr__4800[safe_add( safe_add( _4798,_4805 ),(int)1 )];
      int _4807 = _ptr__4800[safe_add( _4798,_4805 )];
      if ((safe_add( _4807,(int)1 ) < _4806))
      {
        {
          int _4808 = (_4806 - _4807);
          int _4809 = (int)0;
          while ( (_4808 > (int)1) )
          {
            {
              ++ _4809;
              _4808 /= (int)2;
            }
          }
          _4808 = (_4806 - _4807);
          int _4810 = (int)1;
          int _9119 = (int)0;
          int _9120 = safe_add( _4809,(int)1 );
          for (int _4811 = _9119; _4811 < _9120; ++_4811)
          {
            {
              int _4812 = ((safe_add( _4808,_4810 ) - (int)1) / _4810);
              int _4813 = (_4812 / (int)2);
              int _4814 = _4807;
              int _9121 = (int)0;
              int _9122 = _4813;
              for (int _4815 = _9121; _4815 < _9122; ++_4815)
              {
                {
                  int _4816 = safe_mul( safe_mul( _4815,_4810 ),(int)2 );
                  int _9123;
                  bool _9124 = (safe_add( safe_add( _4807,_4816 ),safe_mul( (int)2,_4810 ) ) < _4806);
                  if (_9124)
                  {
                    _9123 = safe_add( safe_add( _4807,_4816 ),safe_mul( (int)2,_4810 ) );
                  }
                  else
                  {
                    _9123 = _4806;
                  }
                  int _4817 = _9123;
                  int _4818 = safe_add( safe_add( _4807,_4816 ),_4810 );
                  int _4819 = safe_add( safe_add( _4807,_4816 ),_4810 );
                  int _4820 = safe_add( _4807,_4816 );
                  while ( ((_4820 < _4819) && (_4818 < _4817)) )
                  {
                    {
                      if ((_ptr__4801[safe_add( _4799,_ptr__4800[safe_add( _4802,_4820 )] )] <= _ptr__4801[safe_add( _4799,_ptr__4800[safe_add( _4802,_4818 )] )]))
                      {
                        {
                          _ptr__4800[safe_add( _4803,_4814 )] = _ptr__4800[safe_add( _4802,_4820 )];
                          ++ _4814;
                          ++ _4820;
                        }
                      }
                      else
                      {
                        {
                          _ptr__4800[safe_add( _4803,_4814 )] = _ptr__4800[safe_add( _4802,_4818 )];
                          ++ _4814;
                          ++ _4818;
                        }
                      }
                    }
                  }
                  while ( (_4820 < _4819) )
                  {
                    {
                      _ptr__4800[safe_add( _4803,_4814 )] = _ptr__4800[safe_add( _4802,_4820 )];
                      ++ _4814;
                      ++ _4820;
                    }
                  }
                  while ( (_4818 < _4817) )
                  {
                    {
                      _ptr__4800[safe_add( _4803,_4814 )] = _ptr__4800[safe_add( _4802,_4818 )];
                      ++ _4814;
                      ++ _4818;
                    }
                  }
                }
              }
              int _9125 = _4814;
              int _9126 = _4806;
              for (int _4821 = _9125; _4821 < _9126; ++_4821)
              {
                {
                  _ptr__4800[safe_add( _4803,_4821 )] = _ptr__4800[safe_add( _4802,_4821 )];
                }
              }
              int _4822 = _4802;
              _4802 = _4803;
              _4803 = _4822;
              _4810 *= (int)2;
            }
          }
        }
      }
      {}
      int _9127 = _4807;
      int _9128 = _4806;
      for (int _4823 = _9127; _4823 < _9128; ++_4823)
      {
        {
          _ptr__4800[safe_add( _4794,_4823 )] = _ptr__4800[safe_add( _4802,_4823 )];
        }
      }
    }
  }
}
std::string mosek::fusion::ExprCompress :: toString() { return mosek::fusion::p_ExprCompress::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprCompress::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprCompress("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprCompress::destroy(){expr.reset();}void mosek::fusion::ExprCompress::destroy() { mosek::fusion::p_ExprCompress::_get_impl(this)->destroy(); }mosek::fusion::ExprCondense::ExprCondense(mosek::fusion::p_ExprCondense *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprCondense()" << this << std::endl; */ }mosek::fusion::ExprCondense::~ExprCondense() {  /* std::cout << "~ExprCondense()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprCondense::p_ExprCondense  (::mosek::fusion::ExprCondense * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprCondense::t mosek::fusion::p_ExprCondense::_new_ExprCondense  (monty::rc_ptr< ::mosek::fusion::Expression > _4824){ return new mosek::fusion::ExprCondense(_4824); }mosek::fusion::ExprCondense::ExprCondense  (monty::rc_ptr< ::mosek::fusion::Expression > _4824) :    ExprCondense(new mosek::fusion::p_ExprCondense(this)){ mosek::fusion::p_ExprCondense::_get_impl(this)->_initialize(_4824); }void mosek::fusion::p_ExprCondense::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4824){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4824->getShape());
    mosek::fusion::p_ExprCondense::_get_impl(::mosek::fusion::ExprCondense::t(_pubthis))->expr = _4824;
  }
}void mosek::fusion::ExprCondense :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4825,monty::rc_ptr< ::mosek::fusion::WorkStack > _4826,monty::rc_ptr< ::mosek::fusion::WorkStack > _4827) { mosek::fusion::p_ExprCondense::_get_impl(this)->eval(_4825,_4826,_4827); }void mosek::fusion::p_ExprCondense::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4825,monty::rc_ptr< ::mosek::fusion::WorkStack > _4826,monty::rc_ptr< ::mosek::fusion::WorkStack > _4827){
  expr->eval(_4825,_4826,_4827);
  int _4828 = _4825->popi32();
  long long _4829 = (int)1;
  int _9129 = (int)0;
  int _9130 = _4828;
  for (int _4830 = _9129; _4830 < _9130; ++_4830)
  {
    {
      _4829 *= _4825->popi32();
    }
  }
  int _4831 = _4825->popi32();
  int _4832 = _4825->popi32();
  bool _4833 = (_4825->popi32() != (int)0);
  if (_4833)
  {
    {
      _4825->popi64(_4831);
    }
  }
  {}
  _4825->pushi32((int)0);
  _4825->pushi32(_4832);
  _4825->pushi32(_4831);
  _4825->pushi32(_4831);
  _4825->pushi32((int)1);
}
void mosek::fusion::p_ExprCondense::destroy(){expr.reset();}void mosek::fusion::ExprCondense::destroy() { mosek::fusion::p_ExprCondense::_get_impl(this)->destroy(); }mosek::fusion::ExprFromVar::ExprFromVar(mosek::fusion::p_ExprFromVar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprFromVar()" << this << std::endl; */ }mosek::fusion::ExprFromVar::~ExprFromVar() {  /* std::cout << "~ExprFromVar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprFromVar::p_ExprFromVar  (::mosek::fusion::ExprFromVar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprFromVar::t mosek::fusion::p_ExprFromVar::_new_ExprFromVar  (monty::rc_ptr< ::mosek::fusion::Variable > _4834){ return new mosek::fusion::ExprFromVar(_4834); }mosek::fusion::ExprFromVar::ExprFromVar  (monty::rc_ptr< ::mosek::fusion::Variable > _4834) :    ExprFromVar(new mosek::fusion::p_ExprFromVar(this)){ mosek::fusion::p_ExprFromVar::_get_impl(this)->_initialize(_4834); }void mosek::fusion::p_ExprFromVar::_initialize  (monty::rc_ptr< ::mosek::fusion::Variable > _4834){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4834->getShape());
    mosek::fusion::p_ExprFromVar::_get_impl(::mosek::fusion::ExprFromVar::t(_pubthis))->x = _4834;
  }
}void mosek::fusion::ExprFromVar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4835,monty::rc_ptr< ::mosek::fusion::WorkStack > _4836,monty::rc_ptr< ::mosek::fusion::WorkStack > _4837) { mosek::fusion::p_ExprFromVar::_get_impl(this)->eval(_4835,_4836,_4837); }void mosek::fusion::p_ExprFromVar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4835,monty::rc_ptr< ::mosek::fusion::WorkStack > _4836,monty::rc_ptr< ::mosek::fusion::WorkStack > _4837){
  std::shared_ptr< monty::ndarray< int,1 > > _4838 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__4838(_4838 ? _4838->raw() : nullptr,_4838 ? _4838->size(0) : 0);
  long long _4839 = ::mosek::fusion::p_Set::size(_4838);
  int _4840 = x->numInst();
  int _4841 = _4840;
  bool _4842 = (_4839 > _4840);
  int _4843 = _4835->alloci32(safe_add( _4840,(int)1 ));
  int _4844 = _4835->alloci64(_4841);
  int _9131;
  bool _9132 = _4842;
  if (_9132)
  {
    _9131 = _4835->alloci64(_4840);
  }
  else
  {
    _9131 = (-(int)1);
  }
  int _4845 = _9131;
  int _4846 = _4835->allocf64(_4841);
  int _4847 = _4835->allocf64(_4840);
  int _9133;
  bool _9134 = _4842;
  if (_9134)
  {
    _9133 = (int)1;
  }
  else
  {
    _9133 = (int)0;
  }
  _4835->pushi32(_9133);
  _4835->pushi32(_4841);
  _4835->pushi32(_4840);
  int _9135 = (int)0;
  int _9136 = (int)((_4838)->size(0));
  for (int _4848 = _9135; _4848 < _9136; ++_4848)
  {
    {
      _4835->pushi32(_ptr__4838[_4848]);
    }
  }
  _4835->pushi32((int)((_4838)->size(0)));
  std::shared_ptr< monty::ndarray< int,1 > > _4849 = mosek::fusion::p_WorkStack::_get_impl(_4835)->i32;
  _checked_ptr_1<int> _ptr__4849(_4849 ? _4849->raw() : nullptr,_4849 ? _4849->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4850 = mosek::fusion::p_WorkStack::_get_impl(_4835)->i64;
  _checked_ptr_1<long long> _ptr__4850(_4850 ? _4850->raw() : nullptr,_4850 ? _4850->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4851 = mosek::fusion::p_WorkStack::_get_impl(_4835)->f64;
  _checked_ptr_1<double> _ptr__4851(_4851 ? _4851->raw() : nullptr,_4851 ? _4851->size(0) : 0);
  {
    int _9137 = (int)0;
    int _9138 = safe_add( _4840,(int)1 );
    for (int _4852 = _9137; _4852 < _9138; ++_4852)
    {
      {
        _ptr__4849[safe_add( _4843,_4852 )] = _4852;
      }
    }
    int _9139 = (int)0;
    int _9140 = _4840;
    for (int _4853 = _9139; _4853 < _9140; ++_4853)
    {
      {
        _ptr__4851[safe_add( _4847,_4853 )] = 0.0;
      }
    }
    int _9141 = (int)0;
    int _9142 = _4841;
    for (int _4854 = _9141; _4854 < _9142; ++_4854)
    {
      {
        _ptr__4851[safe_add( _4846,_4854 )] = 1.0;
      }
    }
  }
  if (_4842)
  {
    {
      x->inst(_4845,_4850,_4844,_4850);
    }
  }
  else
  {
    {
      x->inst(_4844,_4850);
    }
  }
}
std::string mosek::fusion::ExprFromVar :: toString() { return mosek::fusion::p_ExprFromVar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprFromVar::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Expr("))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprFromVar::destroy(){x.reset();}void mosek::fusion::ExprFromVar::destroy() { mosek::fusion::p_ExprFromVar::_get_impl(this)->destroy(); }mosek::fusion::ExprReshape::ExprReshape(mosek::fusion::p_ExprReshape *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprReshape()" << this << std::endl; */ }mosek::fusion::ExprReshape::~ExprReshape() {  /* std::cout << "~ExprReshape()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprReshape::p_ExprReshape  (::mosek::fusion::ExprReshape * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprReshape::t mosek::fusion::p_ExprReshape::_new_ExprReshape  (std::shared_ptr< monty::ndarray< int,1 > > _4855,    monty::rc_ptr< ::mosek::fusion::Expression > _4856){ return new mosek::fusion::ExprReshape(_4855,_4856); }mosek::fusion::ExprReshape::ExprReshape  (std::shared_ptr< monty::ndarray< int,1 > > _4855,    monty::rc_ptr< ::mosek::fusion::Expression > _4856) :    ExprReshape(new mosek::fusion::p_ExprReshape(this)){ mosek::fusion::p_ExprReshape::_get_impl(this)->_initialize(_4855,_4856); }void mosek::fusion::p_ExprReshape::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _4855,    monty::rc_ptr< ::mosek::fusion::Expression > _4856){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4855(_4855 ? _4855->raw() : nullptr, _4855 ? _4855->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::Utils::Tools::arraycopy(_4855));
    long long _4857 = _4856->getSize();
    if ((::mosek::fusion::p_Set::size(_4855) != _4856->getSize()))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Cannot reshape to mismatching shape"));
      }
    }
    {}
    mosek::fusion::p_ExprReshape::_get_impl(::mosek::fusion::ExprReshape::t(_pubthis))->e = _4856;
  }
}void mosek::fusion::ExprReshape :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4858,monty::rc_ptr< ::mosek::fusion::WorkStack > _4859,monty::rc_ptr< ::mosek::fusion::WorkStack > _4860) { mosek::fusion::p_ExprReshape::_get_impl(this)->eval(_4858,_4859,_4860); }void mosek::fusion::p_ExprReshape::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4858,monty::rc_ptr< ::mosek::fusion::WorkStack > _4859,monty::rc_ptr< ::mosek::fusion::WorkStack > _4860){
  std::shared_ptr< monty::ndarray< int,1 > > _4861 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__4861(_4861 ? _4861->raw() : nullptr,_4861 ? _4861->size(0) : 0);
  e->eval(_4858,_4859,_4860);
  _4858->peek_expr();
  int _4862 = _4858->popi32();
  long long _4863 = (int)1;
  int _9143 = (int)0;
  int _9144 = _4862;
  for (int _4864 = _9143; _4864 < _9144; ++_4864)
  {
    {
      _4863 *= _4858->popi32();
    }
  }
  if ((_4863 != _pubthis->getSize()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("The two shapes have different sizes"));
    }
  }
  {}
  int _9145 = (int)0;
  int _9146 = (int)((_4861)->size(0));
  for (int _4865 = _9145; _4865 < _9146; ++_4865)
  {
    {
      _4858->pushi32(_ptr__4861[_4865]);
    }
  }
  _4858->pushi32((int)((_4861)->size(0)));
}
std::string mosek::fusion::ExprReshape :: toString() { return mosek::fusion::p_ExprReshape::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprReshape::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _4866 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprReshape(("));
  if ((_pubthis->getND() > (int)0))
  {
    {
      _4866->__mosek_2fusion_2Utils_2StringBuffer__a(_pubthis->getDim((int)0));
      int _9147 = (int)1;
      int _9148 = _pubthis->getND();
      for (int _4867 = _9147; _4867 < _9148; ++_4867)
      {
        {
          _4866->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_pubthis->getDim(_4867));
        }
      }
    }
  }
  {}
  _4866->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("),"))->__mosek_2fusion_2Utils_2StringBuffer__a(e->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _4866->toString();
}
void mosek::fusion::p_ExprReshape::destroy(){e.reset();}void mosek::fusion::ExprReshape::destroy() { mosek::fusion::p_ExprReshape::_get_impl(this)->destroy(); }mosek::fusion::BaseExpression::BaseExpression(mosek::fusion::p_BaseExpression *_impl) : _impl(_impl) { /*std::cout << "BaseExpression() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::BaseExpression::~BaseExpression() { delete _impl; _impl = nullptr; }mosek::fusion::p_BaseExpression::p_BaseExpression  (::mosek::fusion::BaseExpression * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_BaseExpression::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _4868){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4868(_4868 ? _4868->raw() : nullptr, _4868 ? _4868->size(0) : 0);
    mosek::fusion::p_BaseExpression::_get_impl(::mosek::fusion::BaseExpression::t(_pubthis))->shape = _4868;
  }
}std::string mosek::fusion::BaseExpression :: toString() { return mosek::fusion::p_BaseExpression::_get_impl(this)->toString(); }std::string mosek::fusion::p_BaseExpression::toString(){
  return std::string ("Expression()");
}
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__eval() { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseExpression::eval() { return __mosek_2fusion_2BaseExpression__eval(); }
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__eval() { return __mosek_2fusion_2BaseExpression__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__eval(){
  monty::rc_ptr< ::mosek::fusion::WorkStack > _4869 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  monty::rc_ptr< ::mosek::fusion::WorkStack > _4870 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  monty::rc_ptr< ::mosek::fusion::WorkStack > _4871 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  _pubthis->eval(_4869,_4870,_4871);
  int _4872 = _4869->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _4873 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4872)));
  _checked_ptr_1<int> _ptr__4873(_4873 ? _4873->raw() : nullptr,_4873 ? _4873->size(0) : 0);
  _4869->popi32(_4872,_4873,(int)0);
  int _4874 = _4869->popi32();
  int _4875 = _4869->popi32();
  int _4876 = (int)1;
  int _9149 = (int)0;
  int _9150 = _4872;
  for (int _4877 = _9149; _4877 < _9150; ++_4877)
  {
    {
      _4876 *= _ptr__4873[_4877];
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _4878 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4875)));
  _checked_ptr_1<long long> _ptr__4878(_4878 ? _4878->raw() : nullptr,_4878 ? _4878->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4879 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _4874,(int)1 ))));
  _checked_ptr_1<int> _ptr__4879(_4879 ? _4879->raw() : nullptr,_4879 ? _4879->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4880 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_4874)));
  _checked_ptr_1<double> _ptr__4880(_4880 ? _4880->raw() : nullptr,_4880 ? _4880->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4881 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_4875)));
  _checked_ptr_1<double> _ptr__4881(_4881 ? _4881->raw() : nullptr,_4881 ? _4881->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4882 = nullptr;
  _checked_ptr_1<long long> _ptr__4882(_4882 ? _4882->raw() : nullptr,_4882 ? _4882->size(0) : 0);
  if ((_4876 < _4874))
  {
    {
      _4882 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4874)));
      _ptr__4882.update(_4882 ? _4882->raw() : nullptr, _4882 ? _4882->size(0) : 0);
      _4869->popi64(_4874,_4882,(int)0);
    }
  }
  {}
  _4869->popi32(_4874,_4879,(int)1);
  _4869->popi64(_4875,_4878,(int)0);
  _4869->popf64(_4874,_4880,(int)0);
  _4869->popf64(_4875,_4881,(int)0);
  std::vector<long long> _9151;
  for (int _4883 = (int)0, _9152 = safe_add( _4874,(int)1 ); _4883 < _9152 ; ++_4883)
  {
    _9151.push_back(_ptr__4879[_4883]);
  }
  auto _9153 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9151.size()),_9151.begin(),_9151.end()));
  return ::mosek::fusion::p_FlatExpr::_new_FlatExpr(_4880,_9153,_4878,_4881,_4873,_4882);
}
void mosek::fusion::BaseExpression::storeexpr  ( monty::rc_ptr< ::mosek::fusion::WorkStack > _4884,    std::shared_ptr< monty::ndarray< int,1 > > _4885,    std::shared_ptr< monty::ndarray< int,1 > > _4886,    std::shared_ptr< monty::ndarray< long long,1 > > _4887,    std::shared_ptr< monty::ndarray< long long,1 > > _4888,    std::shared_ptr< monty::ndarray< double,1 > > _4889,    std::shared_ptr< monty::ndarray< double,1 > > _4890) { mosek::fusion::p_BaseExpression::storeexpr(_4884,_4885,_4886,_4887,_4888,_4889,_4890); }void mosek::fusion::p_BaseExpression::storeexpr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4884,std::shared_ptr< monty::ndarray< int,1 > > _4885,std::shared_ptr< monty::ndarray< int,1 > > _4886,std::shared_ptr< monty::ndarray< long long,1 > > _4887,std::shared_ptr< monty::ndarray< long long,1 > > _4888,std::shared_ptr< monty::ndarray< double,1 > > _4889,std::shared_ptr< monty::ndarray< double,1 > > _4890){
  _checked_ptr_1<int> _ptr__4885(_4885 ? _4885->raw() : nullptr, _4885 ? _4885->size(0) : 0);
  _checked_ptr_1<int> _ptr__4886(_4886 ? _4886->raw() : nullptr, _4886 ? _4886->size(0) : 0);
  _checked_ptr_1<long long> _ptr__4887(_4887 ? _4887->raw() : nullptr, _4887 ? _4887->size(0) : 0);
  _checked_ptr_1<long long> _ptr__4888(_4888 ? _4888->raw() : nullptr, _4888 ? _4888->size(0) : 0);
  _checked_ptr_1<double> _ptr__4889(_4889 ? _4889->raw() : nullptr, _4889 ? _4889->size(0) : 0);
  _checked_ptr_1<double> _ptr__4890(_4890 ? _4890->raw() : nullptr, _4890 ? _4890->size(0) : 0);
  int _4891 = _ptr__4886[((int)((_4886)->size(0)) - (int)1)];
  int _4892 = ((int)((_4886)->size(0)) - (int)1);
  int _4893 = (int)((_4885)->size(0));
  {
    int _4894 = _4884->alloci32(safe_add( _4892,(int)1 ));
    ::mosek::fusion::Utils::Tools::arraycopy(_4886,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4884)->i32,_4894,safe_add( _4892,(int)1 ));
  }
  int _9154;
  bool _9155 = (NULL != _4887.get());
  if (_9155)
  {
    _9154 = (int)1;
  }
  else
  {
    _9154 = (int)0;
  }
  _4884->pushi32(_9154);
  _4884->pushi32(_4891);
  _4884->pushi32(_4892);
  {
    int _4895 = _4884->alloci32(_4893);
    ::mosek::fusion::Utils::Tools::arraycopy(_4885,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4884)->i32,_4895,_4893);
  }
  _4884->pushi32(_4893);
  {
    int _4896 = _4884->alloci64(_4891);
    ::mosek::fusion::Utils::Tools::arraycopy(_4888,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4884)->i64,_4896,_4891);
  }
  if ((NULL != _4887.get()))
  {
    {
      int _4897 = _4884->alloci64(_4892);
      ::mosek::fusion::Utils::Tools::arraycopy(_4887,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4884)->i64,_4897,_4892);
    }
  }
  {}
  {
    int _4898 = _4884->allocf64(_4891);
    ::mosek::fusion::Utils::Tools::arraycopy(_4889,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4884)->f64,_4898,_4891);
  }
  {
    int _4899 = _4884->allocf64(_4892);
    if ((NULL != _4890.get()))
    {
      {
        ::mosek::fusion::Utils::Tools::arraycopy(_4890,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4884)->f64,_4899,_4892);
      }
    }
    else
    {
      {
        int _9156 = (int)0;
        int _9157 = _4892;
        for (int _4900 = _9156; _4900 < _9157; ++_4900)
        {
          {
            ((*mosek::fusion::p_WorkStack::_get_impl(_4884)->f64)(safe_add( _4899,_4900 ))) = (int)0;
          }
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4904) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__pick(_4904); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::pick(std::shared_ptr< monty::ndarray< int,2 > > _4904) { return __mosek_2fusion_2BaseExpression__pick(_4904); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4904) { return __mosek_2fusion_2BaseExpression__pick(_4904); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4904){
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4904)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4905) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__pick(_4905); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::pick(std::shared_ptr< monty::ndarray< int,1 > > _4905) { return __mosek_2fusion_2BaseExpression__pick(_4905); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4905) { return __mosek_2fusion_2BaseExpression__pick(_4905); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4905){
  _checked_ptr_1<int> _ptr__4905(_4905 ? _4905->raw() : nullptr, _4905 ? _4905->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _4906 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_4905)->size(0)),(int)1)));
  int _9158 = (int)0;
  int _9159 = (int)((_4905)->size(0));
  for (int _4907 = _9158; _4907 < _9159; ++_4907)
  {
    {
      ((*_4906)(_4907,(int)0)) = _ptr__4905[_4907];
    }
  }
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4906)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__index(std::shared_ptr< monty::ndarray< int,1 > > _4908) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__index(_4908); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::index(std::shared_ptr< monty::ndarray< int,1 > > _4908) { return __mosek_2fusion_2BaseExpression__index(_4908); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__index(std::shared_ptr< monty::ndarray< int,1 > > _4908) { return __mosek_2fusion_2BaseExpression__index(_4908); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__index(std::shared_ptr< monty::ndarray< int,1 > > _4908){
  _checked_ptr_1<int> _ptr__4908(_4908 ? _4908->raw() : nullptr, _4908 ? _4908->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _4909 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)1,(int)((_4908)->size(0)))));
  int _9160 = (int)0;
  int _9161 = (int)((_4908)->size(0));
  for (int _4910 = _9160; _4910 < _9161; ++_4910)
  {
    {
      ((*_4909)((int)0,_4910)) = _ptr__4908[_4910];
    }
  }
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4909)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__index(int _4911) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__index(_4911); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::index(int _4911) { return __mosek_2fusion_2BaseExpression__index(_4911); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__index(int _4911) { return __mosek_2fusion_2BaseExpression__index(_4911); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__index(int _4911){
  std::shared_ptr< monty::ndarray< int,2 > > _4912 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)1,(int)1)));
  ((*_4912)((int)0,(int)0)) = _4911;
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4912)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4913,std::shared_ptr< monty::ndarray< int,1 > > _4914) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__slice(_4913,_4914); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::slice(std::shared_ptr< monty::ndarray< int,1 > > _4913,std::shared_ptr< monty::ndarray< int,1 > > _4914) { return __mosek_2fusion_2BaseExpression__slice(_4913,_4914); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4913,std::shared_ptr< monty::ndarray< int,1 > > _4914) { return __mosek_2fusion_2BaseExpression__slice(_4913,_4914); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4913,std::shared_ptr< monty::ndarray< int,1 > > _4914){
  _checked_ptr_1<int> _ptr__4913(_4913 ? _4913->raw() : nullptr, _4913 ? _4913->size(0) : 0);
  _checked_ptr_1<int> _ptr__4914(_4914 ? _4914->raw() : nullptr, _4914 ? _4914->size(0) : 0);
  return (::mosek::fusion::p_ExprSlice::_new_ExprSlice((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4913,_4914)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__slice(int _4915,int _4916) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__slice(_4915,_4916); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::slice(int _4915,int _4916) { return __mosek_2fusion_2BaseExpression__slice(_4915,_4916); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__slice(int _4915,int _4916) { return __mosek_2fusion_2BaseExpression__slice(_4915,_4916); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__slice(int _4915,int _4916){
  return (::mosek::fusion::p_ExprSlice::_new_ExprSlice((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4915)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4916)}))).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::BaseExpression :: getSize() { return mosek::fusion::p_BaseExpression::_get_impl(this)->getSize(); }long long mosek::fusion::p_BaseExpression::getSize(){
  return ::mosek::fusion::p_Set::size(shape);
}
int mosek::fusion::BaseExpression :: getND() { return mosek::fusion::p_BaseExpression::_get_impl(this)->getND(); }int mosek::fusion::p_BaseExpression::getND(){
  return (int)((shape)->size(0));
}
int mosek::fusion::BaseExpression :: getDim(int _4917) { return mosek::fusion::p_BaseExpression::_get_impl(this)->getDim(_4917); }int mosek::fusion::p_BaseExpression::getDim(int _4917){
  return ((*shape)(_4917));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::BaseExpression :: getShape() { return mosek::fusion::p_BaseExpression::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_BaseExpression::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
void mosek::fusion::p_BaseExpression::destroy(){shape.reset();}void mosek::fusion::BaseExpression::destroy() { mosek::fusion::p_BaseExpression::_get_impl(this)->destroy(); }mosek::fusion::WorkStack::WorkStack(mosek::fusion::p_WorkStack *_impl) : _impl(_impl) { /*std::cout << "WorkStack() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::WorkStack::~WorkStack() { delete _impl; _impl = nullptr; }mosek::fusion::p_WorkStack::p_WorkStack  (::mosek::fusion::WorkStack * _pubthis) :     _pubthis(_pubthis){}int mosek::fusion::WorkStack::get_cof_base() { return _impl->cof_base; }
void mosek::fusion::WorkStack::set_cof_base(int _val) { _impl->cof_base = _val; }
int mosek::fusion::WorkStack::get_bfix_base() { return _impl->bfix_base; }
void mosek::fusion::WorkStack::set_bfix_base(int _val) { _impl->bfix_base = _val; }
int mosek::fusion::WorkStack::get_nidxs_base() { return _impl->nidxs_base; }
void mosek::fusion::WorkStack::set_nidxs_base(int _val) { _impl->nidxs_base = _val; }
int mosek::fusion::WorkStack::get_sp_base() { return _impl->sp_base; }
void mosek::fusion::WorkStack::set_sp_base(int _val) { _impl->sp_base = _val; }
int mosek::fusion::WorkStack::get_shape_base() { return _impl->shape_base; }
void mosek::fusion::WorkStack::set_shape_base(int _val) { _impl->shape_base = _val; }
int mosek::fusion::WorkStack::get_ptr_base() { return _impl->ptr_base; }
void mosek::fusion::WorkStack::set_ptr_base(int _val) { _impl->ptr_base = _val; }
bool mosek::fusion::WorkStack::get_hassp() { return _impl->hassp; }
void mosek::fusion::WorkStack::set_hassp(bool _val) { _impl->hassp = _val; }
int mosek::fusion::WorkStack::get_nelem() { return _impl->nelem; }
void mosek::fusion::WorkStack::set_nelem(int _val) { _impl->nelem = _val; }
int mosek::fusion::WorkStack::get_nnz() { return _impl->nnz; }
void mosek::fusion::WorkStack::set_nnz(int _val) { _impl->nnz = _val; }
int mosek::fusion::WorkStack::get_nd() { return _impl->nd; }
void mosek::fusion::WorkStack::set_nd(int _val) { _impl->nd = _val; }
int mosek::fusion::WorkStack::get_pf64() { return _impl->pf64; }
void mosek::fusion::WorkStack::set_pf64(int _val) { _impl->pf64 = _val; }
int mosek::fusion::WorkStack::get_pi64() { return _impl->pi64; }
void mosek::fusion::WorkStack::set_pi64(int _val) { _impl->pi64 = _val; }
int mosek::fusion::WorkStack::get_pi32() { return _impl->pi32; }
void mosek::fusion::WorkStack::set_pi32(int _val) { _impl->pi32 = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::WorkStack::get_f64() { return _impl->f64; }
void mosek::fusion::WorkStack::set_f64(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->f64 = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::WorkStack::get_i64() { return _impl->i64; }
void mosek::fusion::WorkStack::set_i64(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->i64 = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::WorkStack::get_i32() { return _impl->i32; }
void mosek::fusion::WorkStack::set_i32(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->i32 = _val; }
mosek::fusion::WorkStack::t mosek::fusion::p_WorkStack::_new_WorkStack  (){ return new mosek::fusion::WorkStack(); }mosek::fusion::WorkStack::WorkStack  () :    WorkStack(new mosek::fusion::p_WorkStack(this)){ mosek::fusion::p_WorkStack::_get_impl(this)->_initialize(); }void mosek::fusion::p_WorkStack::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    i32 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)256)));
    i64 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)256)));
    f64 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)256)));
    pi32 = (int)0;
    pi64 = (int)0;
    pf64 = (int)0;
    nd = (int)0;
    nnz = (int)0;
    nelem = (int)0;
    hassp = false;
    ptr_base = (int)0;
    shape_base = (int)0;
    sp_base = (int)0;
    nidxs_base = (int)0;
    bfix_base = (int)0;
    cof_base = (int)0;
  }
}bool mosek::fusion::WorkStack :: peek_hassp() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_hassp(); }bool mosek::fusion::p_WorkStack::peek_hassp(){
  return (_pubthis->peeki32(safe_add( (int)3,_pubthis->peek_nd() )) != (int)0);
}
int mosek::fusion::WorkStack :: peek_nnz() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_nnz(); }int mosek::fusion::p_WorkStack::peek_nnz(){
  return _pubthis->peeki32(safe_add( (int)2,_pubthis->peek_nd() ));
}
int mosek::fusion::WorkStack :: peek_nelem() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_nelem(); }int mosek::fusion::p_WorkStack::peek_nelem(){
  return _pubthis->peeki32(safe_add( (int)1,_pubthis->peek_nd() ));
}
int mosek::fusion::WorkStack :: peek_dim(int _4918) { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_dim(_4918); }int mosek::fusion::p_WorkStack::peek_dim(int _4918){
  return _pubthis->peeki32(safe_add( _4918,(int)1 ));
}
int mosek::fusion::WorkStack :: peek_nd() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_nd(); }int mosek::fusion::p_WorkStack::peek_nd(){
  return _pubthis->peeki32();
}
void mosek::fusion::WorkStack :: alloc_expr(int _4919,int _4920,int _4921,bool _4922) { mosek::fusion::p_WorkStack::_get_impl(this)->alloc_expr(_4919,_4920,_4921,_4922); }void mosek::fusion::p_WorkStack::alloc_expr(int _4919,int _4920,int _4921,bool _4922){
  cof_base = _pubthis->allocf64(_4921);
  bfix_base = _pubthis->allocf64(_4920);
  nidxs_base = _pubthis->alloci64(_4921);
  int _9162;
  bool _9163 = _4922;
  if (_9163)
  {
    _9162 = _pubthis->alloci64(_4920);
  }
  else
  {
    _9162 = (-(int)9999);
  }
  sp_base = _9162;
  ptr_base = _pubthis->alloci32(safe_add( _4920,(int)1 ));
  int _9164;
  bool _9165 = _4922;
  if (_9165)
  {
    _9164 = (int)1;
  }
  else
  {
    _9164 = (int)0;
  }
  _pubthis->pushi32(_9164);
  _pubthis->pushi32(_4921);
  _pubthis->pushi32(_4920);
  shape_base = _pubthis->alloci32(_4919);
  _pubthis->pushi32(_4919);
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->nd = _4919;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->nelem = _4920;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->nnz = _4921;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->hassp = _4922;
}
void mosek::fusion::WorkStack :: move_expr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4923) { mosek::fusion::p_WorkStack::_get_impl(this)->move_expr(_4923); }void mosek::fusion::p_WorkStack::move_expr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4923){
  int _4924 = pi32;
  int _4925 = pi64;
  int _4926 = pf64;
  _pubthis->pop_expr();
  int _4927 = _4923->alloci32((_4924 - pi32));
  int _4928 = _4923->alloci64((_4925 - pi64));
  int _4929 = _4923->allocf64((_4926 - pf64));
  ::mosek::fusion::Utils::Tools::arraycopy(i32,pi32,mosek::fusion::p_WorkStack::_get_impl(_4923)->i32,_4927,(_4924 - pi32));
  ::mosek::fusion::Utils::Tools::arraycopy(i64,pi64,mosek::fusion::p_WorkStack::_get_impl(_4923)->i64,_4928,(_4925 - pi64));
  ::mosek::fusion::Utils::Tools::arraycopy(f64,pf64,mosek::fusion::p_WorkStack::_get_impl(_4923)->f64,_4929,(_4926 - pf64));
}
void mosek::fusion::WorkStack :: peek_expr() { mosek::fusion::p_WorkStack::_get_impl(this)->peek_expr(); }void mosek::fusion::p_WorkStack::peek_expr(){
  int _4930 = pi32;
  int _4931 = pi64;
  int _4932 = pf64;
  _pubthis->pop_expr();
  pi32 = _4930;
  pi64 = _4931;
  pf64 = _4932;
}
void mosek::fusion::WorkStack :: pop_expr() { mosek::fusion::p_WorkStack::_get_impl(this)->pop_expr(); }void mosek::fusion::p_WorkStack::pop_expr(){
  nd = _pubthis->popi32();
  shape_base = _pubthis->popi32(nd);
  nelem = _pubthis->popi32();
  nnz = _pubthis->popi32();
  hassp = (_pubthis->popi32() != (int)0);
  ptr_base = _pubthis->popi32(safe_add( nelem,(int)1 ));
  int _9166;
  bool _9167 = hassp;
  if (_9167)
  {
    _9166 = _pubthis->popi64(nelem);
  }
  else
  {
    _9166 = (-(int)9999);
  }
  sp_base = _9166;
  nidxs_base = _pubthis->popi64(nnz);
  bfix_base = _pubthis->popf64(nelem);
  cof_base = _pubthis->popf64(nnz);
}
void mosek::fusion::WorkStack :: ensure_sparsity() { mosek::fusion::p_WorkStack::_get_impl(this)->ensure_sparsity(); }void mosek::fusion::p_WorkStack::ensure_sparsity(){
  int _4933 = ((*i32)((pi32 - (int)1)));
  bool _4934 = (((*i32)(((pi32 - _4933) - (int)3))) != (int)0);
  int _4935 = ((*i32)(((pi32 - _4933) - (int)1)));
  if ((!_4934))
  {
    {
      ((*i32)(((pi32 - _4933) - (int)3))) = (int)1;
      int _4936 = _pubthis->alloci64(_4935);
      int _9168 = (int)0;
      int _9169 = _4935;
      for (int _4937 = _9168; _4937 < _9169; ++_4937)
      {
        {
          ((*i64)(_4936)) = _4937;
        }
      }
    }
  }
  {}
}
void mosek::fusion::WorkStack :: clear() { mosek::fusion::p_WorkStack::_get_impl(this)->clear(); }void mosek::fusion::p_WorkStack::clear(){
  pi32 = (int)0;
  pi64 = (int)0;
  pf64 = (int)0;
}
int mosek::fusion::WorkStack :: allocf64(int _4938) { return mosek::fusion::p_WorkStack::_get_impl(this)->allocf64(_4938); }int mosek::fusion::p_WorkStack::allocf64(int _4938){
  _pubthis->ensuref64(_4938);
  int _4939 = pf64;
  pf64 += _4938;
  return _4939;
}
int mosek::fusion::WorkStack :: alloci64(int _4940) { return mosek::fusion::p_WorkStack::_get_impl(this)->alloci64(_4940); }int mosek::fusion::p_WorkStack::alloci64(int _4940){
  _pubthis->ensurei64(_4940);
  int _4941 = pi64;
  pi64 += _4940;
  return _4941;
}
int mosek::fusion::WorkStack :: alloci32(int _4942) { return mosek::fusion::p_WorkStack::_get_impl(this)->alloci32(_4942); }int mosek::fusion::p_WorkStack::alloci32(int _4942){
  if ((_4942 > (int)0))
  {
    {
      _pubthis->ensurei32(_4942);
      int _4943 = pi32;
      pi32 += _4942;
      return _4943;
    }
  }
  else
  {
    {
      return (int)0;
    }
  }
}
void mosek::fusion::WorkStack :: pushf64(double _4944) { mosek::fusion::p_WorkStack::_get_impl(this)->pushf64(_4944); }void mosek::fusion::p_WorkStack::pushf64(double _4944){
  _pubthis->ensuref64((int)1);
  ((*f64)(pf64)) = _4944;
  ++ pf64;
}
void mosek::fusion::WorkStack :: pushi64(long long _4945) { mosek::fusion::p_WorkStack::_get_impl(this)->pushi64(_4945); }void mosek::fusion::p_WorkStack::pushi64(long long _4945){
  _pubthis->ensurei64((int)1);
  ((*i64)(pi64)) = _4945;
  ++ pi64;
}
void mosek::fusion::WorkStack :: pushi32(int _4946) { mosek::fusion::p_WorkStack::_get_impl(this)->pushi32(_4946); }void mosek::fusion::p_WorkStack::pushi32(int _4946){
  _pubthis->ensurei32((int)1);
  ((*i32)(pi32)) = _4946;
  ++ pi32;
}
void mosek::fusion::WorkStack :: ensuref64(int _4947) { mosek::fusion::p_WorkStack::_get_impl(this)->ensuref64(_4947); }void mosek::fusion::p_WorkStack::ensuref64(int _4947){
  if ((safe_add( pf64,_4947 ) > (int)((f64)->size(0))))
  {
    {
      int _9170;
      bool _9171 = (_4947 < (int)((f64)->size(0)));
      if (_9171)
      {
        _9170 = safe_mul( (int)((f64)->size(0)),(int)2 );
      }
      else
      {
        _9170 = safe_add( (int)((f64)->size(0)),_4947 );
      }
      int _4948 = _9170;
      std::shared_ptr< monty::ndarray< double,1 > > _4949 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_4948)));
      _checked_ptr_1<double> _ptr__4949(_4949 ? _4949->raw() : nullptr,_4949 ? _4949->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(f64,(int)0,_4949,(int)0,pf64);
      f64 = _4949;
    }
  }
  {}
}
void mosek::fusion::WorkStack :: ensurei64(int _4950) { mosek::fusion::p_WorkStack::_get_impl(this)->ensurei64(_4950); }void mosek::fusion::p_WorkStack::ensurei64(int _4950){
  if ((safe_add( pi64,_4950 ) > (int)((i64)->size(0))))
  {
    {
      int _9172;
      bool _9173 = (_4950 < (int)((i64)->size(0)));
      if (_9173)
      {
        _9172 = (int)((i64)->size(0));
      }
      else
      {
        _9172 = _4950;
      }
      int _4951 = safe_add( (int)((i64)->size(0)),_9172 );
      std::shared_ptr< monty::ndarray< long long,1 > > _4952 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4951)));
      _checked_ptr_1<long long> _ptr__4952(_4952 ? _4952->raw() : nullptr,_4952 ? _4952->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(i64,(int)0,_4952,(int)0,pi64);
      i64 = _4952;
    }
  }
  {}
}
void mosek::fusion::WorkStack :: ensurei32(int _4953) { mosek::fusion::p_WorkStack::_get_impl(this)->ensurei32(_4953); }void mosek::fusion::p_WorkStack::ensurei32(int _4953){
  if ((safe_add( pi32,_4953 ) > (int)((i32)->size(0))))
  {
    {
      int _9174;
      bool _9175 = (_4953 < (int)((i32)->size(0)));
      if (_9175)
      {
        _9174 = safe_mul( (int)((i32)->size(0)),(int)2 );
      }
      else
      {
        _9174 = safe_add( (int)((i32)->size(0)),_4953 );
      }
      int _4954 = _9174;
      std::shared_ptr< monty::ndarray< int,1 > > _4955 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4954)));
      _checked_ptr_1<int> _ptr__4955(_4955 ? _4955->raw() : nullptr,_4955 ? _4955->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(i32,(int)0,_4955,(int)0,pi32);
      i32 = _4955;
    }
  }
  {}
}
int mosek::fusion::WorkStack :: popf64(int _4956) { return mosek::fusion::p_WorkStack::_get_impl(this)->popf64(_4956); }int mosek::fusion::p_WorkStack::popf64(int _4956){
  pf64 -= _4956;
  return pf64;
}
int mosek::fusion::WorkStack :: popi64(int _4957) { return mosek::fusion::p_WorkStack::_get_impl(this)->popi64(_4957); }int mosek::fusion::p_WorkStack::popi64(int _4957){
  pi64 -= _4957;
  return pi64;
}
int mosek::fusion::WorkStack :: popi32(int _4958) { return mosek::fusion::p_WorkStack::_get_impl(this)->popi32(_4958); }int mosek::fusion::p_WorkStack::popi32(int _4958){
  pi32 -= _4958;
  return pi32;
}
void mosek::fusion::WorkStack :: popf64(int _4959,std::shared_ptr< monty::ndarray< double,1 > > _4960,int _4961) { mosek::fusion::p_WorkStack::_get_impl(this)->popf64(_4959,_4960,_4961); }void mosek::fusion::p_WorkStack::popf64(int _4959,std::shared_ptr< monty::ndarray< double,1 > > _4960,int _4961){
  _checked_ptr_1<double> _ptr__4960(_4960 ? _4960->raw() : nullptr, _4960 ? _4960->size(0) : 0);
  pf64 -= _4959;
  ::mosek::fusion::Utils::Tools::arraycopy(f64,pf64,_4960,_4961,_4959);
}
void mosek::fusion::WorkStack :: popi64(int _4962,std::shared_ptr< monty::ndarray< long long,1 > > _4963,int _4964) { mosek::fusion::p_WorkStack::_get_impl(this)->popi64(_4962,_4963,_4964); }void mosek::fusion::p_WorkStack::popi64(int _4962,std::shared_ptr< monty::ndarray< long long,1 > > _4963,int _4964){
  _checked_ptr_1<long long> _ptr__4963(_4963 ? _4963->raw() : nullptr, _4963 ? _4963->size(0) : 0);
  pi64 -= _4962;
  ::mosek::fusion::Utils::Tools::arraycopy(i64,pi64,_4963,_4964,_4962);
}
void mosek::fusion::WorkStack :: popi32(int _4965,std::shared_ptr< monty::ndarray< int,1 > > _4966,int _4967) { mosek::fusion::p_WorkStack::_get_impl(this)->popi32(_4965,_4966,_4967); }void mosek::fusion::p_WorkStack::popi32(int _4965,std::shared_ptr< monty::ndarray< int,1 > > _4966,int _4967){
  _checked_ptr_1<int> _ptr__4966(_4966 ? _4966->raw() : nullptr, _4966 ? _4966->size(0) : 0);
  pi32 -= _4965;
  ::mosek::fusion::Utils::Tools::arraycopy(i32,pi32,_4966,_4967,_4965);
}
double mosek::fusion::WorkStack :: popf64() { return mosek::fusion::p_WorkStack::_get_impl(this)->popf64(); }double mosek::fusion::p_WorkStack::popf64(){
  -- pf64;
  return ((*f64)(pf64));
}
long long mosek::fusion::WorkStack :: popi64() { return mosek::fusion::p_WorkStack::_get_impl(this)->popi64(); }long long mosek::fusion::p_WorkStack::popi64(){
  -- pi64;
  return ((*i64)(pi64));
}
int mosek::fusion::WorkStack :: popi32() { return mosek::fusion::p_WorkStack::_get_impl(this)->popi32(); }int mosek::fusion::p_WorkStack::popi32(){
  -- pi32;
  return ((*i32)(pi32));
}
double mosek::fusion::WorkStack :: peekf64() { return mosek::fusion::p_WorkStack::_get_impl(this)->peekf64(); }double mosek::fusion::p_WorkStack::peekf64(){
  return ((*f64)((pf64 - (int)1)));
}
long long mosek::fusion::WorkStack :: peeki64() { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki64(); }long long mosek::fusion::p_WorkStack::peeki64(){
  return ((*i64)((pi64 - (int)1)));
}
int mosek::fusion::WorkStack :: peeki32() { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki32(); }int mosek::fusion::p_WorkStack::peeki32(){
  return ((*i32)((pi32 - (int)1)));
}
double mosek::fusion::WorkStack :: peekf64(int _4968) { return mosek::fusion::p_WorkStack::_get_impl(this)->peekf64(_4968); }double mosek::fusion::p_WorkStack::peekf64(int _4968){
  return ((*f64)(((pf64 - _4968) - (int)1)));
}
long long mosek::fusion::WorkStack :: peeki64(int _4969) { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki64(_4969); }long long mosek::fusion::p_WorkStack::peeki64(int _4969){
  return ((*i64)(((pi64 - _4969) - (int)1)));
}
int mosek::fusion::WorkStack :: peeki32(int _4970) { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki32(_4970); }int mosek::fusion::p_WorkStack::peeki32(int _4970){
  return ((*i32)(((pi32 - _4970) - (int)1)));
}
void mosek::fusion::p_WorkStack::destroy(){f64.reset();i64.reset();i32.reset();}void mosek::fusion::WorkStack::destroy() { mosek::fusion::p_WorkStack::_get_impl(this)->destroy(); }mosek::fusion::SymmetricExpr::SymmetricExpr(mosek::fusion::p_SymmetricExpr *_impl) : _impl(_impl) { /*std::cout << "SymmetricExpr() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SymmetricExpr::~SymmetricExpr() { delete _impl; _impl = nullptr; }mosek::fusion::p_SymmetricExpr::p_SymmetricExpr  (::mosek::fusion::SymmetricExpr * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::SymmetricExpr::t mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr  (int _4971,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4972,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4973,    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4974){ return new mosek::fusion::SymmetricExpr(_4971,_4972,_4973,_4974); }mosek::fusion::SymmetricExpr::SymmetricExpr  (int _4971,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4972,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4973,    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4974) :    SymmetricExpr(new mosek::fusion::p_SymmetricExpr(this)){ mosek::fusion::p_SymmetricExpr::_get_impl(this)->_initialize(_4971,_4972,_4973,_4974); }void mosek::fusion::p_SymmetricExpr::_initialize  (int _4971,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4972,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4973,    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4974){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->n = _4971;
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->Ms = _4972;
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->xs = _4973;
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->b = _4974;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mosek::fusion::p_SymmetricExpr::add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4975,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4976){
  if ((mosek::fusion::p_SymmetricExpr::_get_impl(_4975)->n != _4976->getdim()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Dimension does not match"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9176;
  bool _9177 = (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4975)->b.get());
  if (_9177)
  {
    _9176 = mosek::fusion::p_SymmetricExpr::_get_impl(_4975)->b->__mosek_2fusion_2SymmetricMatrix__add(_4976);
  }
  else
  {
    _9176 = _4976;
  }
  return ::mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr(mosek::fusion::p_SymmetricExpr::_get_impl(_4975)->n,mosek::fusion::p_SymmetricExpr::_get_impl(_4975)->Ms,mosek::fusion::p_SymmetricExpr::_get_impl(_4975)->xs,_9176);
}
monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mosek::fusion::p_SymmetricExpr::mul(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4977,double _4978){
  std::vector<monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >> _9178;
  for (int _4979 = (int)0, _9179 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4977)->Ms)->size(0)); _4979 < _9179 ; ++_4979)
  {
    _9178.push_back(((*mosek::fusion::p_SymmetricExpr::_get_impl(_4977)->Ms)(_4979))->__mosek_2fusion_2SymmetricMatrix__mul(_4978));
  }
  auto _9180 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 >(monty::shape(_9178.size()),_9178.begin(),_9178.end()));
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9181;
  bool _9182 = (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4977)->b.get());
  if (_9182)
  {
    _9181 = mosek::fusion::p_SymmetricExpr::_get_impl(_4977)->b->__mosek_2fusion_2SymmetricMatrix__mul(_4978);
  }
  else
  {
    _9181 = nullptr;
  }
  return ::mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr(mosek::fusion::p_SymmetricExpr::_get_impl(_4977)->n,_9180,mosek::fusion::p_SymmetricExpr::_get_impl(_4977)->xs,_9181);
}
monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mosek::fusion::p_SymmetricExpr::add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4980,monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4981){
  if ((mosek::fusion::p_SymmetricExpr::_get_impl(_4980)->n != mosek::fusion::p_SymmetricExpr::_get_impl(_4981)->n))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions of operands"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4982 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 >(monty::shape(safe_add( (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4980)->Ms)->size(0)),(int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4981)->Ms)->size(0)) ))));
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4983 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(safe_add( (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4980)->xs)->size(0)),(int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4981)->xs)->size(0)) ))));
  int _4984 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4980)->Ms)->size(0));
  int _9183 = (int)0;
  int _9184 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4980)->Ms)->size(0));
  for (int _4985 = _9183; _4985 < _9184; ++_4985)
  {
    {
      ((*_4982)(_4985)) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_4980)->Ms)(_4985));
    }
  }
  int _9185 = (int)0;
  int _9186 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4981)->Ms)->size(0));
  for (int _4986 = _9185; _4986 < _9186; ++_4986)
  {
    {
      ((*_4982)(safe_add( _4986,_4984 ))) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_4981)->Ms)(_4986));
    }
  }
  int _4987 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4980)->xs)->size(0));
  int _9187 = (int)0;
  int _9188 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4980)->xs)->size(0));
  for (int _4988 = _9187; _4988 < _9188; ++_4988)
  {
    {
      ((*_4983)(_4988)) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_4980)->xs)(_4988));
    }
  }
  int _9189 = (int)0;
  int _9190 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4981)->xs)->size(0));
  for (int _4989 = _9189; _4989 < _9190; ++_4989)
  {
    {
      ((*_4983)(safe_add( _4989,_4987 ))) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_4981)->xs)(_4989));
    }
  }
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9191;
  bool _9192 = ((NULL == mosek::fusion::p_SymmetricExpr::_get_impl(_4980)->b.get()) && (NULL == mosek::fusion::p_SymmetricExpr::_get_impl(_4981)->b.get()));
  if (_9192)
  {
    _9191 = nullptr;
  }
  else
  {
    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9193;
    bool _9194 = ((NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4980)->b.get()) && (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4981)->b.get()));
    if (_9194)
    {
      _9193 = mosek::fusion::p_SymmetricExpr::_get_impl(_4980)->b->__mosek_2fusion_2SymmetricMatrix__add(mosek::fusion::p_SymmetricExpr::_get_impl(_4981)->b);
    }
    else
    {
      monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9195;
      bool _9196 = (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4980)->b.get());
      if (_9196)
      {
        _9195 = mosek::fusion::p_SymmetricExpr::_get_impl(_4980)->b;
      }
      else
      {
        _9195 = mosek::fusion::p_SymmetricExpr::_get_impl(_4981)->b;
      }
      _9193 = _9195;
    }
    _9191 = _9193;
  }
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4990 = _9191;
  return ::mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr(mosek::fusion::p_SymmetricExpr::_get_impl(_4980)->n,_4982,_4983,_4990);
}
std::string mosek::fusion::SymmetricExpr :: toString() { return mosek::fusion::p_SymmetricExpr::_get_impl(this)->toString(); }std::string mosek::fusion::p_SymmetricExpr::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _4991 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _4991->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("SymmetricExpr( ("))->__mosek_2fusion_2Utils_2StringBuffer__a(n)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(n)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") )"));
  return _4991->toString();
}
void mosek::fusion::p_SymmetricExpr::destroy(){xs.reset();b.reset();Ms.reset();}void mosek::fusion::SymmetricExpr::destroy() { mosek::fusion::p_SymmetricExpr::_get_impl(this)->destroy(); }mosek::fusion::Expr::Expr(mosek::fusion::p_Expr *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "Expr()" << this << std::endl; */ }mosek::fusion::Expr::~Expr() {  /* std::cout << "~Expr()" << this << std::endl << std::flush; */ }mosek::fusion::p_Expr::p_Expr  (::mosek::fusion::Expr * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::Expr::t mosek::fusion::p_Expr::_new_Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _4992,    std::shared_ptr< monty::ndarray< long long,1 > > _4993,    std::shared_ptr< monty::ndarray< double,1 > > _4994,    std::shared_ptr< monty::ndarray< double,1 > > _4995,    std::shared_ptr< monty::ndarray< int,1 > > _4996,    std::shared_ptr< monty::ndarray< long long,1 > > _4997){ return new mosek::fusion::Expr(_4992,_4993,_4994,_4995,_4996,_4997); }mosek::fusion::Expr::Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _4992,    std::shared_ptr< monty::ndarray< long long,1 > > _4993,    std::shared_ptr< monty::ndarray< double,1 > > _4994,    std::shared_ptr< monty::ndarray< double,1 > > _4995,    std::shared_ptr< monty::ndarray< int,1 > > _4996,    std::shared_ptr< monty::ndarray< long long,1 > > _4997) :    Expr(new mosek::fusion::p_Expr(this)){ mosek::fusion::p_Expr::_get_impl(this)->_initialize(_4992,_4993,_4994,_4995,_4996,_4997); }void mosek::fusion::p_Expr::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _4992,    std::shared_ptr< monty::ndarray< long long,1 > > _4993,    std::shared_ptr< monty::ndarray< double,1 > > _4994,    std::shared_ptr< monty::ndarray< double,1 > > _4995,    std::shared_ptr< monty::ndarray< int,1 > > _4996,    std::shared_ptr< monty::ndarray< long long,1 > > _4997){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__4992(_4992 ? _4992->raw() : nullptr, _4992 ? _4992->size(0) : 0);
    _checked_ptr_1<long long> _ptr__4993(_4993 ? _4993->raw() : nullptr, _4993 ? _4993->size(0) : 0);
    _checked_ptr_1<double> _ptr__4994(_4994 ? _4994->raw() : nullptr, _4994 ? _4994->size(0) : 0);
    _checked_ptr_1<double> _ptr__4995(_4995 ? _4995->raw() : nullptr, _4995 ? _4995->size(0) : 0);
    _checked_ptr_1<int> _ptr__4996(_4996 ? _4996->raw() : nullptr, _4996 ? _4996->size(0) : 0);
    _checked_ptr_1<long long> _ptr__4997(_4997 ? _4997->raw() : nullptr, _4997 ? _4997->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _9197;
    bool _9198 = (NULL != _4996.get());
    if (_9198)
    {
      _9197 = ::mosek::fusion::Utils::Tools::arraycopy(_4996);
    }
    else
    {
      _9197 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((int)((_4992)->size(0)) - (int)1))});
    }
    std::shared_ptr< monty::ndarray< long long,1 > > _9199;
    bool _9200 = (NULL != _4997.get());
    if (_9200)
    {
      _9199 = ::mosek::fusion::Utils::Tools::arraycopy(_4997);
    }
    else
    {
      _9199 = nullptr;
    }
    mosek::fusion::p_Expr::_initialize(::mosek::fusion::Utils::Tools::arraycopy(_4992),::mosek::fusion::Utils::Tools::arraycopy(_4993),::mosek::fusion::Utils::Tools::arraycopy(_4994),::mosek::fusion::Utils::Tools::arraycopy(_4995),_9197,_9199,(int)1);
    int _4998 = ((int)((_4992)->size(0)) - (int)1);
    if ((_4998 < (int)0))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid ptrb"));
      }
    }
    {}
    long long _4999 = _ptr__4992[_4998];
    if (((_4999 < (int)0) || ((_4999 != (int)((_4994)->size(0))) || (_4999 != (int)((_4993)->size(0))))))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid ptrb construction"));
      }
    }
    {}
    bool _5000 = true;
    bool _5001 = true;
    bool _5002 = true;
    std::shared_ptr< monty::ndarray< int,1 > > _5003 = mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->shape;
    _checked_ptr_1<int> _ptr__5003(_5003 ? _5003->raw() : nullptr,_5003 ? _5003->size(0) : 0);
    long long _5004 = ::mosek::fusion::p_Set::size(_5003);
    {
      int _9201 = (int)0;
      int _9202 = (int)((_5003)->size(0));
      for (int _5005 = _9201; _5005 < _9202; ++_5005)
      {
        {
          _5001 = (_5001 && (_ptr__5003[_5005] >= (int)0));
        }
      }
      int _9203 = (int)0;
      int _9204 = _4998;
      for (int _5006 = _9203; _5006 < _9204; ++_5006)
      {
        {
          _5000 = (_5000 && (_ptr__4992[_5006] <= _ptr__4992[safe_add( _5006,(int)1 )]));
        }
      }
      if (((NULL != _4997.get()) && ((int)((_4997)->size(0)) > (int)0)))
      {
        {
          _5002 = ((_ptr__4997[(int)0] >= (int)0) && (_ptr__4997[(_4998 - (int)1)] < _5004));
          int _9205 = (int)0;
          int _9206 = (_4998 - (int)1);
          for (int _5007 = _9205; _5007 < _9206; ++_5007)
          {
            {
              _5002 = (_5002 && (_ptr__4997[_5007] < _ptr__4997[safe_add( _5007,(int)1 )]));
            }
          }
        }
      }
      {}
    }
    if ((!_5001))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid shape"));
      }
    }
    {}
    if ((!_5000))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid ptrb"));
      }
    }
    {}
    if ((!_5002))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid sparsity pattern"));
      }
    }
    {}
  }
}mosek::fusion::Expr::t mosek::fusion::p_Expr::_new_Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _5008,    std::shared_ptr< monty::ndarray< long long,1 > > _5009,    std::shared_ptr< monty::ndarray< double,1 > > _5010,    std::shared_ptr< monty::ndarray< double,1 > > _5011,    std::shared_ptr< monty::ndarray< int,1 > > _5012,    std::shared_ptr< monty::ndarray< long long,1 > > _5013,    int _5014){ return new mosek::fusion::Expr(_5008,_5009,_5010,_5011,_5012,_5013,_5014); }mosek::fusion::Expr::Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _5008,    std::shared_ptr< monty::ndarray< long long,1 > > _5009,    std::shared_ptr< monty::ndarray< double,1 > > _5010,    std::shared_ptr< monty::ndarray< double,1 > > _5011,    std::shared_ptr< monty::ndarray< int,1 > > _5012,    std::shared_ptr< monty::ndarray< long long,1 > > _5013,    int _5014) :    Expr(new mosek::fusion::p_Expr(this)){ mosek::fusion::p_Expr::_get_impl(this)->_initialize(_5008,_5009,_5010,_5011,_5012,_5013,_5014); }void mosek::fusion::p_Expr::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _5008,    std::shared_ptr< monty::ndarray< long long,1 > > _5009,    std::shared_ptr< monty::ndarray< double,1 > > _5010,    std::shared_ptr< monty::ndarray< double,1 > > _5011,    std::shared_ptr< monty::ndarray< int,1 > > _5012,    std::shared_ptr< monty::ndarray< long long,1 > > _5013,    int _5014){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__5008(_5008 ? _5008->raw() : nullptr, _5008 ? _5008->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5009(_5009 ? _5009->raw() : nullptr, _5009 ? _5009->size(0) : 0);
    _checked_ptr_1<double> _ptr__5010(_5010 ? _5010->raw() : nullptr, _5010 ? _5010->size(0) : 0);
    _checked_ptr_1<double> _ptr__5011(_5011 ? _5011->raw() : nullptr, _5011 ? _5011->size(0) : 0);
    _checked_ptr_1<int> _ptr__5012(_5012 ? _5012->raw() : nullptr, _5012 ? _5012->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5013(_5013 ? _5013->raw() : nullptr, _5013 ? _5013->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_5012);
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->shape = _5012;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->ptrb = _5008;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->subj = _5009;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->cof_v = _5010;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->bfix = _5011;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->inst = _5013;
    if ((NULL == mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->shape.get()))
    {
      {
        throw ::mosek::fusion::UnexpectedError(std::string ("Internal: NULL shape"));
      }
    }
    {}
  }
}mosek::fusion::Expr::t mosek::fusion::p_Expr::_new_Expr  (monty::rc_ptr< ::mosek::fusion::Expression > _5015){ return new mosek::fusion::Expr(_5015); }mosek::fusion::Expr::Expr  (monty::rc_ptr< ::mosek::fusion::Expression > _5015) :    Expr(new mosek::fusion::p_Expr(this)){ mosek::fusion::p_Expr::_get_impl(this)->_initialize(_5015); }void mosek::fusion::p_Expr::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _5015){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_5015->getShape());
    monty::rc_ptr< ::mosek::fusion::Expression > _9207 = _5015;
    if (false) {}
    else if (nullptr != dynamic_cast<::mosek::fusion::Expr*>(_9207.get()))
    {
      ::mosek::fusion::Expr::t _5016 (dynamic_cast<::mosek::fusion::Expr*>(_9207.get()));
      {
        shape = mosek::fusion::p_Expr::_get_impl(_5016)->shape;
        ptrb = mosek::fusion::p_Expr::_get_impl(_5016)->ptrb;
        subj = mosek::fusion::p_Expr::_get_impl(_5016)->subj;
        cof_v = mosek::fusion::p_Expr::_get_impl(_5016)->cof_v;
        bfix = mosek::fusion::p_Expr::_get_impl(_5016)->bfix;
        inst = mosek::fusion::p_Expr::_get_impl(_5016)->inst;
      }
    }
    else
    {
      mosek::fusion::Expression::t _5017 = _9207;
      {
        monty::rc_ptr< ::mosek::fusion::WorkStack > _5018 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
        monty::rc_ptr< ::mosek::fusion::WorkStack > _5019 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
        monty::rc_ptr< ::mosek::fusion::WorkStack > _5020 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
        _5017->eval(_5020,_5019,_5018);
        int _5021 = _5020->popi32();
        int _5022 = _5020->popi32(_5021);
        int _5023 = _5020->popi32();
        int _5024 = _5020->popi32();
        bool _5025 = (_5020->popi32() != (int)0);
        int _5026 = _5020->popi32(safe_add( _5023,(int)1 ));
        int _9208;
        bool _9209 = _5025;
        if (_9209)
        {
          _9208 = _5020->popi64(_5023);
        }
        else
        {
          _9208 = (int)0;
        }
        int _5027 = _9208;
        int _5028 = _5020->popi64(_5024);
        int _5029 = _5020->popf64(_5023);
        int _5030 = _5020->popf64(_5024);
        std::shared_ptr< monty::ndarray< int,1 > > _5031 = mosek::fusion::p_WorkStack::_get_impl(_5020)->i32;
        _checked_ptr_1<int> _ptr__5031(_5031 ? _5031->raw() : nullptr,_5031 ? _5031->size(0) : 0);
        std::shared_ptr< monty::ndarray< long long,1 > > _5032 = mosek::fusion::p_WorkStack::_get_impl(_5020)->i64;
        _checked_ptr_1<long long> _ptr__5032(_5032 ? _5032->raw() : nullptr,_5032 ? _5032->size(0) : 0);
        std::shared_ptr< monty::ndarray< double,1 > > _5033 = mosek::fusion::p_WorkStack::_get_impl(_5020)->f64;
        _checked_ptr_1<double> _ptr__5033(_5033 ? _5033->raw() : nullptr,_5033 ? _5033->size(0) : 0);
        std::vector<int> _9210;
        for (int _5034 = (int)0, _9211 = _5021; _5034 < _9211 ; ++_5034)
        {
          _9210.push_back(_ptr__5031[safe_add( _5022,_5034 )]);
        }
        auto _9212 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9210.size()),_9210.begin(),_9210.end()));
        shape = _9212;
        std::vector<long long> _9213;
        for (int _5035 = (int)0, _9214 = safe_add( _5023,(int)1 ); _5035 < _9214 ; ++_5035)
        {
          _9213.push_back(_ptr__5031[safe_add( _5026,_5035 )]);
        }
        auto _9215 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9213.size()),_9213.begin(),_9213.end()));
        ptrb = _9215;
        std::vector<long long> _9216;
        for (int _5036 = (int)0, _9217 = _5024; _5036 < _9217 ; ++_5036)
        {
          _9216.push_back(_ptr__5032[safe_add( _5028,_5036 )]);
        }
        auto _9218 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9216.size()),_9216.begin(),_9216.end()));
        subj = _9218;
        std::vector<double> _9219;
        for (int _5037 = (int)0, _9220 = _5024; _5037 < _9220 ; ++_5037)
        {
          _9219.push_back(_ptr__5033[safe_add( _5030,_5037 )]);
        }
        auto _9221 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9219.size()),_9219.begin(),_9219.end()));
        cof_v = _9221;
        std::vector<double> _9222;
        for (int _5038 = (int)0, _9223 = _5024; _5038 < _9223 ; ++_5038)
        {
          _9222.push_back(_ptr__5033[safe_add( _5029,_5038 )]);
        }
        auto _9224 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9222.size()),_9222.begin(),_9222.end()));
        bfix = _9224;
        std::shared_ptr< monty::ndarray< long long,1 > > _9225;
        bool _9226 = _5025;
        if (_9226)
        {
          std::vector<long long> _9227;
          for (int _5039 = (int)0, _9228 = _5024; _5039 < _9228 ; ++_5039)
          {
            _9227.push_back(_ptr__5032[safe_add( _5027,_5039 )]);
          }
          auto _9229 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9227.size()),_9227.begin(),_9227.end()));
          _9225 = _9229;
        }
        else
        {
          _9225 = nullptr;
        }
        inst = _9225;
      }
    }
    if ((NULL == shape.get()))
    {
      {
        throw ::mosek::fusion::UnexpectedError(std::string ("Internal: NULL shape"));
      }
    }
    {}
  }
}long long mosek::fusion::p_Expr::prod(std::shared_ptr< monty::ndarray< int,1 > > _5040){
  _checked_ptr_1<int> _ptr__5040(_5040 ? _5040->raw() : nullptr, _5040 ? _5040->size(0) : 0);
  int _5041 = (int)1;
  int _9230 = (int)0;
  int _9231 = (int)((_5040)->size(0));
  for (int _5042 = _9230; _5042 < _9231; ++_5042)
  {
    {
      _5041 *= _ptr__5040[_5042];
    }
  }
  return _5041;
}
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > mosek::fusion::p_Expr::varstack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _5043){
  std::vector<monty::rc_ptr< ::mosek::fusion::Variable >> _9232;
  for (int _5044 = (int)0, _9233 = (int)((_5043)->size(0)); _5044 < _9233 ; ++_5044)
  {
    for (int _5045 = (int)0, _9234 = (int)((((*_5043)(_5044)))->size(0)); _5045 < _9234 ; ++_5045)
    {
      _9232.push_back(((*((*_5043)(_5044)))(_5045)));
    }
  }
  auto _9235 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(_9232.size()),_9232.begin(),_9232.end()));
  return _9235;
}
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > mosek::fusion::p_Expr::varstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5046,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5047){
  if ((NULL == _5046.get()))
  {
    {
      return _5047;
    }
  }
  else if((NULL == _5047.get()))
  {
    {
      return _5046;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5048 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(safe_add( (int)((_5046)->size(0)),(int)((_5047)->size(0)) ))));
      int _9236 = (int)0;
      int _9237 = (int)((_5046)->size(0));
      for (int _5049 = _9236; _5049 < _9237; ++_5049)
      {
        {
          ((*_5048)(_5049)) = ((*_5046)(_5049));
        }
      }
      int _9238 = (int)0;
      int _9239 = (int)((_5047)->size(0));
      for (int _5050 = _9238; _5050 < _9239; ++_5050)
      {
        {
          ((*_5048)(safe_add( _5050,(int)((_5046)->size(0)) ))) = ((*_5047)(_5050));
        }
      }
      return _5048;
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::condense  ( monty::rc_ptr< ::mosek::fusion::Expression > _5051) { return mosek::fusion::p_Expr::condense(_5051); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::condense(monty::rc_ptr< ::mosek::fusion::Expression > _5051){
  return (::mosek::fusion::p_ExprCondense::_new_ExprCondense(_5051)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::flatten  ( monty::rc_ptr< ::mosek::fusion::Expression > _5052) { return mosek::fusion::p_Expr::flatten(_5052); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::flatten(monty::rc_ptr< ::mosek::fusion::Expression > _5052){
  if ((NULL == _5052.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for flatten may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::reshape(_5052,(int)_5052->getSize());
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::reshape  ( monty::rc_ptr< ::mosek::fusion::Expression > _5053,    int _5054,    int _5055) { return mosek::fusion::p_Expr::reshape(_5053,_5054,_5055); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::reshape(monty::rc_ptr< ::mosek::fusion::Expression > _5053,int _5054,int _5055){
  if ((NULL == _5053.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for reshape may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::reshape(_5053,::mosek::fusion::p_Set::make(_5054,_5055));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::reshape  ( monty::rc_ptr< ::mosek::fusion::Expression > _5056,    int _5057) { return mosek::fusion::p_Expr::reshape(_5056,_5057); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::reshape(monty::rc_ptr< ::mosek::fusion::Expression > _5056,int _5057){
  if ((NULL == _5056.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for reshape may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::reshape(_5056,::mosek::fusion::p_Set::make(_5057));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::reshape  ( monty::rc_ptr< ::mosek::fusion::Expression > _5058,    std::shared_ptr< monty::ndarray< int,1 > > _5059) { return mosek::fusion::p_Expr::reshape(_5058,_5059); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::reshape(monty::rc_ptr< ::mosek::fusion::Expression > _5058,std::shared_ptr< monty::ndarray< int,1 > > _5059){
  _checked_ptr_1<int> _ptr__5059(_5059 ? _5059->raw() : nullptr, _5059 ? _5059->size(0) : 0);
  return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5059,_5058)).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::Expr :: size() { return mosek::fusion::p_Expr::_get_impl(this)->size(); }long long mosek::fusion::p_Expr::size(){
  return ((long long)((ptrb)->size(0)) - (int)1);
}
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::Expr :: __mosek_2fusion_2Expr__eval() { return mosek::fusion::p_Expr::_get_impl(this)->__mosek_2fusion_2Expr__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::Expr::eval() { return __mosek_2fusion_2Expr__eval(); }
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::Expr::__mosek_2fusion_2BaseExpression__eval() { return __mosek_2fusion_2Expr__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::p_Expr::__mosek_2fusion_2Expr__eval(){
  std::shared_ptr< monty::ndarray< double,1 > > _9240;
  bool _9241 = (NULL == bfix.get());
  if (_9241)
  {
    _9240 = nullptr;
  }
  else
  {
    _9240 = ::mosek::fusion::Utils::Tools::arraycopy(bfix);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _5060 = _9240;
  _checked_ptr_1<double> _ptr__5060(_5060 ? _5060->raw() : nullptr,_5060 ? _5060->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _9242;
  bool _9243 = (NULL == inst.get());
  if (_9243)
  {
    _9242 = nullptr;
  }
  else
  {
    _9242 = ::mosek::fusion::Utils::Tools::arraycopy(inst);
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _5061 = _9242;
  _checked_ptr_1<long long> _ptr__5061(_5061 ? _5061->raw() : nullptr,_5061 ? _5061->size(0) : 0);
  return ::mosek::fusion::p_FlatExpr::_new_FlatExpr(_5060,::mosek::fusion::Utils::Tools::arraycopy(ptrb),::mosek::fusion::Utils::Tools::arraycopy(subj),::mosek::fusion::Utils::Tools::arraycopy(cof_v),shape,inst);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::zeros  ( std::shared_ptr< monty::ndarray< int,1 > > _5062) { return mosek::fusion::p_Expr::zeros(_5062); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::zeros(std::shared_ptr< monty::ndarray< int,1 > > _5062){
  _checked_ptr_1<int> _ptr__5062(_5062 ? _5062->raw() : nullptr, _5062 ? _5062->size(0) : 0);
  return ::mosek::fusion::p_Expr::constTerm(_5062,(double)((int)0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::zeros  ( int _5063) { return mosek::fusion::p_Expr::zeros(_5063); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::zeros(int _5063){
  return ::mosek::fusion::p_Expr::constTerm(_5063,(double)((int)0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( ) { return mosek::fusion::p_Expr::ones(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(){
  return ::mosek::fusion::p_Expr::constTerm((double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( std::shared_ptr< monty::ndarray< int,1 > > _5064,    std::shared_ptr< monty::ndarray< int,2 > > _5065) { return mosek::fusion::p_Expr::ones(_5064,_5065); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(std::shared_ptr< monty::ndarray< int,1 > > _5064,std::shared_ptr< monty::ndarray< int,2 > > _5065){
  _checked_ptr_1<int> _ptr__5064(_5064 ? _5064->raw() : nullptr, _5064 ? _5064->size(0) : 0);
  return ::mosek::fusion::p_Expr::constTerm(_5064,_5065,(double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( std::shared_ptr< monty::ndarray< int,1 > > _5066) { return mosek::fusion::p_Expr::ones(_5066); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(std::shared_ptr< monty::ndarray< int,1 > > _5066){
  _checked_ptr_1<int> _ptr__5066(_5066 ? _5066->raw() : nullptr, _5066 ? _5066->size(0) : 0);
  return ::mosek::fusion::p_Expr::constTerm(_5066,(double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( int _5067) { return mosek::fusion::p_Expr::ones(_5067); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(int _5067){
  return ::mosek::fusion::p_Expr::constTerm(_5067,(double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5068) { return mosek::fusion::p_Expr::constTerm(_5068); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5068){
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(mosek::fusion::p_NDSparseArray::_get_impl(_5068)->dims,mosek::fusion::p_NDSparseArray::_get_impl(_5068)->inst,mosek::fusion::p_NDSparseArray::_get_impl(_5068)->cof)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5069) { return mosek::fusion::p_Expr::constTerm(_5069); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(monty::rc_ptr< ::mosek::fusion::Matrix > _5069){
  int _5070 = _5069->numRows();
  int _5071 = _5069->numColumns();
  std::shared_ptr< monty::ndarray< int,1 > > _5072 = ::mosek::fusion::p_Set::make(_5070,_5071);
  _checked_ptr_1<int> _ptr__5072(_5072 ? _5072->raw() : nullptr,_5072 ? _5072->size(0) : 0);
  if (_5069->isSparse())
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _5073 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5069->numNonzeros())));
      _checked_ptr_1<double> _ptr__5073(_5073 ? _5073->raw() : nullptr,_5073 ? _5073->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5074 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5069->numNonzeros())));
      _checked_ptr_1<int> _ptr__5074(_5074 ? _5074->raw() : nullptr,_5074 ? _5074->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5075 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5069->numNonzeros())));
      _checked_ptr_1<int> _ptr__5075(_5075 ? _5075->raw() : nullptr,_5075 ? _5075->size(0) : 0);
      _5069->getDataAsTriplets(_5075,_5074,_5073);
      std::vector<long long> _9244;
      for (int _5077 = (int)0, _9245 = (int)((_5074)->size(0)); _5077 < _9245 ; ++_5077)
      {
        _9244.push_back(safe_add( safe_mul( _ptr__5075[_5077],_5071 ),_ptr__5074[_5077] ));
      }
      auto _9246 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9244.size()),_9244.begin(),_9244.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _5076 = _9246;
      _checked_ptr_1<long long> _ptr__5076(_5076 ? _5076->raw() : nullptr,_5076 ? _5076->size(0) : 0);
      return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5072,_5076,_5073)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5072,nullptr,_5069->getDataAsArray())).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( double _5078) { return mosek::fusion::p_Expr::constTerm(_5078); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(double _5078){
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),nullptr,_5078)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< int,1 > > _5079,    std::shared_ptr< monty::ndarray< int,2 > > _5080,    double _5081) { return mosek::fusion::p_Expr::constTerm(_5079,_5080,_5081); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5079,std::shared_ptr< monty::ndarray< int,2 > > _5080,double _5081){
  _checked_ptr_1<int> _ptr__5079(_5079 ? _5079->raw() : nullptr, _5079 ? _5079->size(0) : 0);
  int _5082 = (int)((_5080)->size(0));
  int _5083 = (int)((_5079)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _5084 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5082)));
  _checked_ptr_1<long long> _ptr__5084(_5084 ? _5084->raw() : nullptr,_5084 ? _5084->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5085 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5083)));
  _checked_ptr_1<long long> _ptr__5085(_5085 ? _5085->raw() : nullptr,_5085 ? _5085->size(0) : 0);
  _ptr__5085[(_5083 - (int)1)] = (int)1;
  int _9247 = (int)1;
  int _9248 = _5083;
  for (int _5086 = _9247; _5086 < _9248; ++_5086)
  {
    {
      _ptr__5085[((_5083 - _5086) - (int)1)] = safe_mul( _ptr__5085[(_5083 - _5086)],_ptr__5079[(_5083 - _5086)] );
    }
  }
  int _9249 = (int)0;
  int _9250 = _5082;
  for (int _5087 = _9249; _5087 < _9250; ++_5087)
  {
    {
      int _9251 = (int)0;
      int _9252 = _5083;
      for (int _5088 = _9251; _5088 < _9252; ++_5088)
      {
        {
          _ptr__5084[_5087] += safe_mul( _ptr__5085[_5088],((*_5080)(_5087,_5088)) );
        }
      }
    }
  }
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5079,_5084,_5081)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< int,1 > > _5089,    std::shared_ptr< monty::ndarray< int,2 > > _5090,    std::shared_ptr< monty::ndarray< double,1 > > _5091) { return mosek::fusion::p_Expr::constTerm(_5089,_5090,_5091); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5089,std::shared_ptr< monty::ndarray< int,2 > > _5090,std::shared_ptr< monty::ndarray< double,1 > > _5091){
  _checked_ptr_1<int> _ptr__5089(_5089 ? _5089->raw() : nullptr, _5089 ? _5089->size(0) : 0);
  _checked_ptr_1<double> _ptr__5091(_5091 ? _5091->raw() : nullptr, _5091 ? _5091->size(0) : 0);
  int _5092 = (int)((_5090)->size(0));
  int _5093 = (int)((_5089)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _5094 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5092)));
  _checked_ptr_1<long long> _ptr__5094(_5094 ? _5094->raw() : nullptr,_5094 ? _5094->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5095 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5093)));
  _checked_ptr_1<long long> _ptr__5095(_5095 ? _5095->raw() : nullptr,_5095 ? _5095->size(0) : 0);
  _ptr__5095[(_5093 - (int)1)] = (int)1;
  int _9253 = (int)1;
  int _9254 = _5093;
  for (int _5096 = _9253; _5096 < _9254; ++_5096)
  {
    {
      _ptr__5095[((_5093 - _5096) - (int)1)] = safe_mul( _ptr__5095[(_5093 - _5096)],_ptr__5089[(_5093 - _5096)] );
    }
  }
  int _9255 = (int)0;
  int _9256 = _5092;
  for (int _5097 = _9255; _5097 < _9256; ++_5097)
  {
    {
      int _9257 = (int)0;
      int _9258 = _5093;
      for (int _5098 = _9257; _5098 < _9258; ++_5098)
      {
        {
          _ptr__5094[_5097] += safe_mul( _ptr__5095[_5098],((*_5090)(_5097,_5098)) );
        }
      }
    }
  }
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5089,_5094,_5091)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< int,1 > > _5099,    double _5100) { return mosek::fusion::p_Expr::constTerm(_5099,_5100); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5099,double _5100){
  _checked_ptr_1<int> _ptr__5099(_5099 ? _5099->raw() : nullptr, _5099 ? _5099->size(0) : 0);
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5099,nullptr,_5100)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( int _5101,    double _5102) { return mosek::fusion::p_Expr::constTerm(_5101,_5102); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(int _5101,double _5102){
  std::vector<double> _9259;
  for (int _5103 = (int)0, _9260 = _5101; _5103 < _9260 ; ++_5103)
  {
    _9259.push_back(_5102);
  }
  auto _9261 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9259.size()),_9259.begin(),_9259.end()));
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5101)}),nullptr,_9261)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< double,2 > > _5104) { return mosek::fusion::p_Expr::constTerm(_5104); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< double,2 > > _5104){
  std::vector<double> _9262;
  for (int _5105 = (int)0, _9263 = (int)((_5104)->size(0)); _5105 < _9263 ; ++_5105)
  {
    for (int _5106 = (int)0, _9264 = (int)((_5104)->size(1)); _5106 < _9264 ; ++_5106)
    {
      _9262.push_back(((*_5104)(_5105,_5106)));
    }
  }
  auto _9265 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9262.size()),_9262.begin(),_9262.end()));
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5104)->size(0))),(int)((int)((_5104)->size(1)))}),nullptr,_9265)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< double,1 > > _5107) { return mosek::fusion::p_Expr::constTerm(_5107); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< double,1 > > _5107){
  _checked_ptr_1<double> _ptr__5107(_5107 ? _5107->raw() : nullptr, _5107 ? _5107->size(0) : 0);
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5107)->size(0)))}),nullptr,_5107)).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::Expr :: numNonzeros() { return mosek::fusion::p_Expr::_get_impl(this)->numNonzeros(); }long long mosek::fusion::p_Expr::numNonzeros(){
  return (long long)((cof_v)->size(0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sum  ( monty::rc_ptr< ::mosek::fusion::Expression > _5108,    int _5109) { return mosek::fusion::p_Expr::sum(_5108,_5109); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sum(monty::rc_ptr< ::mosek::fusion::Expression > _5108,int _5109){
  return (::mosek::fusion::p_ExprSumReduce::_new_ExprSumReduce(_5109,_5108)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sum  ( monty::rc_ptr< ::mosek::fusion::Expression > _5110) { return mosek::fusion::p_Expr::sum(_5110); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sum(monty::rc_ptr< ::mosek::fusion::Expression > _5110){
  return (::mosek::fusion::p_ExprSumReduce::_new_ExprSumReduce((int)0,::mosek::fusion::p_Expr::flatten(_5110))).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::neg  ( monty::rc_ptr< ::mosek::fusion::Expression > _5111) { return mosek::fusion::p_Expr::neg(_5111); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::neg(monty::rc_ptr< ::mosek::fusion::Expression > _5111){
  return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst((double)((-(int)1)),_5111)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(bool _5112,monty::rc_ptr< ::mosek::fusion::Matrix > _5113,monty::rc_ptr< ::mosek::fusion::Expression > _5114){
  long long _5115 = _5113->numNonzeros();
  int _5116 = _5113->numRows();
  int _5117 = _5113->numColumns();
  std::shared_ptr< monty::ndarray< double,1 > > _5118 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5115)));
  _checked_ptr_1<double> _ptr__5118(_5118 ? _5118->raw() : nullptr,_5118 ? _5118->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5119 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5115)));
  _checked_ptr_1<int> _ptr__5119(_5119 ? _5119->raw() : nullptr,_5119 ? _5119->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5120 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5115)));
  _checked_ptr_1<int> _ptr__5120(_5120 ? _5120->raw() : nullptr,_5120 ? _5120->size(0) : 0);
  _5113->getDataAsTriplets(_5120,_5119,_5118);
  if (_5112)
  {
    {
      return (::mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft(_5116,_5117,_5120,_5119,_5118,_5114)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight(_5116,_5117,_5120,_5119,_5118,_5114)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Variable > _5121,    monty::rc_ptr< ::mosek::fusion::Matrix > _5122) { return mosek::fusion::p_Expr::mulDiag(_5121,_5122); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _5121,monty::rc_ptr< ::mosek::fusion::Matrix > _5122){
  return ::mosek::fusion::p_Expr::mulDiag(false,_5122,_5121->__mosek_2fusion_2Variable__asExpr());
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5123,    monty::rc_ptr< ::mosek::fusion::Variable > _5124) { return mosek::fusion::p_Expr::mulDiag(_5123,_5124); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _5123,monty::rc_ptr< ::mosek::fusion::Variable > _5124){
  return ::mosek::fusion::p_Expr::mulDiag(true,_5123,_5124->__mosek_2fusion_2Variable__asExpr());
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Expression > _5125,    monty::rc_ptr< ::mosek::fusion::Matrix > _5126) { return mosek::fusion::p_Expr::mulDiag(_5125,_5126); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _5125,monty::rc_ptr< ::mosek::fusion::Matrix > _5126){
  return ::mosek::fusion::p_Expr::mulDiag(false,_5126,_5125);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5127,    monty::rc_ptr< ::mosek::fusion::Expression > _5128) { return mosek::fusion::p_Expr::mulDiag(_5127,_5128); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _5127,monty::rc_ptr< ::mosek::fusion::Expression > _5128){
  return ::mosek::fusion::p_Expr::mulDiag(true,_5127,_5128);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Variable > _5129,    std::shared_ptr< monty::ndarray< double,2 > > _5130) { return mosek::fusion::p_Expr::mulDiag(_5129,_5130); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _5129,std::shared_ptr< monty::ndarray< double,2 > > _5130){
  std::vector<int> _9266;
  for (int _5131 = (int)0, _9267 = (int)((_5130)->size(0)); _5131 < _9267 ; ++_5131)
  {
    for (int _5132 = (int)0, _9268 = (int)((_5130)->size(1)); _5132 < _9268 ; ++_5132)
    {
      _9266.push_back(_5131);
    }
  }
  auto _9269 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9266.size()),_9266.begin(),_9266.end()));
  std::vector<int> _9270;
  for (int _5133 = (int)0, _9271 = (int)((_5130)->size(0)); _5133 < _9271 ; ++_5133)
  {
    for (int _5134 = (int)0, _9272 = (int)((_5130)->size(1)); _5134 < _9272 ; ++_5134)
    {
      _9270.push_back(_5134);
    }
  }
  auto _9273 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9270.size()),_9270.begin(),_9270.end()));
  std::vector<double> _9274;
  for (int _5135 = (int)0, _9275 = (int)((_5130)->size(0)); _5135 < _9275 ; ++_5135)
  {
    for (int _5136 = (int)0, _9276 = (int)((_5130)->size(1)); _5136 < _9276 ; ++_5136)
    {
      _9274.push_back(((*_5130)(_5135,_5136)));
    }
  }
  auto _9277 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9274.size()),_9274.begin(),_9274.end()));
  return (::mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight((int)((_5130)->size(0)),(int)((_5130)->size(1)),_9269,_9273,_9277,_5129->__mosek_2fusion_2Variable__asExpr())).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Expression > _5137,    std::shared_ptr< monty::ndarray< double,2 > > _5138) { return mosek::fusion::p_Expr::mulDiag(_5137,_5138); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _5137,std::shared_ptr< monty::ndarray< double,2 > > _5138){
  std::vector<int> _9278;
  for (int _5139 = (int)0, _9279 = (int)((_5138)->size(0)); _5139 < _9279 ; ++_5139)
  {
    for (int _5140 = (int)0, _9280 = (int)((_5138)->size(1)); _5140 < _9280 ; ++_5140)
    {
      _9278.push_back(_5139);
    }
  }
  auto _9281 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9278.size()),_9278.begin(),_9278.end()));
  std::vector<int> _9282;
  for (int _5141 = (int)0, _9283 = (int)((_5138)->size(0)); _5141 < _9283 ; ++_5141)
  {
    for (int _5142 = (int)0, _9284 = (int)((_5138)->size(1)); _5142 < _9284 ; ++_5142)
    {
      _9282.push_back(_5142);
    }
  }
  auto _9285 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9282.size()),_9282.begin(),_9282.end()));
  std::vector<double> _9286;
  for (int _5143 = (int)0, _9287 = (int)((_5138)->size(0)); _5143 < _9287 ; ++_5143)
  {
    for (int _5144 = (int)0, _9288 = (int)((_5138)->size(1)); _5144 < _9288 ; ++_5144)
    {
      _9286.push_back(((*_5138)(_5143,_5144)));
    }
  }
  auto _9289 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9286.size()),_9286.begin(),_9286.end()));
  return (::mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight((int)((_5138)->size(0)),(int)((_5138)->size(1)),_9281,_9285,_9289,_5137)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( std::shared_ptr< monty::ndarray< double,2 > > _5145,    monty::rc_ptr< ::mosek::fusion::Variable > _5146) { return mosek::fusion::p_Expr::mulDiag(_5145,_5146); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _5145,monty::rc_ptr< ::mosek::fusion::Variable > _5146){
  std::vector<int> _9290;
  for (int _5147 = (int)0, _9291 = (int)((_5145)->size(0)); _5147 < _9291 ; ++_5147)
  {
    for (int _5148 = (int)0, _9292 = (int)((_5145)->size(1)); _5148 < _9292 ; ++_5148)
    {
      _9290.push_back(_5147);
    }
  }
  auto _9293 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9290.size()),_9290.begin(),_9290.end()));
  std::vector<int> _9294;
  for (int _5149 = (int)0, _9295 = (int)((_5145)->size(0)); _5149 < _9295 ; ++_5149)
  {
    for (int _5150 = (int)0, _9296 = (int)((_5145)->size(1)); _5150 < _9296 ; ++_5150)
    {
      _9294.push_back(_5150);
    }
  }
  auto _9297 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9294.size()),_9294.begin(),_9294.end()));
  std::vector<double> _9298;
  for (int _5151 = (int)0, _9299 = (int)((_5145)->size(0)); _5151 < _9299 ; ++_5151)
  {
    for (int _5152 = (int)0, _9300 = (int)((_5145)->size(1)); _5152 < _9300 ; ++_5152)
    {
      _9298.push_back(((*_5145)(_5151,_5152)));
    }
  }
  auto _9301 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9298.size()),_9298.begin(),_9298.end()));
  return (::mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft((int)((_5145)->size(0)),(int)((_5145)->size(1)),_9293,_9297,_9301,_5146->__mosek_2fusion_2Variable__asExpr())).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( std::shared_ptr< monty::ndarray< double,2 > > _5153,    monty::rc_ptr< ::mosek::fusion::Expression > _5154) { return mosek::fusion::p_Expr::mulDiag(_5153,_5154); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _5153,monty::rc_ptr< ::mosek::fusion::Expression > _5154){
  std::vector<int> _9302;
  for (int _5155 = (int)0, _9303 = (int)((_5153)->size(0)); _5155 < _9303 ; ++_5155)
  {
    for (int _5156 = (int)0, _9304 = (int)((_5153)->size(1)); _5156 < _9304 ; ++_5156)
    {
      _9302.push_back(_5155);
    }
  }
  auto _9305 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9302.size()),_9302.begin(),_9302.end()));
  std::vector<int> _9306;
  for (int _5157 = (int)0, _9307 = (int)((_5153)->size(0)); _5157 < _9307 ; ++_5157)
  {
    for (int _5158 = (int)0, _9308 = (int)((_5153)->size(1)); _5158 < _9308 ; ++_5158)
    {
      _9306.push_back(_5158);
    }
  }
  auto _9309 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9306.size()),_9306.begin(),_9306.end()));
  std::vector<double> _9310;
  for (int _5159 = (int)0, _9311 = (int)((_5153)->size(0)); _5159 < _9311 ; ++_5159)
  {
    for (int _5160 = (int)0, _9312 = (int)((_5153)->size(1)); _5160 < _9312 ; ++_5160)
    {
      _9310.push_back(((*_5153)(_5159,_5160)));
    }
  }
  auto _9313 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9310.size()),_9310.begin(),_9310.end()));
  return (::mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft((int)((_5153)->size(0)),(int)((_5153)->size(1)),_9305,_9309,_9313,_5154)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm_(monty::rc_ptr< ::mosek::fusion::Matrix > _5161,monty::rc_ptr< ::mosek::fusion::Expression > _5162){
  std::shared_ptr< monty::ndarray< int,1 > > _5163 = _5162->getShape();
  _checked_ptr_1<int> _ptr__5163(_5163 ? _5163->raw() : nullptr,_5163 ? _5163->size(0) : 0);
  monty::rc_ptr< ::mosek::fusion::Expression > _5164 = _5162;
  if (((int)((_5163)->size(0)) == (int)1))
  {
    {
      _5163 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5163[(int)0]),(int)((int)1)});
      _ptr__5163.update(_5163 ? _5163->raw() : nullptr, _5163 ? _5163->size(0) : 0);
      _5164 = (::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5163,_5162)).as<::mosek::fusion::Expression>();
    }
  }
  {}
  if ((((int)((_5163)->size(0)) != (int)2) || ((_5161->numRows() != _ptr__5163[(int)0]) || (_5161->numColumns() != _ptr__5163[(int)1]))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Dimensions of operands do not match"));
    }
  }
  {}
  int _5165 = _5161->numColumns();
  long long _5166 = _5161->numNonzeros();
  std::shared_ptr< monty::ndarray< int,1 > > _5167 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5166)));
  _checked_ptr_1<int> _ptr__5167(_5167 ? _5167->raw() : nullptr,_5167 ? _5167->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5168 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5166)));
  _checked_ptr_1<int> _ptr__5168(_5168 ? _5168->raw() : nullptr,_5168 ? _5168->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5169 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5166)));
  _checked_ptr_1<double> _ptr__5169(_5169 ? _5169->raw() : nullptr,_5169 ? _5169->size(0) : 0);
  _5161->getDataAsTriplets(_5167,_5168,_5169);
  std::vector<long long> _9314;
  for (long long _5170 = (int)0, _9315 = _5166; _5170 < _9315 ; ++_5170)
  {
    _9314.push_back(safe_add( safe_mul( _ptr__5167[_5170],_5165 ),_ptr__5168[_5170] ));
  }
  auto _9316 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9314.size()),_9314.begin(),_9314.end()));
  return (::mosek::fusion::p_ExprMulElement::_new_ExprMulElement(_5169,_9316,_5164,(int)1)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm_(std::shared_ptr< monty::ndarray< double,1 > > _5171,monty::rc_ptr< ::mosek::fusion::Expression > _5172){
  _checked_ptr_1<double> _ptr__5171(_5171 ? _5171->raw() : nullptr, _5171 ? _5171->size(0) : 0);
  if (((NULL == _5171.get()) || (NULL == _5172.get())))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for mulElm may not be null"));
    }
  }
  {}
  if (((_5172->getND() == (int)0) && ((int)((_5171)->size(0)) == (int)1)))
  {
    {
      return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst(_ptr__5171[(int)0],_5172)).as<::mosek::fusion::Expression>();
    }
  }
  else if(((_5172->getND() != (int)1) || (_5172->getDim((int)0) != (int)((_5171)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Dimensions of operands do not match"));
    }
  }
  else
  {
    {
      std::vector<long long> _9317;
      for (int _5173 = (int)0, _9318 = (int)((_5171)->size(0)); _5173 < _9318 ; ++_5173)
      {
        _9317.push_back(_5173);
      }
      auto _9319 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9317.size()),_9317.begin(),_9317.end()));
      return (::mosek::fusion::p_ExprMulElement::_new_ExprMulElement(_5171,_9319,_5172)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm_(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5174,monty::rc_ptr< ::mosek::fusion::Expression > _5175){
  if (((NULL == _5174.get()) || (NULL == _5175.get())))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for mulElm may not be null"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _5176 = _5175->getShape();
  _checked_ptr_1<int> _ptr__5176(_5176 ? _5176->raw() : nullptr,_5176 ? _5176->size(0) : 0);
  if (((int)((_5176)->size(0)) != (int)((mosek::fusion::p_NDSparseArray::_get_impl(_5174)->dims)->size(0))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Dimension mismatch"));
    }
  }
  {}
  int _9320 = (int)0;
  int _9321 = (int)((mosek::fusion::p_NDSparseArray::_get_impl(_5174)->dims)->size(0));
  for (int _5177 = _9320; _5177 < _9321; ++_5177)
  {
    {
      if ((((*mosek::fusion::p_NDSparseArray::_get_impl(_5174)->dims)(_5177)) != _ptr__5176[_5177]))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Dimensions of operands do not match"));
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_ExprMulElement::_new_ExprMulElement(mosek::fusion::p_NDSparseArray::_get_impl(_5174)->cof,mosek::fusion::p_NDSparseArray::_get_impl(_5174)->inst,_5175)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5178,    double _5179) { return mosek::fusion::p_Expr::mul(_5178,_5179); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5178,double _5179){
  return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst(_5179,_5178)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( double _5180,    monty::rc_ptr< ::mosek::fusion::Expression > _5181) { return mosek::fusion::p_Expr::mul(_5180,_5181); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(double _5180,monty::rc_ptr< ::mosek::fusion::Expression > _5181){
  return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst(_5180,_5181)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5182,    std::shared_ptr< monty::ndarray< double,1 > > _5183) { return mosek::fusion::p_Expr::mul(_5182,_5183); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5182,std::shared_ptr< monty::ndarray< double,1 > > _5183){
  _checked_ptr_1<double> _ptr__5183(_5183 ? _5183->raw() : nullptr, _5183 ? _5183->size(0) : 0);
  return ::mosek::fusion::p_Expr::mul(false,_5183,_5182);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( std::shared_ptr< monty::ndarray< double,1 > > _5184,    monty::rc_ptr< ::mosek::fusion::Expression > _5185) { return mosek::fusion::p_Expr::mul(_5184,_5185); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(std::shared_ptr< monty::ndarray< double,1 > > _5184,monty::rc_ptr< ::mosek::fusion::Expression > _5185){
  _checked_ptr_1<double> _ptr__5184(_5184 ? _5184->raw() : nullptr, _5184 ? _5184->size(0) : 0);
  return ::mosek::fusion::p_Expr::mul(true,_5184,_5185);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5186,    std::shared_ptr< monty::ndarray< double,2 > > _5187) { return mosek::fusion::p_Expr::mul(_5186,_5187); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5186,std::shared_ptr< monty::ndarray< double,2 > > _5187){
  return ::mosek::fusion::p_Expr::mul(false,_5187,_5186);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( std::shared_ptr< monty::ndarray< double,2 > > _5188,    monty::rc_ptr< ::mosek::fusion::Expression > _5189) { return mosek::fusion::p_Expr::mul(_5188,_5189); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(std::shared_ptr< monty::ndarray< double,2 > > _5188,monty::rc_ptr< ::mosek::fusion::Expression > _5189){
  return ::mosek::fusion::p_Expr::mul(true,_5188,_5189);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5190,    monty::rc_ptr< ::mosek::fusion::Matrix > _5191) { return mosek::fusion::p_Expr::mul(_5190,_5191); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5190,monty::rc_ptr< ::mosek::fusion::Matrix > _5191){
  return ::mosek::fusion::p_Expr::mul(false,_5191,_5190);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5192,    monty::rc_ptr< ::mosek::fusion::Expression > _5193) { return mosek::fusion::p_Expr::mul(_5192,_5193); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Matrix > _5192,monty::rc_ptr< ::mosek::fusion::Expression > _5193){
  return ::mosek::fusion::p_Expr::mul(true,_5192,_5193);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5194,std::shared_ptr< monty::ndarray< double,1 > > _5195,monty::rc_ptr< ::mosek::fusion::Expression > _5196){
  _checked_ptr_1<double> _ptr__5195(_5195 ? _5195->raw() : nullptr, _5195 ? _5195->size(0) : 0);
  int _5197 = (int)((_5195)->size(0));
  int _5198 = _5197;
  std::shared_ptr< monty::ndarray< double,1 > > _5199 = ::mosek::fusion::Utils::Tools::arraycopy(_5195);
  _checked_ptr_1<double> _ptr__5199(_5199 ? _5199->raw() : nullptr,_5199 ? _5199->size(0) : 0);
  int _5200 = _5196->getND();
  if ((_5200 == (int)0))
  {
    {
      std::vector<int> _9322;
      for (int _5201 = (int)0, _9323 = _5197; _5201 < _9323 ; ++_5201)
      {
        _9322.push_back(_5201);
      }
      auto _9324 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9322.size()),_9322.begin(),_9322.end()));
      std::vector<int> _9325;
      for (int _5202 = (int)0, _9326 = _5197; _5202 < _9326 ; ++_5202)
      {
        _9325.push_back((int)0);
      }
      auto _9327 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9325.size()),_9325.begin(),_9325.end()));
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5197)}),(::mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul(_5197,(int)1,_9324,_9327,_5199,_5196,(int)1)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5200 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  else if((_5194 && (_5196->getDim((int)0) == (int)((_5195)->size(0)))))
  {
    {
      std::vector<int> _9328;
      for (int _5203 = (int)0, _9329 = _5197; _5203 < _9329 ; ++_5203)
      {
        _9328.push_back((int)0);
      }
      auto _9330 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9328.size()),_9328.begin(),_9328.end()));
      std::vector<int> _9331;
      for (int _5204 = (int)0, _9332 = _5197; _5204 < _9332 ; ++_5204)
      {
        _9331.push_back(_5204);
      }
      auto _9333 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9331.size()),_9331.begin(),_9331.end()));
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5196->getDim((int)1))}),(::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft((int)1,_5197,_9330,_9333,_5199,_5196)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5194 && (_5196->getDim((int)0) == (int)1)))
  {
    {
      std::vector<int> _9334;
      for (int _5205 = (int)0, _9335 = _5197; _5205 < _9335 ; ++_5205)
      {
        _9334.push_back(_5205);
      }
      auto _9336 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9334.size()),_9334.begin(),_9334.end()));
      std::vector<int> _9337;
      for (int _5206 = (int)0, _9338 = _5197; _5206 < _9338 ; ++_5206)
      {
        _9337.push_back((int)0);
      }
      auto _9339 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9337.size()),_9337.begin(),_9337.end()));
      return (::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5197,(int)1,_9336,_9339,_5199,_5196,(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  else if(((!_5194) && (_5196->getDim((int)1) == _5197)))
  {
    {
      std::vector<int> _9340;
      for (int _5207 = (int)0, _9341 = _5197; _5207 < _9341 ; ++_5207)
      {
        _9340.push_back(_5207);
      }
      auto _9342 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9340.size()),_9340.begin(),_9340.end()));
      std::vector<int> _9343;
      for (int _5208 = (int)0, _9344 = _5197; _5208 < _9344 ; ++_5208)
      {
        _9343.push_back((int)0);
      }
      auto _9345 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9343.size()),_9343.begin(),_9343.end()));
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5196->getDim((int)0))}),(::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5197,(int)1,_9342,_9345,_5199,_5196)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if(((!_5194) && (_5196->getDim((int)1) == (int)1)))
  {
    {
      std::vector<int> _9346;
      for (int _5209 = (int)0, _9347 = _5197; _5209 < _9347 ; ++_5209)
      {
        _9346.push_back((int)0);
      }
      auto _9348 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9346.size()),_9346.begin(),_9346.end()));
      std::vector<int> _9349;
      for (int _5210 = (int)0, _9350 = _5197; _5210 < _9350 ; ++_5210)
      {
        _9349.push_back(_5210);
      }
      auto _9351 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9349.size()),_9349.begin(),_9349.end()));
      return (::mosek::fusion::p_ExprMulRight::_new_ExprMulRight((int)1,_5197,_9348,_9351,_5199,_5196,(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5211,std::shared_ptr< monty::ndarray< double,2 > > _5212,monty::rc_ptr< ::mosek::fusion::Expression > _5213){
  int _5214 = (int)((_5212)->size(0));
  int _5215 = (int)((_5212)->size(1));
  int _5216 = safe_mul( _5214,_5215 );
  std::vector<int> _9352;
  for (int _5218 = (int)0, _9353 = _5214; _5218 < _9353 ; ++_5218)
  {
    for (int _5219 = (int)0, _9354 = _5215; _5219 < _9354 ; ++_5219)
    {
      _9352.push_back(_5218);
    }
  }
  auto _9355 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9352.size()),_9352.begin(),_9352.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5217 = _9355;
  _checked_ptr_1<int> _ptr__5217(_5217 ? _5217->raw() : nullptr,_5217 ? _5217->size(0) : 0);
  std::vector<int> _9356;
  for (int _5221 = (int)0, _9357 = _5214; _5221 < _9357 ; ++_5221)
  {
    for (int _5222 = (int)0, _9358 = _5215; _5222 < _9358 ; ++_5222)
    {
      _9356.push_back(_5222);
    }
  }
  auto _9359 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9356.size()),_9356.begin(),_9356.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5220 = _9359;
  _checked_ptr_1<int> _ptr__5220(_5220 ? _5220->raw() : nullptr,_5220 ? _5220->size(0) : 0);
  std::vector<double> _9360;
  for (int _5224 = (int)0, _9361 = _5214; _5224 < _9361 ; ++_5224)
  {
    for (int _5225 = (int)0, _9362 = _5215; _5225 < _9362 ; ++_5225)
    {
      _9360.push_back(((*_5212)(_5224,_5225)));
    }
  }
  auto _9363 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9360.size()),_9360.begin(),_9360.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5223 = _9363;
  _checked_ptr_1<double> _ptr__5223(_5223 ? _5223->raw() : nullptr,_5223 ? _5223->size(0) : 0);
  long long _5226 = _5213->getSize();
  std::shared_ptr< monty::ndarray< int,1 > > _5227 = _5213->getShape();
  _checked_ptr_1<int> _ptr__5227(_5227 ? _5227->raw() : nullptr,_5227 ? _5227->size(0) : 0);
  if (((int)((_5227)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul(_5214,_5215,_5217,_5220,_5223,_5213,(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  else if(_5211)
  {
    {
      if (((int)((_5227)->size(0)) == (int)1))
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5212)->size(0)))}),(::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5214,_5215,_5217,_5220,_5223,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5227[(int)0]),(int)((int)1)}),_5213)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
      else if(((int)((_5227)->size(0)) == (int)2))
      {
        {
          return (::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5214,_5215,_5217,_5220,_5223,_5213)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
    }
  }
  else
  {
    {
      if (((int)((_5227)->size(0)) == (int)1))
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5212)->size(1)))}),(::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5214,_5215,_5217,_5220,_5223,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_ptr__5227[(int)0])}),_5213)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
      else if(((int)((_5227)->size(0)) == (int)2))
      {
        {
          return (::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5214,_5215,_5217,_5220,_5223,_5213)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5228,monty::rc_ptr< ::mosek::fusion::Matrix > _5229,monty::rc_ptr< ::mosek::fusion::Expression > _5230){
  long long _5231 = _5229->numNonzeros();
  std::shared_ptr< monty::ndarray< int,1 > > _5232 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5231)));
  _checked_ptr_1<int> _ptr__5232(_5232 ? _5232->raw() : nullptr,_5232 ? _5232->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5233 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5231)));
  _checked_ptr_1<int> _ptr__5233(_5233 ? _5233->raw() : nullptr,_5233 ? _5233->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5234 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5231)));
  _checked_ptr_1<double> _ptr__5234(_5234 ? _5234->raw() : nullptr,_5234 ? _5234->size(0) : 0);
  int _5235 = _5229->numRows();
  int _5236 = _5229->numColumns();
  _5229->getDataAsTriplets(_5232,_5233,_5234);
  int _5237 = _5230->getND();
  if ((_5237 == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul(_5235,_5236,_5232,_5233,_5234,_5230)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5237 == (int)1))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5238 = _5230->getShape();
      _checked_ptr_1<int> _ptr__5238(_5238 ? _5238->raw() : nullptr,_5238 ? _5238->size(0) : 0);
      if (_5228)
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5235)}),(::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5235,_5236,_5232,_5233,_5234,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5238[(int)0]),(int)((int)1)}),_5230)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5236)}),(::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5235,_5236,_5232,_5233,_5234,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_ptr__5238[(int)0])}),_5230)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
  else if((_5237 == (int)2))
  {
    {
      if (_5228)
      {
        {
          return (::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5235,_5236,_5232,_5233,_5234,_5230)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          return (::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5235,_5236,_5232,_5233,_5234,_5230)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions for multiplication"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Variable > _5239,    monty::rc_ptr< ::mosek::fusion::Matrix > _5240) { return mosek::fusion::p_Expr::mul(_5239,_5240); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Variable > _5239,monty::rc_ptr< ::mosek::fusion::Matrix > _5240){
  int _5241 = _5240->numRows();
  int _5242 = _5240->numColumns();
  std::shared_ptr< monty::ndarray< double,1 > > _5243 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5240->numNonzeros())));
  _checked_ptr_1<double> _ptr__5243(_5243 ? _5243->raw() : nullptr,_5243 ? _5243->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5244 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5240->numNonzeros())));
  _checked_ptr_1<int> _ptr__5244(_5244 ? _5244->raw() : nullptr,_5244 ? _5244->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5245 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5240->numNonzeros())));
  _checked_ptr_1<int> _ptr__5245(_5245 ? _5245->raw() : nullptr,_5245 ? _5245->size(0) : 0);
  _5240->getDataAsTriplets(_5245,_5244,_5243);
  return ::mosek::fusion::p_Expr::mul(false,_5241,_5242,_5245,_5244,_5243,_5239);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5246,    monty::rc_ptr< ::mosek::fusion::Variable > _5247) { return mosek::fusion::p_Expr::mul(_5246,_5247); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Matrix > _5246,monty::rc_ptr< ::mosek::fusion::Variable > _5247){
  int _5248 = _5246->numRows();
  int _5249 = _5246->numColumns();
  std::shared_ptr< monty::ndarray< double,1 > > _5250 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5246->numNonzeros())));
  _checked_ptr_1<double> _ptr__5250(_5250 ? _5250->raw() : nullptr,_5250 ? _5250->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5251 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5246->numNonzeros())));
  _checked_ptr_1<int> _ptr__5251(_5251 ? _5251->raw() : nullptr,_5251 ? _5251->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5252 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5246->numNonzeros())));
  _checked_ptr_1<int> _ptr__5252(_5252 ? _5252->raw() : nullptr,_5252 ? _5252->size(0) : 0);
  _5246->getDataAsTriplets(_5252,_5251,_5250);
  return ::mosek::fusion::p_Expr::mul(true,_5248,_5249,_5252,_5251,_5250,_5247);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5253,int _5254,int _5255,std::shared_ptr< monty::ndarray< int,1 > > _5256,std::shared_ptr< monty::ndarray< int,1 > > _5257,std::shared_ptr< monty::ndarray< double,1 > > _5258,monty::rc_ptr< ::mosek::fusion::Variable > _5259){
  _checked_ptr_1<int> _ptr__5256(_5256 ? _5256->raw() : nullptr, _5256 ? _5256->size(0) : 0);
  _checked_ptr_1<int> _ptr__5257(_5257 ? _5257->raw() : nullptr, _5257 ? _5257->size(0) : 0);
  _checked_ptr_1<double> _ptr__5258(_5258 ? _5258->raw() : nullptr, _5258 ? _5258->size(0) : 0);
  if ((_5259->getND() == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprMulScalarVar::_new_ExprMulScalarVar(_5254,_5255,_5256,_5257,_5258,_5259)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5259->getND() == (int)1))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5260 = _5259->getShape();
      _checked_ptr_1<int> _ptr__5260(_5260 ? _5260->raw() : nullptr,_5260 ? _5260->size(0) : 0);
      int _9364;
      bool _9365 = _5253;
      if (_9365)
      {
        _9364 = _5254;
      }
      else
      {
        _9364 = _5255;
      }
      std::shared_ptr< monty::ndarray< int,1 > > _9366;
      bool _9367 = _5253;
      if (_9367)
      {
        _9366 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5260[(int)0]),(int)((int)1)});
      }
      else
      {
        _9366 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_ptr__5260[(int)0])});
      }
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_9364)}),(::mosek::fusion::p_ExprMulVar::_new_ExprMulVar(_5253,_5254,_5255,_5256,_5257,_5258,::mosek::fusion::p_Var::reshape(_5259,_9366))).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprMulVar::_new_ExprMulVar(_5253,_5254,_5255,_5256,_5257,_5258,_5259)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5261,    monty::rc_ptr< ::mosek::fusion::Matrix > _5262) { return mosek::fusion::p_Expr::dot(_5261,_5262); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5261,monty::rc_ptr< ::mosek::fusion::Matrix > _5262){
  long long _5263 = _5262->numNonzeros();
  if ((!_5262->isSparse()))
  {
    {
      std::vector<long long> _9368;
      for (long long _5264 = (int)0, _9369 = _5263; _5264 < _9369 ; ++_5264)
      {
        _9368.push_back(_5264);
      }
      auto _9370 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9368.size()),_9368.begin(),_9368.end()));
      return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5261,_9370,_5262->getDataAsArray())).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5265 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5263)));
      _checked_ptr_1<int> _ptr__5265(_5265 ? _5265->raw() : nullptr,_5265 ? _5265->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5266 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5263)));
      _checked_ptr_1<int> _ptr__5266(_5266 ? _5266->raw() : nullptr,_5266 ? _5266->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _5267 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5263)));
      _checked_ptr_1<double> _ptr__5267(_5267 ? _5267->raw() : nullptr,_5267 ? _5267->size(0) : 0);
      int _5268 = _5262->numColumns();
      _5262->getDataAsTriplets(_5265,_5266,_5267);
      std::vector<long long> _9371;
      for (int _5269 = (int)0, _9372 = (int)((_5265)->size(0)); _5269 < _9372 ; ++_5269)
      {
        _9371.push_back(safe_add( safe_mul( _ptr__5265[_5269],_5268 ),_ptr__5266[_5269] ));
      }
      auto _9373 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9371.size()),_9371.begin(),_9371.end()));
      return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5261,_9373,_5267)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5270,    std::shared_ptr< monty::ndarray< double,2 > > _5271) { return mosek::fusion::p_Expr::dot(_5270,_5271); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5270,std::shared_ptr< monty::ndarray< double,2 > > _5271){
  std::vector<long long> _9374;
  for (int _5272 = (int)0, _9375 = safe_mul( (int)((_5271)->size(0)),(int)((_5271)->size(1)) ); _5272 < _9375 ; ++_5272)
  {
    _9374.push_back(_5272);
  }
  auto _9376 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9374.size()),_9374.begin(),_9374.end()));
  std::vector<double> _9377;
  for (int _5273 = (int)0, _9378 = (int)((_5271)->size(0)); _5273 < _9378 ; ++_5273)
  {
    for (int _5274 = (int)0, _9379 = (int)((_5271)->size(1)); _5274 < _9379 ; ++_5274)
    {
      _9377.push_back(((*_5271)(_5273,_5274)));
    }
  }
  auto _9380 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9377.size()),_9377.begin(),_9377.end()));
  return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5270,_9376,_9380)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5275,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5276) { return mosek::fusion::p_Expr::dot(_5275,_5276); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5275,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5276){
  return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5275,mosek::fusion::p_NDSparseArray::_get_impl(_5276)->inst,mosek::fusion::p_NDSparseArray::_get_impl(_5276)->cof)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5277,    std::shared_ptr< monty::ndarray< double,1 > > _5278) { return mosek::fusion::p_Expr::dot(_5277,_5278); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5277,std::shared_ptr< monty::ndarray< double,1 > > _5278){
  _checked_ptr_1<double> _ptr__5278(_5278 ? _5278->raw() : nullptr, _5278 ? _5278->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5279 = _5277->getShape();
  _checked_ptr_1<int> _ptr__5279(_5279 ? _5279->raw() : nullptr,_5279 ? _5279->size(0) : 0);
  if (((_5277->getSize() == (int)((_5278)->size(0))) && ((int)((_5279)->size(0)) > (int)1)))
  {
    {
      int _5280 = (int)0;
      int _9381 = (int)0;
      int _9382 = (int)((_5279)->size(0));
      for (int _5281 = _9381; _5281 < _9382; ++_5281)
      {
        {
          if ((_ptr__5279[_5281] > (int)1))
          {
            {
              ++ _5280;
            }
          }
          {}
        }
      }
      if ((_5280 > (int)1))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _5282 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)_5277->getSize())});
          _checked_ptr_1<int> _ptr__5282(_5282 ? _5282->raw() : nullptr,_5282 ? _5282->size(0) : 0);
          return (::mosek::fusion::p_ExprInner::_new_ExprInner((::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5282,_5277)).as<::mosek::fusion::Expression>(),_5278)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5277,_5278)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5283,    monty::rc_ptr< ::mosek::fusion::Expression > _5284) { return mosek::fusion::p_Expr::dot(_5283,_5284); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Matrix > _5283,monty::rc_ptr< ::mosek::fusion::Expression > _5284){
  return ::mosek::fusion::p_Expr::dot(_5284,_5283);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5285,    monty::rc_ptr< ::mosek::fusion::Expression > _5286) { return mosek::fusion::p_Expr::dot(_5285,_5286); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5285,monty::rc_ptr< ::mosek::fusion::Expression > _5286){
  return ::mosek::fusion::p_Expr::dot(_5286,_5285);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( std::shared_ptr< monty::ndarray< double,2 > > _5287,    monty::rc_ptr< ::mosek::fusion::Expression > _5288) { return mosek::fusion::p_Expr::dot(_5287,_5288); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(std::shared_ptr< monty::ndarray< double,2 > > _5287,monty::rc_ptr< ::mosek::fusion::Expression > _5288){
  return ::mosek::fusion::p_Expr::dot(_5288,_5287);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( std::shared_ptr< monty::ndarray< double,1 > > _5289,    monty::rc_ptr< ::mosek::fusion::Expression > _5290) { return mosek::fusion::p_Expr::dot(_5289,_5290); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(std::shared_ptr< monty::ndarray< double,1 > > _5289,monty::rc_ptr< ::mosek::fusion::Expression > _5290){
  _checked_ptr_1<double> _ptr__5289(_5289 ? _5289->raw() : nullptr, _5289 ? _5289->size(0) : 0);
  return ::mosek::fusion::p_Expr::dot(_5290,_5289);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( std::shared_ptr< monty::ndarray< double,1 > > _5291,    monty::rc_ptr< ::mosek::fusion::Expression > _5292) { return mosek::fusion::p_Expr::outer(_5291,_5292); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(std::shared_ptr< monty::ndarray< double,1 > > _5291,monty::rc_ptr< ::mosek::fusion::Expression > _5292){
  _checked_ptr_1<double> _ptr__5291(_5291 ? _5291->raw() : nullptr, _5291 ? _5291->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5293 = _5292->getShape();
  _checked_ptr_1<int> _ptr__5293(_5293 ? _5293->raw() : nullptr,_5293 ? _5293->size(0) : 0);
  if (((int)((_5293)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Arguments must be one-dimensional"));
    }
  }
  {}
  if ((_ptr__5293[(int)0] != (int)((_5291)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Argument lengths do not match"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::FlatExpr > _5294 = _5292->__mosek_2fusion_2Expression__eval();
  std::vector<int> _9383;
  for (int _5295 = (int)0, _9384 = (int)((_5291)->size(0)); _5295 < _9384 ; ++_5295)
  {
    _9383.push_back(_5295);
  }
  auto _9385 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9383.size()),_9383.begin(),_9383.end()));
  return ::mosek::fusion::p_Expr::outer_(((*mosek::fusion::p_FlatExpr::_get_impl(_5294)->shape)((int)0)),mosek::fusion::p_FlatExpr::_get_impl(_5294)->ptrb,mosek::fusion::p_FlatExpr::_get_impl(_5294)->subj,mosek::fusion::p_FlatExpr::_get_impl(_5294)->cof,mosek::fusion::p_FlatExpr::_get_impl(_5294)->bfix,mosek::fusion::p_FlatExpr::_get_impl(_5294)->inst,_5291,_9385,(int)((_5291)->size(0)),true);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Expression > _5296,    std::shared_ptr< monty::ndarray< double,1 > > _5297) { return mosek::fusion::p_Expr::outer(_5296,_5297); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Expression > _5296,std::shared_ptr< monty::ndarray< double,1 > > _5297){
  _checked_ptr_1<double> _ptr__5297(_5297 ? _5297->raw() : nullptr, _5297 ? _5297->size(0) : 0);
  if (((_5296->getND() != (int)1) || (_5296->getND() != (int)1)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Arguments must be one-dimensional"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::FlatExpr > _5298 = _5296->__mosek_2fusion_2Expression__eval();
  std::vector<int> _9386;
  for (int _5299 = (int)0, _9387 = (int)((_5297)->size(0)); _5299 < _9387 ; ++_5299)
  {
    _9386.push_back(_5299);
  }
  auto _9388 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9386.size()),_9386.begin(),_9386.end()));
  return ::mosek::fusion::p_Expr::outer_(((*mosek::fusion::p_FlatExpr::_get_impl(_5298)->shape)((int)0)),mosek::fusion::p_FlatExpr::_get_impl(_5298)->ptrb,mosek::fusion::p_FlatExpr::_get_impl(_5298)->subj,mosek::fusion::p_FlatExpr::_get_impl(_5298)->cof,mosek::fusion::p_FlatExpr::_get_impl(_5298)->bfix,mosek::fusion::p_FlatExpr::_get_impl(_5298)->inst,_5297,_9388,(int)((_5297)->size(0)),false);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5300,    monty::rc_ptr< ::mosek::fusion::Variable > _5301) { return mosek::fusion::p_Expr::outer(_5300,_5301); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Matrix > _5300,monty::rc_ptr< ::mosek::fusion::Variable > _5301){
  std::shared_ptr< monty::ndarray< int,1 > > _5302 = _5301->getShape();
  _checked_ptr_1<int> _ptr__5302(_5302 ? _5302->raw() : nullptr,_5302 ? _5302->size(0) : 0);
  if ((!(((int)((_5302)->size(0)) == (int)1) || (((int)((_5302)->size(0)) == (int)2) && (_ptr__5302[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  if ((mosek::fusion::p_Matrix::_get_impl(_5300)->dimj != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Constant matrix must be a column-vector"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Matrix > _9389 = _5300;
  if (false) {}
  else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9389.get()))
  {
    ::mosek::fusion::DenseMatrix::t _5303 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9389.get()));
    {
      return ::mosek::fusion::p_Expr::outer_(_5301,_ptr__5302[(int)0],mosek::fusion::p_DenseMatrix::_get_impl(_5303)->data,nullptr,(int)((mosek::fusion::p_DenseMatrix::_get_impl(_5303)->data)->size(0)),true);
    }
  }
  else
  {
    mosek::fusion::Matrix::t _5304 = _9389;
    {
      std::shared_ptr< monty::ndarray< double,1 > > _5305 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5304->numNonzeros())));
      _checked_ptr_1<double> _ptr__5305(_5305 ? _5305->raw() : nullptr,_5305 ? _5305->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5306 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5304->numNonzeros())));
      _checked_ptr_1<int> _ptr__5306(_5306 ? _5306->raw() : nullptr,_5306 ? _5306->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5307 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5304->numNonzeros())));
      _checked_ptr_1<int> _ptr__5307(_5307 ? _5307->raw() : nullptr,_5307 ? _5307->size(0) : 0);
      _5304->getDataAsTriplets(_5307,_5306,_5305);
      return ::mosek::fusion::p_Expr::outer_(_5301,_ptr__5302[(int)0],_5305,_5307,mosek::fusion::p_Matrix::_get_impl(_5304)->dimi,true);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Variable > _5308,    monty::rc_ptr< ::mosek::fusion::Matrix > _5309) { return mosek::fusion::p_Expr::outer(_5308,_5309); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Variable > _5308,monty::rc_ptr< ::mosek::fusion::Matrix > _5309){
  std::shared_ptr< monty::ndarray< int,1 > > _5310 = _5308->getShape();
  _checked_ptr_1<int> _ptr__5310(_5310 ? _5310->raw() : nullptr,_5310 ? _5310->size(0) : 0);
  if ((!((_5308->getND() == (int)1) || ((_5308->getND() == (int)2) && (_ptr__5310[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  if ((mosek::fusion::p_Matrix::_get_impl(_5309)->dimj != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Constant matrix must be a column-vector"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Matrix > _9390 = _5309;
  if (false) {}
  else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9390.get()))
  {
    ::mosek::fusion::DenseMatrix::t _5311 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9390.get()));
    {
      return ::mosek::fusion::p_Expr::outer_(_5308,_ptr__5310[(int)0],mosek::fusion::p_DenseMatrix::_get_impl(_5311)->data,nullptr,(int)((mosek::fusion::p_DenseMatrix::_get_impl(_5311)->data)->size(0)),false);
    }
  }
  else
  {
    mosek::fusion::Matrix::t _5312 = _9390;
    {
      std::shared_ptr< monty::ndarray< double,1 > > _5313 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5312->numNonzeros())));
      _checked_ptr_1<double> _ptr__5313(_5313 ? _5313->raw() : nullptr,_5313 ? _5313->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5314 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5312->numNonzeros())));
      _checked_ptr_1<int> _ptr__5314(_5314 ? _5314->raw() : nullptr,_5314 ? _5314->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5315 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5309->numNonzeros())));
      _checked_ptr_1<int> _ptr__5315(_5315 ? _5315->raw() : nullptr,_5315 ? _5315->size(0) : 0);
      _5312->getDataAsTriplets(_5315,_5314,_5313);
      return ::mosek::fusion::p_Expr::outer_(_5308,((*_5308->getShape())((int)0)),_5313,_5315,mosek::fusion::p_Matrix::_get_impl(_5312)->dimi,false);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( std::shared_ptr< monty::ndarray< double,1 > > _5316,    monty::rc_ptr< ::mosek::fusion::Variable > _5317) { return mosek::fusion::p_Expr::outer(_5316,_5317); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(std::shared_ptr< monty::ndarray< double,1 > > _5316,monty::rc_ptr< ::mosek::fusion::Variable > _5317){
  _checked_ptr_1<double> _ptr__5316(_5316 ? _5316->raw() : nullptr, _5316 ? _5316->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5318 = _5317->getShape();
  _checked_ptr_1<int> _ptr__5318(_5318 ? _5318->raw() : nullptr,_5318 ? _5318->size(0) : 0);
  if ((!((_5317->getND() == (int)1) || ((_5317->getND() == (int)2) && (_ptr__5318[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::outer_(_5317,_ptr__5318[(int)0],_5316,nullptr,(int)((_5316)->size(0)),true);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Variable > _5319,    std::shared_ptr< monty::ndarray< double,1 > > _5320) { return mosek::fusion::p_Expr::outer(_5319,_5320); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Variable > _5319,std::shared_ptr< monty::ndarray< double,1 > > _5320){
  _checked_ptr_1<double> _ptr__5320(_5320 ? _5320->raw() : nullptr, _5320 ? _5320->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5321 = _5319->getShape();
  _checked_ptr_1<int> _ptr__5321(_5321 ? _5321->raw() : nullptr,_5321 ? _5321->size(0) : 0);
  if ((!((_5319->getND() == (int)1) || ((_5319->getND() == (int)2) && (_ptr__5321[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::outer_(_5319,_ptr__5321[(int)0],_5320,nullptr,(int)((_5320)->size(0)),false);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer_(int _5322,std::shared_ptr< monty::ndarray< long long,1 > > _5323,std::shared_ptr< monty::ndarray< long long,1 > > _5324,std::shared_ptr< monty::ndarray< double,1 > > _5325,std::shared_ptr< monty::ndarray< double,1 > > _5326,std::shared_ptr< monty::ndarray< long long,1 > > _5327,std::shared_ptr< monty::ndarray< double,1 > > _5328,std::shared_ptr< monty::ndarray< int,1 > > _5329,int _5330,bool _5331){
  _checked_ptr_1<long long> _ptr__5323(_5323 ? _5323->raw() : nullptr, _5323 ? _5323->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5324(_5324 ? _5324->raw() : nullptr, _5324 ? _5324->size(0) : 0);
  _checked_ptr_1<double> _ptr__5325(_5325 ? _5325->raw() : nullptr, _5325 ? _5325->size(0) : 0);
  _checked_ptr_1<double> _ptr__5326(_5326 ? _5326->raw() : nullptr, _5326 ? _5326->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5327(_5327 ? _5327->raw() : nullptr, _5327 ? _5327->size(0) : 0);
  _checked_ptr_1<double> _ptr__5328(_5328 ? _5328->raw() : nullptr, _5328 ? _5328->size(0) : 0);
  _checked_ptr_1<int> _ptr__5329(_5329 ? _5329->raw() : nullptr, _5329 ? _5329->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9391;
  bool _9392 = (!_5331);
  if (_9392)
  {
    _9391 = ::mosek::fusion::p_Set::make(_5322,_5330);
  }
  else
  {
    _9391 = ::mosek::fusion::p_Set::make(_5330,_5322);
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5332 = _9391;
  _checked_ptr_1<int> _ptr__5332(_5332 ? _5332->raw() : nullptr,_5332 ? _5332->size(0) : 0);
  int _5333 = safe_mul( (int)((_5328)->size(0)),(int)((_5327)->size(0)) );
  int _5334 = safe_mul( (int)((_5328)->size(0)),(int)((_5324)->size(0)) );
  std::shared_ptr< monty::ndarray< long long,1 > > _5335 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5333)));
  _checked_ptr_1<long long> _ptr__5335(_5335 ? _5335->raw() : nullptr,_5335 ? _5335->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _9393;
  bool _9394 = (NULL != _5326.get());
  if (_9394)
  {
    _9393 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5333)));
  }
  else
  {
    _9393 = nullptr;
  }
  std::shared_ptr< monty::ndarray< double,1 > > _5336 = _9393;
  _checked_ptr_1<double> _ptr__5336(_5336 ? _5336->raw() : nullptr,_5336 ? _5336->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5337 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5334)));
  _checked_ptr_1<double> _ptr__5337(_5337 ? _5337->raw() : nullptr,_5337 ? _5337->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5338 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5334)));
  _checked_ptr_1<long long> _ptr__5338(_5338 ? _5338->raw() : nullptr,_5338 ? _5338->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5339 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _5333,(int)1 ))));
  _checked_ptr_1<long long> _ptr__5339(_5339 ? _5339->raw() : nullptr,_5339 ? _5339->size(0) : 0);
  int _5340 = (int)_ptr__5339[((int)((_5339)->size(0)) - (int)1)];
  if ((!_5331))
  {
    {
      long long _5341 = (long long)0;
      long long _5342 = (long long)0;
      int _9395 = (int)0;
      int _9396 = (int)((_5327)->size(0));
      for (int _5343 = _9395; _5343 < _9396; ++_5343)
      {
        {
          long long _5344 = (_ptr__5323[safe_add( _5343,(int)1 )] - _ptr__5323[_5343]);
          int _9397 = (int)0;
          int _9398 = (int)((_5328)->size(0));
          for (int _5345 = _9397; _5345 < _9398; ++_5345)
          {
            {
              _ptr__5327[_5341] = safe_add( safe_mul( _ptr__5327[_5343],_5330 ),_ptr__5329[_5345] );
              _ptr__5339[safe_add( _5341,(int)1 )] = safe_add( _ptr__5339[_5341],_5344 );
              ++ _5341;
              long long _9399 = _ptr__5323[_5343];
              long long _9400 = _ptr__5323[safe_add( _5343,(int)1 )];
              for (long long _5346 = _9399; _5346 < _9400; ++_5346)
              {
                {
                  _ptr__5338[_5342] = _ptr__5324[_5346];
                  _ptr__5337[_5342] = (_ptr__5325[_5346] * _ptr__5328[_5345]);
                  ++ _5342;
                }
              }
            }
          }
        }
      }
      if ((NULL != _5336.get()))
      {
        {
          int _5347 = (int)0;
          int _9401 = (int)0;
          int _9402 = (int)((_5327)->size(0));
          for (int _5348 = _9401; _5348 < _9402; ++_5348)
          {
            {
              int _9403 = (int)0;
              int _9404 = (int)((_5328)->size(0));
              for (int _5349 = _9403; _5349 < _9404; ++_5349)
              {
                {
                  _ptr__5336[_5347] = (_ptr__5328[_5349] * _ptr__5326[_5348]);
                  ++ _5347;
                }
              }
            }
          }
        }
      }
      {}
    }
  }
  else
  {
    {
      long long _5350 = (long long)0;
      long long _5351 = (long long)0;
      int _9405 = (int)0;
      int _9406 = (int)((_5328)->size(0));
      for (int _5352 = _9405; _5352 < _9406; ++_5352)
      {
        {
          double _5353 = _ptr__5328[_5352];
          ::mosek::fusion::Utils::Tools::arraycopy(_5324,(long long)((int)0),_5338,_5351,(long long)(_5340));
          int _9407 = (int)0;
          int _9408 = _5340;
          for (int _5354 = _9407; _5354 < _9408; ++_5354)
          {
            {
              _ptr__5337[safe_add( _5351,_5354 )] = (_ptr__5325[_5354] * _ptr__5328[_5352]);
            }
          }
          int _9409 = (int)0;
          int _9410 = (int)((_5327)->size(0));
          for (int _5355 = _9409; _5355 < _9410; ++_5355)
          {
            {
              long long _5356 = (_ptr__5323[safe_add( _5355,(int)1 )] - _ptr__5323[_5355]);
              _ptr__5327[_5350] = safe_add( safe_mul( _ptr__5327[_5355],_5330 ),_ptr__5329[_5352] );
              _ptr__5339[safe_add( _5350,(int)1 )] = safe_add( _ptr__5339[_5350],_5356 );
              ++ _5350;
            }
          }
          _5351 += _5340;
        }
      }
      if ((NULL != _5336.get()))
      {
        {
          int _5357 = (int)0;
          int _9411 = (int)0;
          int _9412 = (int)((_5328)->size(0));
          for (int _5358 = _9411; _5358 < _9412; ++_5358)
          {
            {
              double _5359 = _ptr__5328[_5358];
              int _9413 = (int)0;
              int _9414 = (int)((_5327)->size(0));
              for (int _5360 = _9413; _5360 < _9414; ++_5360)
              {
                {
                  _ptr__5336[_5357] = (_ptr__5326[_5360] * _5359);
                  ++ _5357;
                }
              }
            }
          }
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_Expr::_new_Expr(_5339,_5338,_5337,_5336,_5332,_5335)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer_(monty::rc_ptr< ::mosek::fusion::Variable > _5361,int _5362,std::shared_ptr< monty::ndarray< double,1 > > _5363,std::shared_ptr< monty::ndarray< int,1 > > _5364,int _5365,bool _5366){
  _checked_ptr_1<double> _ptr__5363(_5363 ? _5363->raw() : nullptr, _5363 ? _5363->size(0) : 0);
  _checked_ptr_1<int> _ptr__5364(_5364 ? _5364->raw() : nullptr, _5364 ? _5364->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9415;
  bool _9416 = (!_5366);
  if (_9416)
  {
    _9415 = ::mosek::fusion::p_Set::make(_5362,_5365);
  }
  else
  {
    _9415 = ::mosek::fusion::p_Set::make(_5365,_5362);
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5367 = _9415;
  _checked_ptr_1<int> _ptr__5367(_5367 ? _5367->raw() : nullptr,_5367 ? _5367->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _9417;
  bool _9418 = (_5365 == (int)((_5363)->size(0)));
  if (_9418)
  {
    _9417 = nullptr;
  }
  else
  {
    _9417 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( (int)((_5363)->size(0)),_5362 ))));
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _5368 = _9417;
  _checked_ptr_1<long long> _ptr__5368(_5368 ? _5368->raw() : nullptr,_5368 ? _5368->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5369 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( (int)((_5363)->size(0)),_5362 ))));
  _checked_ptr_1<double> _ptr__5369(_5369 ? _5369->raw() : nullptr,_5369 ? _5369->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5370 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( (int)((_5363)->size(0)),_5362 ))));
  _checked_ptr_1<double> _ptr__5370(_5370 ? _5370->raw() : nullptr,_5370 ? _5370->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5371 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( (int)((_5363)->size(0)),_5362 ))));
  _checked_ptr_1<long long> _ptr__5371(_5371 ? _5371->raw() : nullptr,_5371 ? _5371->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5372 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( safe_mul( (int)((_5363)->size(0)),_5362 ),(int)1 ))));
  _checked_ptr_1<long long> _ptr__5372(_5372 ? _5372->raw() : nullptr,_5372 ? _5372->size(0) : 0);
  if ((_5365 == (int)((_5363)->size(0))))
  {
    {
      long long _5373 = (long long)0;
      if ((!_5366))
      {
        {
          int _9419 = (int)0;
          int _9420 = _5362;
          for (int _5374 = _9419; _5374 < _9420; ++_5374)
          {
            {
              int _9421 = (int)0;
              int _9422 = _5365;
              for (int _5375 = _9421; _5375 < _9422; ++_5375)
              {
                {
                  _ptr__5372[safe_add( _5373,(int)1 )] = safe_add( _5373,(int)1 );
                  _ptr__5371[_5373] = (long long)_5374;
                  _ptr__5370[_5373] = _ptr__5363[_5375];
                  ++ _5373;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _9423 = (int)0;
          int _9424 = _5365;
          for (int _5376 = _9423; _5376 < _9424; ++_5376)
          {
            {
              int _9425 = (int)0;
              int _9426 = _5362;
              for (int _5377 = _9425; _5377 < _9426; ++_5377)
              {
                {
                  _ptr__5372[safe_add( _5373,(int)1 )] = safe_add( _5373,(int)1 );
                  _ptr__5371[_5373] = (long long)_5377;
                  _ptr__5370[_5373] = _ptr__5363[_5376];
                  ++ _5373;
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      long long _5378 = (long long)0;
      if ((!_5366))
      {
        {
          int _9427 = (int)0;
          int _9428 = _5362;
          for (int _5379 = _9427; _5379 < _9428; ++_5379)
          {
            {
              int _9429 = (int)0;
              int _9430 = (int)((_5363)->size(0));
              for (int _5380 = _9429; _5380 < _9430; ++_5380)
              {
                {
                  _ptr__5372[safe_add( _5378,(int)1 )] = safe_add( _5378,(int)1 );
                  _ptr__5371[_5378] = (long long)_5379;
                  _ptr__5370[_5378] = _ptr__5363[_5380];
                  _ptr__5368[_5378] = safe_add( safe_mul( _5379,_5365 ),_ptr__5364[_5380] );
                  ++ _5378;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _9431 = (int)0;
          int _9432 = (int)((_5363)->size(0));
          for (int _5381 = _9431; _5381 < _9432; ++_5381)
          {
            {
              int _9433 = (int)0;
              int _9434 = _5362;
              for (int _5382 = _9433; _5382 < _9434; ++_5382)
              {
                {
                  _ptr__5372[safe_add( _5378,(int)1 )] = safe_add( _5378,(int)1 );
                  _ptr__5371[_5378] = (long long)_5382;
                  _ptr__5370[_5378] = _ptr__5363[_5381];
                  _ptr__5368[_5378] = safe_add( safe_mul( _ptr__5364[_5381],_5362 ),_5382 );
                  ++ _5378;
                }
              }
            }
          }
        }
      }
    }
  }
  return (::mosek::fusion::p_Expr::_new_Expr(_5372,_5371,_5370,_5369,_5367,_5368)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >,1 > > _5383) { return mosek::fusion::p_Expr::stack(_5383); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >,1 > > _5383){
  if ((NULL == _5383.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument exprs may not be null"));
    }
  }
  {}
  int _9435 = (int)0;
  int _9436 = (int)((_5383)->size(0));
  for (int _5384 = _9435; _5384 < _9436; ++_5384)
  {
    {
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5385 = ((*_5383)(_5384));
      if ((NULL == _5385.get()))
      {
        {
          throw monty::NullPointerException(std::string ("Arguments for stack may not be null"));
        }
      }
      {}
      int _9437 = (int)0;
      int _9438 = (int)((_5385)->size(0));
      for (int _5386 = _9437; _5386 < _9438; ++_5386)
      {
        {
          if ((NULL == ((*_5385)(_5386)).get()))
          {
            {
              throw monty::NullPointerException(std::string ("Arguments for stack may not be null"));
            }
          }
          {}
        }
      }
    }
  }
  std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _9439;
  for (int _5388 = (int)0, _9440 = (int)((_5383)->size(0)); _5388 < _9440 ; ++_5388)
  {
    _9439.push_back(::mosek::fusion::p_Expr::stack_(((*_5383)(_5388)),(int)1));
  }
  auto _9441 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_9439.size()),_9439.begin(),_9439.end()));
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5387 = _9441;
  return ::mosek::fusion::p_Expr::stack_(_5387,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5389,    double _5390,    double _5391) { return mosek::fusion::p_Expr::vstack(_5389,_5390,_5391); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5389,double _5390,double _5391){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5389).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5390).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5391).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5392,    double _5393,    monty::rc_ptr< ::mosek::fusion::Expression > _5394) { return mosek::fusion::p_Expr::vstack(_5392,_5393,_5394); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5392,double _5393,monty::rc_ptr< ::mosek::fusion::Expression > _5394){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5392).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5393).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5394.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5395,    monty::rc_ptr< ::mosek::fusion::Expression > _5396,    double _5397) { return mosek::fusion::p_Expr::vstack(_5395,_5396,_5397); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5395,monty::rc_ptr< ::mosek::fusion::Expression > _5396,double _5397){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5395).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5396.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5397).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5398,    monty::rc_ptr< ::mosek::fusion::Expression > _5399,    monty::rc_ptr< ::mosek::fusion::Expression > _5400) { return mosek::fusion::p_Expr::vstack(_5398,_5399,_5400); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5398,monty::rc_ptr< ::mosek::fusion::Expression > _5399,monty::rc_ptr< ::mosek::fusion::Expression > _5400){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5398).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5399.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5400.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5401,    double _5402,    double _5403) { return mosek::fusion::p_Expr::vstack(_5401,_5402,_5403); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5401,double _5402,double _5403){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5401.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5402).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5403).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5404,    double _5405,    monty::rc_ptr< ::mosek::fusion::Expression > _5406) { return mosek::fusion::p_Expr::vstack(_5404,_5405,_5406); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5404,double _5405,monty::rc_ptr< ::mosek::fusion::Expression > _5406){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5404.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5405).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5406.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5407,    monty::rc_ptr< ::mosek::fusion::Expression > _5408,    double _5409) { return mosek::fusion::p_Expr::vstack(_5407,_5408,_5409); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5407,monty::rc_ptr< ::mosek::fusion::Expression > _5408,double _5409){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5407.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5408.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5409).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5410,    monty::rc_ptr< ::mosek::fusion::Expression > _5411,    monty::rc_ptr< ::mosek::fusion::Expression > _5412) { return mosek::fusion::p_Expr::vstack(_5410,_5411,_5412); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5410,monty::rc_ptr< ::mosek::fusion::Expression > _5411,monty::rc_ptr< ::mosek::fusion::Expression > _5412){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5410.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5411.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5412.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5413,    monty::rc_ptr< ::mosek::fusion::Expression > _5414) { return mosek::fusion::p_Expr::vstack(_5413,_5414); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5413,monty::rc_ptr< ::mosek::fusion::Expression > _5414){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5413).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5414.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5415,    double _5416) { return mosek::fusion::p_Expr::vstack(_5415,_5416); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5415,double _5416){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5415.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5416).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5417,    monty::rc_ptr< ::mosek::fusion::Expression > _5418) { return mosek::fusion::p_Expr::vstack(_5417,_5418); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5417,monty::rc_ptr< ::mosek::fusion::Expression > _5418){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5417.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5418.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5419) { return mosek::fusion::p_Expr::vstack(_5419); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5419){
  if ((NULL == _5419.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument exprs may not be null"));
    }
  }
  {}
  int _9442 = (int)0;
  int _9443 = (int)((_5419)->size(0));
  for (int _5420 = _9442; _5420 < _9443; ++_5420)
  {
    {
      if ((NULL == ((*_5419)(_5420)).get()))
      {
        {
          throw monty::NullPointerException(std::string ("Arguments for vstack may not be null"));
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Expr::stack_(_5419,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5421,    monty::rc_ptr< ::mosek::fusion::Expression > _5422,    monty::rc_ptr< ::mosek::fusion::Expression > _5423) { return mosek::fusion::p_Expr::hstack(_5421,_5422,_5423); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5421,monty::rc_ptr< ::mosek::fusion::Expression > _5422,monty::rc_ptr< ::mosek::fusion::Expression > _5423){
  if (((NULL == _5421.get()) || ((NULL == _5422.get()) || (NULL == _5423.get()))))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments e1, e2 and e3 may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5421.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5422.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5423.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5424,    monty::rc_ptr< ::mosek::fusion::Expression > _5425,    double _5426) { return mosek::fusion::p_Expr::hstack(_5424,_5425,_5426); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5424,monty::rc_ptr< ::mosek::fusion::Expression > _5425,double _5426){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5424.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5425.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5426).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5427,    double _5428,    monty::rc_ptr< ::mosek::fusion::Expression > _5429) { return mosek::fusion::p_Expr::hstack(_5427,_5428,_5429); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5427,double _5428,monty::rc_ptr< ::mosek::fusion::Expression > _5429){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5427.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5428).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5429.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5430,    double _5431,    double _5432) { return mosek::fusion::p_Expr::hstack(_5430,_5431,_5432); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5430,double _5431,double _5432){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5430.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5431).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5432).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5433,    monty::rc_ptr< ::mosek::fusion::Expression > _5434,    monty::rc_ptr< ::mosek::fusion::Expression > _5435) { return mosek::fusion::p_Expr::hstack(_5433,_5434,_5435); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5433,monty::rc_ptr< ::mosek::fusion::Expression > _5434,monty::rc_ptr< ::mosek::fusion::Expression > _5435){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5433).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5434.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5435.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5436,    monty::rc_ptr< ::mosek::fusion::Expression > _5437,    double _5438) { return mosek::fusion::p_Expr::hstack(_5436,_5437,_5438); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5436,monty::rc_ptr< ::mosek::fusion::Expression > _5437,double _5438){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5436).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5437.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5438).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5439,    double _5440,    monty::rc_ptr< ::mosek::fusion::Expression > _5441) { return mosek::fusion::p_Expr::hstack(_5439,_5440,_5441); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5439,double _5440,monty::rc_ptr< ::mosek::fusion::Expression > _5441){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5439).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5440).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5441.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5442,    monty::rc_ptr< ::mosek::fusion::Expression > _5443) { return mosek::fusion::p_Expr::hstack(_5442,_5443); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5442,monty::rc_ptr< ::mosek::fusion::Expression > _5443){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5442).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5443.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5444,    double _5445) { return mosek::fusion::p_Expr::hstack(_5444,_5445); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5444,double _5445){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5444.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5445).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5446,    monty::rc_ptr< ::mosek::fusion::Expression > _5447) { return mosek::fusion::p_Expr::hstack(_5446,_5447); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5446,monty::rc_ptr< ::mosek::fusion::Expression > _5447){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5446.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5447.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5448) { return mosek::fusion::p_Expr::hstack(_5448); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5448){
  if ((NULL == _5448.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument exprs may not be null"));
    }
  }
  {}
  int _9444 = (int)0;
  int _9445 = (int)((_5448)->size(0));
  for (int _5449 = _9444; _5449 < _9445; ++_5449)
  {
    {
      if ((NULL == ((*_5448)(_5449)).get()))
      {
        {
          throw monty::NullPointerException(std::string ("Arguments for hstack may not be null"));
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Expr::stack_(_5448,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5450,    monty::rc_ptr< ::mosek::fusion::Expression > _5451,    monty::rc_ptr< ::mosek::fusion::Expression > _5452,    monty::rc_ptr< ::mosek::fusion::Expression > _5453) { return mosek::fusion::p_Expr::stack(_5450,_5451,_5452,_5453); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5450,monty::rc_ptr< ::mosek::fusion::Expression > _5451,monty::rc_ptr< ::mosek::fusion::Expression > _5452,monty::rc_ptr< ::mosek::fusion::Expression > _5453){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5451.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5452.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5453.get())}),_5450);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5454,    monty::rc_ptr< ::mosek::fusion::Expression > _5455,    monty::rc_ptr< ::mosek::fusion::Expression > _5456,    double _5457) { return mosek::fusion::p_Expr::stack(_5454,_5455,_5456,_5457); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5454,monty::rc_ptr< ::mosek::fusion::Expression > _5455,monty::rc_ptr< ::mosek::fusion::Expression > _5456,double _5457){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5455.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5456.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5457).get())}),_5454);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5458,    monty::rc_ptr< ::mosek::fusion::Expression > _5459,    double _5460,    monty::rc_ptr< ::mosek::fusion::Expression > _5461) { return mosek::fusion::p_Expr::stack(_5458,_5459,_5460,_5461); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5458,monty::rc_ptr< ::mosek::fusion::Expression > _5459,double _5460,monty::rc_ptr< ::mosek::fusion::Expression > _5461){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5459.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5460).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5461.get())}),_5458);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5462,    monty::rc_ptr< ::mosek::fusion::Expression > _5463,    double _5464,    double _5465) { return mosek::fusion::p_Expr::stack(_5462,_5463,_5464,_5465); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5462,monty::rc_ptr< ::mosek::fusion::Expression > _5463,double _5464,double _5465){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5463.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5464).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5465).get())}),_5462);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5466,    double _5467,    monty::rc_ptr< ::mosek::fusion::Expression > _5468,    monty::rc_ptr< ::mosek::fusion::Expression > _5469) { return mosek::fusion::p_Expr::stack(_5466,_5467,_5468,_5469); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5466,double _5467,monty::rc_ptr< ::mosek::fusion::Expression > _5468,monty::rc_ptr< ::mosek::fusion::Expression > _5469){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5467).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5468.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5469.get())}),_5466);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5470,    double _5471,    monty::rc_ptr< ::mosek::fusion::Expression > _5472,    double _5473) { return mosek::fusion::p_Expr::stack(_5470,_5471,_5472,_5473); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5470,double _5471,monty::rc_ptr< ::mosek::fusion::Expression > _5472,double _5473){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5471).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5472.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5473).get())}),_5470);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5474,    double _5475,    double _5476,    monty::rc_ptr< ::mosek::fusion::Expression > _5477) { return mosek::fusion::p_Expr::stack(_5474,_5475,_5476,_5477); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5474,double _5475,double _5476,monty::rc_ptr< ::mosek::fusion::Expression > _5477){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5475).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5476).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5477.get())}),_5474);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5478,    double _5479,    monty::rc_ptr< ::mosek::fusion::Expression > _5480) { return mosek::fusion::p_Expr::stack(_5478,_5479,_5480); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5478,double _5479,monty::rc_ptr< ::mosek::fusion::Expression > _5480){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5479).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5480.get())}),_5478);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5481,    monty::rc_ptr< ::mosek::fusion::Expression > _5482,    double _5483) { return mosek::fusion::p_Expr::stack(_5481,_5482,_5483); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5481,monty::rc_ptr< ::mosek::fusion::Expression > _5482,double _5483){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5482.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5483).get())}),_5481);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5484,    monty::rc_ptr< ::mosek::fusion::Expression > _5485,    monty::rc_ptr< ::mosek::fusion::Expression > _5486) { return mosek::fusion::p_Expr::stack(_5484,_5485,_5486); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5484,monty::rc_ptr< ::mosek::fusion::Expression > _5485,monty::rc_ptr< ::mosek::fusion::Expression > _5486){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5485.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5486.get())}),_5484);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5487,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5488) { return mosek::fusion::p_Expr::stack(_5487,_5488); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5487,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5488){
  return ::mosek::fusion::p_Expr::stack_(_5488,_5487);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5489,int _5490){
  if (((int)((_5489)->size(0)) == (int)1))
  {
    {
      return ((*_5489)((int)0));
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprStack::_new_ExprStack(::mosek::fusion::p_Expr::promote(_5489,_5490),_5490)).as<::mosek::fusion::Expression>();
    }
  }
}
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > mosek::fusion::p_Expr::promote(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5491,int _5492){
  int _5493 = (int)((_5491)->size(0));
  std::vector<int> _9446;
  for (int _5495 = (int)0, _9447 = _5493; _5495 < _9447 ; ++_5495)
  {
    _9446.push_back(((*_5491)(_5495))->getND());
  }
  auto _9448 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9446.size()),_9446.begin(),_9446.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5494 = _9448;
  _checked_ptr_1<int> _ptr__5494(_5494 ? _5494->raw() : nullptr,_5494 ? _5494->size(0) : 0);
  int _5496 = _ptr__5494[(int)0];
  int _5497 = _ptr__5494[(int)0];
  int _9449 = (int)1;
  int _9450 = _5493;
  for (int _5498 = _9449; _5498 < _9450; ++_5498)
  {
    {
      if ((_ptr__5494[_5498] < _5497))
      {
        {
          _5497 = _ptr__5494[_5498];
        }
      }
      {}
      if ((_ptr__5494[_5498] > _5496))
      {
        {
          _5496 = _ptr__5494[_5498];
        }
      }
      {}
    }
  }
  if ((_5496 < _5492))
  {
    {
      _5496 = _5492;
    }
  }
  {}
  if ((_5497 < _5496))
  {
    {
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5499 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_5493)));
      std::shared_ptr< monty::ndarray< int,1 > > _5500 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5496)));
      _checked_ptr_1<int> _ptr__5500(_5500 ? _5500->raw() : nullptr,_5500 ? _5500->size(0) : 0);
      int _9451 = (int)0;
      int _9452 = _5493;
      for (int _5501 = _9451; _5501 < _9452; ++_5501)
      {
        {
          if ((((*_5491)(_5501))->getND() == _5496))
          {
            {
              ((*_5499)(_5501)) = ((*_5491)(_5501));
            }
          }
          else
          {
            {
              std::shared_ptr< monty::ndarray< int,1 > > _5502 = ((*_5491)(_5501))->getShape();
              _checked_ptr_1<int> _ptr__5502(_5502 ? _5502->raw() : nullptr,_5502 ? _5502->size(0) : 0);
              int _9453 = (int)0;
              int _9454 = (int)((_5502)->size(0));
              for (int _5503 = _9453; _5503 < _9454; ++_5503)
              {
                {
                  _ptr__5500[_5503] = _ptr__5502[_5503];
                }
              }
              int _9455 = (int)((_5502)->size(0));
              int _9456 = _5496;
              for (int _5504 = _9455; _5504 < _9456; ++_5504)
              {
                {
                  _ptr__5500[_5504] = (int)1;
                }
              }
              ((*_5499)(_5501)) = (::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5500,((*_5491)(_5501)))).as<::mosek::fusion::Expression>();
            }
          }
        }
      }
      return _5499;
    }
  }
  else
  {
    {
      return _5491;
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::repeat  ( monty::rc_ptr< ::mosek::fusion::Expression > _5505,    int _5506,    int _5507) { return mosek::fusion::p_Expr::repeat(_5505,_5506,_5507); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::repeat(monty::rc_ptr< ::mosek::fusion::Expression > _5505,int _5506,int _5507){
  if ((_5506 <= (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Cannot repeat Expression 0 or less times"));
    }
  }
  {}
  std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _9457;
  for (int _5508 = (int)0, _9458 = _5506; _5508 < _9458 ; ++_5508)
  {
    _9457.push_back(_5505);
  }
  auto _9459 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_9457.size()),_9457.begin(),_9457.end()));
  return ::mosek::fusion::p_Expr::stack_(_9459,_5507);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5509) { return mosek::fusion::p_Expr::add(_5509); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5509){
  std::vector<double> _9460;
  for (int _5510 = (int)0, _9461 = (int)((_5509)->size(0)); _5510 < _9461 ; ++_5510)
  {
    _9460.push_back(1.0);
  }
  auto _9462 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9460.size()),_9460.begin(),_9460.end()));
  return (::mosek::fusion::p_ExprWSum::_new_ExprWSum(_5509,_9462)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5511) { return mosek::fusion::p_Expr::add(_5511); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5511){
  if ((NULL == _5511.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument vs may not be null"));
    }
  }
  {}
  if (((int)((_5511)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_Expr::_new_Expr(std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >{(long long)((int)0)}),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0))),nullptr,::mosek::fusion::p_Set::make((int)0),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  {}
  if ((((int)((_5511)->size(0)) > (int)0) && (NULL == ((*_5511)((int)0)).get())))
  {
    {
      throw monty::NullPointerException(std::string ("Argument vs may contain null"));
    }
  }
  {}
  int _5512 = ((*_5511)((int)0))->getND();
  int _9463 = (int)1;
  int _9464 = (int)((_5511)->size(0));
  for (int _5513 = _9463; _5513 < _9464; ++_5513)
  {
    {
      if ((_5512 < ((*_5511)(_5513))->getND()))
      {
        {
          _5512 = ((*_5511)(_5513))->getND();
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,2 > > _5514 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_5511)->size(0)),_5512)));
  int _9465 = (int)0;
  int _9466 = (int)((_5511)->size(0));
  for (int _5515 = _9465; _5515 < _9466; ++_5515)
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5516 = ((*_5511)(_5515))->getShape();
      _checked_ptr_1<int> _ptr__5516(_5516 ? _5516->raw() : nullptr,_5516 ? _5516->size(0) : 0);
      int _9467 = (int)0;
      int _9468 = (int)((_5516)->size(0));
      for (int _5517 = _9467; _5517 < _9468; ++_5517)
      {
        {
          ((*_5514)(_5515,_5517)) = _ptr__5516[_5517];
        }
      }
      int _9469 = (int)((_5516)->size(0));
      int _9470 = _5512;
      for (int _5518 = _9469; _5518 < _9470; ++_5518)
      {
        {
          ((*_5514)(_5515,_5518)) = (int)1;
        }
      }
    }
  }
  int _9471 = (int)1;
  int _9472 = (int)((_5511)->size(0));
  for (int _5519 = _9471; _5519 < _9472; ++_5519)
  {
    {
      int _9473 = (int)0;
      int _9474 = _5512;
      for (int _5520 = _9473; _5520 < _9474; ++_5520)
      {
        {
          if ((((*_5514)((int)0,_5520)) != ((*_5514)(_5519,_5520))))
          {
            {
              throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
            }
          }
          {}
        }
      }
    }
  }
  std::vector<int> _9475;
  for (int _5522 = (int)0, _9476 = _5512; _5522 < _9476 ; ++_5522)
  {
    _9475.push_back(((*_5514)((int)0,_5522)));
  }
  auto _9477 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9475.size()),_9475.begin(),_9475.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5521 = _9477;
  _checked_ptr_1<int> _ptr__5521(_5521 ? _5521->raw() : nullptr,_5521 ? _5521->size(0) : 0);
  int _5523 = (int)1;
  int _9478 = (int)0;
  int _9479 = _5512;
  for (int _5524 = _9478; _5524 < _9479; ++_5524)
  {
    {
      _5523 *= _ptr__5521[_5524];
    }
  }
  int _5525 = (int)0;
  int _5526 = (int)0;
  int _9480 = (int)0;
  int _9481 = (int)((_5511)->size(0));
  for (int _5527 = _9480; _5527 < _9481; ++_5527)
  {
    {
      int _5528 = ((*_5511)(_5527))->numInst();
      _5525 += _5528;
      int _9482;
      bool _9483 = (_5526 > _5528);
      if (_9483)
      {
        _9482 = _5526;
      }
      else
      {
        _9482 = _5528;
      }
      _5526 = _9482;
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _5529 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _5523,(int)1 ))));
  _checked_ptr_1<long long> _ptr__5529(_5529 ? _5529->raw() : nullptr,_5529 ? _5529->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5530 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5525)));
  _checked_ptr_1<long long> _ptr__5530(_5530 ? _5530->raw() : nullptr,_5530 ? _5530->size(0) : 0);
  std::vector<double> _9484;
  for (int _5532 = (int)0, _9485 = _5525; _5532 < _9485 ; ++_5532)
  {
    _9484.push_back(1.0);
  }
  auto _9486 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9484.size()),_9484.begin(),_9484.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5531 = _9486;
  _checked_ptr_1<double> _ptr__5531(_5531 ? _5531->raw() : nullptr,_5531 ? _5531->size(0) : 0);
  {
    std::shared_ptr< monty::ndarray< long long,1 > > _5533 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5526)));
    _checked_ptr_1<long long> _ptr__5533(_5533 ? _5533->raw() : nullptr,_5533 ? _5533->size(0) : 0);
    std::shared_ptr< monty::ndarray< long long,1 > > _5534 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5526)));
    _checked_ptr_1<long long> _ptr__5534(_5534 ? _5534->raw() : nullptr,_5534 ? _5534->size(0) : 0);
    int _9487 = (int)0;
    int _9488 = (int)((_5511)->size(0));
    for (int _5535 = _9487; _5535 < _9488; ++_5535)
    {
      {
        int _5536 = ((*_5511)(_5535))->inst((int)0,_5533,(int)0,_5534);
        int _9489 = (int)0;
        int _9490 = _5536;
        for (int _5537 = _9489; _5537 < _9490; ++_5537)
        {
          {
            _ptr__5529[safe_add( _ptr__5533[_5537],(int)1 )] += (int)1;
          }
        }
      }
    }
    int _9491 = (int)0;
    int _9492 = _5523;
    for (int _5538 = _9491; _5538 < _9492; ++_5538)
    {
      {
        _ptr__5529[safe_add( _5538,(int)1 )] += _ptr__5529[_5538];
      }
    }
    int _9493 = (int)0;
    int _9494 = (int)((_5511)->size(0));
    for (int _5539 = _9493; _5539 < _9494; ++_5539)
    {
      {
        int _5540 = ((*_5511)(_5539))->inst((int)0,_5533,(int)0,_5534);
        int _9495 = (int)0;
        int _9496 = _5540;
        for (int _5541 = _9495; _5541 < _9496; ++_5541)
        {
          {
            _ptr__5530[_ptr__5529[_ptr__5533[_5541]]] = _ptr__5534[_5541];
            ++ _ptr__5529[_ptr__5533[_5541]];
          }
        }
      }
    }
    int _9497 = (int)0;
    int _9498 = _5523;
    for (int _5542 = _9497; _5542 < _9498; ++_5542)
    {
      {
        _ptr__5529[(_5523 - _5542)] = _ptr__5529[((_5523 - _5542) - (int)1)];
      }
    }
    _ptr__5529[(int)0] = (int)0;
  }
  std::vector<double> _9499;
  for (int _5543 = (int)0, _9500 = _5523; _5543 < _9500 ; ++_5543)
  {
    _9499.push_back(0.0);
  }
  auto _9501 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9499.size()),_9499.begin(),_9499.end()));
  return (::mosek::fusion::p_Expr::_new_Expr(_5529,_5530,_5531,_9501,_5521,nullptr,(int)1)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add_(monty::rc_ptr< ::mosek::fusion::Expression > _5544,double _5545,monty::rc_ptr< ::mosek::fusion::Expression > _5546,double _5547){
  int _5548 = _5544->getND();
  int _5549 = _5546->getND();
  if ((_5548 == _5549))
  {
    {
      return (::mosek::fusion::p_ExprAdd::_new_ExprAdd(_5544,_5546,_5545,_5547)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      int _9502;
      bool _9503 = (_5548 > _5549);
      if (_9503)
      {
        _9502 = _5548;
      }
      else
      {
        _9502 = _5549;
      }
      int _5550 = _9502;
      std::shared_ptr< monty::ndarray< int,1 > > _5551 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5550)));
      _checked_ptr_1<int> _ptr__5551(_5551 ? _5551->raw() : nullptr,_5551 ? _5551->size(0) : 0);
      if ((_5548 < _5549))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _5552 = _5544->getShape();
          _checked_ptr_1<int> _ptr__5552(_5552 ? _5552->raw() : nullptr,_5552 ? _5552->size(0) : 0);
          int _9504 = (int)0;
          int _9505 = _5548;
          for (int _5553 = _9504; _5553 < _9505; ++_5553)
          {
            {
              _ptr__5551[_5553] = _ptr__5552[_5553];
            }
          }
          int _9506 = _5548;
          int _9507 = _5550;
          for (int _5554 = _9506; _5554 < _9507; ++_5554)
          {
            {
              _ptr__5551[_5554] = (int)1;
            }
          }
          return (::mosek::fusion::p_ExprAdd::_new_ExprAdd((::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5551,_5544)).as<::mosek::fusion::Expression>(),_5546,_5545,_5547)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _5555 = _5546->getShape();
          _checked_ptr_1<int> _ptr__5555(_5555 ? _5555->raw() : nullptr,_5555 ? _5555->size(0) : 0);
          int _9508 = (int)0;
          int _9509 = _5549;
          for (int _5556 = _9508; _5556 < _9509; ++_5556)
          {
            {
              _ptr__5551[_5556] = _ptr__5555[_5556];
            }
          }
          int _9510 = _5549;
          int _9511 = _5550;
          for (int _5557 = _9510; _5557 < _9511; ++_5557)
          {
            {
              _ptr__5551[_5557] = (int)1;
            }
          }
          return (::mosek::fusion::p_ExprAdd::_new_ExprAdd(_5544,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5551,_5546)).as<::mosek::fusion::Expression>(),_5545,_5547)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::transpose  ( monty::rc_ptr< ::mosek::fusion::Expression > _5558) { return mosek::fusion::p_Expr::transpose(_5558); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::transpose(monty::rc_ptr< ::mosek::fusion::Expression > _5558){
  if ((_5558->getND() == (int)0))
  {
    {
      return _5558;
    }
  }
  else if((_5558->getND() == (int)1))
  {
    {
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_5558->getDim((int)0))}),_5558)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5558->getND() == (int)2))
  {
    {
      return (::mosek::fusion::p_ExprTranspose::_new_ExprTranspose(_5558)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Incorrect number of dimensions for transpose"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5559,    monty::rc_ptr< ::mosek::fusion::Expression > _5560) { return mosek::fusion::p_Expr::mulElm(_5559,_5560); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Matrix > _5559,monty::rc_ptr< ::mosek::fusion::Expression > _5560){
  return ::mosek::fusion::p_Expr::mulElm_(_5559,_5560);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5561,    monty::rc_ptr< ::mosek::fusion::Expression > _5562) { return mosek::fusion::p_Expr::mulElm(_5561,_5562); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5561,monty::rc_ptr< ::mosek::fusion::Expression > _5562){
  return ::mosek::fusion::p_Expr::mulElm_(_5561,_5562);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( std::shared_ptr< monty::ndarray< double,2 > > _5563,    monty::rc_ptr< ::mosek::fusion::Expression > _5564) { return mosek::fusion::p_Expr::mulElm(_5563,_5564); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(std::shared_ptr< monty::ndarray< double,2 > > _5563,monty::rc_ptr< ::mosek::fusion::Expression > _5564){
  return ::mosek::fusion::p_Expr::mulElm_(::mosek::fusion::p_Matrix::dense(_5563),_5564);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( std::shared_ptr< monty::ndarray< double,1 > > _5565,    monty::rc_ptr< ::mosek::fusion::Expression > _5566) { return mosek::fusion::p_Expr::mulElm(_5565,_5566); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(std::shared_ptr< monty::ndarray< double,1 > > _5565,monty::rc_ptr< ::mosek::fusion::Expression > _5566){
  _checked_ptr_1<double> _ptr__5565(_5565 ? _5565->raw() : nullptr, _5565 ? _5565->size(0) : 0);
  return ::mosek::fusion::p_Expr::mulElm_(_5565,_5566);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5567,    monty::rc_ptr< ::mosek::fusion::Matrix > _5568) { return mosek::fusion::p_Expr::mulElm(_5567,_5568); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5567,monty::rc_ptr< ::mosek::fusion::Matrix > _5568){
  return ::mosek::fusion::p_Expr::mulElm_(_5568,_5567);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5569,    std::shared_ptr< monty::ndarray< double,2 > > _5570) { return mosek::fusion::p_Expr::mulElm(_5569,_5570); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5569,std::shared_ptr< monty::ndarray< double,2 > > _5570){
  return ::mosek::fusion::p_Expr::mulElm_(::mosek::fusion::p_Matrix::dense(_5570),_5569);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5571,    std::shared_ptr< monty::ndarray< double,1 > > _5572) { return mosek::fusion::p_Expr::mulElm(_5571,_5572); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5571,std::shared_ptr< monty::ndarray< double,1 > > _5572){
  _checked_ptr_1<double> _ptr__5572(_5572 ? _5572->raw() : nullptr, _5572 ? _5572->size(0) : 0);
  return ::mosek::fusion::p_Expr::mulElm_(_5572,_5571);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5573,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5574) { return mosek::fusion::p_Expr::mulElm(_5573,_5574); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5573,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5574){
  return ::mosek::fusion::p_Expr::mulElm_(_5574,_5573);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5575,    monty::rc_ptr< ::mosek::fusion::Expression > _5576) { return mosek::fusion::p_Expr::sub(_5575,_5576); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5575,monty::rc_ptr< ::mosek::fusion::Expression > _5576){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5575),1.0,_5576,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5577,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5578) { return mosek::fusion::p_Expr::sub(_5577,_5578); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5577,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5578){
  return ::mosek::fusion::p_Expr::add_(_5577,1.0,::mosek::fusion::p_Expr::constTerm(_5578),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5579,    monty::rc_ptr< ::mosek::fusion::Expression > _5580) { return mosek::fusion::p_Expr::sub(_5579,_5580); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Matrix > _5579,monty::rc_ptr< ::mosek::fusion::Expression > _5580){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5579),1.0,_5580,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5581,    monty::rc_ptr< ::mosek::fusion::Matrix > _5582) { return mosek::fusion::p_Expr::sub(_5581,_5582); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5581,monty::rc_ptr< ::mosek::fusion::Matrix > _5582){
  return ::mosek::fusion::p_Expr::add_(_5581,1.0,::mosek::fusion::p_Expr::constTerm(_5582),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( double _5583,    monty::rc_ptr< ::mosek::fusion::Expression > _5584) { return mosek::fusion::p_Expr::sub(_5583,_5584); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(double _5583,monty::rc_ptr< ::mosek::fusion::Expression > _5584){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5584->getShape(),_5583),1.0,_5584,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5585,    double _5586) { return mosek::fusion::p_Expr::sub(_5585,_5586); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5585,double _5586){
  return ::mosek::fusion::p_Expr::add_(_5585,1.0,::mosek::fusion::p_Expr::constTerm(_5585->getShape(),_5586),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( std::shared_ptr< monty::ndarray< double,2 > > _5587,    monty::rc_ptr< ::mosek::fusion::Expression > _5588) { return mosek::fusion::p_Expr::sub(_5587,_5588); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(std::shared_ptr< monty::ndarray< double,2 > > _5587,monty::rc_ptr< ::mosek::fusion::Expression > _5588){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5587),1.0,_5588,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( std::shared_ptr< monty::ndarray< double,1 > > _5589,    monty::rc_ptr< ::mosek::fusion::Expression > _5590) { return mosek::fusion::p_Expr::sub(_5589,_5590); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(std::shared_ptr< monty::ndarray< double,1 > > _5589,monty::rc_ptr< ::mosek::fusion::Expression > _5590){
  _checked_ptr_1<double> _ptr__5589(_5589 ? _5589->raw() : nullptr, _5589 ? _5589->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5589),1.0,_5590,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5591,    std::shared_ptr< monty::ndarray< double,2 > > _5592) { return mosek::fusion::p_Expr::sub(_5591,_5592); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5591,std::shared_ptr< monty::ndarray< double,2 > > _5592){
  return ::mosek::fusion::p_Expr::add_(_5591,1.0,::mosek::fusion::p_Expr::constTerm(_5592),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5593,    std::shared_ptr< monty::ndarray< double,1 > > _5594) { return mosek::fusion::p_Expr::sub(_5593,_5594); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5593,std::shared_ptr< monty::ndarray< double,1 > > _5594){
  _checked_ptr_1<double> _ptr__5594(_5594 ? _5594->raw() : nullptr, _5594 ? _5594->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(_5593,1.0,::mosek::fusion::p_Expr::constTerm(_5594),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5595,    monty::rc_ptr< ::mosek::fusion::Expression > _5596) { return mosek::fusion::p_Expr::sub(_5595,_5596); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5595,monty::rc_ptr< ::mosek::fusion::Expression > _5596){
  return ::mosek::fusion::p_Expr::add_(_5595,1.0,_5596,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5597,    monty::rc_ptr< ::mosek::fusion::Expression > _5598) { return mosek::fusion::p_Expr::add(_5597,_5598); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5597,monty::rc_ptr< ::mosek::fusion::Expression > _5598){
  return ::mosek::fusion::p_Expr::add_(_5598,1.0,::mosek::fusion::p_Expr::constTerm(_5597),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5599,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5600) { return mosek::fusion::p_Expr::add(_5599,_5600); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5599,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5600){
  return ::mosek::fusion::p_Expr::add_(_5599,1.0,::mosek::fusion::p_Expr::constTerm(_5600),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5601,    monty::rc_ptr< ::mosek::fusion::Expression > _5602) { return mosek::fusion::p_Expr::add(_5601,_5602); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Matrix > _5601,monty::rc_ptr< ::mosek::fusion::Expression > _5602){
  return ::mosek::fusion::p_Expr::add_(_5602,1.0,::mosek::fusion::p_Expr::constTerm(_5601),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5603,    monty::rc_ptr< ::mosek::fusion::Matrix > _5604) { return mosek::fusion::p_Expr::add(_5603,_5604); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5603,monty::rc_ptr< ::mosek::fusion::Matrix > _5604){
  return ::mosek::fusion::p_Expr::add_(_5603,1.0,::mosek::fusion::p_Expr::constTerm(_5604),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( double _5605,    monty::rc_ptr< ::mosek::fusion::Expression > _5606) { return mosek::fusion::p_Expr::add(_5605,_5606); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(double _5605,monty::rc_ptr< ::mosek::fusion::Expression > _5606){
  return ::mosek::fusion::p_Expr::add_(_5606,1.0,::mosek::fusion::p_Expr::constTerm(_5606->getShape(),_5605),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5607,    double _5608) { return mosek::fusion::p_Expr::add(_5607,_5608); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5607,double _5608){
  return ::mosek::fusion::p_Expr::add_(_5607,1.0,::mosek::fusion::p_Expr::constTerm(_5607->getShape(),_5608),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< double,2 > > _5609,    monty::rc_ptr< ::mosek::fusion::Expression > _5610) { return mosek::fusion::p_Expr::add(_5609,_5610); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< double,2 > > _5609,monty::rc_ptr< ::mosek::fusion::Expression > _5610){
  return ::mosek::fusion::p_Expr::add_(_5610,1.0,::mosek::fusion::p_Expr::constTerm(_5609),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< double,1 > > _5611,    monty::rc_ptr< ::mosek::fusion::Expression > _5612) { return mosek::fusion::p_Expr::add(_5611,_5612); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< double,1 > > _5611,monty::rc_ptr< ::mosek::fusion::Expression > _5612){
  _checked_ptr_1<double> _ptr__5611(_5611 ? _5611->raw() : nullptr, _5611 ? _5611->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(_5612,1.0,::mosek::fusion::p_Expr::constTerm(_5611),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5613,    std::shared_ptr< monty::ndarray< double,2 > > _5614) { return mosek::fusion::p_Expr::add(_5613,_5614); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5613,std::shared_ptr< monty::ndarray< double,2 > > _5614){
  return ::mosek::fusion::p_Expr::add_(_5613,1.0,::mosek::fusion::p_Expr::constTerm(_5614),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5615,    std::shared_ptr< monty::ndarray< double,1 > > _5616) { return mosek::fusion::p_Expr::add(_5615,_5616); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5615,std::shared_ptr< monty::ndarray< double,1 > > _5616){
  _checked_ptr_1<double> _ptr__5616(_5616 ? _5616->raw() : nullptr, _5616 ? _5616->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(_5615,1.0,::mosek::fusion::p_Expr::constTerm(_5616),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5617,    monty::rc_ptr< ::mosek::fusion::Expression > _5618) { return mosek::fusion::p_Expr::add(_5617,_5618); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5617,monty::rc_ptr< ::mosek::fusion::Expression > _5618){
  return ::mosek::fusion::p_Expr::add_(_5617,1.0,_5618,1.0);
}
int mosek::fusion::Expr :: getND() { return mosek::fusion::p_Expr::_get_impl(this)->getND(); }int mosek::fusion::p_Expr::getND(){
  return (int)((shape)->size(0));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Expr :: getShape() { return mosek::fusion::p_Expr::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Expr::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
void mosek::fusion::Expr :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5619,monty::rc_ptr< ::mosek::fusion::WorkStack > _5620,monty::rc_ptr< ::mosek::fusion::WorkStack > _5621) { mosek::fusion::p_Expr::_get_impl(this)->eval(_5619,_5620,_5621); }void mosek::fusion::p_Expr::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5619,monty::rc_ptr< ::mosek::fusion::WorkStack > _5620,monty::rc_ptr< ::mosek::fusion::WorkStack > _5621){
  std::vector<int> _9512;
  for (int _5622 = (int)0, _9513 = (int)((ptrb)->size(0)); _5622 < _9513 ; ++_5622)
  {
    _9512.push_back((int)((*ptrb)(_5622)));
  }
  auto _9514 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9512.size()),_9512.begin(),_9512.end()));
  ::mosek::fusion::p_BaseExpression::storeexpr(_5619,shape,_9514,inst,subj,cof_v,bfix);
}
void mosek::fusion::p_Expr::validateData(std::shared_ptr< monty::ndarray< long long,1 > > _5623,std::shared_ptr< monty::ndarray< long long,1 > > _5624,std::shared_ptr< monty::ndarray< double,1 > > _5625,std::shared_ptr< monty::ndarray< double,1 > > _5626,std::shared_ptr< monty::ndarray< int,1 > > _5627,std::shared_ptr< monty::ndarray< long long,1 > > _5628){
  _checked_ptr_1<long long> _ptr__5623(_5623 ? _5623->raw() : nullptr, _5623 ? _5623->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5624(_5624 ? _5624->raw() : nullptr, _5624 ? _5624->size(0) : 0);
  _checked_ptr_1<double> _ptr__5625(_5625 ? _5625->raw() : nullptr, _5625 ? _5625->size(0) : 0);
  _checked_ptr_1<double> _ptr__5626(_5626 ? _5626->raw() : nullptr, _5626 ? _5626->size(0) : 0);
  _checked_ptr_1<int> _ptr__5627(_5627 ? _5627->raw() : nullptr, _5627 ? _5627->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5628(_5628 ? _5628->raw() : nullptr, _5628 ? _5628->size(0) : 0);
  if ((NULL == _5627.get()))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'shape' in expression is null"));
    }
  }
  {}
  int _5629 = ((int)((_5623)->size(0)) - (int)1);
  long long _5630 = _ptr__5623[((int)((_5623)->size(0)) - (int)1)];
  int _5631 = (int)((_5627)->size(0));
  long long _5632 = (long long)1;
  int _9515 = (int)0;
  int _9516 = _5631;
  for (int _5633 = _9515; _5633 < _9516; ++_5633)
  {
    {
      _5632 *= _ptr__5627[_5633];
    }
  }
  if (((int)((_5623)->size(0)) < (int)1))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'ptrb' in expression has wrong size"));
    }
  }
  {}
  if ((_5630 != (int)((_5624)->size(0))))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'subj' in expression has wrong size"));
    }
  }
  {}
  if ((_5630 != (int)((_5625)->size(0))))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'cof' in expression has wrong size"));
    }
  }
  {}
  if (((NULL == _5626.get()) || (_5629 != (int)((_5626)->size(0)))))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'bfix' in expression has wrong length"));
    }
  }
  {}
  if (((NULL != _5628.get()) && ((int)((_5628)->size(0)) < _5632)))
  {
    {
      if (((int)((_5628)->size(0)) != ((int)((_5623)->size(0)) - (int)1)))
      {
        {
          throw ::mosek::fusion::ExpressionError(std::string ("Array 'inst' in expression has wrong length"));
        }
      }
      {}
      if (((int)((_5628)->size(0)) > (int)0))
      {
        {
          if (((_ptr__5628[(int)0] < (int)0) || (_ptr__5628[(int)0] >= _5632)))
          {
            {
              throw ::mosek::fusion::ExpressionError(std::string ("Array 'inst' contains an invalid index"));
            }
          }
          {}
          bool _5634 = true;
          long long _5635 = _5632;
          int _9517 = (int)1;
          int _9518 = (int)((_5628)->size(0));
          for (int _5636 = _9517; _5636 < _9518; ++_5636)
          {
            {
              _5634 = (_5634 && ((_ptr__5628[_5636] >= (int)0) && ((_ptr__5628[_5636] < _5635) && (_ptr__5628[_5636] > _ptr__5628[(_5636 - (int)1)]))));
            }
          }
          if ((!_5634))
          {
            {
              throw ::mosek::fusion::ExpressionError(std::string ("Invalid array 'inst'"));
            }
          }
          {}
        }
      }
      {}
    }
  }
  else
  {
    {
      if ((_5632 != ((long long)((_5623)->size(0)) - (int)1)))
      {
        {
          throw ::mosek::fusion::ExpressionError(std::string ("Array 'ptrb' in expression has wrong length"));
        }
      }
      {}
    }
  }
  bool _5637 = false;
  bool _5638 = false;
  if ((_ptr__5623[(int)0] != (long long)0))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Invalid 'ptrb' argument in expression"));
    }
  }
  {}
  bool _5639 = true;
  int _9519 = (int)0;
  int _9520 = _5629;
  for (int _5640 = _9519; _5640 < _9520; ++_5640)
  {
    {
      _5639 = (_5639 && (_ptr__5623[_5640] <= _ptr__5623[safe_add( _5640,(int)1 )]));
    }
  }
  if ((!_5639))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Invalid 'ptrb' argument in expression"));
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Expr::extractModel(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5641){
  monty::rc_ptr< ::mosek::fusion::Model > _9521;
  bool _9522 = ((NULL == _5641.get()) || ((int)((_5641)->size(0)) == (int)0));
  if (_9522)
  {
    _9521 = nullptr;
  }
  else
  {
    _9521 = ((*_5641)((int)0))->__mosek_2fusion_2Variable__getModel();
  }
  return _9521;
}
void mosek::fusion::p_Expr::destroy(){inst.reset();cof_v.reset();subj.reset();ptrb.reset();bfix.reset();shape.reset();}void mosek::fusion::Expr::destroy() { mosek::fusion::p_Expr::_get_impl(this)->destroy(); }monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::pick(std::shared_ptr< monty::ndarray< int,2 > > _5642) { return __mosek_2fusion_2Expression__pick(_5642); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::pick(std::shared_ptr< monty::ndarray< int,1 > > _5643) { return __mosek_2fusion_2Expression__pick(_5643); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::index(std::shared_ptr< monty::ndarray< int,1 > > _5644) { return __mosek_2fusion_2Expression__index(_5644); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::index(int _5645) { return __mosek_2fusion_2Expression__index(_5645); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::slice(std::shared_ptr< monty::ndarray< int,1 > > _5646,std::shared_ptr< monty::ndarray< int,1 > > _5647) { return __mosek_2fusion_2Expression__slice(_5646,_5647); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::slice(int _5648,int _5649) { return __mosek_2fusion_2Expression__slice(_5648,_5649); }
monty::rc_ptr< mosek::fusion::FlatExpr > mosek::fusion::Expression::eval() { return __mosek_2fusion_2Expression__eval(); }
mosek::fusion::FlatExpr::FlatExpr(mosek::fusion::p_FlatExpr *_impl) : _impl(_impl) { /*std::cout << "FlatExpr() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::FlatExpr::~FlatExpr() { delete _impl; _impl = nullptr; }mosek::fusion::p_FlatExpr::p_FlatExpr  (::mosek::fusion::FlatExpr * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::FlatExpr::get_inst() { return _impl->inst; }
void mosek::fusion::FlatExpr::set_inst(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->inst = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::FlatExpr::get_shape() { return _impl->shape; }
void mosek::fusion::FlatExpr::set_shape(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->shape = _val; }
long long mosek::fusion::FlatExpr::get_nnz() { return _impl->nnz; }
void mosek::fusion::FlatExpr::set_nnz(long long _val) { _impl->nnz = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::FlatExpr::get_cof() { return _impl->cof; }
void mosek::fusion::FlatExpr::set_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->cof = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::FlatExpr::get_subj() { return _impl->subj; }
void mosek::fusion::FlatExpr::set_subj(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->subj = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::FlatExpr::get_ptrb() { return _impl->ptrb; }
void mosek::fusion::FlatExpr::set_ptrb(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->ptrb = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::FlatExpr::get_bfix() { return _impl->bfix; }
void mosek::fusion::FlatExpr::set_bfix(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bfix = _val; }
mosek::fusion::FlatExpr::t mosek::fusion::p_FlatExpr::_new_FlatExpr  (monty::rc_ptr< ::mosek::fusion::FlatExpr > _5654){ return new mosek::fusion::FlatExpr(_5654); }mosek::fusion::FlatExpr::FlatExpr  (monty::rc_ptr< ::mosek::fusion::FlatExpr > _5654) :    FlatExpr(new mosek::fusion::p_FlatExpr(this)){ mosek::fusion::p_FlatExpr::_get_impl(this)->_initialize(_5654); }void mosek::fusion::p_FlatExpr::_initialize  (monty::rc_ptr< ::mosek::fusion::FlatExpr > _5654){monty::rc_reserve __reserve_this(_pubthis);   {
    bfix = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5654)->bfix);
    ptrb = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5654)->ptrb);
    subj = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5654)->subj);
    cof = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5654)->cof);
    nnz = mosek::fusion::p_FlatExpr::_get_impl(_5654)->nnz;
    shape = mosek::fusion::p_FlatExpr::_get_impl(_5654)->shape;
    inst = mosek::fusion::p_FlatExpr::_get_impl(_5654)->inst;
  }
}mosek::fusion::FlatExpr::t mosek::fusion::p_FlatExpr::_new_FlatExpr  (std::shared_ptr< monty::ndarray< double,1 > > _5655,    std::shared_ptr< monty::ndarray< long long,1 > > _5656,    std::shared_ptr< monty::ndarray< long long,1 > > _5657,    std::shared_ptr< monty::ndarray< double,1 > > _5658,    std::shared_ptr< monty::ndarray< int,1 > > _5659,    std::shared_ptr< monty::ndarray< long long,1 > > _5660){ return new mosek::fusion::FlatExpr(_5655,_5656,_5657,_5658,_5659,_5660); }mosek::fusion::FlatExpr::FlatExpr  (std::shared_ptr< monty::ndarray< double,1 > > _5655,    std::shared_ptr< monty::ndarray< long long,1 > > _5656,    std::shared_ptr< monty::ndarray< long long,1 > > _5657,    std::shared_ptr< monty::ndarray< double,1 > > _5658,    std::shared_ptr< monty::ndarray< int,1 > > _5659,    std::shared_ptr< monty::ndarray< long long,1 > > _5660) :    FlatExpr(new mosek::fusion::p_FlatExpr(this)){ mosek::fusion::p_FlatExpr::_get_impl(this)->_initialize(_5655,_5656,_5657,_5658,_5659,_5660); }void mosek::fusion::p_FlatExpr::_initialize  (std::shared_ptr< monty::ndarray< double,1 > > _5655,    std::shared_ptr< monty::ndarray< long long,1 > > _5656,    std::shared_ptr< monty::ndarray< long long,1 > > _5657,    std::shared_ptr< monty::ndarray< double,1 > > _5658,    std::shared_ptr< monty::ndarray< int,1 > > _5659,    std::shared_ptr< monty::ndarray< long long,1 > > _5660){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__5655(_5655 ? _5655->raw() : nullptr, _5655 ? _5655->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5656(_5656 ? _5656->raw() : nullptr, _5656 ? _5656->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5657(_5657 ? _5657->raw() : nullptr, _5657 ? _5657->size(0) : 0);
    _checked_ptr_1<double> _ptr__5658(_5658 ? _5658->raw() : nullptr, _5658 ? _5658->size(0) : 0);
    _checked_ptr_1<int> _ptr__5659(_5659 ? _5659->raw() : nullptr, _5659 ? _5659->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5660(_5660 ? _5660->raw() : nullptr, _5660 ? _5660->size(0) : 0);
    if (((NULL != _5655.get()) && ((int)((_5655)->size(0)) != ((int)((_5656)->size(0)) - (int)1))))
    {
      {
        throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching lengths of bfix and ptrb"));
      }
    }
    {}
    if (((NULL == _5658.get()) || ((NULL == _5657.get()) || ((int)((_5657)->size(0)) != (int)((_5658)->size(0))))))
    {
      {
        throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching lengths of subj and cof"));
      }
    }
    {}
    if ((NULL != _5659.get()))
    {
      {
        if ((NULL != _5660.get()))
        {
          {
            if (((int)((_5660)->size(0)) != ((int)((_5656)->size(0)) - (int)1)))
            {
              {
                throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching lengths of inst and ptrb"));
              }
            }
            {}
          }
        }
        else if((::mosek::fusion::p_Set::size(_5659) != ((long long)((_5656)->size(0)) - (int)1)))
        {
          {
            throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching shape and ptrb"));
          }
        }
        {}
      }
    }
    {}
    bfix = _5655;
    ptrb = _5656;
    subj = _5657;
    cof = _5658;
    nnz = ((*ptrb)(((int)((ptrb)->size(0)) - (int)1)));
    shape = _5659;
    inst = _5660;
  }
}std::string mosek::fusion::FlatExpr :: toString() { return mosek::fusion::p_FlatExpr::_get_impl(this)->toString(); }std::string mosek::fusion::p_FlatExpr::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _5661 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _5661->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("FlatExpr:"))->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("+-----------------"))->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| ptrb["))->__mosek_2fusion_2Utils_2StringBuffer__a((int)((ptrb)->size(0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(ptrb)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| subj["))->__mosek_2fusion_2Utils_2StringBuffer__a((int)((subj)->size(0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(subj)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| cof ["))->__mosek_2fusion_2Utils_2StringBuffer__a((int)((cof)->size(0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(cof)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| bfix["));
  if ((NULL != bfix.get()))
  {
    {
      _5661->__mosek_2fusion_2Utils_2StringBuffer__a((int)((bfix)->size(0)));
    }
  }
  {}
  _5661->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(bfix)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| inst["));
  if ((NULL != inst.get()))
  {
    {
      _5661->__mosek_2fusion_2Utils_2StringBuffer__a((int)((inst)->size(0)));
    }
  }
  {}
  _5661->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(inst)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("+-----------------"));
  return _5661->toString();
}
int mosek::fusion::FlatExpr :: size() { return mosek::fusion::p_FlatExpr::_get_impl(this)->size(); }int mosek::fusion::p_FlatExpr::size(){
  return ((int)((ptrb)->size(0)) - (int)1);
}
void mosek::fusion::p_FlatExpr::destroy(){inst.reset();shape.reset();cof.reset();subj.reset();ptrb.reset();bfix.reset();}void mosek::fusion::FlatExpr::destroy() { mosek::fusion::p_FlatExpr::_get_impl(this)->destroy(); }mosek::fusion::SymmetricMatrix::SymmetricMatrix(mosek::fusion::p_SymmetricMatrix *_impl) : _impl(_impl) { /*std::cout << "SymmetricMatrix() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SymmetricMatrix::~SymmetricMatrix() { delete _impl; _impl = nullptr; }mosek::fusion::p_SymmetricMatrix::p_SymmetricMatrix  (::mosek::fusion::SymmetricMatrix * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::SymmetricMatrix::t mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix  (int _5662,    int _5663,    std::shared_ptr< monty::ndarray< int,1 > > _5664,    std::shared_ptr< monty::ndarray< int,1 > > _5665,    std::shared_ptr< monty::ndarray< double,1 > > _5666,    std::shared_ptr< monty::ndarray< int,1 > > _5667,    std::shared_ptr< monty::ndarray< int,1 > > _5668,    std::shared_ptr< monty::ndarray< double,1 > > _5669,    double _5670){ return new mosek::fusion::SymmetricMatrix(_5662,_5663,_5664,_5665,_5666,_5667,_5668,_5669,_5670); }mosek::fusion::SymmetricMatrix::SymmetricMatrix  (int _5662,    int _5663,    std::shared_ptr< monty::ndarray< int,1 > > _5664,    std::shared_ptr< monty::ndarray< int,1 > > _5665,    std::shared_ptr< monty::ndarray< double,1 > > _5666,    std::shared_ptr< monty::ndarray< int,1 > > _5667,    std::shared_ptr< monty::ndarray< int,1 > > _5668,    std::shared_ptr< monty::ndarray< double,1 > > _5669,    double _5670) :    SymmetricMatrix(new mosek::fusion::p_SymmetricMatrix(this)){ mosek::fusion::p_SymmetricMatrix::_get_impl(this)->_initialize(_5662,_5663,_5664,_5665,_5666,_5667,_5668,_5669,_5670); }void mosek::fusion::p_SymmetricMatrix::_initialize  (int _5662,    int _5663,    std::shared_ptr< monty::ndarray< int,1 > > _5664,    std::shared_ptr< monty::ndarray< int,1 > > _5665,    std::shared_ptr< monty::ndarray< double,1 > > _5666,    std::shared_ptr< monty::ndarray< int,1 > > _5667,    std::shared_ptr< monty::ndarray< int,1 > > _5668,    std::shared_ptr< monty::ndarray< double,1 > > _5669,    double _5670){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5664(_5664 ? _5664->raw() : nullptr, _5664 ? _5664->size(0) : 0);
    _checked_ptr_1<int> _ptr__5665(_5665 ? _5665->raw() : nullptr, _5665 ? _5665->size(0) : 0);
    _checked_ptr_1<double> _ptr__5666(_5666 ? _5666->raw() : nullptr, _5666 ? _5666->size(0) : 0);
    _checked_ptr_1<int> _ptr__5667(_5667 ? _5667->raw() : nullptr, _5667 ? _5667->size(0) : 0);
    _checked_ptr_1<int> _ptr__5668(_5668 ? _5668->raw() : nullptr, _5668 ? _5668->size(0) : 0);
    _checked_ptr_1<double> _ptr__5669(_5669 ? _5669->raw() : nullptr, _5669 ? _5669->size(0) : 0);
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->d0 = _5662;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->d1 = _5663;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->usubi = _5664;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->usubj = _5665;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->uval = _5666;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->vsubi = _5667;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->vsubj = _5668;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->vval = _5669;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->scale = _5670;
    nnz = (-(int)1);
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::rankOne  ( int _5671,    std::shared_ptr< monty::ndarray< int,1 > > _5672,    std::shared_ptr< monty::ndarray< double,1 > > _5673) { return mosek::fusion::p_SymmetricMatrix::rankOne(_5671,_5672,_5673); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::rankOne(int _5671,std::shared_ptr< monty::ndarray< int,1 > > _5672,std::shared_ptr< monty::ndarray< double,1 > > _5673){
  _checked_ptr_1<int> _ptr__5672(_5672 ? _5672->raw() : nullptr, _5672 ? _5672->size(0) : 0);
  _checked_ptr_1<double> _ptr__5673(_5673 ? _5673->raw() : nullptr, _5673 ? _5673->size(0) : 0);
  if (((int)((_5672)->size(0)) != (int)((_5673)->size(0))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching array lengths"));
    }
  }
  {}
  int _9523 = (int)0;
  int _9524 = (int)((_5672)->size(0));
  for (int _5674 = _9523; _5674 < _9524; ++_5674)
  {
    {
      if (((_ptr__5672[_5674] < (int)0) || (_ptr__5672[_5674] >= _5671)))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid index in argument 'sub'"));
        }
      }
      {}
    }
  }
  std::vector<int> _9525;
  for (int _5676 = (int)0, _9526 = (int)((_5672)->size(0)); _5676 < _9526 ; ++_5676)
  {
    _9525.push_back(_ptr__5672[_5676]);
  }
  auto _9527 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9525.size()),_9525.begin(),_9525.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5675 = _9527;
  _checked_ptr_1<int> _ptr__5675(_5675 ? _5675->raw() : nullptr,_5675 ? _5675->size(0) : 0);
  std::vector<int> _9528;
  for (int _5678 = (int)0, _9529 = (int)((_5672)->size(0)); _5678 < _9529 ; ++_5678)
  {
    _9528.push_back((int)1);
  }
  auto _9530 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9528.size()),_9528.begin(),_9528.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5677 = _9530;
  _checked_ptr_1<int> _ptr__5677(_5677 ? _5677->raw() : nullptr,_5677 ? _5677->size(0) : 0);
  std::vector<double> _9531;
  for (int _5680 = (int)0, _9532 = (int)((_5673)->size(0)); _5680 < _9532 ; ++_5680)
  {
    _9531.push_back(_ptr__5673[_5680]);
  }
  auto _9533 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9531.size()),_9531.begin(),_9531.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5679 = _9533;
  _checked_ptr_1<double> _ptr__5679(_5679 ? _5679->raw() : nullptr,_5679 ? _5679->size(0) : 0);
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5671,(int)1,_5675,_5677,_5679,_5675,_5677,_5679,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::rankOne  ( std::shared_ptr< monty::ndarray< double,1 > > _5681) { return mosek::fusion::p_SymmetricMatrix::rankOne(_5681); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::rankOne(std::shared_ptr< monty::ndarray< double,1 > > _5681){
  _checked_ptr_1<double> _ptr__5681(_5681 ? _5681->raw() : nullptr, _5681 ? _5681->size(0) : 0);
  int _5682 = (int)((_5681)->size(0));
  std::vector<int> _9534;
  for (int _5684 = (int)0, _9535 = _5682; _5684 < _9535 ; ++_5684)
  {
    _9534.push_back(_5684);
  }
  auto _9536 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9534.size()),_9534.begin(),_9534.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5683 = _9536;
  _checked_ptr_1<int> _ptr__5683(_5683 ? _5683->raw() : nullptr,_5683 ? _5683->size(0) : 0);
  std::vector<int> _9537;
  for (int _5686 = (int)0, _9538 = _5682; _5686 < _9538 ; ++_5686)
  {
    _9537.push_back((int)1);
  }
  auto _9539 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9537.size()),_9537.begin(),_9537.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5685 = _9539;
  _checked_ptr_1<int> _ptr__5685(_5685 ? _5685->raw() : nullptr,_5685 ? _5685->size(0) : 0);
  std::vector<double> _9540;
  for (int _5688 = (int)0, _9541 = _5682; _5688 < _9541 ; ++_5688)
  {
    _9540.push_back(_ptr__5681[_5688]);
  }
  auto _9542 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9540.size()),_9540.begin(),_9540.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5687 = _9542;
  _checked_ptr_1<double> _ptr__5687(_5687 ? _5687->raw() : nullptr,_5687 ? _5687->size(0) : 0);
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5682,(int)1,_5683,_5685,_5687,_5683,_5685,_5687,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::antiDiag  ( std::shared_ptr< monty::ndarray< double,1 > > _5689) { return mosek::fusion::p_SymmetricMatrix::antiDiag(_5689); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::antiDiag(std::shared_ptr< monty::ndarray< double,1 > > _5689){
  _checked_ptr_1<double> _ptr__5689(_5689 ? _5689->raw() : nullptr, _5689 ? _5689->size(0) : 0);
  int _5690 = (int)((_5689)->size(0));
  std::vector<int> _9543;
  for (int _5692 = (int)0, _9544 = _5690; _5692 < _9544 ; ++_5692)
  {
    _9543.push_back(_5692);
  }
  auto _9545 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9543.size()),_9543.begin(),_9543.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5691 = _9545;
  _checked_ptr_1<int> _ptr__5691(_5691 ? _5691->raw() : nullptr,_5691 ? _5691->size(0) : 0);
  std::vector<int> _9546;
  for (int _5693 = (int)0, _9547 = _5690; _5693 < _9547 ; ++_5693)
  {
    _9546.push_back((_5690 - _5693));
  }
  auto _9548 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9546.size()),_9546.begin(),_9546.end()));
  std::vector<double> _9549;
  for (int _5694 = (int)0, _9550 = _5690; _5694 < _9550 ; ++_5694)
  {
    _9549.push_back(_ptr__5689[_5694]);
  }
  auto _9551 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9549.size()),_9549.begin(),_9549.end()));
  std::vector<double> _9552;
  for (int _5695 = (int)0, _9553 = _5690; _5695 < _9553 ; ++_5695)
  {
    _9552.push_back(1.0);
  }
  auto _9554 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9552.size()),_9552.begin(),_9552.end()));
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5690,_5690,_5691,_9548,_9551,_5691,_5691,_9554,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::diag  ( std::shared_ptr< monty::ndarray< double,1 > > _5696) { return mosek::fusion::p_SymmetricMatrix::diag(_5696); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::diag(std::shared_ptr< monty::ndarray< double,1 > > _5696){
  _checked_ptr_1<double> _ptr__5696(_5696 ? _5696->raw() : nullptr, _5696 ? _5696->size(0) : 0);
  int _5697 = (int)((_5696)->size(0));
  std::vector<int> _9555;
  for (int _5699 = (int)0, _9556 = _5697; _5699 < _9556 ; ++_5699)
  {
    _9555.push_back(_5699);
  }
  auto _9557 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9555.size()),_9555.begin(),_9555.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5698 = _9557;
  _checked_ptr_1<int> _ptr__5698(_5698 ? _5698->raw() : nullptr,_5698 ? _5698->size(0) : 0);
  std::vector<double> _9558;
  for (int _5700 = (int)0, _9559 = _5697; _5700 < _9559 ; ++_5700)
  {
    _9558.push_back(_ptr__5696[_5700]);
  }
  auto _9560 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9558.size()),_9558.begin(),_9558.end()));
  std::vector<double> _9561;
  for (int _5701 = (int)0, _9562 = _5697; _5701 < _9562 ; ++_5701)
  {
    _9561.push_back(1.0);
  }
  auto _9563 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9561.size()),_9561.begin(),_9561.end()));
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5697,_5697,_5698,_5698,_9560,_5698,_5698,_9563,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix :: __mosek_2fusion_2SymmetricMatrix__add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5702) { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->__mosek_2fusion_2SymmetricMatrix__add(_5702); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5702) { return __mosek_2fusion_2SymmetricMatrix__add(_5702); }
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::__mosek_2fusion_2SymmetricMatrix__add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5702){
  int _5703 = _pubthis->getdim();
  if ((_5702->getdim() != _5703))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions"));
    }
  }
  {}
  int _5704 = (int)((usubi)->size(0));
  int _5705 = (int)((mosek::fusion::p_SymmetricMatrix::_get_impl(_5702)->usubi)->size(0));
  int _5706 = safe_add( _5704,_5705 );
  int _5707 = (int)((vsubi)->size(0));
  int _5708 = (int)((mosek::fusion::p_SymmetricMatrix::_get_impl(_5702)->vsubi)->size(0));
  int _5709 = safe_add( _5707,_5708 );
  std::shared_ptr< monty::ndarray< double,1 > > _5710 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5709)));
  _checked_ptr_1<double> _ptr__5710(_5710 ? _5710->raw() : nullptr,_5710 ? _5710->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5711 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5709)));
  _checked_ptr_1<int> _ptr__5711(_5711 ? _5711->raw() : nullptr,_5711 ? _5711->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5712 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5709)));
  _checked_ptr_1<int> _ptr__5712(_5712 ? _5712->raw() : nullptr,_5712 ? _5712->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5713 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5706)));
  _checked_ptr_1<double> _ptr__5713(_5713 ? _5713->raw() : nullptr,_5713 ? _5713->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5714 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5706)));
  _checked_ptr_1<int> _ptr__5714(_5714 ? _5714->raw() : nullptr,_5714 ? _5714->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5715 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5706)));
  _checked_ptr_1<int> _ptr__5715(_5715 ? _5715->raw() : nullptr,_5715 ? _5715->size(0) : 0);
  ::mosek::fusion::Utils::Tools::arraycopy(usubi,(int)0,_5715,(int)0,_5704);
  ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5702)->usubi,(int)0,_5715,_5704,_5705);
  ::mosek::fusion::Utils::Tools::arraycopy(usubj,(int)0,_5714,(int)0,_5704);
  int _9564 = (int)0;
  int _9565 = _5705;
  for (int _5716 = _9564; _5716 < _9565; ++_5716)
  {
    {
      _ptr__5714[safe_add( _5716,_5704 )] = safe_add( ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5702)->usubj)(_5716)),d1 );
    }
  }
  if (((scale > 1.0) || (scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(uval,(int)0,_5713,(int)0,_5704);
    }
  }
  else
  {
    {
      int _9566 = (int)0;
      int _9567 = _5704;
      for (int _5717 = _9566; _5717 < _9567; ++_5717)
      {
        {
          _ptr__5713[_5717] = (scale * ((*uval)(_5717)));
        }
      }
    }
  }
  if (((mosek::fusion::p_SymmetricMatrix::_get_impl(_5702)->scale > 1.0) || (mosek::fusion::p_SymmetricMatrix::_get_impl(_5702)->scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5702)->uval,(int)0,_5713,_5704,_5705);
    }
  }
  else
  {
    {
      int _9568 = (int)0;
      int _9569 = _5705;
      for (int _5718 = _9568; _5718 < _9569; ++_5718)
      {
        {
          _ptr__5713[safe_add( _5718,_5704 )] = (mosek::fusion::p_SymmetricMatrix::_get_impl(_5702)->scale * ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5702)->uval)(_5718)));
        }
      }
    }
  }
  ::mosek::fusion::Utils::Tools::arraycopy(usubi,(int)0,_5715,(int)0,_5704);
  int _9570 = (int)0;
  int _9571 = _5708;
  for (int _5719 = _9570; _5719 < _9571; ++_5719)
  {
    {
      _ptr__5712[safe_add( _5719,_5707 )] = safe_add( ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5702)->vsubi)(_5719)),mosek::fusion::p_SymmetricMatrix::_get_impl(_5702)->d1 );
    }
  }
  ::mosek::fusion::Utils::Tools::arraycopy(vsubj,(int)0,_5711,(int)0,_5707);
  ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5702)->vsubj,_5707,_5711,_5707,_5708);
  if (((scale > 1.0) || (scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(vval,(int)0,_5710,(int)0,_5707);
    }
  }
  else
  {
    {
      int _9572 = (int)0;
      int _9573 = _5707;
      for (int _5720 = _9572; _5720 < _9573; ++_5720)
      {
        {
          _ptr__5710[_5720] = (scale * ((*vval)(_5720)));
        }
      }
    }
  }
  if (((mosek::fusion::p_SymmetricMatrix::_get_impl(_5702)->scale > 1.0) || (mosek::fusion::p_SymmetricMatrix::_get_impl(_5702)->scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5702)->vval,(int)0,_5710,_5707,_5708);
    }
  }
  else
  {
    {
      int _9574 = (int)0;
      int _9575 = _5708;
      for (int _5721 = _9574; _5721 < _9575; ++_5721)
      {
        {
          _ptr__5710[safe_add( _5721,_5707 )] = (mosek::fusion::p_SymmetricMatrix::_get_impl(_5702)->scale * ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5702)->vval)(_5721)));
        }
      }
    }
  }
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(d0,safe_add( d1,mosek::fusion::p_SymmetricMatrix::_get_impl(_5702)->d1 ),_5715,_5714,_5713,_5712,_5711,_5710,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix :: __mosek_2fusion_2SymmetricMatrix__sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5722) { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->__mosek_2fusion_2SymmetricMatrix__sub(_5722); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5722) { return __mosek_2fusion_2SymmetricMatrix__sub(_5722); }
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::__mosek_2fusion_2SymmetricMatrix__sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5722){
  return _pubthis->__mosek_2fusion_2SymmetricMatrix__add(_5722->__mosek_2fusion_2SymmetricMatrix__mul((-1.0)));
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix :: __mosek_2fusion_2SymmetricMatrix__mul(double _5723) { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->__mosek_2fusion_2SymmetricMatrix__mul(_5723); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::mul(double _5723) { return __mosek_2fusion_2SymmetricMatrix__mul(_5723); }
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::__mosek_2fusion_2SymmetricMatrix__mul(double _5723){
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(d0,d1,usubi,usubj,uval,vsubi,vsubj,vval,(scale * _5723));
}
int mosek::fusion::SymmetricMatrix :: getdim() { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->getdim(); }int mosek::fusion::p_SymmetricMatrix::getdim(){
  return d0;
}
void mosek::fusion::p_SymmetricMatrix::destroy(){vval.reset();vsubj.reset();vsubi.reset();uval.reset();usubj.reset();usubi.reset();}void mosek::fusion::SymmetricMatrix::destroy() { mosek::fusion::p_SymmetricMatrix::_get_impl(this)->destroy(); }mosek::fusion::NDSparseArray::NDSparseArray(mosek::fusion::p_NDSparseArray *_impl) : _impl(_impl) { /*std::cout << "NDSparseArray() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::NDSparseArray::~NDSparseArray() { delete _impl; _impl = nullptr; }mosek::fusion::p_NDSparseArray::p_NDSparseArray  (::mosek::fusion::NDSparseArray * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::NDSparseArray::t mosek::fusion::p_NDSparseArray::_new_NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5724,    std::shared_ptr< monty::ndarray< int,2 > > _5725,    std::shared_ptr< monty::ndarray< double,1 > > _5726){ return new mosek::fusion::NDSparseArray(_5724,_5725,_5726); }mosek::fusion::NDSparseArray::NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5724,    std::shared_ptr< monty::ndarray< int,2 > > _5725,    std::shared_ptr< monty::ndarray< double,1 > > _5726) :    NDSparseArray(new mosek::fusion::p_NDSparseArray(this)){ mosek::fusion::p_NDSparseArray::_get_impl(this)->_initialize(_5724,_5725,_5726); }void mosek::fusion::p_NDSparseArray::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _5724,    std::shared_ptr< monty::ndarray< int,2 > > _5725,    std::shared_ptr< monty::ndarray< double,1 > > _5726){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5724(_5724 ? _5724->raw() : nullptr, _5724 ? _5724->size(0) : 0);
    _checked_ptr_1<double> _ptr__5726(_5726 ? _5726->raw() : nullptr, _5726 ? _5726->size(0) : 0);
    std::shared_ptr< monty::ndarray< long long,1 > > _5727 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_5725)->size(0)))));
    _checked_ptr_1<long long> _ptr__5727(_5727 ? _5727->raw() : nullptr,_5727 ? _5727->size(0) : 0);
    size = (long long)1;
    int _9576 = (int)0;
    int _9577 = (int)((_5724)->size(0));
    for (int _5728 = _9576; _5728 < _9577; ++_5728)
    {
      {
        size = safe_mul( size,_ptr__5724[_5728] );
      }
    }
    int _5729 = (int)((_5724)->size(0));
    if (((int)((_5725)->size(0)) != (int)((_5726)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching data array length"));
      }
    }
    {}
    if (((int)((_5725)->size(1)) != _5729))
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("An index key in sub has wrong length"));
      }
    }
    {}
    bool _5730 = false;
    int _9578 = (int)0;
    int _9579 = (int)((_5725)->size(0));
    for (int _5731 = _9578; _5731 < _9579; ++_5731)
    {
      {
        int _9580 = (int)0;
        int _9581 = (int)((_5725)->size(1));
        for (int _5732 = _9580; _5732 < _9581; ++_5732)
        {
          {
            if (((((*_5725)(_5731,_5732)) < (int)0) || (((*_5725)(_5731,_5732)) >= _ptr__5724[_5732])))
            {
              {
                _5730 = true;
              }
            }
            {}
          }
        }
      }
    }
    if (_5730)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("An index in sub is out of bounds"));
      }
    }
    {}
    int _9582 = (int)0;
    int _9583 = (int)((_5725)->size(0));
    for (int _5733 = _9582; _5733 < _9583; ++_5733)
    {
      {
        long long _5734 = (long long)0;
        int _9584 = (int)0;
        int _9585 = (int)((_5725)->size(1));
        for (int _5735 = _9584; _5735 < _9585; ++_5735)
        {
          {
            _5734 = safe_add( safe_mul( _5734,_ptr__5724[_5735] ),((*_5725)(_5733,_5735)) );
          }
        }
        _ptr__5727[_5733] = _5734;
      }
    }
    dims = ::mosek::fusion::Utils::Tools::arraycopy(_5724);
    bool _5736 = true;
    int _9586 = (int)1;
    int _9587 = (int)((_5727)->size(0));
    for (int _5737 = _9586; _5737 < _9587; ++_5737)
    {
      {
        _5736 = (_5736 && (_ptr__5727[_5737] >= _ptr__5727[(_5737 - (int)1)]));
      }
    }
    if (_5736)
    {
      {
        int _5738 = (int)1;
        int _9588 = (int)1;
        int _9589 = (int)((_5727)->size(0));
        for (int _5739 = _9588; _5739 < _9589; ++_5739)
        {
          {
            if ((_ptr__5727[(_5739 - (int)1)] < _ptr__5727[_5739]))
            {
              {
                ++ _5738;
              }
            }
            {}
          }
        }
        if ((_5738 == (int)((_5727)->size(0))))
        {
          {
            inst = ::mosek::fusion::Utils::Tools::arraycopy(_5727);
            cof = ::mosek::fusion::Utils::Tools::arraycopy(_5726);
          }
        }
        else
        {
          {
            inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5738)));
            ((*inst)((int)0)) = _ptr__5727[(int)0];
            cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5738)));
            ((*cof)((int)0)) = _ptr__5726[(int)0];
            int _5740 = (int)0;
            int _9590 = (int)1;
            int _9591 = (int)((_5727)->size(0));
            for (int _5741 = _9590; _5741 < _9591; ++_5741)
            {
              {
                if ((_ptr__5727[_5741] > _ptr__5727[(_5741 - (int)1)]))
                {
                  {
                    ++ _5740;
                    ((*inst)(_5740)) = _ptr__5727[_5741];
                    ((*cof)(_5740)) = _ptr__5726[_5741];
                  }
                }
                else
                {
                  {
                    ((*cof)(_5740)) = (((*cof)(_5740)) + _ptr__5726[_5741]);
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        std::shared_ptr< monty::ndarray< long long,1 > > _5742 = ::mosek::fusion::Utils::Tools::range((long long)((_5727)->size(0)));
        _checked_ptr_1<long long> _ptr__5742(_5742 ? _5742->raw() : nullptr,_5742 ? _5742->size(0) : 0);
        ::mosek::fusion::p_CommonTools::argQsort(_5742,_5727,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)0,(long long)((_5727)->size(0)));
        int _5743 = (int)1;
        int _9592 = (int)1;
        int _9593 = (int)((_5727)->size(0));
        for (int _5744 = _9592; _5744 < _9593; ++_5744)
        {
          {
            if ((_ptr__5727[_ptr__5742[(_5744 - (int)1)]] < _ptr__5727[_ptr__5742[_5744]]))
            {
              {
                ++ _5743;
              }
            }
            {}
          }
        }
        inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5743)));
        ((*inst)((int)0)) = _ptr__5727[_ptr__5742[(int)0]];
        cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5743)));
        ((*cof)((int)0)) = _ptr__5726[_ptr__5742[(int)0]];
        int _5745 = (int)0;
        int _9594 = (int)1;
        int _9595 = (int)((_5727)->size(0));
        for (int _5746 = _9594; _5746 < _9595; ++_5746)
        {
          {
            if ((_ptr__5727[_ptr__5742[_5746]] > _ptr__5727[_ptr__5742[(_5746 - (int)1)]]))
            {
              {
                ++ _5745;
                ((*inst)(_5745)) = _ptr__5727[_ptr__5742[_5746]];
                ((*cof)(_5745)) = _ptr__5726[_ptr__5742[_5746]];
              }
            }
            else
            {
              {
                ((*cof)(_5745)) = (((*cof)(_5745)) + _ptr__5726[_ptr__5742[_5746]]);
              }
            }
          }
        }
      }
    }
  }
}mosek::fusion::NDSparseArray::t mosek::fusion::p_NDSparseArray::_new_NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5747,    std::shared_ptr< monty::ndarray< long long,1 > > _5748,    std::shared_ptr< monty::ndarray< double,1 > > _5749){ return new mosek::fusion::NDSparseArray(_5747,_5748,_5749); }mosek::fusion::NDSparseArray::NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5747,    std::shared_ptr< monty::ndarray< long long,1 > > _5748,    std::shared_ptr< monty::ndarray< double,1 > > _5749) :    NDSparseArray(new mosek::fusion::p_NDSparseArray(this)){ mosek::fusion::p_NDSparseArray::_get_impl(this)->_initialize(_5747,_5748,_5749); }void mosek::fusion::p_NDSparseArray::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _5747,    std::shared_ptr< monty::ndarray< long long,1 > > _5748,    std::shared_ptr< monty::ndarray< double,1 > > _5749){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5747(_5747 ? _5747->raw() : nullptr, _5747 ? _5747->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5748(_5748 ? _5748->raw() : nullptr, _5748 ? _5748->size(0) : 0);
    _checked_ptr_1<double> _ptr__5749(_5749 ? _5749->raw() : nullptr, _5749 ? _5749->size(0) : 0);
    size = (long long)1;
    int _9596 = (int)0;
    int _9597 = (int)((_5747)->size(0));
    for (int _5750 = _9596; _5750 < _9597; ++_5750)
    {
      {
        size = safe_mul( size,_ptr__5747[_5750] );
      }
    }
    if (((int)((_5748)->size(0)) != (int)((_5749)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching data array length"));
      }
    }
    {}
    {
      bool _5751 = false;
      int _9598 = (int)0;
      int _9599 = (int)((_5748)->size(0));
      for (int _5752 = _9598; _5752 < _9599; ++_5752)
      {
        {
          _5751 = (_5751 || ((_ptr__5748[_5752] < (int)0) || (_ptr__5748[_5752] >= size)));
        }
      }
      if (_5751)
      {
        {
          throw ::mosek::fusion::IndexError(std::string ("An index in inst is out of bounds"));
        }
      }
      {}
    }
    dims = ::mosek::fusion::Utils::Tools::arraycopy(_5747);
    bool _5753 = true;
    int _9600 = (int)1;
    int _9601 = (int)((_5748)->size(0));
    for (int _5754 = _9600; _5754 < _9601; ++_5754)
    {
      {
        _5753 = (_5753 && (_ptr__5748[_5754] >= _ptr__5748[(_5754 - (int)1)]));
      }
    }
    if (_5753)
    {
      {
        int _5755 = (int)1;
        int _9602 = (int)1;
        int _9603 = (int)((_5748)->size(0));
        for (int _5756 = _9602; _5756 < _9603; ++_5756)
        {
          {
            if ((_ptr__5748[(_5756 - (int)1)] < _ptr__5748[_5756]))
            {
              {
                ++ _5755;
              }
            }
            {}
          }
        }
        if ((_5755 == (int)((_5748)->size(0))))
        {
          {
            inst = ::mosek::fusion::Utils::Tools::arraycopy(_5748);
            cof = ::mosek::fusion::Utils::Tools::arraycopy(_5749);
          }
        }
        else
        {
          {
            inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5755)));
            ((*inst)((int)0)) = _ptr__5748[(int)0];
            cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5755)));
            ((*cof)((int)0)) = _ptr__5749[(int)0];
            int _5757 = (int)0;
            int _9604 = (int)1;
            int _9605 = (int)((_5748)->size(0));
            for (int _5758 = _9604; _5758 < _9605; ++_5758)
            {
              {
                if ((_ptr__5748[_5758] > _ptr__5748[(_5758 - (int)1)]))
                {
                  {
                    ++ _5757;
                    ((*inst)(_5757)) = _ptr__5748[_5758];
                    ((*cof)(_5757)) = _ptr__5749[_5758];
                  }
                }
                else
                {
                  {
                    ((*cof)(_5757)) = (((*cof)(_5757)) + _ptr__5749[_5758]);
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        std::shared_ptr< monty::ndarray< long long,1 > > _5759 = ::mosek::fusion::Utils::Tools::range((long long)((_5748)->size(0)));
        _checked_ptr_1<long long> _ptr__5759(_5759 ? _5759->raw() : nullptr,_5759 ? _5759->size(0) : 0);
        ::mosek::fusion::p_CommonTools::argQsort(_5759,_5748,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)0,(long long)((_5748)->size(0)));
        int _5760 = (int)1;
        int _9606 = (int)1;
        int _9607 = (int)((_5748)->size(0));
        for (int _5761 = _9606; _5761 < _9607; ++_5761)
        {
          {
            if ((_ptr__5748[_ptr__5759[(_5761 - (int)1)]] < _ptr__5748[_ptr__5759[_5761]]))
            {
              {
                ++ _5760;
              }
            }
            {}
          }
        }
        inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5760)));
        ((*inst)((int)0)) = _ptr__5748[_ptr__5759[(int)0]];
        cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5760)));
        ((*cof)((int)0)) = _ptr__5749[_ptr__5759[(int)0]];
        int _5762 = (int)0;
        int _9608 = (int)1;
        int _9609 = (int)((_5748)->size(0));
        for (int _5763 = _9608; _5763 < _9609; ++_5763)
        {
          {
            if ((_ptr__5748[_ptr__5759[_5763]] > ((*inst)(_ptr__5759[(_5763 - (int)1)]))))
            {
              {
                ++ _5762;
                ((*inst)(_5762)) = _ptr__5748[_ptr__5759[_5763]];
                ((*cof)(_5762)) = _ptr__5749[_ptr__5759[_5763]];
              }
            }
            else
            {
              {
                ((*cof)(_5762)) = (((*cof)(_5762)) + _ptr__5749[_ptr__5759[_5763]]);
              }
            }
          }
        }
      }
    }
  }
}mosek::fusion::NDSparseArray::t mosek::fusion::p_NDSparseArray::_new_NDSparseArray  (monty::rc_ptr< ::mosek::fusion::Matrix > _5764){ return new mosek::fusion::NDSparseArray(_5764); }mosek::fusion::NDSparseArray::NDSparseArray  (monty::rc_ptr< ::mosek::fusion::Matrix > _5764) :    NDSparseArray(new mosek::fusion::p_NDSparseArray(this)){ mosek::fusion::p_NDSparseArray::_get_impl(this)->_initialize(_5764); }void mosek::fusion::p_NDSparseArray::_initialize  (monty::rc_ptr< ::mosek::fusion::Matrix > _5764){monty::rc_reserve __reserve_this(_pubthis);   {
    long long _5765 = _5764->numNonzeros();
    int _5766 = _5764->numColumns();
    int _5767 = _5764->numRows();
    std::shared_ptr< monty::ndarray< double,1 > > _5768 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5765)));
    _checked_ptr_1<double> _ptr__5768(_5768 ? _5768->raw() : nullptr,_5768 ? _5768->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _5769 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5765)));
    _checked_ptr_1<int> _ptr__5769(_5769 ? _5769->raw() : nullptr,_5769 ? _5769->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _5770 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5765)));
    _checked_ptr_1<int> _ptr__5770(_5770 ? _5770->raw() : nullptr,_5770 ? _5770->size(0) : 0);
    _5764->getDataAsTriplets(_5770,_5769,_5768);
    size = safe_mul( (long long)_5764->numRows(),(long long)_5764->numColumns() );
    dims = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5767),(int)(_5766)});
    std::vector<long long> _9610;
    for (long long _5771 = (long long)0, _9611 = _5765; _5771 < _9611 ; ++_5771)
    {
      _9610.push_back(safe_add( safe_mul( (long long)_ptr__5770[_5771],_5766 ),(long long)_ptr__5769[_5771] ));
    }
    auto _9612 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9610.size()),_9610.begin(),_9610.end()));
    inst = _9612;
    cof = _5768;
  }
}monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::NDSparseArray::make  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5772) { return mosek::fusion::p_NDSparseArray::make(_5772); }monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::p_NDSparseArray::make(monty::rc_ptr< ::mosek::fusion::Matrix > _5772){
  return ::mosek::fusion::p_NDSparseArray::_new_NDSparseArray(_5772);
}
monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::NDSparseArray::make  ( std::shared_ptr< monty::ndarray< int,1 > > _5773,    std::shared_ptr< monty::ndarray< long long,1 > > _5774,    std::shared_ptr< monty::ndarray< double,1 > > _5775) { return mosek::fusion::p_NDSparseArray::make(_5773,_5774,_5775); }monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::p_NDSparseArray::make(std::shared_ptr< monty::ndarray< int,1 > > _5773,std::shared_ptr< monty::ndarray< long long,1 > > _5774,std::shared_ptr< monty::ndarray< double,1 > > _5775){
  _checked_ptr_1<int> _ptr__5773(_5773 ? _5773->raw() : nullptr, _5773 ? _5773->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5774(_5774 ? _5774->raw() : nullptr, _5774 ? _5774->size(0) : 0);
  _checked_ptr_1<double> _ptr__5775(_5775 ? _5775->raw() : nullptr, _5775 ? _5775->size(0) : 0);
  return ::mosek::fusion::p_NDSparseArray::_new_NDSparseArray(_5773,_5774,_5775);
}
monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::NDSparseArray::make  ( std::shared_ptr< monty::ndarray< int,1 > > _5776,    std::shared_ptr< monty::ndarray< int,2 > > _5777,    std::shared_ptr< monty::ndarray< double,1 > > _5778) { return mosek::fusion::p_NDSparseArray::make(_5776,_5777,_5778); }monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::p_NDSparseArray::make(std::shared_ptr< monty::ndarray< int,1 > > _5776,std::shared_ptr< monty::ndarray< int,2 > > _5777,std::shared_ptr< monty::ndarray< double,1 > > _5778){
  _checked_ptr_1<int> _ptr__5776(_5776 ? _5776->raw() : nullptr, _5776 ? _5776->size(0) : 0);
  _checked_ptr_1<double> _ptr__5778(_5778 ? _5778->raw() : nullptr, _5778 ? _5778->size(0) : 0);
  return ::mosek::fusion::p_NDSparseArray::_new_NDSparseArray(_5776,_5777,_5778);
}
void mosek::fusion::p_NDSparseArray::destroy(){cof.reset();inst.reset();dims.reset();}void mosek::fusion::NDSparseArray::destroy() { mosek::fusion::p_NDSparseArray::_get_impl(this)->destroy(); }mosek::fusion::DenseMatrix::DenseMatrix(mosek::fusion::p_DenseMatrix *_impl) : mosek::fusion::Matrix(_impl) { /*std::cout << "DenseMatrix()" << this << std::endl; */ }mosek::fusion::DenseMatrix::~DenseMatrix() {  /* std::cout << "~DenseMatrix()" << this << std::endl << std::flush; */ }mosek::fusion::p_DenseMatrix::p_DenseMatrix  (::mosek::fusion::DenseMatrix * _pubthis) :     mosek::fusion::p_Matrix(_pubthis),    _pubthis(_pubthis){}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (int _5779,    int _5780,    std::shared_ptr< monty::ndarray< double,1 > > _5781){ return new mosek::fusion::DenseMatrix(_5779,_5780,_5781); }mosek::fusion::DenseMatrix::DenseMatrix  (int _5779,    int _5780,    std::shared_ptr< monty::ndarray< double,1 > > _5781) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5779,_5780,_5781); }void mosek::fusion::p_DenseMatrix::_initialize  (int _5779,    int _5780,    std::shared_ptr< monty::ndarray< double,1 > > _5781){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__5781(_5781 ? _5781->raw() : nullptr, _5781 ? _5781->size(0) : 0);
    mosek::fusion::p_Matrix::_initialize(_5779,_5780);
    nnz = (long long)safe_mul( _5779,_5780 );
    data = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( _5779,_5780 ))));
    ::mosek::fusion::Utils::Tools::arraycopy(_5781,(int)0,data,(int)0,safe_mul( _5779,_5780 ));
  }
}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (monty::rc_ptr< ::mosek::fusion::Matrix > _5782){ return new mosek::fusion::DenseMatrix(_5782); }mosek::fusion::DenseMatrix::DenseMatrix  (monty::rc_ptr< ::mosek::fusion::Matrix > _5782) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5782); }void mosek::fusion::p_DenseMatrix::_initialize  (monty::rc_ptr< ::mosek::fusion::Matrix > _5782){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Matrix::_initialize(mosek::fusion::p_Matrix::_get_impl(_5782)->dimi,mosek::fusion::p_Matrix::_get_impl(_5782)->dimj);
    monty::rc_ptr< ::mosek::fusion::Matrix > _9613 = _5782;
    if (false) {}
    else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9613.get()))
    {
      ::mosek::fusion::DenseMatrix::t _5783 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9613.get()));
      {
        data = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_DenseMatrix::_get_impl(_5783)->data);
      }
    }
    else if (nullptr != dynamic_cast<::mosek::fusion::SparseMatrix*>(_9613.get()))
    {
      ::mosek::fusion::SparseMatrix::t _5784 (dynamic_cast<::mosek::fusion::SparseMatrix*>(_9613.get()));
      {
        data = ::mosek::fusion::Utils::Tools::zeros(safe_mul( mosek::fusion::p_Matrix::_get_impl(_5784)->dimi,mosek::fusion::p_Matrix::_get_impl(_5784)->dimj ));
        long long _9614 = (long long)0;
        long long _9615 = mosek::fusion::p_SparseMatrix::_get_impl(_5784)->nnz;
        for (long long _5786 = _9614; _5786 < _9615; ++_5786)
        {
          {
            ((*data)(safe_add( safe_mul( ((*mosek::fusion::p_SparseMatrix::_get_impl(_5784)->subi)(_5786)),dimj ),((*mosek::fusion::p_SparseMatrix::_get_impl(_5784)->subj)(_5786)) ))) = ((*mosek::fusion::p_SparseMatrix::_get_impl(_5784)->val)(_5786));
          }
        }
      }
    }
    else
    {
      mosek::fusion::Matrix::t _5785 = _9613;
      {
        throw ::mosek::fusion::MatrixError(std::string ("Unknown matrix type."));
      }
    }
    nnz = (long long)safe_mul( dimi,dimj );
  }
}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (std::shared_ptr< monty::ndarray< double,2 > > _5787){ return new mosek::fusion::DenseMatrix(_5787); }mosek::fusion::DenseMatrix::DenseMatrix  (std::shared_ptr< monty::ndarray< double,2 > > _5787) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5787); }void mosek::fusion::p_DenseMatrix::_initialize  (std::shared_ptr< monty::ndarray< double,2 > > _5787){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Matrix::_initialize((int)((_5787)->size(0)),(int)((_5787)->size(1)));
    std::vector<double> _9616;
    for (int _5788 = (int)0, _9617 = dimi; _5788 < _9617 ; ++_5788)
    {
      for (int _5789 = (int)0, _9618 = dimj; _5789 < _9618 ; ++_5789)
      {
        _9616.push_back(((*_5787)(_5788,_5789)));
      }
    }
    auto _9619 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9616.size()),_9616.begin(),_9616.end()));
    data = _9619;
    nnz = (long long)safe_mul( dimi,dimj );
  }
}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (int _5790,    int _5791,    double _5792){ return new mosek::fusion::DenseMatrix(_5790,_5791,_5792); }mosek::fusion::DenseMatrix::DenseMatrix  (int _5790,    int _5791,    double _5792) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5790,_5791,_5792); }void mosek::fusion::p_DenseMatrix::_initialize  (int _5790,    int _5791,    double _5792){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Matrix::_initialize(_5790,_5791);
    std::vector<double> _9620;
    for (int _5793 = (int)0, _9621 = _5790; _5793 < _9621 ; ++_5793)
    {
      for (int _5794 = (int)0, _9622 = _5791; _5794 < _9622 ; ++_5794)
      {
        _9620.push_back(_5792);
      }
    }
    auto _9623 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9620.size()),_9620.begin(),_9620.end()));
    data = _9623;
    nnz = (long long)safe_mul( _5790,_5791 );
  }
}std::string mosek::fusion::DenseMatrix :: toString() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->toString(); }std::string mosek::fusion::p_DenseMatrix::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _5795 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _5795->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("DenseMatrix("));
  _5795->__mosek_2fusion_2Utils_2StringBuffer__a(dimi);
  _5795->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","));
  _5795->__mosek_2fusion_2Utils_2StringBuffer__a(dimj);
  _5795->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (": "));
  int _5796 = (int)0;
  {
    int _5797 = (int)0;
    for(;(_5797 < dimi);++ _5797)
    {
      {
        if ((_5797 > (int)0))
        {
          {
            _5795->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","));
          }
        }
        {}
        _5795->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("[ "));
        _5795->__mosek_2fusion_2Utils_2StringBuffer__a(((*data)(_5796)));
        ++ _5796;
        {
          int _5798 = (int)1;
          for(;(_5798 < dimj);++ _5798)
          {
            {
              _5795->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","));
              _5795->__mosek_2fusion_2Utils_2StringBuffer__a(((*data)(_5796)));
              ++ _5796;
            }
          }
        }
        _5795->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" ]"));
      }
    }
  }
  _5795->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _5795->toString();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::DenseMatrix :: __mosek_2fusion_2DenseMatrix__transpose() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->__mosek_2fusion_2DenseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::DenseMatrix::transpose() { return __mosek_2fusion_2DenseMatrix__transpose(); }
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::DenseMatrix::__mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2DenseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_DenseMatrix::__mosek_2fusion_2DenseMatrix__transpose(){
  std::shared_ptr< monty::ndarray< double,1 > > _5799 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( dimi,dimj ))));
  _checked_ptr_1<double> _ptr__5799(_5799 ? _5799->raw() : nullptr,_5799 ? _5799->size(0) : 0);
  int _5800 = (int)0;
  int _5801 = dimi;
  int _9624 = (int)0;
  int _9625 = dimi;
  for (int _5802 = _9624; _5802 < _9625; ++_5802)
  {
    {
      int _5803 = _5802;
      int _9626 = (int)0;
      int _9627 = dimj;
      for (int _5804 = _9626; _5804 < _9627; ++_5804)
      {
        {
          _ptr__5799[_5803] = ((*data)(_5800));
          _5803 = safe_add( _5803,_5801 );
          ++ _5800;
        }
      }
    }
  }
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(dimj,dimi,_5799)).as<::mosek::fusion::Matrix>();
}
bool mosek::fusion::DenseMatrix :: isSparse() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->isSparse(); }bool mosek::fusion::p_DenseMatrix::isSparse(){
  return false;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::DenseMatrix :: getDataAsArray() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->getDataAsArray(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_DenseMatrix::getDataAsArray(){
  return ::mosek::fusion::Utils::Tools::arraycopy(data);
}
void mosek::fusion::DenseMatrix :: getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5805,std::shared_ptr< monty::ndarray< int,1 > > _5806,std::shared_ptr< monty::ndarray< double,1 > > _5807) { mosek::fusion::p_DenseMatrix::_get_impl(this)->getDataAsTriplets(_5805,_5806,_5807); }void mosek::fusion::p_DenseMatrix::getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5805,std::shared_ptr< monty::ndarray< int,1 > > _5806,std::shared_ptr< monty::ndarray< double,1 > > _5807){
  _checked_ptr_1<int> _ptr__5805(_5805 ? _5805->raw() : nullptr, _5805 ? _5805->size(0) : 0);
  _checked_ptr_1<int> _ptr__5806(_5806 ? _5806->raw() : nullptr, _5806 ? _5806->size(0) : 0);
  _checked_ptr_1<double> _ptr__5807(_5807 ? _5807->raw() : nullptr, _5807 ? _5807->size(0) : 0);
  if ((((int)((_5805)->size(0)) < nnz) || (((int)((_5806)->size(0)) < nnz) || ((int)((_5807)->size(0)) < nnz))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Output arrays are not long enough."));
    }
  }
  {}
  ::mosek::fusion::Utils::Tools::arraycopy(data,(int)0,_5807,(int)0,(int)((data)->size(0)));
  int _5808 = (int)0;
  int _9628 = (int)0;
  int _9629 = dimi;
  for (int _5809 = _9628; _5809 < _9629; ++_5809)
  {
    {
      int _9630 = (int)0;
      int _9631 = dimj;
      for (int _5810 = _9630; _5810 < _9631; ++_5810)
      {
        {
          _ptr__5805[_5808] = _5809;
          _ptr__5806[_5808] = _5810;
          ++ _5808;
        }
      }
    }
  }
}
double mosek::fusion::DenseMatrix :: get(int _5811,int _5812) { return mosek::fusion::p_DenseMatrix::_get_impl(this)->get(_5811,_5812); }double mosek::fusion::p_DenseMatrix::get(int _5811,int _5812){
  return ((*data)(safe_add( safe_mul( _5811,dimj ),_5812 )));
}
long long mosek::fusion::DenseMatrix :: numNonzeros() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->numNonzeros(); }long long mosek::fusion::p_DenseMatrix::numNonzeros(){
  return (long long)safe_mul( dimi,dimj );
}
void mosek::fusion::p_DenseMatrix::destroy(){data.reset();}void mosek::fusion::DenseMatrix::destroy() { mosek::fusion::p_DenseMatrix::_get_impl(this)->destroy(); }mosek::fusion::SparseMatrix::SparseMatrix(mosek::fusion::p_SparseMatrix *_impl) : mosek::fusion::Matrix(_impl) { /*std::cout << "SparseMatrix()" << this << std::endl; */ }mosek::fusion::SparseMatrix::~SparseMatrix() {  /* std::cout << "~SparseMatrix()" << this << std::endl << std::flush; */ }mosek::fusion::p_SparseMatrix::p_SparseMatrix  (::mosek::fusion::SparseMatrix * _pubthis) :     mosek::fusion::p_Matrix(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SparseMatrix::t mosek::fusion::p_SparseMatrix::_new_SparseMatrix  (int _5813,    int _5814,    std::shared_ptr< monty::ndarray< int,1 > > _5815,    std::shared_ptr< monty::ndarray< int,1 > > _5816,    std::shared_ptr< monty::ndarray< double,1 > > _5817,    long long _5818){ return new mosek::fusion::SparseMatrix(_5813,_5814,_5815,_5816,_5817,_5818); }mosek::fusion::SparseMatrix::SparseMatrix  (int _5813,    int _5814,    std::shared_ptr< monty::ndarray< int,1 > > _5815,    std::shared_ptr< monty::ndarray< int,1 > > _5816,    std::shared_ptr< monty::ndarray< double,1 > > _5817,    long long _5818) :    SparseMatrix(new mosek::fusion::p_SparseMatrix(this)){ mosek::fusion::p_SparseMatrix::_get_impl(this)->_initialize(_5813,_5814,_5815,_5816,_5817,_5818); }void mosek::fusion::p_SparseMatrix::_initialize  (int _5813,    int _5814,    std::shared_ptr< monty::ndarray< int,1 > > _5815,    std::shared_ptr< monty::ndarray< int,1 > > _5816,    std::shared_ptr< monty::ndarray< double,1 > > _5817,    long long _5818){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5815(_5815 ? _5815->raw() : nullptr, _5815 ? _5815->size(0) : 0);
    _checked_ptr_1<int> _ptr__5816(_5816 ? _5816->raw() : nullptr, _5816 ? _5816->size(0) : 0);
    _checked_ptr_1<double> _ptr__5817(_5817 ? _5817->raw() : nullptr, _5817 ? _5817->size(0) : 0);
    mosek::fusion::p_Matrix::_initialize(_5813,_5814);
    if ((_5818 > (int)0))
    {
      {
        if ((((int)((_5815)->size(0)) < _5818) || (((int)((_5816)->size(0)) < _5818) || ((int)((_5817)->size(0)) < _5818))))
        {
          {
            throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching arrays in sparse data."));
          }
        }
        {}
        bool _5819 = false;
        long long _9632 = (long long)0;
        long long _9633 = _5818;
        for (long long _5820 = _9632; _5820 < _9633; ++_5820)
        {
          {
            if (((_ptr__5815[_5820] < (int)0) || ((_ptr__5815[_5820] >= dimi) || ((_ptr__5816[_5820] < (int)0) || (_ptr__5816[_5820] >= dimj)))))
            {
              {
                _5819 = true;
              }
            }
            {}
          }
        }
        if (_5819)
        {
          {
            throw ::mosek::fusion::SparseFormatError(std::string ("Subscript out of bounds."));
          }
        }
        {}
        std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _5821 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape((int)1)));
        std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _5822 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape((int)1)));
        std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _5823 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 >(monty::shape((int)1)));
        ::mosek::fusion::p_CommonTools::tripletSort(_5815,_5816,_5817,_5821,_5822,_5823,_5818,dimi,dimj);
        subi = ((*_5821)((int)0));
        subj = ((*_5822)((int)0));
        val = ((*_5823)((int)0));
        nnz = (long long)((val)->size(0));
      }
    }
    else
    {
      {
        subi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
        subj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
        val = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0)));
        nnz = (long long)0;
      }
    }
  }
}mosek::fusion::SparseMatrix::t mosek::fusion::p_SparseMatrix::_new_SparseMatrix  (int _5824,    int _5825,    std::shared_ptr< monty::ndarray< int,1 > > _5826,    std::shared_ptr< monty::ndarray< int,1 > > _5827,    std::shared_ptr< monty::ndarray< double,1 > > _5828){ return new mosek::fusion::SparseMatrix(_5824,_5825,_5826,_5827,_5828); }mosek::fusion::SparseMatrix::SparseMatrix  (int _5824,    int _5825,    std::shared_ptr< monty::ndarray< int,1 > > _5826,    std::shared_ptr< monty::ndarray< int,1 > > _5827,    std::shared_ptr< monty::ndarray< double,1 > > _5828) :    SparseMatrix(new mosek::fusion::p_SparseMatrix(this)){ mosek::fusion::p_SparseMatrix::_get_impl(this)->_initialize(_5824,_5825,_5826,_5827,_5828); }void mosek::fusion::p_SparseMatrix::_initialize  (int _5824,    int _5825,    std::shared_ptr< monty::ndarray< int,1 > > _5826,    std::shared_ptr< monty::ndarray< int,1 > > _5827,    std::shared_ptr< monty::ndarray< double,1 > > _5828){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5826(_5826 ? _5826->raw() : nullptr, _5826 ? _5826->size(0) : 0);
    _checked_ptr_1<int> _ptr__5827(_5827 ? _5827->raw() : nullptr, _5827 ? _5827->size(0) : 0);
    _checked_ptr_1<double> _ptr__5828(_5828 ? _5828->raw() : nullptr, _5828 ? _5828->size(0) : 0);
    mosek::fusion::p_Matrix::_initialize(_5824,_5825);
    int _5829 = (int)0;
    int _9634 = (int)0;
    int _9635 = (int)((_5828)->size(0));
    for (int _5830 = _9634; _5830 < _9635; ++_5830)
    {
      {
        if (((_ptr__5828[_5830] > (int)0) || (_ptr__5828[_5830] < (int)0)))
        {
          {
            ++ _5829;
          }
        }
        {}
      }
    }
    if (((_5829 > (int)0) && (_5829 < (int)((_5826)->size(0)))))
    {
      {
        subi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5829)));
        subj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5829)));
        val = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5829)));
        nnz = _5829;
        int _5831 = (int)0;
        int _9636 = (int)0;
        int _9637 = (int)((_5828)->size(0));
        for (int _5832 = _9636; _5832 < _9637; ++_5832)
        {
          {
            if (((_ptr__5828[_5832] < (int)0) || (_ptr__5828[_5832] > (int)0)))
            {
              {
                ((*val)(_5831)) = _ptr__5828[_5832];
                ((*subj)(_5831)) = _ptr__5827[_5832];
                ((*subi)(_5831)) = _ptr__5826[_5832];
                ++ _5831;
              }
            }
            {}
          }
        }
      }
    }
    else
    {
      {
        subi = _5826;
        subj = _5827;
        val = _5828;
        if ((NULL == _5826.get()))
        {
          {
            nnz = (long long)0;
          }
        }
        else
        {
          {
            nnz = (long long)((subi)->size(0));
          }
        }
      }
    }
  }
}std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SparseMatrix::formPtrb(){
  std::shared_ptr< monty::ndarray< long long,1 > > _5833 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( dimi,(int)1 ))));
  _checked_ptr_1<long long> _ptr__5833(_5833 ? _5833->raw() : nullptr,_5833 ? _5833->size(0) : 0);
  long long _5834 = (long long)0;
  int _9638 = (int)0;
  int _9639 = dimi;
  for (int _5835 = _9638; _5835 < _9639; ++_5835)
  {
    {
      _ptr__5833[_5835] = _5834;
      {
        for(;((_5834 < nnz) && (((*subi)(_5834)) == _5835));++ _5834)
        {
          {
          }
        }
      }
    }
  }
  _ptr__5833[dimi] = _5834;
  return _5833;
}
std::string mosek::fusion::SparseMatrix :: toString() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->toString(); }std::string mosek::fusion::p_SparseMatrix::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _5836 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _5836->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("SparseMatrix("))->__mosek_2fusion_2Utils_2StringBuffer__a(dimi)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(dimj)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (", ["));
  if (((NULL != subi.get()) && ((int)((subi)->size(0)) > (int)0)))
  {
    {
      _5836->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("("))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subi)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subj)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*val)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
      int _9640 = (int)1;
      int _9641 = (int)((subi)->size(0));
      for (int _5837 = _9640; _5837 < _9641; ++_5837)
      {
        {
          _5836->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",("))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subi)(_5837)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subj)(_5837)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*val)(_5837)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
        }
      }
    }
  }
  {}
  _5836->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" ])"));
  return _5836->toString();
}
long long mosek::fusion::SparseMatrix :: numNonzeros() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->numNonzeros(); }long long mosek::fusion::p_SparseMatrix::numNonzeros(){
  return nnz;
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::SparseMatrix :: __mosek_2fusion_2SparseMatrix__transpose() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->__mosek_2fusion_2SparseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::SparseMatrix::transpose() { return __mosek_2fusion_2SparseMatrix__transpose(); }
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::SparseMatrix::__mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2SparseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_SparseMatrix::__mosek_2fusion_2SparseMatrix__transpose(){
  return ::mosek::fusion::p_Matrix::sparse(dimj,dimi,subj,subi,val);
}
bool mosek::fusion::SparseMatrix :: isSparse() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->isSparse(); }bool mosek::fusion::p_SparseMatrix::isSparse(){
  return true;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SparseMatrix :: getDataAsArray() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->getDataAsArray(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_SparseMatrix::getDataAsArray(){
  std::shared_ptr< monty::ndarray< double,1 > > _5838 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( dimi,dimj ))));
  _checked_ptr_1<double> _ptr__5838(_5838 ? _5838->raw() : nullptr,_5838 ? _5838->size(0) : 0);
  int _9642 = (int)0;
  int _9643 = (int)((subi)->size(0));
  for (int _5839 = _9642; _5839 < _9643; ++_5839)
  {
    {
      _ptr__5838[safe_add( safe_mul( ((*subi)(_5839)),dimj ),((*subj)(_5839)) )] = ((*val)(_5839));
    }
  }
  return _5838;
}
void mosek::fusion::SparseMatrix :: getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5840,std::shared_ptr< monty::ndarray< int,1 > > _5841,std::shared_ptr< monty::ndarray< double,1 > > _5842) { mosek::fusion::p_SparseMatrix::_get_impl(this)->getDataAsTriplets(_5840,_5841,_5842); }void mosek::fusion::p_SparseMatrix::getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5840,std::shared_ptr< monty::ndarray< int,1 > > _5841,std::shared_ptr< monty::ndarray< double,1 > > _5842){
  _checked_ptr_1<int> _ptr__5840(_5840 ? _5840->raw() : nullptr, _5840 ? _5840->size(0) : 0);
  _checked_ptr_1<int> _ptr__5841(_5841 ? _5841->raw() : nullptr, _5841 ? _5841->size(0) : 0);
  _checked_ptr_1<double> _ptr__5842(_5842 ? _5842->raw() : nullptr, _5842 ? _5842->size(0) : 0);
  if ((((long long)((_5840)->size(0)) < nnz) || (((long long)((_5841)->size(0)) < nnz) || ((long long)((_5842)->size(0)) < nnz))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Output arrays are not long enough."));
    }
  }
  {}
  if (((NULL != subi.get()) && ((int)((subi)->size(0)) > (int)0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(subi,(long long)0,_5840,(long long)0,nnz);
      ::mosek::fusion::Utils::Tools::arraycopy(subj,(long long)0,_5841,(long long)0,nnz);
      ::mosek::fusion::Utils::Tools::arraycopy(val,(long long)0,_5842,(long long)0,nnz);
    }
  }
  {}
}
double mosek::fusion::SparseMatrix :: get(int _5843,int _5844) { return mosek::fusion::p_SparseMatrix::_get_impl(this)->get(_5843,_5844); }double mosek::fusion::p_SparseMatrix::get(int _5843,int _5844){
  if (((_5843 < (int)0) || ((_5843 >= dimi) || ((_5844 < (int)0) || (_5844 >= dimj)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Index out if bounds"));
    }
  }
  {}
  int _5845 = (int)((subi)->size(0));
  int _5846 = (int)0;
  while ( ((_5845 - _5846) > (int)1) )
  {
    {
      int _5847 = (safe_add( _5846,_5845 ) / (int)2);
      if (((((*subi)(_5847)) < _5843) || ((((*subi)(_5847)) == _5843) && (((*subj)(_5847)) < _5844))))
      {
        {
          _5846 = _5847;
        }
      }
      else if(((((*subi)(_5847)) > _5843) || ((((*subi)(_5847)) == _5843) && (((*subj)(_5847)) > _5844))))
      {
        {
          _5845 = _5847;
        }
      }
      else
      {
        {
          return ((*val)(_5847));
        }
      }
    }
  }
  if (((((*subi)(_5846)) == _5843) && (((*subj)(_5846)) == _5844)))
  {
    {
      return ((*val)(_5846));
    }
  }
  else
  {
    {
      return 0.0;
    }
  }
}
void mosek::fusion::p_SparseMatrix::destroy(){val.reset();subj.reset();subi.reset();}void mosek::fusion::SparseMatrix::destroy() { mosek::fusion::p_SparseMatrix::_get_impl(this)->destroy(); }mosek::fusion::Matrix::Matrix(mosek::fusion::p_Matrix *_impl) : _impl(_impl) { /*std::cout << "Matrix() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Matrix::~Matrix() { delete _impl; _impl = nullptr; }mosek::fusion::p_Matrix::p_Matrix  (::mosek::fusion::Matrix * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_Matrix::_initialize  (int _5848,    int _5849){monty::rc_reserve __reserve_this(_pubthis);   {
    if (((_5848 < (int)0) || (_5849 < (int)0)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid dimensions"));
      }
    }
    {}
    dimi = _5848;
    dimj = _5849;
  }
}std::string mosek::fusion::Matrix :: toString() { return mosek::fusion::p_Matrix::_get_impl(this)->toString(); }std::string mosek::fusion::p_Matrix::toString(){
  return std::string ("");
}
void mosek::fusion::p_Matrix::switchDims(){
  int _5850 = dimi;
  dimi = dimj;
  dimj = _5850;
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( int _5851,    monty::rc_ptr< ::mosek::fusion::Matrix > _5852) { return mosek::fusion::p_Matrix::diag(_5851,_5852); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(int _5851,monty::rc_ptr< ::mosek::fusion::Matrix > _5852){
  std::vector<monty::rc_ptr< ::mosek::fusion::Matrix >> _9644;
  for (int _5853 = (int)0, _9645 = _5851; _5853 < _9645 ; ++_5853)
  {
    _9644.push_back(_5852);
  }
  auto _9646 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 >(monty::shape(_9644.size()),_9644.begin(),_9644.end()));
  return ::mosek::fusion::p_Matrix::diag(_9646);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5854) { return mosek::fusion::p_Matrix::diag(_5854); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5854){
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5855 = _5854;
  long long _5856 = (long long)0;
  int _5857 = (int)0;
  int _5858 = (int)0;
  int _9647 = (int)0;
  int _9648 = (int)((_5854)->size(0));
  for (int _5859 = _9647; _5859 < _9648; ++_5859)
  {
    {
      _5858 = safe_add( _5858,mosek::fusion::p_Matrix::_get_impl(((*_5854)(_5859)))->dimi );
      _5857 = safe_add( _5857,mosek::fusion::p_Matrix::_get_impl(((*_5854)(_5859)))->dimj );
      _5856 = safe_add( _5856,((*_5854)(_5859))->numNonzeros() );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5860 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5856)));
  _checked_ptr_1<int> _ptr__5860(_5860 ? _5860->raw() : nullptr,_5860 ? _5860->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5861 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5856)));
  _checked_ptr_1<int> _ptr__5861(_5861 ? _5861->raw() : nullptr,_5861 ? _5861->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5862 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5856)));
  _checked_ptr_1<double> _ptr__5862(_5862 ? _5862->raw() : nullptr,_5862 ? _5862->size(0) : 0);
  {
    int _5863 = (int)0;
    int _5864 = (int)0;
    long long _5865 = (long long)0;
    int _9649 = (int)0;
    int _9650 = (int)((_5854)->size(0));
    for (int _5866 = _9649; _5866 < _9650; ++_5866)
    {
      {
        long long _5867 = ((*_5854)(_5866))->numNonzeros();
        std::shared_ptr< monty::ndarray< double,1 > > _5868 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5867)));
        _checked_ptr_1<double> _ptr__5868(_5868 ? _5868->raw() : nullptr,_5868 ? _5868->size(0) : 0);
        std::shared_ptr< monty::ndarray< int,1 > > _5869 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5867)));
        _checked_ptr_1<int> _ptr__5869(_5869 ? _5869->raw() : nullptr,_5869 ? _5869->size(0) : 0);
        std::shared_ptr< monty::ndarray< int,1 > > _5870 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5867)));
        _checked_ptr_1<int> _ptr__5870(_5870 ? _5870->raw() : nullptr,_5870 ? _5870->size(0) : 0);
        ((*_5854)(_5866))->getDataAsTriplets(_5870,_5869,_5868);
        ::mosek::fusion::Utils::Tools::arraycopy(_5868,(long long)0,_5862,_5865,_5867);
        long long _9651 = (long long)0;
        long long _9652 = _5867;
        for (long long _5871 = _9651; _5871 < _9652; ++_5871)
        {
          {
            _ptr__5860[safe_add( _5865,_5871 )] = safe_add( _ptr__5870[_5871],_5864 );
            _ptr__5861[safe_add( _5865,_5871 )] = safe_add( _ptr__5870[_5871],_5863 );
          }
        }
        _5865 = safe_add( _5865,_5867 );
        _5864 = safe_add( _5864,mosek::fusion::p_Matrix::_get_impl(((*_5854)(_5866)))->dimi );
        _5863 = safe_add( _5863,mosek::fusion::p_Matrix::_get_impl(((*_5854)(_5866)))->dimj );
      }
    }
  }
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5858,_5857,_5860,_5861,_5862)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( int _5872,    double _5873,    int _5874) { return mosek::fusion::p_Matrix::antidiag(_5872,_5873,_5874); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(int _5872,double _5873,int _5874){
  if (((_5874 < _5872) && (_5874 >= (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::antidiag(::mosek::fusion::Utils::Tools::makevector(_5873,(_5872 - _5874)),_5874);
    }
  }
  else if(((_5874 > (-_5872)) && (_5874 < (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::antidiag(::mosek::fusion::Utils::Tools::makevector(_5873,safe_add( _5872,_5874 )),_5874);
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Diagonal index out of bounds"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( int _5875,    double _5876) { return mosek::fusion::p_Matrix::antidiag(_5875,_5876); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(int _5875,double _5876){
  return ::mosek::fusion::p_Matrix::antidiag(::mosek::fusion::Utils::Tools::makevector(_5876,_5875),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( int _5877,    double _5878,    int _5879) { return mosek::fusion::p_Matrix::diag(_5877,_5878,_5879); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(int _5877,double _5878,int _5879){
  if (((_5879 < _5877) && (_5879 >= (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::diag(::mosek::fusion::Utils::Tools::makevector(_5878,(_5877 - _5879)),_5879);
    }
  }
  else if(((_5879 > (-_5877)) && (_5879 < (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::diag(::mosek::fusion::Utils::Tools::makevector(_5878,safe_add( _5877,_5879 )),_5879);
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Diagonal index out of bounds"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( int _5880,    double _5881) { return mosek::fusion::p_Matrix::diag(_5880,_5881); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(int _5880,double _5881){
  return ::mosek::fusion::p_Matrix::diag(::mosek::fusion::Utils::Tools::makevector(_5881,_5880),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( std::shared_ptr< monty::ndarray< double,1 > > _5882,    int _5883) { return mosek::fusion::p_Matrix::antidiag(_5882,_5883); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(std::shared_ptr< monty::ndarray< double,1 > > _5882,int _5883){
  _checked_ptr_1<double> _ptr__5882(_5882 ? _5882->raw() : nullptr, _5882 ? _5882->size(0) : 0);
  int _9653;
  bool _9654 = (_5883 > (int)0);
  if (_9654)
  {
    _9653 = _5883;
  }
  else
  {
    _9653 = (-_5883);
  }
  int _5884 = _9653;
  int _5885 = safe_add( (int)((_5882)->size(0)),_5884 );
  int _5886 = (int)((_5882)->size(0));
  if ((_5883 >= (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5887 = ::mosek::fusion::Utils::Tools::range(_5883,safe_add( _5886,_5883 ));
      _checked_ptr_1<int> _ptr__5887(_5887 ? _5887->raw() : nullptr,_5887 ? _5887->size(0) : 0);
      std::vector<int> _9655;
      for (int _5889 = (int)1, _9656 = safe_add( _5886,(int)1 ); _5889 < _9656 ; ++_5889)
      {
        _9655.push_back((safe_add( _5886,_5883 ) - _5889));
      }
      auto _9657 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9655.size()),_9655.begin(),_9655.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _5888 = _9657;
      _checked_ptr_1<int> _ptr__5888(_5888 ? _5888->raw() : nullptr,_5888 ? _5888->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5885,_5885,_5887,_5888,_5882)).as<::mosek::fusion::Matrix>();
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5890 = ::mosek::fusion::Utils::Tools::range((int)0,_5886);
      _checked_ptr_1<int> _ptr__5890(_5890 ? _5890->raw() : nullptr,_5890 ? _5890->size(0) : 0);
      std::vector<int> _9658;
      for (int _5892 = (int)1, _9659 = safe_add( _5886,(int)1 ); _5892 < _9659 ; ++_5892)
      {
        _9658.push_back((_5886 - _5892));
      }
      auto _9660 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9658.size()),_9658.begin(),_9658.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _5891 = _9660;
      _checked_ptr_1<int> _ptr__5891(_5891 ? _5891->raw() : nullptr,_5891 ? _5891->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5885,_5885,_5890,_5891,_5882)).as<::mosek::fusion::Matrix>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( std::shared_ptr< monty::ndarray< double,1 > > _5893) { return mosek::fusion::p_Matrix::antidiag(_5893); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(std::shared_ptr< monty::ndarray< double,1 > > _5893){
  _checked_ptr_1<double> _ptr__5893(_5893 ? _5893->raw() : nullptr, _5893 ? _5893->size(0) : 0);
  return ::mosek::fusion::p_Matrix::antidiag(_5893,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( std::shared_ptr< monty::ndarray< double,1 > > _5894,    int _5895) { return mosek::fusion::p_Matrix::diag(_5894,_5895); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(std::shared_ptr< monty::ndarray< double,1 > > _5894,int _5895){
  _checked_ptr_1<double> _ptr__5894(_5894 ? _5894->raw() : nullptr, _5894 ? _5894->size(0) : 0);
  int _9661;
  bool _9662 = (_5895 > (int)0);
  if (_9662)
  {
    _9661 = _5895;
  }
  else
  {
    _9661 = (-_5895);
  }
  int _5896 = _9661;
  int _5897 = safe_add( (int)((_5894)->size(0)),_5896 );
  int _5898 = (int)((_5894)->size(0));
  if ((_5895 >= (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5899 = ::mosek::fusion::Utils::Tools::range((int)0,_5898);
      _checked_ptr_1<int> _ptr__5899(_5899 ? _5899->raw() : nullptr,_5899 ? _5899->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5900 = ::mosek::fusion::Utils::Tools::range(_5896,safe_add( _5898,_5896 ));
      _checked_ptr_1<int> _ptr__5900(_5900 ? _5900->raw() : nullptr,_5900 ? _5900->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5897,_5897,_5899,_5900,_5894)).as<::mosek::fusion::Matrix>();
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5901 = ::mosek::fusion::Utils::Tools::range(_5896,safe_add( _5898,_5896 ));
      _checked_ptr_1<int> _ptr__5901(_5901 ? _5901->raw() : nullptr,_5901 ? _5901->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5902 = ::mosek::fusion::Utils::Tools::range((int)0,_5898);
      _checked_ptr_1<int> _ptr__5902(_5902 ? _5902->raw() : nullptr,_5902 ? _5902->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5897,_5897,_5901,_5902,_5894)).as<::mosek::fusion::Matrix>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( std::shared_ptr< monty::ndarray< double,1 > > _5903) { return mosek::fusion::p_Matrix::diag(_5903); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(std::shared_ptr< monty::ndarray< double,1 > > _5903){
  _checked_ptr_1<double> _ptr__5903(_5903 ? _5903->raw() : nullptr, _5903 ? _5903->size(0) : 0);
  return ::mosek::fusion::p_Matrix::diag(_5903,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::ones  ( int _5904,    int _5905) { return mosek::fusion::p_Matrix::ones(_5904,_5905); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::ones(int _5904,int _5905){
  return ::mosek::fusion::p_Matrix::dense(_5904,_5905,1.0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::eye  ( int _5906) { return mosek::fusion::p_Matrix::eye(_5906); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::eye(int _5906){
  std::vector<double> _9663;
  for (int _5907 = (int)0, _9664 = _5906; _5907 < _9664 ; ++_5907)
  {
    _9663.push_back(1.0);
  }
  auto _9665 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9663.size()),_9663.begin(),_9663.end()));
  return ::mosek::fusion::p_Matrix::diag(_9665);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5908) { return mosek::fusion::p_Matrix::dense(_5908); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(monty::rc_ptr< ::mosek::fusion::Matrix > _5908){
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5908)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( int _5909,    int _5910,    double _5911) { return mosek::fusion::p_Matrix::dense(_5909,_5910,_5911); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(int _5909,int _5910,double _5911){
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5909,_5910,_5911)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( int _5912,    int _5913,    std::shared_ptr< monty::ndarray< double,1 > > _5914) { return mosek::fusion::p_Matrix::dense(_5912,_5913,_5914); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(int _5912,int _5913,std::shared_ptr< monty::ndarray< double,1 > > _5914){
  _checked_ptr_1<double> _ptr__5914(_5914 ? _5914->raw() : nullptr, _5914 ? _5914->size(0) : 0);
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5912,_5913,_5914)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( std::shared_ptr< monty::ndarray< double,2 > > _5915) { return mosek::fusion::p_Matrix::dense(_5915); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(std::shared_ptr< monty::ndarray< double,2 > > _5915){
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5915)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5916) { return mosek::fusion::p_Matrix::sparse(_5916); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(monty::rc_ptr< ::mosek::fusion::Matrix > _5916){
  std::shared_ptr< monty::ndarray< int,1 > > _5917 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5916->numNonzeros())));
  _checked_ptr_1<int> _ptr__5917(_5917 ? _5917->raw() : nullptr,_5917 ? _5917->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5918 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5916->numNonzeros())));
  _checked_ptr_1<int> _ptr__5918(_5918 ? _5918->raw() : nullptr,_5918 ? _5918->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5919 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5916->numNonzeros())));
  _checked_ptr_1<double> _ptr__5919(_5919 ? _5919->raw() : nullptr,_5919 ? _5919->size(0) : 0);
  _5916->getDataAsTriplets(_5917,_5918,_5919);
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5916->numRows(),_5916->numColumns(),_5917,_5918,_5919)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >,1 > > _5920) { return mosek::fusion::p_Matrix::sparse(_5920); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >,1 > > _5920){
  int _5921 = (int)((_5920)->size(0));
  int _5922 = (int)((((*_5920)((int)0)))->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _5923 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5921)));
  _checked_ptr_1<int> _ptr__5923(_5923 ? _5923->raw() : nullptr,_5923 ? _5923->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5924 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5922)));
  _checked_ptr_1<int> _ptr__5924(_5924 ? _5924->raw() : nullptr,_5924 ? _5924->size(0) : 0);
  long long _5925 = (long long)0;
  int _5926 = (int)0;
  {
    int _5927 = (int)0;
    for(;(_5927 < _5921);++ _5927)
    {
      {
        {
          int _5928 = (int)0;
          for(;(_5928 < _5922);++ _5928)
          {
            {
              monty::rc_ptr< ::mosek::fusion::Matrix > _5929 = ((*((*_5920)(_5927)))(_5928));
              if ((NULL != _5929.get()))
              {
                {
                  if ((_ptr__5924[_5928] == (int)0))
                  {
                    {
                      _ptr__5924[_5928] = mosek::fusion::p_Matrix::_get_impl(_5929)->dimj;
                    }
                  }
                  else if((_ptr__5924[_5928] != mosek::fusion::p_Matrix::_get_impl(_5929)->dimj))
                  {
                    {
                      throw ::mosek::fusion::SparseFormatError(std::string ("Sparse matrix construction blocks are not aligned"));
                    }
                  }
                  {}
                  if ((_ptr__5923[_5927] == (int)0))
                  {
                    {
                      _ptr__5923[_5927] = mosek::fusion::p_Matrix::_get_impl(_5929)->dimi;
                    }
                  }
                  else if((_ptr__5923[_5927] != mosek::fusion::p_Matrix::_get_impl(_5929)->dimi))
                  {
                    {
                      throw ::mosek::fusion::SparseFormatError(std::string ("Sparse matrix construction blocks are not aligned"));
                    }
                  }
                  {}
                  _5925 = safe_add( _5925,_5929->numNonzeros() );
                }
              }
              {}
              ++ _5926;
            }
          }
        }
      }
    }
  }
  std::shared_ptr< monty::ndarray< double,1 > > _5930 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5925)));
  _checked_ptr_1<double> _ptr__5930(_5930 ? _5930->raw() : nullptr,_5930 ? _5930->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5931 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5925)));
  _checked_ptr_1<int> _ptr__5931(_5931 ? _5931->raw() : nullptr,_5931 ? _5931->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5932 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5925)));
  _checked_ptr_1<int> _ptr__5932(_5932 ? _5932->raw() : nullptr,_5932 ? _5932->size(0) : 0);
  int _5933 = (int)0;
  int _5934 = (int)0;
  {
    int _5935 = (int)0;
    for(;(_5935 < _5921);++ _5935)
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _5936 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5922)));
        _checked_ptr_1<int> _ptr__5936(_5936 ? _5936->raw() : nullptr,_5936 ? _5936->size(0) : 0);
        {
          int _5937 = (int)0;
          for(;(_5937 < _ptr__5923[_5935]);++ _5937)
          {
            {
              int _5938 = (int)0;
              {
                int _5939 = (int)0;
                for(;(_5939 < _5922);++ _5939)
                {
                  {
                    monty::rc_ptr< ::mosek::fusion::Matrix > _5940 = ((*((*_5920)(_5935)))(_5939));
                    if ((NULL != _5940.get()))
                    {
                      {
                        monty::rc_ptr< ::mosek::fusion::Matrix > _9666 = _5940;
                        if (false) {}
                        else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9666.get()))
                        {
                          ::mosek::fusion::DenseMatrix::t _5941 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9666.get()));
                          {
                            int _5944 = _ptr__5936[_5939];
                            {
                              int _5945 = (int)0;
                              for(;(_5945 < mosek::fusion::p_Matrix::_get_impl(_5941)->dimj);++ _5945)
                              {
                                {
                                  _ptr__5930[_5933] = ((*mosek::fusion::p_DenseMatrix::_get_impl(_5941)->data)(_5944));
                                  _ptr__5931[_5933] = safe_add( _5934,_5937 );
                                  _ptr__5932[_5933] = safe_add( _5938,_5945 );
                                  ++ _5944;
                                  ++ _5933;
                                }
                              }
                            }
                            _ptr__5936[_5939] = _5944;
                          }
                        }
                        else if (nullptr != dynamic_cast<::mosek::fusion::SparseMatrix*>(_9666.get()))
                        {
                          ::mosek::fusion::SparseMatrix::t _5942 (dynamic_cast<::mosek::fusion::SparseMatrix*>(_9666.get()));
                          {
                            int _5946;
                            {
                              _5946 = _ptr__5936[_5939];
                              for(;((_5946 < mosek::fusion::p_SparseMatrix::_get_impl(_5942)->nnz) && (((*mosek::fusion::p_SparseMatrix::_get_impl(_5942)->subi)(_5946)) == _5937));++ _5946)
                              {
                                {
                                  _ptr__5930[_5933] = ((*mosek::fusion::p_SparseMatrix::_get_impl(_5942)->val)(_5946));
                                  _ptr__5932[_5933] = safe_add( ((*mosek::fusion::p_SparseMatrix::_get_impl(_5942)->subj)(_5946)),_5938 );
                                  _ptr__5931[_5933] = safe_add( _5934,_5937 );
                                  ++ _5933;
                                }
                              }
                            }
                            _ptr__5936[_5939] = _5946;
                          }
                        }
                        else
                        {
                          mosek::fusion::Matrix::t _5943 = _9666;
                          {
                            throw ::mosek::fusion::MatrixError(std::string ("Unknown matrix type."));
                          }
                        }
                      }
                    }
                    {}
                    _5938 = safe_add( _5938,_ptr__5924[_5939] );
                  }
                }
              }
            }
          }
        }
        _5934 = safe_add( _5934,_ptr__5923[_5935] );
      }
    }
  }
  int _5947 = (int)0;
  int _5948 = (int)0;
  {
    int _5949 = (int)0;
    for(;(_5949 < _5921);++ _5949)
    {
      {
        _5947 = safe_add( _5947,_ptr__5923[_5949] );
      }
    }
  }
  {
    int _5950 = (int)0;
    for(;(_5950 < _5922);++ _5950)
    {
      {
        _5948 = safe_add( _5948,_ptr__5924[_5950] );
      }
    }
  }
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5947,_5948,_5931,_5932,_5930)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< double,2 > > _5951) { return mosek::fusion::p_Matrix::sparse(_5951); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< double,2 > > _5951){
  int _5952 = (int)((_5951)->size(0));
  int _5953 = (int)((_5951)->size(1));
  long long _5954 = (long long)safe_mul( _5952,_5953 );
  int _5955 = (int)0;
  std::shared_ptr< monty::ndarray< int,1 > > _5956 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5954)));
  _checked_ptr_1<int> _ptr__5956(_5956 ? _5956->raw() : nullptr,_5956 ? _5956->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5957 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5954)));
  _checked_ptr_1<int> _ptr__5957(_5957 ? _5957->raw() : nullptr,_5957 ? _5957->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5958 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5954)));
  _checked_ptr_1<double> _ptr__5958(_5958 ? _5958->raw() : nullptr,_5958 ? _5958->size(0) : 0);
  {
    int _5959 = (int)0;
    for(;(_5959 < _5952);++ _5959)
    {
      {
        {
          int _5960 = (int)0;
          for(;(_5960 < _5953);++ _5960)
          {
            {
              _ptr__5956[_5955] = _5959;
              _ptr__5957[_5955] = _5960;
              _ptr__5958[_5955] = ((*_5951)(_5959,_5960));
              ++ _5955;
            }
          }
        }
      }
    }
  }
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5952,_5953,_5956,_5957,_5958)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( int _5961,    int _5962) { return mosek::fusion::p_Matrix::sparse(_5961,_5962); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(int _5961,int _5962){
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5961,_5962,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0))),(long long)0)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( int _5963,    int _5964,    std::shared_ptr< monty::ndarray< int,1 > > _5965,    std::shared_ptr< monty::ndarray< int,1 > > _5966,    double _5967) { return mosek::fusion::p_Matrix::sparse(_5963,_5964,_5965,_5966,_5967); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(int _5963,int _5964,std::shared_ptr< monty::ndarray< int,1 > > _5965,std::shared_ptr< monty::ndarray< int,1 > > _5966,double _5967){
  _checked_ptr_1<int> _ptr__5965(_5965 ? _5965->raw() : nullptr, _5965 ? _5965->size(0) : 0);
  _checked_ptr_1<int> _ptr__5966(_5966 ? _5966->raw() : nullptr, _5966 ? _5966->size(0) : 0);
  int _5968 = (int)0;
  if ((NULL != _5965.get()))
  {
    {
      _5968 = (int)((_5965)->size(0));
    }
  }
  else if((NULL != _5966.get()))
  {
    {
      _5968 = (int)((_5966)->size(0));
    }
  }
  {}
  return ::mosek::fusion::p_Matrix::sparse(_5963,_5964,_5965,_5966,::mosek::fusion::Utils::Tools::makevector(_5967,_5968));
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< int,1 > > _5969,    std::shared_ptr< monty::ndarray< int,1 > > _5970,    double _5971) { return mosek::fusion::p_Matrix::sparse(_5969,_5970,_5971); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< int,1 > > _5969,std::shared_ptr< monty::ndarray< int,1 > > _5970,double _5971){
  _checked_ptr_1<int> _ptr__5969(_5969 ? _5969->raw() : nullptr, _5969 ? _5969->size(0) : 0);
  _checked_ptr_1<int> _ptr__5970(_5970 ? _5970->raw() : nullptr, _5970 ? _5970->size(0) : 0);
  int _5972 = (int)0;
  int _5973 = (int)0;
  int _5974 = (int)((_5969)->size(0));
  if ((_5974 > (int)((_5970)->size(0))))
  {
    {
      _5974 = (int)((_5970)->size(0));
    }
  }
  {}
  int _9667 = (int)0;
  int _9668 = _5974;
  for (int _5975 = _9667; _5975 < _9668; ++_5975)
  {
    {
      if ((_5973 < _ptr__5969[_5975]))
      {
        {
          _5973 = _ptr__5969[_5975];
        }
      }
      {}
      if ((_5972 < _ptr__5970[_5975]))
      {
        {
          _5972 = _ptr__5970[_5975];
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Matrix::sparse(safe_add( _5973,(int)1 ),safe_add( _5972,(int)1 ),_5969,_5970,_5971);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< int,1 > > _5976,    std::shared_ptr< monty::ndarray< int,1 > > _5977,    std::shared_ptr< monty::ndarray< double,1 > > _5978) { return mosek::fusion::p_Matrix::sparse(_5976,_5977,_5978); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< int,1 > > _5976,std::shared_ptr< monty::ndarray< int,1 > > _5977,std::shared_ptr< monty::ndarray< double,1 > > _5978){
  _checked_ptr_1<int> _ptr__5976(_5976 ? _5976->raw() : nullptr, _5976 ? _5976->size(0) : 0);
  _checked_ptr_1<int> _ptr__5977(_5977 ? _5977->raw() : nullptr, _5977 ? _5977->size(0) : 0);
  _checked_ptr_1<double> _ptr__5978(_5978 ? _5978->raw() : nullptr, _5978 ? _5978->size(0) : 0);
  int _5979 = (int)0;
  int _5980 = (int)0;
  int _5981 = (int)((_5976)->size(0));
  if ((_5981 > (int)((_5977)->size(0))))
  {
    {
      _5981 = (int)((_5977)->size(0));
    }
  }
  {}
  if ((_5981 > (int)((_5978)->size(0))))
  {
    {
      _5981 = (int)((_5978)->size(0));
    }
  }
  {}
  int _9669 = (int)0;
  int _9670 = _5981;
  for (int _5982 = _9669; _5982 < _9670; ++_5982)
  {
    {
      if ((_5980 < _ptr__5976[_5982]))
      {
        {
          _5980 = _ptr__5976[_5982];
        }
      }
      {}
      if ((_5979 < _ptr__5977[_5982]))
      {
        {
          _5979 = _ptr__5977[_5982];
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Matrix::sparse(safe_add( _5980,(int)1 ),safe_add( _5979,(int)1 ),_5976,_5977,_5978);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( int _5983,    int _5984,    std::shared_ptr< monty::ndarray< int,1 > > _5985,    std::shared_ptr< monty::ndarray< int,1 > > _5986,    std::shared_ptr< monty::ndarray< double,1 > > _5987) { return mosek::fusion::p_Matrix::sparse(_5983,_5984,_5985,_5986,_5987); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(int _5983,int _5984,std::shared_ptr< monty::ndarray< int,1 > > _5985,std::shared_ptr< monty::ndarray< int,1 > > _5986,std::shared_ptr< monty::ndarray< double,1 > > _5987){
  _checked_ptr_1<int> _ptr__5985(_5985 ? _5985->raw() : nullptr, _5985 ? _5985->size(0) : 0);
  _checked_ptr_1<int> _ptr__5986(_5986 ? _5986->raw() : nullptr, _5986 ? _5986->size(0) : 0);
  _checked_ptr_1<double> _ptr__5987(_5987 ? _5987->raw() : nullptr, _5987 ? _5987->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _9671;
  bool _9672 = (NULL != _5987.get());
  if (_9672)
  {
    _9671 = _5987;
  }
  else
  {
    _9671 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0)));
  }
  std::shared_ptr< monty::ndarray< double,1 > > _5988 = _9671;
  _checked_ptr_1<double> _ptr__5988(_5988 ? _5988->raw() : nullptr,_5988 ? _5988->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9673;
  bool _9674 = (NULL != _5986.get());
  if (_9674)
  {
    _9673 = _5986;
  }
  else
  {
    _9673 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5989 = _9673;
  _checked_ptr_1<int> _ptr__5989(_5989 ? _5989->raw() : nullptr,_5989 ? _5989->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9675;
  bool _9676 = (NULL != _5985.get());
  if (_9676)
  {
    _9675 = _5985;
  }
  else
  {
    _9675 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5990 = _9675;
  _checked_ptr_1<int> _ptr__5990(_5990 ? _5990->raw() : nullptr,_5990 ? _5990->size(0) : 0);
  long long _5991 = (long long)((_5990)->size(0));
  if ((((long long)((_5989)->size(0)) != _5991) || ((long long)((_5988)->size(0)) != _5991)))
  {
    {
      throw ::mosek::fusion::SparseFormatError(std::string ("Arrays defining sparse data have different lengths"));
    }
  }
  {}
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5983,_5984,_5990,_5989,_5988,_5991)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix :: transpose() { return __mosek_2fusion_2Matrix__transpose(); }
int mosek::fusion::Matrix :: numColumns() { return mosek::fusion::p_Matrix::_get_impl(this)->numColumns(); }int mosek::fusion::p_Matrix::numColumns(){
  return dimj;
}
int mosek::fusion::Matrix :: numRows() { return mosek::fusion::p_Matrix::_get_impl(this)->numRows(); }int mosek::fusion::p_Matrix::numRows(){
  return dimi;
}
void mosek::fusion::p_Matrix::destroy(){}void mosek::fusion::Matrix::destroy() { mosek::fusion::p_Matrix::_get_impl(this)->destroy(); }mosek::fusion::UnimplementedError::UnimplementedError  ( const std::string &  _5997) : RuntimeException(_5997)  {
  }
mosek::fusion::FatalError::FatalError  ( const std::string &  _5998) : RuntimeException(_5998)  {
  }
mosek::fusion::UnexpectedError::UnexpectedError  ( ::mosek::fusion::FusionException _5999) : RuntimeException(_5999.toString())  {
  }
mosek::fusion::UnexpectedError::UnexpectedError  ( const std::string &  _6000) : RuntimeException(_6000)  {
  }
mosek::fusion::SparseFormatError::SparseFormatError  ( const std::string &  _6001) : mosek::fusion::FusionRuntimeException(_6001)  {
  }
mosek::fusion::SolutionError::SolutionError  ( ) : mosek::fusion::FusionException(std::string ("Solution is invalid or undefined"))  {
  }
mosek::fusion::SolutionError::SolutionError  ( const std::string &  _6002) : mosek::fusion::FusionException(_6002)  {
  }
mosek::fusion::SliceError::SliceError  ( ) : mosek::fusion::FusionRuntimeException(std::string ("Invalid slice range"))  {
  }
mosek::fusion::SliceError::SliceError  ( const std::string &  _6003) : mosek::fusion::FusionRuntimeException(_6003)  {
  }
mosek::fusion::SetDefinitionError::SetDefinitionError  ( const std::string &  _6004) : mosek::fusion::FusionRuntimeException(_6004)  {
  }
mosek::fusion::OptimizeError::OptimizeError  ( const std::string &  _6005) : mosek::fusion::FusionRuntimeException(_6005)  {
  }
mosek::fusion::NameError::NameError  ( const std::string &  _6006) : mosek::fusion::FusionRuntimeException(_6006)  {
  }
mosek::fusion::ModelError::ModelError  ( const std::string &  _6007) : mosek::fusion::FusionRuntimeException(_6007)  {
  }
mosek::fusion::MatrixError::MatrixError  ( const std::string &  _6008) : mosek::fusion::FusionRuntimeException(_6008)  {
  }
mosek::fusion::DimensionError::DimensionError  ( const std::string &  _6009) : mosek::fusion::FusionRuntimeException(_6009)  {
  }
mosek::fusion::LengthError::LengthError  ( const std::string &  _6010) : mosek::fusion::FusionRuntimeException(_6010)  {
  }
mosek::fusion::RangeError::RangeError  ( const std::string &  _6011) : mosek::fusion::FusionRuntimeException(_6011)  {
  }
mosek::fusion::IndexError::IndexError  ( const std::string &  _6012) : mosek::fusion::FusionRuntimeException(_6012)  {
  }
mosek::fusion::DomainError::DomainError  ( const std::string &  _6013) : mosek::fusion::FusionRuntimeException(_6013)  {
  }
mosek::fusion::ValueConversionError::ValueConversionError  ( const std::string &  _6014) : mosek::fusion::FusionRuntimeException(_6014)  {
  }
mosek::fusion::ParameterError::ParameterError  ( const std::string &  _6015) : mosek::fusion::FusionRuntimeException(_6015)  {
  }
mosek::fusion::ExpressionError::ExpressionError  ( const std::string &  _6016) : mosek::fusion::FusionRuntimeException(_6016)  {
  }
mosek::fusion::IOError::IOError  ( const std::string &  _6017) : mosek::fusion::FusionRuntimeException(_6017)  {
  }
mosek::fusion::FusionRuntimeException::FusionRuntimeException  ( const std::string &  _6018) : RuntimeException(_6018)  {
    msg = _6018;
  }
std::string mosek::fusion::FusionRuntimeException::toString(){
  return msg;
}
mosek::fusion::FusionException::FusionException  ( const std::string &  _6019) : Exception(_6019)  {
    msg = _6019;
  }
std::string mosek::fusion::FusionException::toString(){
  return msg;
}
mosek::fusion::LinkedBlocks::LinkedBlocks(mosek::fusion::p_LinkedBlocks *_impl) : _impl(_impl) { /*std::cout << "LinkedBlocks() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinkedBlocks::~LinkedBlocks() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinkedBlocks::p_LinkedBlocks  (::mosek::fusion::LinkedBlocks * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinkedBlocks::t mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks  (){ return new mosek::fusion::LinkedBlocks(); }mosek::fusion::LinkedBlocks::LinkedBlocks  () :    LinkedBlocks(new mosek::fusion::p_LinkedBlocks(this)){ mosek::fusion::p_LinkedBlocks::_get_impl(this)->_initialize(); }void mosek::fusion::p_LinkedBlocks::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_LinkedBlocks::_initialize((int)0);
  }
}mosek::fusion::LinkedBlocks::t mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks  (int _6020){ return new mosek::fusion::LinkedBlocks(_6020); }mosek::fusion::LinkedBlocks::LinkedBlocks  (int _6020) :    LinkedBlocks(new mosek::fusion::p_LinkedBlocks(this)){ mosek::fusion::p_LinkedBlocks::_get_impl(this)->_initialize(_6020); }void mosek::fusion::p_LinkedBlocks::_initialize  (int _6020){monty::rc_reserve __reserve_this(_pubthis);   {
    ints = ::mosek::fusion::p_LinkedInts::_new_LinkedInts(_6020);
    blocks = ::mosek::fusion::p_LinkedInts::_new_LinkedInts((int)128);
    bsize = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)128)));
    bfirst = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)128)));
  }
}mosek::fusion::LinkedBlocks::t mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks  (monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _6021){ return new mosek::fusion::LinkedBlocks(_6021); }mosek::fusion::LinkedBlocks::LinkedBlocks  (monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _6021) :    LinkedBlocks(new mosek::fusion::p_LinkedBlocks(this)){ mosek::fusion::p_LinkedBlocks::_get_impl(this)->_initialize(_6021); }void mosek::fusion::p_LinkedBlocks::_initialize  (monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _6021){monty::rc_reserve __reserve_this(_pubthis);   {
    ints = ::mosek::fusion::p_LinkedInts::_new_LinkedInts(mosek::fusion::p_LinkedBlocks::_get_impl(_6021)->ints);
    blocks = ::mosek::fusion::p_LinkedInts::_new_LinkedInts(mosek::fusion::p_LinkedBlocks::_get_impl(_6021)->blocks);
    bsize = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedBlocks::_get_impl(_6021)->bsize);
    bfirst = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedBlocks::_get_impl(_6021)->bfirst);
  }
}void mosek::fusion::LinkedBlocks :: free(int _6022) { mosek::fusion::p_LinkedBlocks::_get_impl(this)->free(_6022); }void mosek::fusion::p_LinkedBlocks::free(int _6022){
  int _6023 = ((*bfirst)(_6022));
  ints->free(_6022,((*bsize)(_6022)));
  ((*bsize)(_6022)) = (-(int)1);
  ((*bfirst)(_6022)) = (-(int)1);
  blocks->free(_6023,(int)1);
}
int mosek::fusion::LinkedBlocks :: alloc(int _6024) { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->alloc(_6024); }int mosek::fusion::p_LinkedBlocks::alloc(int _6024){
  int _9677;
  bool _9678 = (_6024 > (int)0);
  if (_9678)
  {
    _9677 = ints->alloc(_6024);
  }
  else
  {
    _9677 = (-(int)1);
  }
  int _6025 = _9677;
  int _6026 = blocks->alloc();
  if ((blocks->capacity() > (int)((bsize)->size(0))))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _6027 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(blocks->capacity())));
      _checked_ptr_1<int> _ptr__6027(_6027 ? _6027->raw() : nullptr,_6027 ? _6027->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _6028 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(blocks->capacity())));
      _checked_ptr_1<int> _ptr__6028(_6028 ? _6028->raw() : nullptr,_6028 ? _6028->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(bsize,(int)0,_6027,(int)0,(int)((bsize)->size(0)));
      ::mosek::fusion::Utils::Tools::arraycopy(bfirst,(int)0,_6028,(int)0,(int)((bfirst)->size(0)));
      bsize = _6027;
      bfirst = _6028;
    }
  }
  {}
  ((*bfirst)(_6026)) = _6025;
  ((*bsize)(_6026)) = _6024;
  return _6026;
}
int mosek::fusion::LinkedBlocks :: maxidx(int _6029) { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->maxidx(_6029); }int mosek::fusion::p_LinkedBlocks::maxidx(int _6029){
  return ints->maxidx(((*bfirst)(_6029)),((*bsize)(_6029)));
}
void mosek::fusion::LinkedBlocks :: get(int _6030,std::shared_ptr< monty::ndarray< int,1 > > _6031,int _6032) { mosek::fusion::p_LinkedBlocks::_get_impl(this)->get(_6030,_6031,_6032); }void mosek::fusion::p_LinkedBlocks::get(int _6030,std::shared_ptr< monty::ndarray< int,1 > > _6031,int _6032){
  _checked_ptr_1<int> _ptr__6031(_6031 ? _6031->raw() : nullptr, _6031 ? _6031->size(0) : 0);
  ints->get(((*bfirst)(_6030)),((*bsize)(_6030)),_6031,_6032);
}
int mosek::fusion::LinkedBlocks :: numblocks() { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->numblocks(); }int mosek::fusion::p_LinkedBlocks::numblocks(){
  return (int)((bsize)->size(0));
}
int mosek::fusion::LinkedBlocks :: blocksize(int _6033) { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->blocksize(_6033); }int mosek::fusion::p_LinkedBlocks::blocksize(int _6033){
  return ((*bsize)(_6033));
}
int mosek::fusion::LinkedBlocks :: capacity() { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->capacity(); }int mosek::fusion::p_LinkedBlocks::capacity(){
  return ints->capacity();
}
bool mosek::fusion::LinkedBlocks :: validate() { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->validate(); }bool mosek::fusion::p_LinkedBlocks::validate(){
  return (ints->validate() && blocks->validate());
}
void mosek::fusion::p_LinkedBlocks::destroy(){bfirst.reset();bsize.reset();blocks.reset();ints.reset();}void mosek::fusion::LinkedBlocks::destroy() { mosek::fusion::p_LinkedBlocks::_get_impl(this)->destroy(); }mosek::fusion::LinkedInts::LinkedInts(mosek::fusion::p_LinkedInts *_impl) : _impl(_impl) { /*std::cout << "LinkedInts() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinkedInts::~LinkedInts() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinkedInts::p_LinkedInts  (::mosek::fusion::LinkedInts * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinkedInts::t mosek::fusion::p_LinkedInts::_new_LinkedInts  (int _6034){ return new mosek::fusion::LinkedInts(_6034); }mosek::fusion::LinkedInts::LinkedInts  (int _6034) :    LinkedInts(new mosek::fusion::p_LinkedInts(this)){ mosek::fusion::p_LinkedInts::_get_impl(this)->_initialize(_6034); }void mosek::fusion::p_LinkedInts::_initialize  (int _6034){monty::rc_reserve __reserve_this(_pubthis);   {
    int _9679;
    bool _9680 = (_6034 > (int)0);
    if (_9680)
    {
      _9679 = _6034;
    }
    else
    {
      _9679 = (int)128;
    }
    int _6035 = _9679;
    next = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6035)));
    prev = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6035)));
    first_used = (-(int)1);
    first_free = (int)0;
    last_free = (_6035 - (int)1);
    int _9681 = (int)1;
    int _9682 = _6035;
    for (int _6036 = _9681; _6036 < _9682; ++_6036)
    {
      {
        ((*prev)(_6036)) = (_6036 - (int)1);
        ((*next)((_6036 - (int)1))) = _6036;
      }
    }
    ((*prev)((int)0)) = (-(int)1);
    ((*next)((_6035 - (int)1))) = (-(int)1);
    nfree = _6035;
  }
}mosek::fusion::LinkedInts::t mosek::fusion::p_LinkedInts::_new_LinkedInts  (){ return new mosek::fusion::LinkedInts(); }mosek::fusion::LinkedInts::LinkedInts  () :    LinkedInts(new mosek::fusion::p_LinkedInts(this)){ mosek::fusion::p_LinkedInts::_get_impl(this)->_initialize(); }void mosek::fusion::p_LinkedInts::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_LinkedInts::_initialize((int)128);
  }
}mosek::fusion::LinkedInts::t mosek::fusion::p_LinkedInts::_new_LinkedInts  (monty::rc_ptr< ::mosek::fusion::LinkedInts > _6037){ return new mosek::fusion::LinkedInts(_6037); }mosek::fusion::LinkedInts::LinkedInts  (monty::rc_ptr< ::mosek::fusion::LinkedInts > _6037) :    LinkedInts(new mosek::fusion::p_LinkedInts(this)){ mosek::fusion::p_LinkedInts::_get_impl(this)->_initialize(_6037); }void mosek::fusion::p_LinkedInts::_initialize  (monty::rc_ptr< ::mosek::fusion::LinkedInts > _6037){monty::rc_reserve __reserve_this(_pubthis);   {
    next = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedInts::_get_impl(_6037)->next);
    prev = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedInts::_get_impl(_6037)->prev);
    first_used = mosek::fusion::p_LinkedInts::_get_impl(_6037)->first_used;
    first_free = mosek::fusion::p_LinkedInts::_get_impl(_6037)->first_free;
    last_free = mosek::fusion::p_LinkedInts::_get_impl(_6037)->last_free;
    nfree = mosek::fusion::p_LinkedInts::_get_impl(_6037)->nfree;
  }
}void mosek::fusion::LinkedInts :: free(int _6038,int _6039) { mosek::fusion::p_LinkedInts::_get_impl(this)->free(_6038,_6039); }void mosek::fusion::p_LinkedInts::free(int _6038,int _6039){
  int _6040 = _6038;
  int _6041 = _6040;
  int _9683 = (int)0;
  int _9684 = (_6039 - (int)1);
  for (int _6042 = _9683; _6042 < _9684; ++_6042)
  {
    {
      _6041 = ((*next)(_6041));
    }
  }
  int _6043 = ((*prev)(_6040));
  int _6044 = ((*next)(_6041));
  if ((_6043 >= (int)0))
  {
    {
      ((*next)(_6043)) = _6044;
    }
  }
  {}
  if ((_6044 >= (int)0))
  {
    {
      ((*prev)(_6044)) = _6043;
    }
  }
  {}
  ((*prev)(_6040)) = (-(int)1);
  ((*next)(_6041)) = first_free;
  if ((first_free >= (int)0))
  {
    {
      ((*prev)(first_free)) = _6041;
    }
  }
  {}
  first_free = _6040;
  nfree += _6039;
}
int mosek::fusion::LinkedInts :: alloc() { return mosek::fusion::p_LinkedInts::_get_impl(this)->alloc(); }int mosek::fusion::p_LinkedInts::alloc(){
  return allocblock((int)1);
}
int mosek::fusion::LinkedInts :: alloc(int _6045) { return mosek::fusion::p_LinkedInts::_get_impl(this)->alloc(_6045); }int mosek::fusion::p_LinkedInts::alloc(int _6045){
  return allocblock(_6045);
}
void mosek::fusion::LinkedInts :: alloc(int _6046,std::shared_ptr< monty::ndarray< int,1 > > _6047,int _6048) { mosek::fusion::p_LinkedInts::_get_impl(this)->alloc(_6046,_6047,_6048); }void mosek::fusion::p_LinkedInts::alloc(int _6046,std::shared_ptr< monty::ndarray< int,1 > > _6047,int _6048){
  _checked_ptr_1<int> _ptr__6047(_6047 ? _6047->raw() : nullptr, _6047 ? _6047->size(0) : 0);
  int _6049 = allocblock(_6046);
  int _9685 = (int)0;
  int _9686 = _6046;
  for (int _6050 = _9685; _6050 < _9686; ++_6050)
  {
    {
      _ptr__6047[safe_add( _6050,_6048 )] = _6049;
      _6049 = ((*next)(_6049));
    }
  }
}
void mosek::fusion::LinkedInts :: get(int _6051,int _6052,std::shared_ptr< monty::ndarray< int,1 > > _6053,int _6054) { mosek::fusion::p_LinkedInts::_get_impl(this)->get(_6051,_6052,_6053,_6054); }void mosek::fusion::p_LinkedInts::get(int _6051,int _6052,std::shared_ptr< monty::ndarray< int,1 > > _6053,int _6054){
  _checked_ptr_1<int> _ptr__6053(_6053 ? _6053->raw() : nullptr, _6053 ? _6053->size(0) : 0);
  int _6055 = _6051;
  int _9687 = (int)0;
  int _9688 = _6052;
  for (int _6056 = _9687; _6056 < _9688; ++_6056)
  {
    {
      _ptr__6053[safe_add( _6056,_6054 )] = _6055;
      _6055 = ((*next)(_6055));
    }
  }
}
int mosek::fusion::LinkedInts :: maxidx(int _6057,int _6058) { return mosek::fusion::p_LinkedInts::_get_impl(this)->maxidx(_6057,_6058); }int mosek::fusion::p_LinkedInts::maxidx(int _6057,int _6058){
  int _6059 = _6057;
  int _6060 = _6057;
  int _9689 = (int)1;
  int _9690 = _6058;
  for (int _6061 = _9689; _6061 < _9690; ++_6061)
  {
    {
      _6060 = ((*next)(_6060));
      if ((_6059 < _6060))
      {
        {
          _6059 = _6060;
        }
      }
      {}
    }
  }
  return _6059;
}
int mosek::fusion::p_LinkedInts::allocblock(int _6062){
  int _6063 = (int)((next)->size(0));
  if ((nfree < _6062))
  {
    {
      int _6064 = (_6062 - nfree);
      if ((_6064 < _6063))
      {
        {
          _6064 = _6063;
        }
      }
      {}
      recap(safe_add( _6064,_6063 ));
    }
  }
  {}
  int _6065 = first_free;
  int _6066 = _6065;
  int _9691 = (int)0;
  int _9692 = (_6062 - (int)1);
  for (int _6067 = _9691; _6067 < _9692; ++_6067)
  {
    {
      _6066 = ((*next)(_6066));
    }
  }
  first_free = ((*next)(_6066));
  if ((first_free < (int)0))
  {
    {
      last_free = (-(int)1);
    }
  }
  else
  {
    {
      ((*prev)(first_free)) = (-(int)1);
    }
  }
  ((*next)(_6066)) = first_used;
  if ((first_used >= (int)0))
  {
    {
      ((*prev)(first_used)) = _6066;
    }
  }
  {}
  first_used = _6065;
  nfree -= _6062;
  return _6065;
}
void mosek::fusion::p_LinkedInts::recap(int _6068){
  int _6069 = (int)((next)->size(0));
  if ((_6068 > _6069))
  {
    {
      next = ::mosek::fusion::p_CommonTools::resize(next,_6068);
      prev = ::mosek::fusion::p_CommonTools::resize(prev,_6068);
      int _9693 = _6069;
      int _9694 = (_6068 - (int)1);
      for (int _6070 = _9693; _6070 < _9694; ++_6070)
      {
        {
          ((*next)(_6070)) = safe_add( _6070,(int)1 );
          ((*prev)(safe_add( _6070,(int)1 ))) = _6070;
        }
      }
      ((*next)((_6068 - (int)1))) = (-(int)1);
      ((*prev)(_6069)) = last_free;
      if ((last_free < (int)0))
      {
        {
          first_free = _6069;
        }
      }
      else
      {
        {
          ((*next)(last_free)) = _6069;
        }
      }
      last_free = (_6068 - (int)1);
      nfree += (_6068 - _6069);
    }
  }
  {}
}
int mosek::fusion::LinkedInts :: capacity() { return mosek::fusion::p_LinkedInts::_get_impl(this)->capacity(); }int mosek::fusion::p_LinkedInts::capacity(){
  return (int)((next)->size(0));
}
bool mosek::fusion::LinkedInts :: validate() { return mosek::fusion::p_LinkedInts::_get_impl(this)->validate(); }bool mosek::fusion::p_LinkedInts::validate(){
  std::shared_ptr< monty::ndarray< bool,1 > > _6071 = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape((int)((next)->size(0)))));
  int _6072 = first_used;
  while ( (_6072 >= (int)0) )
  {
    {
      ((*_6071)(_6072)) = true;
      _6072 = ((*next)(_6072));
      if (((_6072 >= (int)0) && ((*_6071)(_6072))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("used list/next is inconsistent"));
        }
      }
      {}
    }
  }
  _6072 = first_free;
  int _6073 = (int)0;
  while ( (_6072 >= (int)0) )
  {
    {
      ++ _6073;
      ((*_6071)(_6072)) = true;
      _6072 = ((*next)(_6072));
      if (((_6072 >= (int)0) && ((*_6071)(_6072))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("free list/next is inconsistent"));
        }
      }
      {}
    }
  }
  if ((_6073 != nfree))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("free next list did not contain nfree elements"));
    }
  }
  {}
  int _9695 = (int)0;
  int _9696 = (int)((_6071)->size(0));
  for (int _6074 = _9695; _6074 < _9696; ++_6074)
  {
    {
      if ((!((*_6071)(_6072))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("elements missing from used+free list"));
        }
      }
      {}
    }
  }
  int _9697 = (int)0;
  int _9698 = (int)((_6071)->size(0));
  for (int _6075 = _9697; _6075 < _9698; ++_6075)
  {
    {
      ((*_6071)(_6075)) = false;
    }
  }
  _6072 = last_free;
  int _6076 = (int)0;
  while ( (_6072 >= (int)0) )
  {
    {
      ++ _6076;
      ((*_6071)(_6072)) = true;
      _6072 = ((*prev)(_6072));
      if (((_6072 >= (int)0) && ((*_6071)(_6072))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("prev list is inconsistent"));
        }
      }
      {}
    }
  }
  if ((_6076 != nfree))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("free prev list did not contain nfree elements"));
    }
  }
  {}
  return true;
}
void mosek::fusion::p_LinkedInts::destroy(){prev.reset();next.reset();}void mosek::fusion::LinkedInts::destroy() { mosek::fusion::p_LinkedInts::_get_impl(this)->destroy(); }mosek::fusion::Parameters::Parameters(mosek::fusion::p_Parameters *_impl) : _impl(_impl) { /*std::cout << "Parameters() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Parameters::~Parameters() { delete _impl; _impl = nullptr; }mosek::fusion::p_Parameters::p_Parameters  (::mosek::fusion::Parameters * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::Parameters::setParameter  ( monty::rc_ptr< ::mosek::fusion::Model > _6077,    const std::string & _6078,    double _6079) { mosek::fusion::p_Parameters::setParameter(_6077,_6078,_6079); }void mosek::fusion::p_Parameters::setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6077,const std::string & _6078,double _6079){
  if (false)
  {
    {
    }
  }
  else if((_6078 == std::string ("autoUpdateSolInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (autoUpdateSolInfo)"));
    }
  }
  else if((_6078 == std::string ("removeUnusedSolutions")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (removeUnusedSolutions)"));
    }
  }
  {}
  if ((_6078 == std::string ("numThreads")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6080 = _6079;
          if (((int)0 <= _6080))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_NUM_THREADS"),_6080);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("intpntMultiThread")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMultiThread)"));
    }
  }
  {}
  if ((_6078 == std::string ("mtSpincount")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6081 = _6079;
          if ((((int)0 <= _6081) && (_6081 <= (int)1000000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_MT_SPINCOUNT"),_6081);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("optimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizer)"));
    }
  }
  {}
  if ((_6078 == std::string ("biMaxIterations")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6082 = _6079;
          if (((int)0 <= _6082))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_BI_MAX_ITERATIONS"),_6082);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6083 = _6079;
          if (((int)0 <= _6083))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_TRH_EXPIRY_WRN"),_6083);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("logCutSecondOpt")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6084 = _6079;
          if (((int)0 <= _6084))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_LOG_CUT_SECOND_OPT"),_6084);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("logResponse")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6085 = _6079;
          if (((int)0 <= _6085))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_LOG_RESPONSE"),_6085);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("logLocalInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logLocalInfo)"));
    }
  }
  {}
  if ((_6078 == std::string ("logBi")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6086 = _6079;
          if (((int)0 <= _6086))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI"),_6086);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("logBiFreq")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6087 = _6079;
          if (((int)0 <= _6087))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI_FREQ"),_6087);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("biCleanOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biCleanOptimizer)"));
    }
  }
  else if((_6078 == std::string ("intpntStartingPoint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntStartingPoint)"));
    }
  }
  else if((_6078 == std::string ("intpntDiffStep")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntDiffStep)"));
    }
  }
  else if((_6078 == std::string ("intpntScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntScaling)"));
    }
  }
  else if((_6078 == std::string ("intpntSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntSolveForm)"));
    }
  }
  {}
  if ((_6078 == std::string ("logIntpnt")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6088 = _6079;
          if (((int)0 <= _6088))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_LOG_INTPNT"),_6088);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("intpntMaxIterations")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6089 = _6079;
          if (((int)0 <= _6089))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_ITERATIONS"),_6089);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("intpntOffColTrh")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6090 = _6079;
          if (((int)0 <= _6090))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_OFF_COL_TRH"),_6090);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("intpntOrderMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderMethod)"));
    }
  }
  {}
  if ((_6078 == std::string ("intpntOrderGpNumSeeds")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6091 = _6079;
          if (((int)0 <= _6091))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_ORDER_GP_NUM_SEEDS"),_6091);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderGpNumSeeds)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderGpNumSeeds)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("intpntBasis")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntBasis)"));
    }
  }
  else if((_6078 == std::string ("biIgnoreMaxIter")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreMaxIter)"));
    }
  }
  else if((_6078 == std::string ("biIgnoreNumError")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreNumError)"));
    }
  }
  {}
  if ((_6078 == std::string ("intpntMaxNumCor")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6092 = _6079;
          if (((-(int)1) <= _6092))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_NUM_COR"),_6092);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("presolveUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveUse)"));
    }
  }
  {}
  if ((_6078 == std::string ("presolveLevel")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6093 = _6079;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LEVEL"),_6093);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("logPresolve")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6094 = _6079;
          if (((int)0 <= _6094))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_LOG_PRESOLVE"),_6094);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("presolveLindepUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepUse)"));
    }
  }
  {}
  if ((_6078 == std::string ("presolveMaxNumPass")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6095 = _6079;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_MAX_NUM_PASS"),_6095);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6096 = _6079;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_NUM_TRIES"),_6096);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6097 = _6079;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_FILL"),_6097);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("simPrimalCrash")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6098 = _6079;
          if (((int)0 <= _6098))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_CRASH"),_6098);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("logSim")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6099 = _6079;
          if (((int)0 <= _6099))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM"),_6099);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("logSimMinor")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6100 = _6079;
          if (((int)0 <= _6100))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_MINOR"),_6100);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("logSimFreq")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6101 = _6079;
          if (((int)0 <= _6101))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_FREQ"),_6101);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("simPrimalRestrictSelection")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6102 = _6079;
          if ((((int)0 <= _6102) && (_6102 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_RESTRICT_SELECTION"),_6102);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("simPrimalSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalSelection)"));
    }
  }
  {}
  if ((_6078 == std::string ("simDualRestrictSelection")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6103 = _6079;
          if ((((int)0 <= _6103) && (_6103 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_RESTRICT_SELECTION"),_6103);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("simDualSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualSelection)"));
    }
  }
  {}
  if ((_6078 == std::string ("simMaxIterations")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6104 = _6079;
          if (((int)0 <= _6104))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_ITERATIONS"),_6104);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("simHotstartLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstartLu)"));
    }
  }
  {}
  if ((_6078 == std::string ("simRefactorFreq")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6105 = _6079;
          if (((int)0 <= _6105))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFACTOR_FREQ"),_6105);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("simSeed")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6106 = _6079;
          if ((((int)0 <= _6106) && (_6106 <= (int)32749)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_SIM_SEED"),_6106);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("mioMode")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMode)"));
    }
  }
  {}
  if ((_6078 == std::string ("logMio")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6107 = _6079;
          if (((int)0 <= _6107))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO"),_6107);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("logMioFreq")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6108 = _6079;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO_FREQ"),_6108);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("mioMaxNumRelaxs")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6109 = _6079;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_RELAXS"),_6109);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("mioMaxNumBranches")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6110 = _6079;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_BRANCHES"),_6110);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("mioMaxNumRootCutRounds")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6111 = _6079;
          if (((int)0 <= _6111))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_ROOT_CUT_ROUNDS"),_6111);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("mioMaxNumSolutions")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6112 = _6079;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_SOLUTIONS"),_6112);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("mioNodeSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeSelection)"));
    }
  }
  {}
  if ((_6078 == std::string ("mioHeuristicLevel")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6113 = _6079;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_MIO_HEURISTIC_LEVEL"),_6113);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("mioProbingLevel")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6114 = _6079;
          if ((((-(int)1) <= _6114) && (_6114 <= (int)3)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROBING_LEVEL"),_6114);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("mioCutSelectionLevel")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6115 = _6079;
          if ((((-(int)1) <= _6115) && (_6115 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_SELECTION_LEVEL"),_6115);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("mioVbDetectionLevel")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6116 = _6079;
          if ((((-(int)1) <= _6116) && (_6116 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_MIO_VB_DETECTION_LEVEL"),_6116);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("mioBranchDir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioBranchDir)"));
    }
  }
  else if((_6078 == std::string ("mioRootOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootOptimizer)"));
    }
  }
  else if((_6078 == std::string ("mioNodeOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeOptimizer)"));
    }
  }
  else if((_6078 == std::string ("mioPerspectiveReformulate")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPerspectiveReformulate)"));
    }
  }
  else if((_6078 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPropagateObjectiveConstraint)"));
    }
  }
  {}
  if ((_6078 == std::string ("mioSeed")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6117 = _6079;
          if (((int)0 <= _6117))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_MIO_SEED"),_6117);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("mioConicOuterApproximation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioConicOuterApproximation)"));
    }
  }
  else if((_6078 == std::string ("writeLpQuotedNames")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpQuotedNames)"));
    }
  }
  {}
  if ((_6078 == std::string ("writeLpLineWidth")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6118 = _6079;
          if (((int)40 <= _6118))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_LINE_WIDTH"),_6118);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("writeLpTermsPerLine")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6119 = _6079;
          if (((int)0 <= _6119))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_TERMS_PER_LINE"),_6119);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("writeLpFullObj")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpFullObj)"));
    }
  }
  {}
  if ((_6078 == std::string ("logInfeasAna")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6120 = _6079;
          if (((int)0 <= _6120))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_LOG_INFEAS_ANA"),_6120);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("licenseWait")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseWait)"));
    }
  }
  else if((_6078 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseSuppressExpireWrns)"));
    }
  }
  {}
  if ((_6078 == std::string ("licensePauseTime")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6121 = _6079;
          if ((((int)0 <= _6121) && (_6121 <= (int)1000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_PAUSE_TIME"),_6121);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("licenseDebug")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseDebug)"));
    }
  }
  {}
  if ((_6078 == std::string ("log")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6122 = _6079;
          if (((int)0 <= _6122))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_LOG"),_6122);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("logExpand")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6123 = _6079;
          if (((int)0 <= _6123))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_LOG_EXPAND"),_6123);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("logFile")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6124 = _6079;
          if (((int)0 <= _6124))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_LOG_FILE"),_6124);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("logOrder")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6125 = _6079;
          if (((int)0 <= _6125))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_LOG_ORDER"),_6125);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("simScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScaling)"));
    }
  }
  else if((_6078 == std::string ("simScalingMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScalingMethod)"));
    }
  }
  {}
  if ((_6078 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6126 = _6079;
          if ((((int)0 <= _6126) && (_6126 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_PHASEONE_METHOD"),_6126);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("simDualPhaseoneMethod")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6127 = _6079;
          if ((((int)0 <= _6127) && (_6127 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_PHASEONE_METHOD"),_6127);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("simMaxNumSetbacks")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6128 = _6079;
          if (((int)0 <= _6128))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_NUM_SETBACKS"),_6128);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("simHotstart")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstart)"));
    }
  }
  else if((_6078 == std::string ("simBasisFactorUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simBasisFactorUse)"));
    }
  }
  else if((_6078 == std::string ("simDegen")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDegen)"));
    }
  }
  else if((_6078 == std::string ("simReformulation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simReformulation)"));
    }
  }
  else if((_6078 == std::string ("simExploitDupvec")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simExploitDupvec)"));
    }
  }
  else if((_6078 == std::string ("simSaveLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSaveLu)"));
    }
  }
  else if((_6078 == std::string ("simNonSingular")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simNonSingular)"));
    }
  }
  {}
  if ((_6078 == std::string ("simDualCrash")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6129 = _6079;
          if (((int)0 <= _6129))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_CRASH"),_6129);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("infeasPreferPrimal")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (infeasPreferPrimal)"));
    }
  }
  {}
  if ((_6078 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6130 = _6079;
          if ((((-(int)1) <= _6130) && (_6130 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_REPEAT_PRESOLVE_LEVEL"),_6130);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("mioCutCmir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutCmir)"));
    }
  }
  else if((_6078 == std::string ("mioCutClique")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutClique)"));
    }
  }
  else if((_6078 == std::string ("mioCutImpliedBound")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutImpliedBound)"));
    }
  }
  else if((_6078 == std::string ("mioCutKnapsackCover")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutKnapsackCover)"));
    }
  }
  else if((_6078 == std::string ("mioCutGmi")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutGmi)"));
    }
  }
  {}
  if ((_6078 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6131 = _6079;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_REL_WORK_TRH"),_6131);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6132 = _6079;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_ABS_WORK_TRH"),_6132);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("cacheLicense")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (cacheLicense)"));
    }
  }
  else if((_6078 == std::string ("intpntRegularizationUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntRegularizationUse)"));
    }
  }
  else if((_6078 == std::string ("simSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSolveForm)"));
    }
  }
  else if((_6078 == std::string ("simSwitchOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSwitchOptimizer)"));
    }
  }
  {}
  if ((_6078 == std::string ("mioRinsMaxNodes")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6133 = _6079;
          if (((-(int)1) <= _6133))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_MIO_RINS_MAX_NODES"),_6133);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("mioFeaspumpLevel")))
  {
    {
      if (((_6079 - (int)_6079) == 0.0))
      {
        {
          double _6134 = _6079;
          if ((((-(int)1) <= _6134) && (_6134 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_IPAR_MIO_FEASPUMP_LEVEL"),_6134);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("optimizerMaxTime")))
  {
    {
      double _6135 = _6079;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_OPTIMIZER_MAX_TIME"),_6135);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("lowerObjCut")))
  {
    {
      double _6136 = _6079;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT"),_6136);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("upperObjCut")))
  {
    {
      double _6137 = _6079;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT"),_6137);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      double _6138 = _6079;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT_FINITE_TRH"),_6138);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      double _6139 = _6079;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT_FINITE_TRH"),_6139);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("intpntTolRelGap")))
  {
    {
      double _6140 = _6079;
      if ((1.000000e-14 <= _6140))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_GAP"),_6140);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("intpntTolStepSize")))
  {
    {
      double _6141 = _6079;
      if (((0.000000e+00 <= _6141) && (_6141 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_STEP_SIZE"),_6141);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("simLuTolRelPiv")))
  {
    {
      double _6142 = _6079;
      if (((1.000000e-06 <= _6142) && (_6142 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_SIM_LU_TOL_REL_PIV"),_6142);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("intpntTolRelStep")))
  {
    {
      double _6143 = _6079;
      if (((1.000000e-04 <= _6143) && (_6143 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_STEP"),_6143);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("intpntTolPath")))
  {
    {
      double _6144 = _6079;
      if (((0.000000e+00 <= _6144) && (_6144 <= 9.999000e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PATH"),_6144);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("intpntTolPfeas")))
  {
    {
      double _6145 = _6079;
      if (((0.000000e+00 <= _6145) && (_6145 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PFEAS"),_6145);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("intpntTolDfeas")))
  {
    {
      double _6146 = _6079;
      if (((0.000000e+00 <= _6146) && (_6146 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DFEAS"),_6146);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("intpntTolMuRed")))
  {
    {
      double _6147 = _6079;
      if (((0.000000e+00 <= _6147) && (_6147 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_MU_RED"),_6147);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("intpntTolInfeas")))
  {
    {
      double _6148 = _6079;
      if (((0.000000e+00 <= _6148) && (_6148 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_INFEAS"),_6148);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("intpntCoTolRelGap")))
  {
    {
      double _6149 = _6079;
      if (((0.000000e+00 <= _6149) && (_6149 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_REL_GAP"),_6149);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("intpntCoTolPfeas")))
  {
    {
      double _6150 = _6079;
      if (((0.000000e+00 <= _6150) && (_6150 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_PFEAS"),_6150);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("intpntCoTolDfeas")))
  {
    {
      double _6151 = _6079;
      if (((0.000000e+00 <= _6151) && (_6151 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_DFEAS"),_6151);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("intpntCoTolMuRed")))
  {
    {
      double _6152 = _6079;
      if (((0.000000e+00 <= _6152) && (_6152 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_MU_RED"),_6152);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("intpntCoTolNearRel")))
  {
    {
      double _6153 = _6079;
      if ((1.000000e+00 <= _6153))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_NEAR_REL"),_6153);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("intpntCoTolInfeas")))
  {
    {
      double _6154 = _6079;
      if (((0.000000e+00 <= _6154) && (_6154 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_INFEAS"),_6154);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("intpntTolPsafe")))
  {
    {
      double _6155 = _6079;
      if ((1.000000e-04 <= _6155))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PSAFE"),_6155);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("intpntTolDsafe")))
  {
    {
      double _6156 = _6079;
      if ((1.000000e-04 <= _6156))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DSAFE"),_6156);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("mioMaxTime")))
  {
    {
      double _6157 = _6079;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_MIO_MAX_TIME"),_6157);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("mioRelGapConst")))
  {
    {
      double _6158 = _6079;
      if ((1.000000e-15 <= _6158))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_MIO_REL_GAP_CONST"),_6158);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("mioTolRelGap")))
  {
    {
      double _6159 = _6079;
      if ((0.000000e+00 <= _6159))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_GAP"),_6159);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("mioTolAbsGap")))
  {
    {
      double _6160 = _6079;
      if ((0.000000e+00 <= _6160))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_GAP"),_6160);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      double _6161 = _6079;
      if ((1.000000e-09 <= _6161))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_RELAX_INT"),_6161);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("basisTolX")))
  {
    {
      double _6162 = _6079;
      if ((1.000000e-09 <= _6162))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_X"),_6162);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("basisTolS")))
  {
    {
      double _6163 = _6079;
      if ((1.000000e-09 <= _6163))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_S"),_6163);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("basisRelTolS")))
  {
    {
      double _6164 = _6079;
      if ((0.000000e+00 <= _6164))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_BASIS_REL_TOL_S"),_6164);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("presolveTolX")))
  {
    {
      double _6165 = _6079;
      if ((0.000000e+00 <= _6165))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_X"),_6165);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("presolveTolS")))
  {
    {
      double _6166 = _6079;
      if ((0.000000e+00 <= _6166))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_S"),_6166);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("presolveTolAij")))
  {
    {
      double _6167 = _6079;
      if ((1.000000e-15 <= _6167))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_AIJ"),_6167);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("presolveTolAbsLindep")))
  {
    {
      double _6168 = _6079;
      if ((0.000000e+00 <= _6168))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_ABS_LINDEP"),_6168);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("presolveTolRelLindep")))
  {
    {
      double _6169 = _6079;
      if ((0.000000e+00 <= _6169))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_REL_LINDEP"),_6169);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("simplexAbsTolPiv")))
  {
    {
      double _6170 = _6079;
      if ((1.000000e-12 <= _6170))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_SIMPLEX_ABS_TOL_PIV"),_6170);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("mioTolFeas")))
  {
    {
      double _6171 = _6079;
      if (((1.000000e-09 <= _6171) && (_6171 <= 1.000000e-03)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_FEAS"),_6171);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
        }
      }
    }
  }
  {}
  if ((_6078 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      double _6172 = _6079;
      if (((0.000000e+00 <= _6172) && (_6172 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6077.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_DUAL_BOUND_IMPROVEMENT"),_6172);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
        }
      }
    }
  }
  else if((_6078 == std::string ("dataFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (dataFileName)"));
    }
  }
  else if((_6078 == std::string ("basSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basSolFileName)"));
    }
  }
  else if((_6078 == std::string ("itrSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (itrSolFileName)"));
    }
  }
  else if((_6078 == std::string ("intSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intSolFileName)"));
    }
  }
  else if((_6078 == std::string ("writeLpGenVarName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpGenVarName)"));
    }
  }
  else if((_6078 == std::string ("remoteAccessToken")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (remoteAccessToken)"));
    }
  }
  {}
  throw ::mosek::fusion::ParameterError(std::string ("Unknown parameter"));
}
void mosek::fusion::Parameters::setParameter  ( monty::rc_ptr< ::mosek::fusion::Model > _6173,    const std::string & _6174,    int _6175) { mosek::fusion::p_Parameters::setParameter(_6173,_6174,_6175); }void mosek::fusion::p_Parameters::setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6173,const std::string & _6174,int _6175){
  if (false)
  {
    {
    }
  }
  else if((_6174 == std::string ("autoUpdateSolInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (autoUpdateSolInfo)"));
    }
  }
  else if((_6174 == std::string ("removeUnusedSolutions")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (removeUnusedSolutions)"));
    }
  }
  {}
  if ((_6174 == std::string ("numThreads")))
  {
    {
      int _6176 = _6175;
      if (((int)0 <= _6176))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_NUM_THREADS"),_6176);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("intpntMultiThread")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMultiThread)"));
    }
  }
  {}
  if ((_6174 == std::string ("mtSpincount")))
  {
    {
      int _6177 = _6175;
      if ((((int)0 <= _6177) && (_6177 <= (int)1000000000)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_MT_SPINCOUNT"),_6177);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("optimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizer)"));
    }
  }
  {}
  if ((_6174 == std::string ("biMaxIterations")))
  {
    {
      int _6178 = _6175;
      if (((int)0 <= _6178))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_BI_MAX_ITERATIONS"),_6178);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      int _6179 = _6175;
      if (((int)0 <= _6179))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_TRH_EXPIRY_WRN"),_6179);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("logCutSecondOpt")))
  {
    {
      int _6180 = _6175;
      if (((int)0 <= _6180))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_LOG_CUT_SECOND_OPT"),_6180);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("logResponse")))
  {
    {
      int _6181 = _6175;
      if (((int)0 <= _6181))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_LOG_RESPONSE"),_6181);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("logLocalInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logLocalInfo)"));
    }
  }
  {}
  if ((_6174 == std::string ("logBi")))
  {
    {
      int _6182 = _6175;
      if (((int)0 <= _6182))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI"),_6182);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("logBiFreq")))
  {
    {
      int _6183 = _6175;
      if (((int)0 <= _6183))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI_FREQ"),_6183);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("biCleanOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biCleanOptimizer)"));
    }
  }
  else if((_6174 == std::string ("intpntStartingPoint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntStartingPoint)"));
    }
  }
  else if((_6174 == std::string ("intpntDiffStep")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntDiffStep)"));
    }
  }
  else if((_6174 == std::string ("intpntScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntScaling)"));
    }
  }
  else if((_6174 == std::string ("intpntSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntSolveForm)"));
    }
  }
  {}
  if ((_6174 == std::string ("logIntpnt")))
  {
    {
      int _6184 = _6175;
      if (((int)0 <= _6184))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_LOG_INTPNT"),_6184);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("intpntMaxIterations")))
  {
    {
      int _6185 = _6175;
      if (((int)0 <= _6185))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_ITERATIONS"),_6185);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("intpntOffColTrh")))
  {
    {
      int _6186 = _6175;
      if (((int)0 <= _6186))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_OFF_COL_TRH"),_6186);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("intpntOrderMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderMethod)"));
    }
  }
  {}
  if ((_6174 == std::string ("intpntOrderGpNumSeeds")))
  {
    {
      int _6187 = _6175;
      if (((int)0 <= _6187))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_ORDER_GP_NUM_SEEDS"),_6187);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderGpNumSeeds)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("intpntBasis")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntBasis)"));
    }
  }
  else if((_6174 == std::string ("biIgnoreMaxIter")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreMaxIter)"));
    }
  }
  else if((_6174 == std::string ("biIgnoreNumError")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreNumError)"));
    }
  }
  {}
  if ((_6174 == std::string ("intpntMaxNumCor")))
  {
    {
      int _6188 = _6175;
      if (((-(int)1) <= _6188))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_NUM_COR"),_6188);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("presolveUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveUse)"));
    }
  }
  {}
  if ((_6174 == std::string ("presolveLevel")))
  {
    {
      int _6189 = _6175;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LEVEL"),_6189);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("logPresolve")))
  {
    {
      int _6190 = _6175;
      if (((int)0 <= _6190))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_LOG_PRESOLVE"),_6190);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("presolveLindepUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepUse)"));
    }
  }
  {}
  if ((_6174 == std::string ("presolveMaxNumPass")))
  {
    {
      int _6191 = _6175;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_MAX_NUM_PASS"),_6191);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      int _6192 = _6175;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_NUM_TRIES"),_6192);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      int _6193 = _6175;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_FILL"),_6193);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("simPrimalCrash")))
  {
    {
      int _6194 = _6175;
      if (((int)0 <= _6194))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_CRASH"),_6194);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("logSim")))
  {
    {
      int _6195 = _6175;
      if (((int)0 <= _6195))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM"),_6195);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("logSimMinor")))
  {
    {
      int _6196 = _6175;
      if (((int)0 <= _6196))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_MINOR"),_6196);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("logSimFreq")))
  {
    {
      int _6197 = _6175;
      if (((int)0 <= _6197))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_FREQ"),_6197);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("simPrimalRestrictSelection")))
  {
    {
      int _6198 = _6175;
      if ((((int)0 <= _6198) && (_6198 <= (int)100)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_RESTRICT_SELECTION"),_6198);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("simPrimalSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalSelection)"));
    }
  }
  {}
  if ((_6174 == std::string ("simDualRestrictSelection")))
  {
    {
      int _6199 = _6175;
      if ((((int)0 <= _6199) && (_6199 <= (int)100)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_RESTRICT_SELECTION"),_6199);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("simDualSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualSelection)"));
    }
  }
  {}
  if ((_6174 == std::string ("simMaxIterations")))
  {
    {
      int _6200 = _6175;
      if (((int)0 <= _6200))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_ITERATIONS"),_6200);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("simHotstartLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstartLu)"));
    }
  }
  {}
  if ((_6174 == std::string ("simRefactorFreq")))
  {
    {
      int _6201 = _6175;
      if (((int)0 <= _6201))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFACTOR_FREQ"),_6201);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("simSeed")))
  {
    {
      int _6202 = _6175;
      if ((((int)0 <= _6202) && (_6202 <= (int)32749)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_SIM_SEED"),_6202);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("mioMode")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMode)"));
    }
  }
  {}
  if ((_6174 == std::string ("logMio")))
  {
    {
      int _6203 = _6175;
      if (((int)0 <= _6203))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO"),_6203);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("logMioFreq")))
  {
    {
      int _6204 = _6175;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO_FREQ"),_6204);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("mioMaxNumRelaxs")))
  {
    {
      int _6205 = _6175;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_RELAXS"),_6205);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("mioMaxNumBranches")))
  {
    {
      int _6206 = _6175;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_BRANCHES"),_6206);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("mioMaxNumRootCutRounds")))
  {
    {
      int _6207 = _6175;
      if (((int)0 <= _6207))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_ROOT_CUT_ROUNDS"),_6207);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("mioMaxNumSolutions")))
  {
    {
      int _6208 = _6175;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_SOLUTIONS"),_6208);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("mioNodeSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeSelection)"));
    }
  }
  {}
  if ((_6174 == std::string ("mioHeuristicLevel")))
  {
    {
      int _6209 = _6175;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_MIO_HEURISTIC_LEVEL"),_6209);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("mioProbingLevel")))
  {
    {
      int _6210 = _6175;
      if ((((-(int)1) <= _6210) && (_6210 <= (int)3)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROBING_LEVEL"),_6210);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("mioCutSelectionLevel")))
  {
    {
      int _6211 = _6175;
      if ((((-(int)1) <= _6211) && (_6211 <= (int)1)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_SELECTION_LEVEL"),_6211);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("mioVbDetectionLevel")))
  {
    {
      int _6212 = _6175;
      if ((((-(int)1) <= _6212) && (_6212 <= (int)2)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_MIO_VB_DETECTION_LEVEL"),_6212);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("mioBranchDir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioBranchDir)"));
    }
  }
  else if((_6174 == std::string ("mioRootOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootOptimizer)"));
    }
  }
  else if((_6174 == std::string ("mioNodeOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeOptimizer)"));
    }
  }
  else if((_6174 == std::string ("mioPerspectiveReformulate")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPerspectiveReformulate)"));
    }
  }
  else if((_6174 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPropagateObjectiveConstraint)"));
    }
  }
  {}
  if ((_6174 == std::string ("mioSeed")))
  {
    {
      int _6213 = _6175;
      if (((int)0 <= _6213))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_MIO_SEED"),_6213);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("mioConicOuterApproximation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioConicOuterApproximation)"));
    }
  }
  else if((_6174 == std::string ("writeLpQuotedNames")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpQuotedNames)"));
    }
  }
  {}
  if ((_6174 == std::string ("writeLpLineWidth")))
  {
    {
      int _6214 = _6175;
      if (((int)40 <= _6214))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_LINE_WIDTH"),_6214);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("writeLpTermsPerLine")))
  {
    {
      int _6215 = _6175;
      if (((int)0 <= _6215))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_TERMS_PER_LINE"),_6215);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("writeLpFullObj")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpFullObj)"));
    }
  }
  {}
  if ((_6174 == std::string ("logInfeasAna")))
  {
    {
      int _6216 = _6175;
      if (((int)0 <= _6216))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_LOG_INFEAS_ANA"),_6216);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("licenseWait")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseWait)"));
    }
  }
  else if((_6174 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseSuppressExpireWrns)"));
    }
  }
  {}
  if ((_6174 == std::string ("licensePauseTime")))
  {
    {
      int _6217 = _6175;
      if ((((int)0 <= _6217) && (_6217 <= (int)1000000)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_PAUSE_TIME"),_6217);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("licenseDebug")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseDebug)"));
    }
  }
  {}
  if ((_6174 == std::string ("log")))
  {
    {
      int _6218 = _6175;
      if (((int)0 <= _6218))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_LOG"),_6218);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("logExpand")))
  {
    {
      int _6219 = _6175;
      if (((int)0 <= _6219))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_LOG_EXPAND"),_6219);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("logFile")))
  {
    {
      int _6220 = _6175;
      if (((int)0 <= _6220))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_LOG_FILE"),_6220);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("logOrder")))
  {
    {
      int _6221 = _6175;
      if (((int)0 <= _6221))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_LOG_ORDER"),_6221);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("simScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScaling)"));
    }
  }
  else if((_6174 == std::string ("simScalingMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScalingMethod)"));
    }
  }
  {}
  if ((_6174 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      int _6222 = _6175;
      if ((((int)0 <= _6222) && (_6222 <= (int)10)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_PHASEONE_METHOD"),_6222);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("simDualPhaseoneMethod")))
  {
    {
      int _6223 = _6175;
      if ((((int)0 <= _6223) && (_6223 <= (int)10)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_PHASEONE_METHOD"),_6223);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("simMaxNumSetbacks")))
  {
    {
      int _6224 = _6175;
      if (((int)0 <= _6224))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_NUM_SETBACKS"),_6224);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("simHotstart")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstart)"));
    }
  }
  else if((_6174 == std::string ("simBasisFactorUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simBasisFactorUse)"));
    }
  }
  else if((_6174 == std::string ("simDegen")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDegen)"));
    }
  }
  else if((_6174 == std::string ("simReformulation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simReformulation)"));
    }
  }
  else if((_6174 == std::string ("simExploitDupvec")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simExploitDupvec)"));
    }
  }
  else if((_6174 == std::string ("simSaveLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSaveLu)"));
    }
  }
  else if((_6174 == std::string ("simNonSingular")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simNonSingular)"));
    }
  }
  {}
  if ((_6174 == std::string ("simDualCrash")))
  {
    {
      int _6225 = _6175;
      if (((int)0 <= _6225))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_CRASH"),_6225);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("infeasPreferPrimal")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (infeasPreferPrimal)"));
    }
  }
  {}
  if ((_6174 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      int _6226 = _6175;
      if ((((-(int)1) <= _6226) && (_6226 <= (int)1)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_REPEAT_PRESOLVE_LEVEL"),_6226);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("mioCutCmir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutCmir)"));
    }
  }
  else if((_6174 == std::string ("mioCutClique")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutClique)"));
    }
  }
  else if((_6174 == std::string ("mioCutImpliedBound")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutImpliedBound)"));
    }
  }
  else if((_6174 == std::string ("mioCutKnapsackCover")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutKnapsackCover)"));
    }
  }
  else if((_6174 == std::string ("mioCutGmi")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutGmi)"));
    }
  }
  {}
  if ((_6174 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      int _6227 = _6175;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_REL_WORK_TRH"),_6227);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      int _6228 = _6175;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_ABS_WORK_TRH"),_6228);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("cacheLicense")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (cacheLicense)"));
    }
  }
  else if((_6174 == std::string ("intpntRegularizationUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntRegularizationUse)"));
    }
  }
  else if((_6174 == std::string ("simSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSolveForm)"));
    }
  }
  else if((_6174 == std::string ("simSwitchOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSwitchOptimizer)"));
    }
  }
  {}
  if ((_6174 == std::string ("mioRinsMaxNodes")))
  {
    {
      int _6229 = _6175;
      if (((-(int)1) <= _6229))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_MIO_RINS_MAX_NODES"),_6229);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("mioFeaspumpLevel")))
  {
    {
      int _6230 = _6175;
      if ((((-(int)1) <= _6230) && (_6230 <= (int)2)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_IPAR_MIO_FEASPUMP_LEVEL"),_6230);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("optimizerMaxTime")))
  {
    {
      double _6231 = (double)_6175;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_OPTIMIZER_MAX_TIME"),_6231);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("lowerObjCut")))
  {
    {
      double _6232 = (double)_6175;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT"),_6232);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("upperObjCut")))
  {
    {
      double _6233 = (double)_6175;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT"),_6233);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      double _6234 = (double)_6175;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT_FINITE_TRH"),_6234);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      double _6235 = (double)_6175;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT_FINITE_TRH"),_6235);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("intpntTolRelGap")))
  {
    {
      double _6236 = (double)_6175;
      if ((1.000000e-14 <= _6236))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_GAP"),_6236);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("intpntTolStepSize")))
  {
    {
      double _6237 = (double)_6175;
      if (((0.000000e+00 <= _6237) && (_6237 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_STEP_SIZE"),_6237);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("simLuTolRelPiv")))
  {
    {
      double _6238 = (double)_6175;
      if (((1.000000e-06 <= _6238) && (_6238 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_SIM_LU_TOL_REL_PIV"),_6238);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("intpntTolRelStep")))
  {
    {
      double _6239 = (double)_6175;
      if (((1.000000e-04 <= _6239) && (_6239 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_STEP"),_6239);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("intpntTolPath")))
  {
    {
      double _6240 = (double)_6175;
      if (((0.000000e+00 <= _6240) && (_6240 <= 9.999000e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PATH"),_6240);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("intpntTolPfeas")))
  {
    {
      double _6241 = (double)_6175;
      if (((0.000000e+00 <= _6241) && (_6241 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PFEAS"),_6241);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("intpntTolDfeas")))
  {
    {
      double _6242 = (double)_6175;
      if (((0.000000e+00 <= _6242) && (_6242 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DFEAS"),_6242);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("intpntTolMuRed")))
  {
    {
      double _6243 = (double)_6175;
      if (((0.000000e+00 <= _6243) && (_6243 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_MU_RED"),_6243);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("intpntTolInfeas")))
  {
    {
      double _6244 = (double)_6175;
      if (((0.000000e+00 <= _6244) && (_6244 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_INFEAS"),_6244);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("intpntCoTolRelGap")))
  {
    {
      double _6245 = (double)_6175;
      if (((0.000000e+00 <= _6245) && (_6245 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_REL_GAP"),_6245);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("intpntCoTolPfeas")))
  {
    {
      double _6246 = (double)_6175;
      if (((0.000000e+00 <= _6246) && (_6246 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_PFEAS"),_6246);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("intpntCoTolDfeas")))
  {
    {
      double _6247 = (double)_6175;
      if (((0.000000e+00 <= _6247) && (_6247 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_DFEAS"),_6247);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("intpntCoTolMuRed")))
  {
    {
      double _6248 = (double)_6175;
      if (((0.000000e+00 <= _6248) && (_6248 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_MU_RED"),_6248);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("intpntCoTolNearRel")))
  {
    {
      double _6249 = (double)_6175;
      if ((1.000000e+00 <= _6249))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_NEAR_REL"),_6249);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("intpntCoTolInfeas")))
  {
    {
      double _6250 = (double)_6175;
      if (((0.000000e+00 <= _6250) && (_6250 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_INFEAS"),_6250);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("intpntTolPsafe")))
  {
    {
      double _6251 = (double)_6175;
      if ((1.000000e-04 <= _6251))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PSAFE"),_6251);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("intpntTolDsafe")))
  {
    {
      double _6252 = (double)_6175;
      if ((1.000000e-04 <= _6252))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DSAFE"),_6252);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("mioMaxTime")))
  {
    {
      double _6253 = (double)_6175;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_MIO_MAX_TIME"),_6253);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("mioRelGapConst")))
  {
    {
      double _6254 = (double)_6175;
      if ((1.000000e-15 <= _6254))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_MIO_REL_GAP_CONST"),_6254);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("mioTolRelGap")))
  {
    {
      double _6255 = (double)_6175;
      if ((0.000000e+00 <= _6255))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_GAP"),_6255);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("mioTolAbsGap")))
  {
    {
      double _6256 = (double)_6175;
      if ((0.000000e+00 <= _6256))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_GAP"),_6256);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      double _6257 = (double)_6175;
      if ((1.000000e-09 <= _6257))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_RELAX_INT"),_6257);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("basisTolX")))
  {
    {
      double _6258 = (double)_6175;
      if ((1.000000e-09 <= _6258))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_X"),_6258);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("basisTolS")))
  {
    {
      double _6259 = (double)_6175;
      if ((1.000000e-09 <= _6259))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_S"),_6259);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("basisRelTolS")))
  {
    {
      double _6260 = (double)_6175;
      if ((0.000000e+00 <= _6260))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_BASIS_REL_TOL_S"),_6260);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("presolveTolX")))
  {
    {
      double _6261 = (double)_6175;
      if ((0.000000e+00 <= _6261))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_X"),_6261);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("presolveTolS")))
  {
    {
      double _6262 = (double)_6175;
      if ((0.000000e+00 <= _6262))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_S"),_6262);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("presolveTolAij")))
  {
    {
      double _6263 = (double)_6175;
      if ((1.000000e-15 <= _6263))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_AIJ"),_6263);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("presolveTolAbsLindep")))
  {
    {
      double _6264 = (double)_6175;
      if ((0.000000e+00 <= _6264))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_ABS_LINDEP"),_6264);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("presolveTolRelLindep")))
  {
    {
      double _6265 = (double)_6175;
      if ((0.000000e+00 <= _6265))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_REL_LINDEP"),_6265);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("simplexAbsTolPiv")))
  {
    {
      double _6266 = (double)_6175;
      if ((1.000000e-12 <= _6266))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_SIMPLEX_ABS_TOL_PIV"),_6266);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("mioTolFeas")))
  {
    {
      double _6267 = (double)_6175;
      if (((1.000000e-09 <= _6267) && (_6267 <= 1.000000e-03)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_FEAS"),_6267);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
        }
      }
    }
  }
  {}
  if ((_6174 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      double _6268 = (double)_6175;
      if (((0.000000e+00 <= _6268) && (_6268 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6173.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_DUAL_BOUND_IMPROVEMENT"),_6268);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
        }
      }
    }
  }
  else if((_6174 == std::string ("dataFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (dataFileName)"));
    }
  }
  else if((_6174 == std::string ("basSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basSolFileName)"));
    }
  }
  else if((_6174 == std::string ("itrSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (itrSolFileName)"));
    }
  }
  else if((_6174 == std::string ("intSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intSolFileName)"));
    }
  }
  else if((_6174 == std::string ("writeLpGenVarName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpGenVarName)"));
    }
  }
  else if((_6174 == std::string ("remoteAccessToken")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (remoteAccessToken)"));
    }
  }
  {}
  throw ::mosek::fusion::ParameterError(std::string ("Unknown parameter"));
}
void mosek::fusion::Parameters::setParameter  ( monty::rc_ptr< ::mosek::fusion::Model > _6269,    const std::string & _6270,    const std::string & _6271) { mosek::fusion::p_Parameters::setParameter(_6269,_6270,_6271); }void mosek::fusion::p_Parameters::setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6269,const std::string & _6270,const std::string & _6271){
  if (false)
  {
    {
    }
  }
  {}
  if ((_6270 == std::string ("autoUpdateSolInfo")))
  {
    {
      int _6272 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6272 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (autoUpdateSolInfo)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_AUTO_UPDATE_SOL_INFO"),_6272);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("removeUnusedSolutions")))
  {
    {
      int _6273 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6273 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (removeUnusedSolutions)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_REMOVE_UNUSED_SOLUTIONS"),_6273);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("numThreads")))
  {
    {
      try
      {
        {
          int _6275 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6275))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_NUM_THREADS"),_6275);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6274)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("intpntMultiThread")))
  {
    {
      int _6276 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6276 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMultiThread)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MULTI_THREAD"),_6276);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("mtSpincount")))
  {
    {
      try
      {
        {
          int _6278 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if ((((int)0 <= _6278) && (_6278 <= (int)1000000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MT_SPINCOUNT"),_6278);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6277)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("optimizer")))
  {
    {
      int _6279 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6271);
      if ((_6279 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_OPTIMIZER"),_6279);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("biMaxIterations")))
  {
    {
      try
      {
        {
          int _6281 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6281))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_BI_MAX_ITERATIONS"),_6281);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6280)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      try
      {
        {
          int _6283 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6283))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_TRH_EXPIRY_WRN"),_6283);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6282)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("logCutSecondOpt")))
  {
    {
      try
      {
        {
          int _6285 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6285))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LOG_CUT_SECOND_OPT"),_6285);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6284)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("logResponse")))
  {
    {
      try
      {
        {
          int _6287 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6287))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LOG_RESPONSE"),_6287);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6286)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("logLocalInfo")))
  {
    {
      int _6288 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6288 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logLocalInfo)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LOG_LOCAL_INFO"),_6288);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("logBi")))
  {
    {
      try
      {
        {
          int _6290 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6290))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI"),_6290);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6289)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("logBiFreq")))
  {
    {
      try
      {
        {
          int _6292 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6292))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI_FREQ"),_6292);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6291)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("biCleanOptimizer")))
  {
    {
      int _6293 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6271);
      if ((_6293 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biCleanOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_BI_CLEAN_OPTIMIZER"),_6293);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("intpntStartingPoint")))
  {
    {
      int _6294 = ::mosek::fusion::p_Parameters::string_to_startpointtype_value(_6271);
      if ((_6294 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntStartingPoint)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_STARTING_POINT"),_6294);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("intpntDiffStep")))
  {
    {
      int _6295 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6295 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntDiffStep)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_DIFF_STEP"),_6295);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("intpntScaling")))
  {
    {
      int _6296 = ::mosek::fusion::p_Parameters::string_to_scalingtype_value(_6271);
      if ((_6296 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntScaling)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_SCALING"),_6296);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("intpntSolveForm")))
  {
    {
      int _6297 = ::mosek::fusion::p_Parameters::string_to_solveform_value(_6271);
      if ((_6297 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntSolveForm)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_SOLVE_FORM"),_6297);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("logIntpnt")))
  {
    {
      try
      {
        {
          int _6299 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6299))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LOG_INTPNT"),_6299);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6298)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("intpntMaxIterations")))
  {
    {
      try
      {
        {
          int _6301 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6301))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_ITERATIONS"),_6301);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6300)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("intpntOffColTrh")))
  {
    {
      try
      {
        {
          int _6303 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6303))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_OFF_COL_TRH"),_6303);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6302)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("intpntOrderMethod")))
  {
    {
      int _6304 = ::mosek::fusion::p_Parameters::string_to_orderingtype_value(_6271);
      if ((_6304 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderMethod)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_ORDER_METHOD"),_6304);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("intpntOrderGpNumSeeds")))
  {
    {
      try
      {
        {
          int _6306 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6306))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_ORDER_GP_NUM_SEEDS"),_6306);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderGpNumSeeds)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6305)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderGpNumSeeds)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("intpntBasis")))
  {
    {
      int _6307 = ::mosek::fusion::p_Parameters::string_to_basindtype_value(_6271);
      if ((_6307 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntBasis)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_BASIS"),_6307);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("biIgnoreMaxIter")))
  {
    {
      int _6308 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6308 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreMaxIter)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_BI_IGNORE_MAX_ITER"),_6308);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("biIgnoreNumError")))
  {
    {
      int _6309 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6309 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreNumError)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_BI_IGNORE_NUM_ERROR"),_6309);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("intpntMaxNumCor")))
  {
    {
      try
      {
        {
          int _6311 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((-(int)1) <= _6311))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_NUM_COR"),_6311);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6310)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("presolveUse")))
  {
    {
      int _6312 = ::mosek::fusion::p_Parameters::string_to_presolvemode_value(_6271);
      if ((_6312 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_USE"),_6312);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("presolveLevel")))
  {
    {
      try
      {
        {
          int _6314 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LEVEL"),_6314);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6313)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("logPresolve")))
  {
    {
      try
      {
        {
          int _6316 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6316))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LOG_PRESOLVE"),_6316);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6315)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("presolveLindepUse")))
  {
    {
      int _6317 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6317 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_USE"),_6317);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("presolveMaxNumPass")))
  {
    {
      try
      {
        {
          int _6319 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_MAX_NUM_PASS"),_6319);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6318)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      try
      {
        {
          int _6321 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_NUM_TRIES"),_6321);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6320)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      try
      {
        {
          int _6323 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_FILL"),_6323);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6322)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("simPrimalCrash")))
  {
    {
      try
      {
        {
          int _6325 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6325))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_CRASH"),_6325);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6324)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("logSim")))
  {
    {
      try
      {
        {
          int _6327 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6327))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM"),_6327);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6326)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("logSimMinor")))
  {
    {
      try
      {
        {
          int _6329 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6329))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_MINOR"),_6329);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6328)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("logSimFreq")))
  {
    {
      try
      {
        {
          int _6331 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6331))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_FREQ"),_6331);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6330)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("simPrimalRestrictSelection")))
  {
    {
      try
      {
        {
          int _6333 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if ((((int)0 <= _6333) && (_6333 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_RESTRICT_SELECTION"),_6333);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6332)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("simPrimalSelection")))
  {
    {
      int _6334 = ::mosek::fusion::p_Parameters::string_to_simseltype_value(_6271);
      if ((_6334 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalSelection)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_SELECTION"),_6334);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("simDualRestrictSelection")))
  {
    {
      try
      {
        {
          int _6336 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if ((((int)0 <= _6336) && (_6336 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_RESTRICT_SELECTION"),_6336);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6335)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("simDualSelection")))
  {
    {
      int _6337 = ::mosek::fusion::p_Parameters::string_to_simseltype_value(_6271);
      if ((_6337 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualSelection)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_SELECTION"),_6337);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("simMaxIterations")))
  {
    {
      try
      {
        {
          int _6339 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6339))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_ITERATIONS"),_6339);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6338)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("simHotstartLu")))
  {
    {
      int _6340 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6340 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstartLu)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_HOTSTART_LU"),_6340);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("simRefactorFreq")))
  {
    {
      try
      {
        {
          int _6342 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6342))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFACTOR_FREQ"),_6342);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6341)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("simSeed")))
  {
    {
      try
      {
        {
          int _6344 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if ((((int)0 <= _6344) && (_6344 <= (int)32749)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_SEED"),_6344);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6343)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("mioMode")))
  {
    {
      int _6345 = ::mosek::fusion::p_Parameters::string_to_miomode_value(_6271);
      if ((_6345 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMode)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_MODE"),_6345);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("logMio")))
  {
    {
      try
      {
        {
          int _6347 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6347))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO"),_6347);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6346)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("logMioFreq")))
  {
    {
      try
      {
        {
          int _6349 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO_FREQ"),_6349);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6348)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("mioMaxNumRelaxs")))
  {
    {
      try
      {
        {
          int _6351 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_RELAXS"),_6351);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6350)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("mioMaxNumBranches")))
  {
    {
      try
      {
        {
          int _6353 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_BRANCHES"),_6353);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6352)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("mioMaxNumRootCutRounds")))
  {
    {
      try
      {
        {
          int _6355 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6355))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_ROOT_CUT_ROUNDS"),_6355);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6354)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("mioMaxNumSolutions")))
  {
    {
      try
      {
        {
          int _6357 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_SOLUTIONS"),_6357);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6356)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("mioNodeSelection")))
  {
    {
      int _6358 = ::mosek::fusion::p_Parameters::string_to_mionodeseltype_value(_6271);
      if ((_6358 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeSelection)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_NODE_SELECTION"),_6358);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("mioHeuristicLevel")))
  {
    {
      try
      {
        {
          int _6360 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_HEURISTIC_LEVEL"),_6360);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6359)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("mioProbingLevel")))
  {
    {
      try
      {
        {
          int _6362 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if ((((-(int)1) <= _6362) && (_6362 <= (int)3)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROBING_LEVEL"),_6362);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6361)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("mioCutSelectionLevel")))
  {
    {
      try
      {
        {
          int _6364 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if ((((-(int)1) <= _6364) && (_6364 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_SELECTION_LEVEL"),_6364);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6363)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("mioVbDetectionLevel")))
  {
    {
      try
      {
        {
          int _6366 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if ((((-(int)1) <= _6366) && (_6366 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_VB_DETECTION_LEVEL"),_6366);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6365)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("mioBranchDir")))
  {
    {
      int _6367 = ::mosek::fusion::p_Parameters::string_to_branchdir_value(_6271);
      if ((_6367 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioBranchDir)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_BRANCH_DIR"),_6367);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("mioRootOptimizer")))
  {
    {
      int _6368 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6271);
      if ((_6368 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_OPTIMIZER"),_6368);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("mioNodeOptimizer")))
  {
    {
      int _6369 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6271);
      if ((_6369 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_NODE_OPTIMIZER"),_6369);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("mioPerspectiveReformulate")))
  {
    {
      int _6370 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6370 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPerspectiveReformulate)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_PERSPECTIVE_REFORMULATE"),_6370);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      int _6371 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6371 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPropagateObjectiveConstraint)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROPAGATE_OBJECTIVE_CONSTRAINT"),_6371);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("mioSeed")))
  {
    {
      try
      {
        {
          int _6373 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6373))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_SEED"),_6373);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6372)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("mioConicOuterApproximation")))
  {
    {
      int _6374 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6374 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioConicOuterApproximation)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_CONIC_OUTER_APPROXIMATION"),_6374);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("writeLpQuotedNames")))
  {
    {
      int _6375 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6375 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpQuotedNames)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_QUOTED_NAMES"),_6375);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("writeLpLineWidth")))
  {
    {
      try
      {
        {
          int _6377 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)40 <= _6377))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_LINE_WIDTH"),_6377);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6376)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("writeLpTermsPerLine")))
  {
    {
      try
      {
        {
          int _6379 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6379))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_TERMS_PER_LINE"),_6379);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6378)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("writeLpFullObj")))
  {
    {
      int _6380 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6380 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpFullObj)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_FULL_OBJ"),_6380);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("logInfeasAna")))
  {
    {
      try
      {
        {
          int _6382 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6382))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LOG_INFEAS_ANA"),_6382);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6381)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("licenseWait")))
  {
    {
      int _6383 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6383 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseWait)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_WAIT"),_6383);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      int _6384 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6384 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseSuppressExpireWrns)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_SUPPRESS_EXPIRE_WRNS"),_6384);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("licensePauseTime")))
  {
    {
      try
      {
        {
          int _6386 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if ((((int)0 <= _6386) && (_6386 <= (int)1000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_PAUSE_TIME"),_6386);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6385)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("licenseDebug")))
  {
    {
      int _6387 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6387 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseDebug)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_DEBUG"),_6387);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("log")))
  {
    {
      try
      {
        {
          int _6389 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6389))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LOG"),_6389);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6388)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("logExpand")))
  {
    {
      try
      {
        {
          int _6391 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6391))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LOG_EXPAND"),_6391);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6390)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("logFile")))
  {
    {
      try
      {
        {
          int _6393 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6393))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LOG_FILE"),_6393);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6392)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("logOrder")))
  {
    {
      try
      {
        {
          int _6395 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6395))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_LOG_ORDER"),_6395);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6394)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("simScaling")))
  {
    {
      int _6396 = ::mosek::fusion::p_Parameters::string_to_scalingtype_value(_6271);
      if ((_6396 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScaling)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_SCALING"),_6396);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("simScalingMethod")))
  {
    {
      int _6397 = ::mosek::fusion::p_Parameters::string_to_scalingmethod_value(_6271);
      if ((_6397 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScalingMethod)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_SCALING_METHOD"),_6397);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      try
      {
        {
          int _6399 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if ((((int)0 <= _6399) && (_6399 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_PHASEONE_METHOD"),_6399);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6398)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("simDualPhaseoneMethod")))
  {
    {
      try
      {
        {
          int _6401 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if ((((int)0 <= _6401) && (_6401 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_PHASEONE_METHOD"),_6401);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6400)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("simMaxNumSetbacks")))
  {
    {
      try
      {
        {
          int _6403 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6403))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_NUM_SETBACKS"),_6403);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6402)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("simHotstart")))
  {
    {
      int _6404 = ::mosek::fusion::p_Parameters::string_to_simhotstart_value(_6271);
      if ((_6404 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstart)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_HOTSTART"),_6404);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("simBasisFactorUse")))
  {
    {
      int _6405 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6405 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simBasisFactorUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_BASIS_FACTOR_USE"),_6405);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("simDegen")))
  {
    {
      int _6406 = ::mosek::fusion::p_Parameters::string_to_simdegen_value(_6271);
      if ((_6406 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDegen)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_DEGEN"),_6406);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("simReformulation")))
  {
    {
      int _6407 = ::mosek::fusion::p_Parameters::string_to_simreform_value(_6271);
      if ((_6407 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simReformulation)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFORMULATION"),_6407);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("simExploitDupvec")))
  {
    {
      int _6408 = ::mosek::fusion::p_Parameters::string_to_simdupvec_value(_6271);
      if ((_6408 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simExploitDupvec)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_EXPLOIT_DUPVEC"),_6408);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("simSaveLu")))
  {
    {
      int _6409 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6409 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSaveLu)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_SAVE_LU"),_6409);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("simNonSingular")))
  {
    {
      int _6410 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6410 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simNonSingular)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_NON_SINGULAR"),_6410);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("simDualCrash")))
  {
    {
      try
      {
        {
          int _6412 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((int)0 <= _6412))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_CRASH"),_6412);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6411)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("infeasPreferPrimal")))
  {
    {
      int _6413 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6413 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (infeasPreferPrimal)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_INFEAS_PREFER_PRIMAL"),_6413);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      try
      {
        {
          int _6415 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if ((((-(int)1) <= _6415) && (_6415 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_REPEAT_PRESOLVE_LEVEL"),_6415);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6414)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("mioCutCmir")))
  {
    {
      int _6416 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6416 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutCmir)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_CMIR"),_6416);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("mioCutClique")))
  {
    {
      int _6417 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6417 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutClique)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_CLIQUE"),_6417);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("mioCutImpliedBound")))
  {
    {
      int _6418 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6418 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutImpliedBound)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_IMPLIED_BOUND"),_6418);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("mioCutKnapsackCover")))
  {
    {
      int _6419 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6419 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutKnapsackCover)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_KNAPSACK_COVER"),_6419);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("mioCutGmi")))
  {
    {
      int _6420 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6420 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutGmi)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_GMI"),_6420);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      try
      {
        {
          int _6422 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_REL_WORK_TRH"),_6422);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6421)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      try
      {
        {
          int _6424 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_ABS_WORK_TRH"),_6424);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6423)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("cacheLicense")))
  {
    {
      int _6425 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6425 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (cacheLicense)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_CACHE_LICENSE"),_6425);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("intpntRegularizationUse")))
  {
    {
      int _6426 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6426 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntRegularizationUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_REGULARIZATION_USE"),_6426);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("simSolveForm")))
  {
    {
      int _6427 = ::mosek::fusion::p_Parameters::string_to_solveform_value(_6271);
      if ((_6427 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSolveForm)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_SOLVE_FORM"),_6427);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("simSwitchOptimizer")))
  {
    {
      int _6428 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6271);
      if ((_6428 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSwitchOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_SIM_SWITCH_OPTIMIZER"),_6428);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("mioRinsMaxNodes")))
  {
    {
      try
      {
        {
          int _6430 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if (((-(int)1) <= _6430))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_RINS_MAX_NODES"),_6430);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6429)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("mioFeaspumpLevel")))
  {
    {
      try
      {
        {
          int _6432 = ::mosek::fusion::Utils::Tools::toInt(_6271);
          if ((((-(int)1) <= _6432) && (_6432 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_IPAR_MIO_FEASPUMP_LEVEL"),_6432);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6431)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("optimizerMaxTime")))
  {
    {
      try
      {
        {
          double _6434 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_OPTIMIZER_MAX_TIME"),_6434);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6433)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("lowerObjCut")))
  {
    {
      try
      {
        {
          double _6436 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT"),_6436);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6435)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("upperObjCut")))
  {
    {
      try
      {
        {
          double _6438 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT"),_6438);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6437)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      try
      {
        {
          double _6440 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT_FINITE_TRH"),_6440);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6439)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      try
      {
        {
          double _6442 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT_FINITE_TRH"),_6442);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6441)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("intpntTolRelGap")))
  {
    {
      try
      {
        {
          double _6444 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if ((1.000000e-14 <= _6444))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_GAP"),_6444);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6443)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("intpntTolStepSize")))
  {
    {
      try
      {
        {
          double _6446 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if (((0.000000e+00 <= _6446) && (_6446 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_STEP_SIZE"),_6446);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6445)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("simLuTolRelPiv")))
  {
    {
      try
      {
        {
          double _6448 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if (((1.000000e-06 <= _6448) && (_6448 <= 9.999990e-01)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_SIM_LU_TOL_REL_PIV"),_6448);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6447)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("intpntTolRelStep")))
  {
    {
      try
      {
        {
          double _6450 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if (((1.000000e-04 <= _6450) && (_6450 <= 9.999990e-01)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_STEP"),_6450);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6449)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("intpntTolPath")))
  {
    {
      try
      {
        {
          double _6452 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if (((0.000000e+00 <= _6452) && (_6452 <= 9.999000e-01)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PATH"),_6452);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6451)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("intpntTolPfeas")))
  {
    {
      try
      {
        {
          double _6454 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if (((0.000000e+00 <= _6454) && (_6454 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PFEAS"),_6454);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6453)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("intpntTolDfeas")))
  {
    {
      try
      {
        {
          double _6456 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if (((0.000000e+00 <= _6456) && (_6456 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DFEAS"),_6456);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6455)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("intpntTolMuRed")))
  {
    {
      try
      {
        {
          double _6458 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if (((0.000000e+00 <= _6458) && (_6458 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_MU_RED"),_6458);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6457)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("intpntTolInfeas")))
  {
    {
      try
      {
        {
          double _6460 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if (((0.000000e+00 <= _6460) && (_6460 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_INFEAS"),_6460);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6459)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("intpntCoTolRelGap")))
  {
    {
      try
      {
        {
          double _6462 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if (((0.000000e+00 <= _6462) && (_6462 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_REL_GAP"),_6462);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6461)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("intpntCoTolPfeas")))
  {
    {
      try
      {
        {
          double _6464 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if (((0.000000e+00 <= _6464) && (_6464 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_PFEAS"),_6464);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6463)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("intpntCoTolDfeas")))
  {
    {
      try
      {
        {
          double _6466 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if (((0.000000e+00 <= _6466) && (_6466 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_DFEAS"),_6466);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6465)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("intpntCoTolMuRed")))
  {
    {
      try
      {
        {
          double _6468 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if (((0.000000e+00 <= _6468) && (_6468 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_MU_RED"),_6468);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6467)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("intpntCoTolNearRel")))
  {
    {
      try
      {
        {
          double _6470 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if ((1.000000e+00 <= _6470))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_NEAR_REL"),_6470);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6469)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("intpntCoTolInfeas")))
  {
    {
      try
      {
        {
          double _6472 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if (((0.000000e+00 <= _6472) && (_6472 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_INFEAS"),_6472);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6471)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("intpntTolPsafe")))
  {
    {
      try
      {
        {
          double _6474 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if ((1.000000e-04 <= _6474))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PSAFE"),_6474);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6473)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("intpntTolDsafe")))
  {
    {
      try
      {
        {
          double _6476 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if ((1.000000e-04 <= _6476))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DSAFE"),_6476);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6475)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("mioMaxTime")))
  {
    {
      try
      {
        {
          double _6478 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_MIO_MAX_TIME"),_6478);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6477)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("mioRelGapConst")))
  {
    {
      try
      {
        {
          double _6480 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if ((1.000000e-15 <= _6480))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_MIO_REL_GAP_CONST"),_6480);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6479)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("mioTolRelGap")))
  {
    {
      try
      {
        {
          double _6482 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if ((0.000000e+00 <= _6482))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_GAP"),_6482);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6481)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("mioTolAbsGap")))
  {
    {
      try
      {
        {
          double _6484 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if ((0.000000e+00 <= _6484))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_GAP"),_6484);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6483)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      try
      {
        {
          double _6486 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if ((1.000000e-09 <= _6486))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_RELAX_INT"),_6486);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6485)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("basisTolX")))
  {
    {
      try
      {
        {
          double _6488 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if ((1.000000e-09 <= _6488))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_X"),_6488);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6487)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("basisTolS")))
  {
    {
      try
      {
        {
          double _6490 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if ((1.000000e-09 <= _6490))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_S"),_6490);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6489)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("basisRelTolS")))
  {
    {
      try
      {
        {
          double _6492 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if ((0.000000e+00 <= _6492))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_BASIS_REL_TOL_S"),_6492);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6491)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("presolveTolX")))
  {
    {
      try
      {
        {
          double _6494 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if ((0.000000e+00 <= _6494))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_X"),_6494);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6493)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("presolveTolS")))
  {
    {
      try
      {
        {
          double _6496 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if ((0.000000e+00 <= _6496))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_S"),_6496);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6495)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("presolveTolAij")))
  {
    {
      try
      {
        {
          double _6498 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if ((1.000000e-15 <= _6498))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_AIJ"),_6498);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6497)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("presolveTolAbsLindep")))
  {
    {
      try
      {
        {
          double _6500 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if ((0.000000e+00 <= _6500))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_ABS_LINDEP"),_6500);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6499)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("presolveTolRelLindep")))
  {
    {
      try
      {
        {
          double _6502 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if ((0.000000e+00 <= _6502))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_REL_LINDEP"),_6502);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6501)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("simplexAbsTolPiv")))
  {
    {
      try
      {
        {
          double _6504 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if ((1.000000e-12 <= _6504))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_SIMPLEX_ABS_TOL_PIV"),_6504);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6503)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("mioTolFeas")))
  {
    {
      try
      {
        {
          double _6506 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if (((1.000000e-09 <= _6506) && (_6506 <= 1.000000e-03)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_FEAS"),_6506);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6505)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      try
      {
        {
          double _6508 = ::mosek::fusion::Utils::Tools::toDouble(_6271);
          if (((0.000000e+00 <= _6508) && (_6508 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_DUAL_BOUND_IMPROVEMENT"),_6508);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6507)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
        }
      }
    }
  }
  {}
  if ((_6270 == std::string ("dataFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_SPAR_DATA_FILE_NAME"),_6271);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("basSolFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_SPAR_BAS_SOL_FILE_NAME"),_6271);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("itrSolFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_SPAR_ITR_SOL_FILE_NAME"),_6271);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("intSolFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_SPAR_INT_SOL_FILE_NAME"),_6271);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("writeLpGenVarName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_SPAR_WRITE_LP_GEN_VAR_NAME"),_6271);
      return;
    }
  }
  {}
  if ((_6270 == std::string ("remoteAccessToken")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6269.get())->task_put_param(std::string ("MSK_SPAR_REMOTE_ACCESS_TOKEN"),_6271);
      return;
    }
  }
  {}
  throw ::mosek::fusion::ParameterError(std::string ("Unknown parameter"));
}
int mosek::fusion::p_Parameters::string_to_variabletype_value(const std::string & _6509){
  if ((_6509 == std::string ("typeCont")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6509 == std::string ("typeInt")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_value_value(const std::string & _6510){
  if ((_6510 == std::string ("maxStrLen")))
  {
    {
      return (int)1024;
    }
  }
  {}
  if ((_6510 == std::string ("licenseBufferLength")))
  {
    {
      return (int)21;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_streamtype_value(const std::string & _6511){
  if ((_6511 == std::string ("log")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6511 == std::string ("msg")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6511 == std::string ("err")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6511 == std::string ("wrn")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_startpointtype_value(const std::string & _6512){
  if ((_6512 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6512 == std::string ("guess")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6512 == std::string ("constant")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6512 == std::string ("satisfyBounds")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_stakey_value(const std::string & _6513){
  if ((_6513 == std::string ("unk")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6513 == std::string ("bas")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6513 == std::string ("supbas")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6513 == std::string ("low")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6513 == std::string ("upr")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6513 == std::string ("fix")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6513 == std::string ("inf")))
  {
    {
      return (int)6;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_sparam_value(const std::string & _6514){
  if ((_6514 == std::string ("dataFileName")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6514 == std::string ("paramReadFileName")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6514 == std::string ("paramWriteFileName")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6514 == std::string ("paramCommentSign")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6514 == std::string ("debugFileName")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6514 == std::string ("basSolFileName")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6514 == std::string ("itrSolFileName")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6514 == std::string ("intSolFileName")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6514 == std::string ("solFilterXcLow")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6514 == std::string ("solFilterXcUpr")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6514 == std::string ("solFilterXxLow")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6514 == std::string ("solFilterXxUpr")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6514 == std::string ("readMpsObjName")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6514 == std::string ("readMpsRanName")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6514 == std::string ("readMpsRhsName")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6514 == std::string ("readMpsBouName")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6514 == std::string ("statFileName")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6514 == std::string ("statName")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6514 == std::string ("statKey")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6514 == std::string ("writeLpGenVarName")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6514 == std::string ("sensitivityResFileName")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6514 == std::string ("sensitivityFileName")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6514 == std::string ("mioDebugString")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6514 == std::string ("remoteAccessToken")))
  {
    {
      return (int)13;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_solveform_value(const std::string & _6515){
  if ((_6515 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6515 == std::string ("primal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6515 == std::string ("dual")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_soltype_value(const std::string & _6516){
  if ((_6516 == std::string ("bas")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6516 == std::string ("itr")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6516 == std::string ("itg")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_solsta_value(const std::string & _6517){
  if ((_6517 == std::string ("unknown")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6517 == std::string ("optimal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6517 == std::string ("primFeas")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6517 == std::string ("dualFeas")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6517 == std::string ("primAndDualFeas")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6517 == std::string ("primInfeasCer")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6517 == std::string ("dualInfeasCer")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6517 == std::string ("primIllposedCer")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6517 == std::string ("dualIllposedCer")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6517 == std::string ("integerOptimal")))
  {
    {
      return (int)9;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_solitem_value(const std::string & _6518){
  if ((_6518 == std::string ("xc")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6518 == std::string ("xx")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6518 == std::string ("y")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6518 == std::string ("slc")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6518 == std::string ("suc")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6518 == std::string ("slx")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6518 == std::string ("sux")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6518 == std::string ("snx")))
  {
    {
      return (int)7;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simseltype_value(const std::string & _6519){
  if ((_6519 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6519 == std::string ("full")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6519 == std::string ("ase")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6519 == std::string ("devex")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6519 == std::string ("se")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6519 == std::string ("partial")))
  {
    {
      return (int)5;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_sensitivitytype_value(const std::string & _6520){
  if ((_6520 == std::string ("basis")))
  {
    {
      return (int)0;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_scalingmethod_value(const std::string & _6521){
  if ((_6521 == std::string ("pow2")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6521 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_scalingtype_value(const std::string & _6522){
  if ((_6522 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6522 == std::string ("none")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6522 == std::string ("moderate")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6522 == std::string ("aggressive")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_rescodetype_value(const std::string & _6523){
  if ((_6523 == std::string ("ok")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6523 == std::string ("wrn")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6523 == std::string ("trm")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6523 == std::string ("err")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6523 == std::string ("unk")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_rescode_value(const std::string & _6524){
  if ((_6524 == std::string ("ok")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6524 == std::string ("wrnOpenParamFile")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6524 == std::string ("wrnLargeBound")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6524 == std::string ("wrnLargeLoBound")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6524 == std::string ("wrnLargeUpBound")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6524 == std::string ("wrnLargeConFx")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6524 == std::string ("wrnLargeCj")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6524 == std::string ("wrnLargeAij")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6524 == std::string ("wrnZeroAij")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6524 == std::string ("wrnNameMaxLen")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6524 == std::string ("wrnSparMaxLen")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6524 == std::string ("wrnMpsSplitRhsVector")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6524 == std::string ("wrnMpsSplitRanVector")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6524 == std::string ("wrnMpsSplitBouVector")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6524 == std::string ("wrnLpOldQuadFormat")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6524 == std::string ("wrnLpDropVariable")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6524 == std::string ("wrnNzInUprTri")))
  {
    {
      return (int)200;
    }
  }
  {}
  if ((_6524 == std::string ("wrnDroppedNzQobj")))
  {
    {
      return (int)201;
    }
  }
  {}
  if ((_6524 == std::string ("wrnIgnoreInteger")))
  {
    {
      return (int)250;
    }
  }
  {}
  if ((_6524 == std::string ("wrnNoGlobalOptimizer")))
  {
    {
      return (int)251;
    }
  }
  {}
  if ((_6524 == std::string ("wrnMioInfeasibleFinal")))
  {
    {
      return (int)270;
    }
  }
  {}
  if ((_6524 == std::string ("wrnSolFilter")))
  {
    {
      return (int)300;
    }
  }
  {}
  if ((_6524 == std::string ("wrnUndefSolFileName")))
  {
    {
      return (int)350;
    }
  }
  {}
  if ((_6524 == std::string ("wrnSolFileIgnoredCon")))
  {
    {
      return (int)351;
    }
  }
  {}
  if ((_6524 == std::string ("wrnSolFileIgnoredVar")))
  {
    {
      return (int)352;
    }
  }
  {}
  if ((_6524 == std::string ("wrnTooFewBasisVars")))
  {
    {
      return (int)400;
    }
  }
  {}
  if ((_6524 == std::string ("wrnTooManyBasisVars")))
  {
    {
      return (int)405;
    }
  }
  {}
  if ((_6524 == std::string ("wrnLicenseExpire")))
  {
    {
      return (int)500;
    }
  }
  {}
  if ((_6524 == std::string ("wrnLicenseServer")))
  {
    {
      return (int)501;
    }
  }
  {}
  if ((_6524 == std::string ("wrnEmptyName")))
  {
    {
      return (int)502;
    }
  }
  {}
  if ((_6524 == std::string ("wrnUsingGenericNames")))
  {
    {
      return (int)503;
    }
  }
  {}
  if ((_6524 == std::string ("wrnLicenseFeatureExpire")))
  {
    {
      return (int)505;
    }
  }
  {}
  if ((_6524 == std::string ("wrnParamNameDou")))
  {
    {
      return (int)510;
    }
  }
  {}
  if ((_6524 == std::string ("wrnParamNameInt")))
  {
    {
      return (int)511;
    }
  }
  {}
  if ((_6524 == std::string ("wrnParamNameStr")))
  {
    {
      return (int)512;
    }
  }
  {}
  if ((_6524 == std::string ("wrnParamStrValue")))
  {
    {
      return (int)515;
    }
  }
  {}
  if ((_6524 == std::string ("wrnParamIgnoredCmio")))
  {
    {
      return (int)516;
    }
  }
  {}
  if ((_6524 == std::string ("wrnZerosInSparseRow")))
  {
    {
      return (int)705;
    }
  }
  {}
  if ((_6524 == std::string ("wrnZerosInSparseCol")))
  {
    {
      return (int)710;
    }
  }
  {}
  if ((_6524 == std::string ("wrnIncompleteLinearDependencyCheck")))
  {
    {
      return (int)800;
    }
  }
  {}
  if ((_6524 == std::string ("wrnEliminatorSpace")))
  {
    {
      return (int)801;
    }
  }
  {}
  if ((_6524 == std::string ("wrnPresolveOutofspace")))
  {
    {
      return (int)802;
    }
  }
  {}
  if ((_6524 == std::string ("wrnWriteChangedNames")))
  {
    {
      return (int)803;
    }
  }
  {}
  if ((_6524 == std::string ("wrnWriteDiscardedCfix")))
  {
    {
      return (int)804;
    }
  }
  {}
  if ((_6524 == std::string ("wrnDuplicateConstraintNames")))
  {
    {
      return (int)850;
    }
  }
  {}
  if ((_6524 == std::string ("wrnDuplicateVariableNames")))
  {
    {
      return (int)851;
    }
  }
  {}
  if ((_6524 == std::string ("wrnDuplicateBarvariableNames")))
  {
    {
      return (int)852;
    }
  }
  {}
  if ((_6524 == std::string ("wrnDuplicateConeNames")))
  {
    {
      return (int)853;
    }
  }
  {}
  if ((_6524 == std::string ("wrnAnaLargeBounds")))
  {
    {
      return (int)900;
    }
  }
  {}
  if ((_6524 == std::string ("wrnAnaCZero")))
  {
    {
      return (int)901;
    }
  }
  {}
  if ((_6524 == std::string ("wrnAnaEmptyCols")))
  {
    {
      return (int)902;
    }
  }
  {}
  if ((_6524 == std::string ("wrnAnaCloseBounds")))
  {
    {
      return (int)903;
    }
  }
  {}
  if ((_6524 == std::string ("wrnAnaAlmostIntBounds")))
  {
    {
      return (int)904;
    }
  }
  {}
  if ((_6524 == std::string ("wrnQuadConesWithRootFixedAtZero")))
  {
    {
      return (int)930;
    }
  }
  {}
  if ((_6524 == std::string ("wrnRquadConesWithRootFixedAtZero")))
  {
    {
      return (int)931;
    }
  }
  {}
  if ((_6524 == std::string ("wrnExpConesWithVariablesFixedAtZero")))
  {
    {
      return (int)932;
    }
  }
  {}
  if ((_6524 == std::string ("wrnPowConesWithRootFixedAtZero")))
  {
    {
      return (int)933;
    }
  }
  {}
  if ((_6524 == std::string ("wrnNoDualizer")))
  {
    {
      return (int)950;
    }
  }
  {}
  if ((_6524 == std::string ("wrnSymMatLarge")))
  {
    {
      return (int)960;
    }
  }
  {}
  if ((_6524 == std::string ("errLicense")))
  {
    {
      return (int)1000;
    }
  }
  {}
  if ((_6524 == std::string ("errLicenseExpired")))
  {
    {
      return (int)1001;
    }
  }
  {}
  if ((_6524 == std::string ("errLicenseVersion")))
  {
    {
      return (int)1002;
    }
  }
  {}
  if ((_6524 == std::string ("errSizeLicense")))
  {
    {
      return (int)1005;
    }
  }
  {}
  if ((_6524 == std::string ("errProbLicense")))
  {
    {
      return (int)1006;
    }
  }
  {}
  if ((_6524 == std::string ("errFileLicense")))
  {
    {
      return (int)1007;
    }
  }
  {}
  if ((_6524 == std::string ("errMissingLicenseFile")))
  {
    {
      return (int)1008;
    }
  }
  {}
  if ((_6524 == std::string ("errSizeLicenseCon")))
  {
    {
      return (int)1010;
    }
  }
  {}
  if ((_6524 == std::string ("errSizeLicenseVar")))
  {
    {
      return (int)1011;
    }
  }
  {}
  if ((_6524 == std::string ("errSizeLicenseIntvar")))
  {
    {
      return (int)1012;
    }
  }
  {}
  if ((_6524 == std::string ("errOptimizerLicense")))
  {
    {
      return (int)1013;
    }
  }
  {}
  if ((_6524 == std::string ("errFlexlm")))
  {
    {
      return (int)1014;
    }
  }
  {}
  if ((_6524 == std::string ("errLicenseServer")))
  {
    {
      return (int)1015;
    }
  }
  {}
  if ((_6524 == std::string ("errLicenseMax")))
  {
    {
      return (int)1016;
    }
  }
  {}
  if ((_6524 == std::string ("errLicenseMoseklmDaemon")))
  {
    {
      return (int)1017;
    }
  }
  {}
  if ((_6524 == std::string ("errLicenseFeature")))
  {
    {
      return (int)1018;
    }
  }
  {}
  if ((_6524 == std::string ("errPlatformNotLicensed")))
  {
    {
      return (int)1019;
    }
  }
  {}
  if ((_6524 == std::string ("errLicenseCannotAllocate")))
  {
    {
      return (int)1020;
    }
  }
  {}
  if ((_6524 == std::string ("errLicenseCannotConnect")))
  {
    {
      return (int)1021;
    }
  }
  {}
  if ((_6524 == std::string ("errLicenseInvalidHostid")))
  {
    {
      return (int)1025;
    }
  }
  {}
  if ((_6524 == std::string ("errLicenseServerVersion")))
  {
    {
      return (int)1026;
    }
  }
  {}
  if ((_6524 == std::string ("errLicenseNoServerSupport")))
  {
    {
      return (int)1027;
    }
  }
  {}
  if ((_6524 == std::string ("errLicenseNoServerLine")))
  {
    {
      return (int)1028;
    }
  }
  {}
  if ((_6524 == std::string ("errOlderDll")))
  {
    {
      return (int)1035;
    }
  }
  {}
  if ((_6524 == std::string ("errNewerDll")))
  {
    {
      return (int)1036;
    }
  }
  {}
  if ((_6524 == std::string ("errLinkFileDll")))
  {
    {
      return (int)1040;
    }
  }
  {}
  if ((_6524 == std::string ("errThreadMutexInit")))
  {
    {
      return (int)1045;
    }
  }
  {}
  if ((_6524 == std::string ("errThreadMutexLock")))
  {
    {
      return (int)1046;
    }
  }
  {}
  if ((_6524 == std::string ("errThreadMutexUnlock")))
  {
    {
      return (int)1047;
    }
  }
  {}
  if ((_6524 == std::string ("errThreadCreate")))
  {
    {
      return (int)1048;
    }
  }
  {}
  if ((_6524 == std::string ("errThreadCondInit")))
  {
    {
      return (int)1049;
    }
  }
  {}
  if ((_6524 == std::string ("errUnknown")))
  {
    {
      return (int)1050;
    }
  }
  {}
  if ((_6524 == std::string ("errSpace")))
  {
    {
      return (int)1051;
    }
  }
  {}
  if ((_6524 == std::string ("errFileOpen")))
  {
    {
      return (int)1052;
    }
  }
  {}
  if ((_6524 == std::string ("errFileRead")))
  {
    {
      return (int)1053;
    }
  }
  {}
  if ((_6524 == std::string ("errFileWrite")))
  {
    {
      return (int)1054;
    }
  }
  {}
  if ((_6524 == std::string ("errDataFileExt")))
  {
    {
      return (int)1055;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidFileName")))
  {
    {
      return (int)1056;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidSolFileName")))
  {
    {
      return (int)1057;
    }
  }
  {}
  if ((_6524 == std::string ("errEndOfFile")))
  {
    {
      return (int)1059;
    }
  }
  {}
  if ((_6524 == std::string ("errNullEnv")))
  {
    {
      return (int)1060;
    }
  }
  {}
  if ((_6524 == std::string ("errNullTask")))
  {
    {
      return (int)1061;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidStream")))
  {
    {
      return (int)1062;
    }
  }
  {}
  if ((_6524 == std::string ("errNoInitEnv")))
  {
    {
      return (int)1063;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidTask")))
  {
    {
      return (int)1064;
    }
  }
  {}
  if ((_6524 == std::string ("errNullPointer")))
  {
    {
      return (int)1065;
    }
  }
  {}
  if ((_6524 == std::string ("errLivingTasks")))
  {
    {
      return (int)1066;
    }
  }
  {}
  if ((_6524 == std::string ("errBlankName")))
  {
    {
      return (int)1070;
    }
  }
  {}
  if ((_6524 == std::string ("errDupName")))
  {
    {
      return (int)1071;
    }
  }
  {}
  if ((_6524 == std::string ("errFormatString")))
  {
    {
      return (int)1072;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidObjName")))
  {
    {
      return (int)1075;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidConName")))
  {
    {
      return (int)1076;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidVarName")))
  {
    {
      return (int)1077;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidConeName")))
  {
    {
      return (int)1078;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidBarvarName")))
  {
    {
      return (int)1079;
    }
  }
  {}
  if ((_6524 == std::string ("errSpaceLeaking")))
  {
    {
      return (int)1080;
    }
  }
  {}
  if ((_6524 == std::string ("errSpaceNoInfo")))
  {
    {
      return (int)1081;
    }
  }
  {}
  if ((_6524 == std::string ("errReadFormat")))
  {
    {
      return (int)1090;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsFile")))
  {
    {
      return (int)1100;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsInvField")))
  {
    {
      return (int)1101;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsInvMarker")))
  {
    {
      return (int)1102;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsNullConName")))
  {
    {
      return (int)1103;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsNullVarName")))
  {
    {
      return (int)1104;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsUndefConName")))
  {
    {
      return (int)1105;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsUndefVarName")))
  {
    {
      return (int)1106;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsInvConKey")))
  {
    {
      return (int)1107;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsInvBoundKey")))
  {
    {
      return (int)1108;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsInvSecName")))
  {
    {
      return (int)1109;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsNoObjective")))
  {
    {
      return (int)1110;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsSplittedVar")))
  {
    {
      return (int)1111;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsMulConName")))
  {
    {
      return (int)1112;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsMulQsec")))
  {
    {
      return (int)1113;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsMulQobj")))
  {
    {
      return (int)1114;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsInvSecOrder")))
  {
    {
      return (int)1115;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsMulCsec")))
  {
    {
      return (int)1116;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsConeType")))
  {
    {
      return (int)1117;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsConeOverlap")))
  {
    {
      return (int)1118;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsConeRepeat")))
  {
    {
      return (int)1119;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsNonSymmetricQ")))
  {
    {
      return (int)1120;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsDuplicateQElement")))
  {
    {
      return (int)1121;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsInvalidObjsense")))
  {
    {
      return (int)1122;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsTabInField2")))
  {
    {
      return (int)1125;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsTabInField3")))
  {
    {
      return (int)1126;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsTabInField5")))
  {
    {
      return (int)1127;
    }
  }
  {}
  if ((_6524 == std::string ("errMpsInvalidObjName")))
  {
    {
      return (int)1128;
    }
  }
  {}
  if ((_6524 == std::string ("errLpIncompatible")))
  {
    {
      return (int)1150;
    }
  }
  {}
  if ((_6524 == std::string ("errLpEmpty")))
  {
    {
      return (int)1151;
    }
  }
  {}
  if ((_6524 == std::string ("errLpDupSlackName")))
  {
    {
      return (int)1152;
    }
  }
  {}
  if ((_6524 == std::string ("errWriteMpsInvalidName")))
  {
    {
      return (int)1153;
    }
  }
  {}
  if ((_6524 == std::string ("errLpInvalidVarName")))
  {
    {
      return (int)1154;
    }
  }
  {}
  if ((_6524 == std::string ("errLpFreeConstraint")))
  {
    {
      return (int)1155;
    }
  }
  {}
  if ((_6524 == std::string ("errWriteOpfInvalidVarName")))
  {
    {
      return (int)1156;
    }
  }
  {}
  if ((_6524 == std::string ("errLpFileFormat")))
  {
    {
      return (int)1157;
    }
  }
  {}
  if ((_6524 == std::string ("errWriteLpFormat")))
  {
    {
      return (int)1158;
    }
  }
  {}
  if ((_6524 == std::string ("errReadLpMissingEndTag")))
  {
    {
      return (int)1159;
    }
  }
  {}
  if ((_6524 == std::string ("errLpFormat")))
  {
    {
      return (int)1160;
    }
  }
  {}
  if ((_6524 == std::string ("errWriteLpNonUniqueName")))
  {
    {
      return (int)1161;
    }
  }
  {}
  if ((_6524 == std::string ("errReadLpNonexistingName")))
  {
    {
      return (int)1162;
    }
  }
  {}
  if ((_6524 == std::string ("errLpWriteConicProblem")))
  {
    {
      return (int)1163;
    }
  }
  {}
  if ((_6524 == std::string ("errLpWriteGecoProblem")))
  {
    {
      return (int)1164;
    }
  }
  {}
  if ((_6524 == std::string ("errWritingFile")))
  {
    {
      return (int)1166;
    }
  }
  {}
  if ((_6524 == std::string ("errPtfFormat")))
  {
    {
      return (int)1167;
    }
  }
  {}
  if ((_6524 == std::string ("errOpfFormat")))
  {
    {
      return (int)1168;
    }
  }
  {}
  if ((_6524 == std::string ("errOpfNewVariable")))
  {
    {
      return (int)1169;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidNameInSolFile")))
  {
    {
      return (int)1170;
    }
  }
  {}
  if ((_6524 == std::string ("errLpInvalidConName")))
  {
    {
      return (int)1171;
    }
  }
  {}
  if ((_6524 == std::string ("errOpfPrematureEof")))
  {
    {
      return (int)1172;
    }
  }
  {}
  if ((_6524 == std::string ("errJsonSyntax")))
  {
    {
      return (int)1175;
    }
  }
  {}
  if ((_6524 == std::string ("errJsonString")))
  {
    {
      return (int)1176;
    }
  }
  {}
  if ((_6524 == std::string ("errJsonNumberOverflow")))
  {
    {
      return (int)1177;
    }
  }
  {}
  if ((_6524 == std::string ("errJsonFormat")))
  {
    {
      return (int)1178;
    }
  }
  {}
  if ((_6524 == std::string ("errJsonData")))
  {
    {
      return (int)1179;
    }
  }
  {}
  if ((_6524 == std::string ("errJsonMissingData")))
  {
    {
      return (int)1180;
    }
  }
  {}
  if ((_6524 == std::string ("errArgumentLenneq")))
  {
    {
      return (int)1197;
    }
  }
  {}
  if ((_6524 == std::string ("errArgumentType")))
  {
    {
      return (int)1198;
    }
  }
  {}
  if ((_6524 == std::string ("errNumArguments")))
  {
    {
      return (int)1199;
    }
  }
  {}
  if ((_6524 == std::string ("errInArgument")))
  {
    {
      return (int)1200;
    }
  }
  {}
  if ((_6524 == std::string ("errArgumentDimension")))
  {
    {
      return (int)1201;
    }
  }
  {}
  if ((_6524 == std::string ("errShapeIsTooLarge")))
  {
    {
      return (int)1202;
    }
  }
  {}
  if ((_6524 == std::string ("errIndexIsTooSmall")))
  {
    {
      return (int)1203;
    }
  }
  {}
  if ((_6524 == std::string ("errIndexIsTooLarge")))
  {
    {
      return (int)1204;
    }
  }
  {}
  if ((_6524 == std::string ("errParamName")))
  {
    {
      return (int)1205;
    }
  }
  {}
  if ((_6524 == std::string ("errParamNameDou")))
  {
    {
      return (int)1206;
    }
  }
  {}
  if ((_6524 == std::string ("errParamNameInt")))
  {
    {
      return (int)1207;
    }
  }
  {}
  if ((_6524 == std::string ("errParamNameStr")))
  {
    {
      return (int)1208;
    }
  }
  {}
  if ((_6524 == std::string ("errParamIndex")))
  {
    {
      return (int)1210;
    }
  }
  {}
  if ((_6524 == std::string ("errParamIsTooLarge")))
  {
    {
      return (int)1215;
    }
  }
  {}
  if ((_6524 == std::string ("errParamIsTooSmall")))
  {
    {
      return (int)1216;
    }
  }
  {}
  if ((_6524 == std::string ("errParamValueStr")))
  {
    {
      return (int)1217;
    }
  }
  {}
  if ((_6524 == std::string ("errParamType")))
  {
    {
      return (int)1218;
    }
  }
  {}
  if ((_6524 == std::string ("errInfDouIndex")))
  {
    {
      return (int)1219;
    }
  }
  {}
  if ((_6524 == std::string ("errInfIntIndex")))
  {
    {
      return (int)1220;
    }
  }
  {}
  if ((_6524 == std::string ("errIndexArrIsTooSmall")))
  {
    {
      return (int)1221;
    }
  }
  {}
  if ((_6524 == std::string ("errIndexArrIsTooLarge")))
  {
    {
      return (int)1222;
    }
  }
  {}
  if ((_6524 == std::string ("errInfLintIndex")))
  {
    {
      return (int)1225;
    }
  }
  {}
  if ((_6524 == std::string ("errArgIsTooSmall")))
  {
    {
      return (int)1226;
    }
  }
  {}
  if ((_6524 == std::string ("errArgIsTooLarge")))
  {
    {
      return (int)1227;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidWhichsol")))
  {
    {
      return (int)1228;
    }
  }
  {}
  if ((_6524 == std::string ("errInfDouName")))
  {
    {
      return (int)1230;
    }
  }
  {}
  if ((_6524 == std::string ("errInfIntName")))
  {
    {
      return (int)1231;
    }
  }
  {}
  if ((_6524 == std::string ("errInfType")))
  {
    {
      return (int)1232;
    }
  }
  {}
  if ((_6524 == std::string ("errInfLintName")))
  {
    {
      return (int)1234;
    }
  }
  {}
  if ((_6524 == std::string ("errIndex")))
  {
    {
      return (int)1235;
    }
  }
  {}
  if ((_6524 == std::string ("errWhichsol")))
  {
    {
      return (int)1236;
    }
  }
  {}
  if ((_6524 == std::string ("errSolitem")))
  {
    {
      return (int)1237;
    }
  }
  {}
  if ((_6524 == std::string ("errWhichitemNotAllowed")))
  {
    {
      return (int)1238;
    }
  }
  {}
  if ((_6524 == std::string ("errMaxnumcon")))
  {
    {
      return (int)1240;
    }
  }
  {}
  if ((_6524 == std::string ("errMaxnumvar")))
  {
    {
      return (int)1241;
    }
  }
  {}
  if ((_6524 == std::string ("errMaxnumbarvar")))
  {
    {
      return (int)1242;
    }
  }
  {}
  if ((_6524 == std::string ("errMaxnumqnz")))
  {
    {
      return (int)1243;
    }
  }
  {}
  if ((_6524 == std::string ("errTooSmallMaxNumNz")))
  {
    {
      return (int)1245;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidIdx")))
  {
    {
      return (int)1246;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidMaxNum")))
  {
    {
      return (int)1247;
    }
  }
  {}
  if ((_6524 == std::string ("errNumconlim")))
  {
    {
      return (int)1250;
    }
  }
  {}
  if ((_6524 == std::string ("errNumvarlim")))
  {
    {
      return (int)1251;
    }
  }
  {}
  if ((_6524 == std::string ("errTooSmallMaxnumanz")))
  {
    {
      return (int)1252;
    }
  }
  {}
  if ((_6524 == std::string ("errInvAptre")))
  {
    {
      return (int)1253;
    }
  }
  {}
  if ((_6524 == std::string ("errMulAElement")))
  {
    {
      return (int)1254;
    }
  }
  {}
  if ((_6524 == std::string ("errInvBk")))
  {
    {
      return (int)1255;
    }
  }
  {}
  if ((_6524 == std::string ("errInvBkc")))
  {
    {
      return (int)1256;
    }
  }
  {}
  if ((_6524 == std::string ("errInvBkx")))
  {
    {
      return (int)1257;
    }
  }
  {}
  if ((_6524 == std::string ("errInvVarType")))
  {
    {
      return (int)1258;
    }
  }
  {}
  if ((_6524 == std::string ("errSolverProbtype")))
  {
    {
      return (int)1259;
    }
  }
  {}
  if ((_6524 == std::string ("errObjectiveRange")))
  {
    {
      return (int)1260;
    }
  }
  {}
  if ((_6524 == std::string ("errUndefSolution")))
  {
    {
      return (int)1265;
    }
  }
  {}
  if ((_6524 == std::string ("errBasis")))
  {
    {
      return (int)1266;
    }
  }
  {}
  if ((_6524 == std::string ("errInvSkc")))
  {
    {
      return (int)1267;
    }
  }
  {}
  if ((_6524 == std::string ("errInvSkx")))
  {
    {
      return (int)1268;
    }
  }
  {}
  if ((_6524 == std::string ("errInvSkn")))
  {
    {
      return (int)1274;
    }
  }
  {}
  if ((_6524 == std::string ("errInvSkStr")))
  {
    {
      return (int)1269;
    }
  }
  {}
  if ((_6524 == std::string ("errInvSk")))
  {
    {
      return (int)1270;
    }
  }
  {}
  if ((_6524 == std::string ("errInvConeTypeStr")))
  {
    {
      return (int)1271;
    }
  }
  {}
  if ((_6524 == std::string ("errInvConeType")))
  {
    {
      return (int)1272;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidSurplus")))
  {
    {
      return (int)1275;
    }
  }
  {}
  if ((_6524 == std::string ("errInvNameItem")))
  {
    {
      return (int)1280;
    }
  }
  {}
  if ((_6524 == std::string ("errProItem")))
  {
    {
      return (int)1281;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidFormatType")))
  {
    {
      return (int)1283;
    }
  }
  {}
  if ((_6524 == std::string ("errFirsti")))
  {
    {
      return (int)1285;
    }
  }
  {}
  if ((_6524 == std::string ("errLasti")))
  {
    {
      return (int)1286;
    }
  }
  {}
  if ((_6524 == std::string ("errFirstj")))
  {
    {
      return (int)1287;
    }
  }
  {}
  if ((_6524 == std::string ("errLastj")))
  {
    {
      return (int)1288;
    }
  }
  {}
  if ((_6524 == std::string ("errMaxLenIsTooSmall")))
  {
    {
      return (int)1289;
    }
  }
  {}
  if ((_6524 == std::string ("errNonlinearEquality")))
  {
    {
      return (int)1290;
    }
  }
  {}
  if ((_6524 == std::string ("errNonconvex")))
  {
    {
      return (int)1291;
    }
  }
  {}
  if ((_6524 == std::string ("errNonlinearRanged")))
  {
    {
      return (int)1292;
    }
  }
  {}
  if ((_6524 == std::string ("errConQNotPsd")))
  {
    {
      return (int)1293;
    }
  }
  {}
  if ((_6524 == std::string ("errConQNotNsd")))
  {
    {
      return (int)1294;
    }
  }
  {}
  if ((_6524 == std::string ("errObjQNotPsd")))
  {
    {
      return (int)1295;
    }
  }
  {}
  if ((_6524 == std::string ("errObjQNotNsd")))
  {
    {
      return (int)1296;
    }
  }
  {}
  if ((_6524 == std::string ("errArgumentPermArray")))
  {
    {
      return (int)1299;
    }
  }
  {}
  if ((_6524 == std::string ("errConeIndex")))
  {
    {
      return (int)1300;
    }
  }
  {}
  if ((_6524 == std::string ("errConeSize")))
  {
    {
      return (int)1301;
    }
  }
  {}
  if ((_6524 == std::string ("errConeOverlap")))
  {
    {
      return (int)1302;
    }
  }
  {}
  if ((_6524 == std::string ("errConeRepVar")))
  {
    {
      return (int)1303;
    }
  }
  {}
  if ((_6524 == std::string ("errMaxnumcone")))
  {
    {
      return (int)1304;
    }
  }
  {}
  if ((_6524 == std::string ("errConeType")))
  {
    {
      return (int)1305;
    }
  }
  {}
  if ((_6524 == std::string ("errConeTypeStr")))
  {
    {
      return (int)1306;
    }
  }
  {}
  if ((_6524 == std::string ("errConeOverlapAppend")))
  {
    {
      return (int)1307;
    }
  }
  {}
  if ((_6524 == std::string ("errRemoveConeVariable")))
  {
    {
      return (int)1310;
    }
  }
  {}
  if ((_6524 == std::string ("errAppendingTooBigCone")))
  {
    {
      return (int)1311;
    }
  }
  {}
  if ((_6524 == std::string ("errConeParameter")))
  {
    {
      return (int)1320;
    }
  }
  {}
  if ((_6524 == std::string ("errSolFileInvalidNumber")))
  {
    {
      return (int)1350;
    }
  }
  {}
  if ((_6524 == std::string ("errHugeC")))
  {
    {
      return (int)1375;
    }
  }
  {}
  if ((_6524 == std::string ("errHugeAij")))
  {
    {
      return (int)1380;
    }
  }
  {}
  if ((_6524 == std::string ("errDuplicateAij")))
  {
    {
      return (int)1385;
    }
  }
  {}
  if ((_6524 == std::string ("errLowerBoundIsANan")))
  {
    {
      return (int)1390;
    }
  }
  {}
  if ((_6524 == std::string ("errUpperBoundIsANan")))
  {
    {
      return (int)1391;
    }
  }
  {}
  if ((_6524 == std::string ("errInfiniteBound")))
  {
    {
      return (int)1400;
    }
  }
  {}
  if ((_6524 == std::string ("errInvQobjSubi")))
  {
    {
      return (int)1401;
    }
  }
  {}
  if ((_6524 == std::string ("errInvQobjSubj")))
  {
    {
      return (int)1402;
    }
  }
  {}
  if ((_6524 == std::string ("errInvQobjVal")))
  {
    {
      return (int)1403;
    }
  }
  {}
  if ((_6524 == std::string ("errInvQconSubk")))
  {
    {
      return (int)1404;
    }
  }
  {}
  if ((_6524 == std::string ("errInvQconSubi")))
  {
    {
      return (int)1405;
    }
  }
  {}
  if ((_6524 == std::string ("errInvQconSubj")))
  {
    {
      return (int)1406;
    }
  }
  {}
  if ((_6524 == std::string ("errInvQconVal")))
  {
    {
      return (int)1407;
    }
  }
  {}
  if ((_6524 == std::string ("errQconSubiTooSmall")))
  {
    {
      return (int)1408;
    }
  }
  {}
  if ((_6524 == std::string ("errQconSubiTooLarge")))
  {
    {
      return (int)1409;
    }
  }
  {}
  if ((_6524 == std::string ("errQobjUpperTriangle")))
  {
    {
      return (int)1415;
    }
  }
  {}
  if ((_6524 == std::string ("errQconUpperTriangle")))
  {
    {
      return (int)1417;
    }
  }
  {}
  if ((_6524 == std::string ("errFixedBoundValues")))
  {
    {
      return (int)1420;
    }
  }
  {}
  if ((_6524 == std::string ("errTooSmallATruncationValue")))
  {
    {
      return (int)1421;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidObjectiveSense")))
  {
    {
      return (int)1445;
    }
  }
  {}
  if ((_6524 == std::string ("errUndefinedObjectiveSense")))
  {
    {
      return (int)1446;
    }
  }
  {}
  if ((_6524 == std::string ("errYIsUndefined")))
  {
    {
      return (int)1449;
    }
  }
  {}
  if ((_6524 == std::string ("errNanInDoubleData")))
  {
    {
      return (int)1450;
    }
  }
  {}
  if ((_6524 == std::string ("errNanInBlc")))
  {
    {
      return (int)1461;
    }
  }
  {}
  if ((_6524 == std::string ("errNanInBuc")))
  {
    {
      return (int)1462;
    }
  }
  {}
  if ((_6524 == std::string ("errNanInC")))
  {
    {
      return (int)1470;
    }
  }
  {}
  if ((_6524 == std::string ("errNanInBlx")))
  {
    {
      return (int)1471;
    }
  }
  {}
  if ((_6524 == std::string ("errNanInBux")))
  {
    {
      return (int)1472;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidAij")))
  {
    {
      return (int)1473;
    }
  }
  {}
  if ((_6524 == std::string ("errSymMatInvalid")))
  {
    {
      return (int)1480;
    }
  }
  {}
  if ((_6524 == std::string ("errSymMatHuge")))
  {
    {
      return (int)1482;
    }
  }
  {}
  if ((_6524 == std::string ("errInvProblem")))
  {
    {
      return (int)1500;
    }
  }
  {}
  if ((_6524 == std::string ("errMixedConicAndNl")))
  {
    {
      return (int)1501;
    }
  }
  {}
  if ((_6524 == std::string ("errGlobalInvConicProblem")))
  {
    {
      return (int)1503;
    }
  }
  {}
  if ((_6524 == std::string ("errInvOptimizer")))
  {
    {
      return (int)1550;
    }
  }
  {}
  if ((_6524 == std::string ("errMioNoOptimizer")))
  {
    {
      return (int)1551;
    }
  }
  {}
  if ((_6524 == std::string ("errNoOptimizerVarType")))
  {
    {
      return (int)1552;
    }
  }
  {}
  if ((_6524 == std::string ("errFinalSolution")))
  {
    {
      return (int)1560;
    }
  }
  {}
  if ((_6524 == std::string ("errFirst")))
  {
    {
      return (int)1570;
    }
  }
  {}
  if ((_6524 == std::string ("errLast")))
  {
    {
      return (int)1571;
    }
  }
  {}
  if ((_6524 == std::string ("errSliceSize")))
  {
    {
      return (int)1572;
    }
  }
  {}
  if ((_6524 == std::string ("errNegativeSurplus")))
  {
    {
      return (int)1573;
    }
  }
  {}
  if ((_6524 == std::string ("errNegativeAppend")))
  {
    {
      return (int)1578;
    }
  }
  {}
  if ((_6524 == std::string ("errPostsolve")))
  {
    {
      return (int)1580;
    }
  }
  {}
  if ((_6524 == std::string ("errOverflow")))
  {
    {
      return (int)1590;
    }
  }
  {}
  if ((_6524 == std::string ("errNoBasisSol")))
  {
    {
      return (int)1600;
    }
  }
  {}
  if ((_6524 == std::string ("errBasisFactor")))
  {
    {
      return (int)1610;
    }
  }
  {}
  if ((_6524 == std::string ("errBasisSingular")))
  {
    {
      return (int)1615;
    }
  }
  {}
  if ((_6524 == std::string ("errFactor")))
  {
    {
      return (int)1650;
    }
  }
  {}
  if ((_6524 == std::string ("errFeasrepairCannotRelax")))
  {
    {
      return (int)1700;
    }
  }
  {}
  if ((_6524 == std::string ("errFeasrepairSolvingRelaxed")))
  {
    {
      return (int)1701;
    }
  }
  {}
  if ((_6524 == std::string ("errFeasrepairInconsistentBound")))
  {
    {
      return (int)1702;
    }
  }
  {}
  if ((_6524 == std::string ("errRepairInvalidProblem")))
  {
    {
      return (int)1710;
    }
  }
  {}
  if ((_6524 == std::string ("errRepairOptimizationFailed")))
  {
    {
      return (int)1711;
    }
  }
  {}
  if ((_6524 == std::string ("errNameMaxLen")))
  {
    {
      return (int)1750;
    }
  }
  {}
  if ((_6524 == std::string ("errNameIsNull")))
  {
    {
      return (int)1760;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidCompression")))
  {
    {
      return (int)1800;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidIomode")))
  {
    {
      return (int)1801;
    }
  }
  {}
  if ((_6524 == std::string ("errNoPrimalInfeasCer")))
  {
    {
      return (int)2000;
    }
  }
  {}
  if ((_6524 == std::string ("errNoDualInfeasCer")))
  {
    {
      return (int)2001;
    }
  }
  {}
  if ((_6524 == std::string ("errNoSolutionInCallback")))
  {
    {
      return (int)2500;
    }
  }
  {}
  if ((_6524 == std::string ("errInvMarki")))
  {
    {
      return (int)2501;
    }
  }
  {}
  if ((_6524 == std::string ("errInvMarkj")))
  {
    {
      return (int)2502;
    }
  }
  {}
  if ((_6524 == std::string ("errInvNumi")))
  {
    {
      return (int)2503;
    }
  }
  {}
  if ((_6524 == std::string ("errInvNumj")))
  {
    {
      return (int)2504;
    }
  }
  {}
  if ((_6524 == std::string ("errTaskIncompatible")))
  {
    {
      return (int)2560;
    }
  }
  {}
  if ((_6524 == std::string ("errTaskInvalid")))
  {
    {
      return (int)2561;
    }
  }
  {}
  if ((_6524 == std::string ("errTaskWrite")))
  {
    {
      return (int)2562;
    }
  }
  {}
  if ((_6524 == std::string ("errLuMaxNumTries")))
  {
    {
      return (int)2800;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidUtf8")))
  {
    {
      return (int)2900;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidWchar")))
  {
    {
      return (int)2901;
    }
  }
  {}
  if ((_6524 == std::string ("errNoDualForItgSol")))
  {
    {
      return (int)2950;
    }
  }
  {}
  if ((_6524 == std::string ("errNoSnxForBasSol")))
  {
    {
      return (int)2953;
    }
  }
  {}
  if ((_6524 == std::string ("errInternal")))
  {
    {
      return (int)3000;
    }
  }
  {}
  if ((_6524 == std::string ("errApiArrayTooSmall")))
  {
    {
      return (int)3001;
    }
  }
  {}
  if ((_6524 == std::string ("errApiCbConnect")))
  {
    {
      return (int)3002;
    }
  }
  {}
  if ((_6524 == std::string ("errApiFatalError")))
  {
    {
      return (int)3005;
    }
  }
  {}
  if ((_6524 == std::string ("errApiInternal")))
  {
    {
      return (int)3999;
    }
  }
  {}
  if ((_6524 == std::string ("errSenFormat")))
  {
    {
      return (int)3050;
    }
  }
  {}
  if ((_6524 == std::string ("errSenUndefName")))
  {
    {
      return (int)3051;
    }
  }
  {}
  if ((_6524 == std::string ("errSenIndexRange")))
  {
    {
      return (int)3052;
    }
  }
  {}
  if ((_6524 == std::string ("errSenBoundInvalidUp")))
  {
    {
      return (int)3053;
    }
  }
  {}
  if ((_6524 == std::string ("errSenBoundInvalidLo")))
  {
    {
      return (int)3054;
    }
  }
  {}
  if ((_6524 == std::string ("errSenIndexInvalid")))
  {
    {
      return (int)3055;
    }
  }
  {}
  if ((_6524 == std::string ("errSenInvalidRegexp")))
  {
    {
      return (int)3056;
    }
  }
  {}
  if ((_6524 == std::string ("errSenSolutionStatus")))
  {
    {
      return (int)3057;
    }
  }
  {}
  if ((_6524 == std::string ("errSenNumerical")))
  {
    {
      return (int)3058;
    }
  }
  {}
  if ((_6524 == std::string ("errSenUnhandledProblemType")))
  {
    {
      return (int)3080;
    }
  }
  {}
  if ((_6524 == std::string ("errUnbStepSize")))
  {
    {
      return (int)3100;
    }
  }
  {}
  if ((_6524 == std::string ("errIdenticalTasks")))
  {
    {
      return (int)3101;
    }
  }
  {}
  if ((_6524 == std::string ("errAdInvalidCodelist")))
  {
    {
      return (int)3102;
    }
  }
  {}
  if ((_6524 == std::string ("errInternalTestFailed")))
  {
    {
      return (int)3500;
    }
  }
  {}
  if ((_6524 == std::string ("errXmlInvalidProblemType")))
  {
    {
      return (int)3600;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidAmplStub")))
  {
    {
      return (int)3700;
    }
  }
  {}
  if ((_6524 == std::string ("errInt64ToInt32Cast")))
  {
    {
      return (int)3800;
    }
  }
  {}
  if ((_6524 == std::string ("errSizeLicenseNumcores")))
  {
    {
      return (int)3900;
    }
  }
  {}
  if ((_6524 == std::string ("errInfeasUndefined")))
  {
    {
      return (int)3910;
    }
  }
  {}
  if ((_6524 == std::string ("errNoBarxForSolution")))
  {
    {
      return (int)3915;
    }
  }
  {}
  if ((_6524 == std::string ("errNoBarsForSolution")))
  {
    {
      return (int)3916;
    }
  }
  {}
  if ((_6524 == std::string ("errBarVarDim")))
  {
    {
      return (int)3920;
    }
  }
  {}
  if ((_6524 == std::string ("errSymMatInvalidRowIndex")))
  {
    {
      return (int)3940;
    }
  }
  {}
  if ((_6524 == std::string ("errSymMatInvalidColIndex")))
  {
    {
      return (int)3941;
    }
  }
  {}
  if ((_6524 == std::string ("errSymMatNotLowerTringular")))
  {
    {
      return (int)3942;
    }
  }
  {}
  if ((_6524 == std::string ("errSymMatInvalidValue")))
  {
    {
      return (int)3943;
    }
  }
  {}
  if ((_6524 == std::string ("errSymMatDuplicate")))
  {
    {
      return (int)3944;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidSymMatDim")))
  {
    {
      return (int)3950;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidFileFormatForSymMat")))
  {
    {
      return (int)4000;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidFileFormatForCfix")))
  {
    {
      return (int)4001;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidFileFormatForRangedConstraints")))
  {
    {
      return (int)4002;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidFileFormatForFreeConstraints")))
  {
    {
      return (int)4003;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidFileFormatForCones")))
  {
    {
      return (int)4005;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidFileFormatForNonlinear")))
  {
    {
      return (int)4010;
    }
  }
  {}
  if ((_6524 == std::string ("errDuplicateConstraintNames")))
  {
    {
      return (int)4500;
    }
  }
  {}
  if ((_6524 == std::string ("errDuplicateVariableNames")))
  {
    {
      return (int)4501;
    }
  }
  {}
  if ((_6524 == std::string ("errDuplicateBarvariableNames")))
  {
    {
      return (int)4502;
    }
  }
  {}
  if ((_6524 == std::string ("errDuplicateConeNames")))
  {
    {
      return (int)4503;
    }
  }
  {}
  if ((_6524 == std::string ("errNonUniqueArray")))
  {
    {
      return (int)5000;
    }
  }
  {}
  if ((_6524 == std::string ("errArgumentIsTooLarge")))
  {
    {
      return (int)5005;
    }
  }
  {}
  if ((_6524 == std::string ("errMioInternal")))
  {
    {
      return (int)5010;
    }
  }
  {}
  if ((_6524 == std::string ("errInvalidProblemType")))
  {
    {
      return (int)6000;
    }
  }
  {}
  if ((_6524 == std::string ("errUnhandledSolutionStatus")))
  {
    {
      return (int)6010;
    }
  }
  {}
  if ((_6524 == std::string ("errUpperTriangle")))
  {
    {
      return (int)6020;
    }
  }
  {}
  if ((_6524 == std::string ("errLauSingularMatrix")))
  {
    {
      return (int)7000;
    }
  }
  {}
  if ((_6524 == std::string ("errLauNotPositiveDefinite")))
  {
    {
      return (int)7001;
    }
  }
  {}
  if ((_6524 == std::string ("errLauInvalidLowerTriangularMatrix")))
  {
    {
      return (int)7002;
    }
  }
  {}
  if ((_6524 == std::string ("errLauUnknown")))
  {
    {
      return (int)7005;
    }
  }
  {}
  if ((_6524 == std::string ("errLauArgM")))
  {
    {
      return (int)7010;
    }
  }
  {}
  if ((_6524 == std::string ("errLauArgN")))
  {
    {
      return (int)7011;
    }
  }
  {}
  if ((_6524 == std::string ("errLauArgK")))
  {
    {
      return (int)7012;
    }
  }
  {}
  if ((_6524 == std::string ("errLauArgTransa")))
  {
    {
      return (int)7015;
    }
  }
  {}
  if ((_6524 == std::string ("errLauArgTransb")))
  {
    {
      return (int)7016;
    }
  }
  {}
  if ((_6524 == std::string ("errLauArgUplo")))
  {
    {
      return (int)7017;
    }
  }
  {}
  if ((_6524 == std::string ("errLauArgTrans")))
  {
    {
      return (int)7018;
    }
  }
  {}
  if ((_6524 == std::string ("errLauInvalidSparseSymmetricMatrix")))
  {
    {
      return (int)7019;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfParse")))
  {
    {
      return (int)7100;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfObjSense")))
  {
    {
      return (int)7101;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfNoVariables")))
  {
    {
      return (int)7102;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfTooManyConstraints")))
  {
    {
      return (int)7103;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfTooManyVariables")))
  {
    {
      return (int)7104;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfNoVersionSpecified")))
  {
    {
      return (int)7105;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfSyntax")))
  {
    {
      return (int)7106;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfDuplicateObj")))
  {
    {
      return (int)7107;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfDuplicateCon")))
  {
    {
      return (int)7108;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfDuplicateVar")))
  {
    {
      return (int)7109;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfDuplicateInt")))
  {
    {
      return (int)7110;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfInvalidVarType")))
  {
    {
      return (int)7111;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfInvalidConType")))
  {
    {
      return (int)7112;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfInvalidDomainDimension")))
  {
    {
      return (int)7113;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfDuplicateObjacoord")))
  {
    {
      return (int)7114;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfDuplicateBcoord")))
  {
    {
      return (int)7115;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfDuplicateAcoord")))
  {
    {
      return (int)7116;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfTooFewVariables")))
  {
    {
      return (int)7117;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfTooFewConstraints")))
  {
    {
      return (int)7118;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfTooFewInts")))
  {
    {
      return (int)7119;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfTooManyInts")))
  {
    {
      return (int)7120;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfInvalidIntIndex")))
  {
    {
      return (int)7121;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfUnsupported")))
  {
    {
      return (int)7122;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfDuplicatePsdvar")))
  {
    {
      return (int)7123;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfInvalidPsdvarDimension")))
  {
    {
      return (int)7124;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfTooFewPsdvar")))
  {
    {
      return (int)7125;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfInvalidExpDimension")))
  {
    {
      return (int)7126;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfDuplicatePowCones")))
  {
    {
      return (int)7130;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfDuplicatePowStarCones")))
  {
    {
      return (int)7131;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfInvalidPower")))
  {
    {
      return (int)7132;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfPowerConeIsTooLong")))
  {
    {
      return (int)7133;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfInvalidPowerConeIndex")))
  {
    {
      return (int)7134;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfInvalidPowerStarConeIndex")))
  {
    {
      return (int)7135;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfUnhandledPowerConeType")))
  {
    {
      return (int)7136;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfUnhandledPowerStarConeType")))
  {
    {
      return (int)7137;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfPowerConeMismatch")))
  {
    {
      return (int)7138;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfPowerStarConeMismatch")))
  {
    {
      return (int)7139;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfInvalidNumberOfCones")))
  {
    {
      return (int)7740;
    }
  }
  {}
  if ((_6524 == std::string ("errCbfInvalidDimensionOfCones")))
  {
    {
      return (int)7741;
    }
  }
  {}
  if ((_6524 == std::string ("errMioInvalidRootOptimizer")))
  {
    {
      return (int)7700;
    }
  }
  {}
  if ((_6524 == std::string ("errMioInvalidNodeOptimizer")))
  {
    {
      return (int)7701;
    }
  }
  {}
  if ((_6524 == std::string ("errToconicConstrQNotPsd")))
  {
    {
      return (int)7800;
    }
  }
  {}
  if ((_6524 == std::string ("errToconicConstraintFx")))
  {
    {
      return (int)7801;
    }
  }
  {}
  if ((_6524 == std::string ("errToconicConstraintRa")))
  {
    {
      return (int)7802;
    }
  }
  {}
  if ((_6524 == std::string ("errToconicConstrNotConic")))
  {
    {
      return (int)7803;
    }
  }
  {}
  if ((_6524 == std::string ("errToconicObjectiveNotPsd")))
  {
    {
      return (int)7804;
    }
  }
  {}
  if ((_6524 == std::string ("errServerConnect")))
  {
    {
      return (int)8000;
    }
  }
  {}
  if ((_6524 == std::string ("errServerProtocol")))
  {
    {
      return (int)8001;
    }
  }
  {}
  if ((_6524 == std::string ("errServerStatus")))
  {
    {
      return (int)8002;
    }
  }
  {}
  if ((_6524 == std::string ("errServerToken")))
  {
    {
      return (int)8003;
    }
  }
  {}
  if ((_6524 == std::string ("trmMaxIterations")))
  {
    {
      return (int)10000;
    }
  }
  {}
  if ((_6524 == std::string ("trmMaxTime")))
  {
    {
      return (int)10001;
    }
  }
  {}
  if ((_6524 == std::string ("trmObjectiveRange")))
  {
    {
      return (int)10002;
    }
  }
  {}
  if ((_6524 == std::string ("trmMioNumRelaxs")))
  {
    {
      return (int)10008;
    }
  }
  {}
  if ((_6524 == std::string ("trmMioNumBranches")))
  {
    {
      return (int)10009;
    }
  }
  {}
  if ((_6524 == std::string ("trmNumMaxNumIntSolutions")))
  {
    {
      return (int)10015;
    }
  }
  {}
  if ((_6524 == std::string ("trmStall")))
  {
    {
      return (int)10006;
    }
  }
  {}
  if ((_6524 == std::string ("trmUserCallback")))
  {
    {
      return (int)10007;
    }
  }
  {}
  if ((_6524 == std::string ("trmMaxNumSetbacks")))
  {
    {
      return (int)10020;
    }
  }
  {}
  if ((_6524 == std::string ("trmNumericalProblem")))
  {
    {
      return (int)10025;
    }
  }
  {}
  if ((_6524 == std::string ("trmInternal")))
  {
    {
      return (int)10030;
    }
  }
  {}
  if ((_6524 == std::string ("trmInternalStop")))
  {
    {
      return (int)10031;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_xmlwriteroutputtype_value(const std::string & _6525){
  if ((_6525 == std::string ("row")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6525 == std::string ("col")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_prosta_value(const std::string & _6526){
  if ((_6526 == std::string ("unknown")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6526 == std::string ("primAndDualFeas")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6526 == std::string ("primFeas")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6526 == std::string ("dualFeas")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6526 == std::string ("primInfeas")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6526 == std::string ("dualInfeas")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6526 == std::string ("primAndDualInfeas")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6526 == std::string ("illPosed")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6526 == std::string ("primInfeasOrUnbounded")))
  {
    {
      return (int)8;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_problemtype_value(const std::string & _6527){
  if ((_6527 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6527 == std::string ("qo")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6527 == std::string ("qcqo")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6527 == std::string ("conic")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6527 == std::string ("mixed")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_problemitem_value(const std::string & _6528){
  if ((_6528 == std::string ("var")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6528 == std::string ("con")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6528 == std::string ("cone")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_parametertype_value(const std::string & _6529){
  if ((_6529 == std::string ("invalidType")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6529 == std::string ("douType")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6529 == std::string ("intType")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6529 == std::string ("strType")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_presolvemode_value(const std::string & _6530){
  if ((_6530 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6530 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6530 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_orderingtype_value(const std::string & _6531){
  if ((_6531 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6531 == std::string ("appminloc")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6531 == std::string ("experimental")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6531 == std::string ("tryGraphpar")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6531 == std::string ("forceGraphpar")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6531 == std::string ("none")))
  {
    {
      return (int)5;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_optimizertype_value(const std::string & _6532){
  if ((_6532 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6532 == std::string ("intpnt")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6532 == std::string ("conic")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6532 == std::string ("primalSimplex")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6532 == std::string ("dualSimplex")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6532 == std::string ("freeSimplex")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6532 == std::string ("mixedInt")))
  {
    {
      return (int)5;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_onoffkey_value(const std::string & _6533){
  if ((_6533 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6533 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_objsense_value(const std::string & _6534){
  if ((_6534 == std::string ("minimize")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6534 == std::string ("maximize")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_mpsformat_value(const std::string & _6535){
  if ((_6535 == std::string ("strict")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6535 == std::string ("relaxed")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6535 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6535 == std::string ("cplex")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_mionodeseltype_value(const std::string & _6536){
  if ((_6536 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6536 == std::string ("first")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6536 == std::string ("best")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6536 == std::string ("pseudo")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_miomode_value(const std::string & _6537){
  if ((_6537 == std::string ("ignored")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6537 == std::string ("satisfied")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_miocontsoltype_value(const std::string & _6538){
  if ((_6538 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6538 == std::string ("root")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6538 == std::string ("itg")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6538 == std::string ("itgRel")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_branchdir_value(const std::string & _6539){
  if ((_6539 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6539 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6539 == std::string ("down")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6539 == std::string ("near")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6539 == std::string ("far")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6539 == std::string ("rootLp")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6539 == std::string ("guided")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6539 == std::string ("pseudocost")))
  {
    {
      return (int)7;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_iparam_value(const std::string & _6540){
  if ((_6540 == std::string ("autoUpdateSolInfo")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6540 == std::string ("removeUnusedSolutions")))
  {
    {
      return (int)118;
    }
  }
  {}
  if ((_6540 == std::string ("intpntHotstart")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6540 == std::string ("intpntPurify")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6540 == std::string ("numThreads")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6540 == std::string ("intpntMultiThread")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6540 == std::string ("timingLevel")))
  {
    {
      return (int)152;
    }
  }
  {}
  if ((_6540 == std::string ("mtSpincount")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6540 == std::string ("maxNumWarnings")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6540 == std::string ("optimizer")))
  {
    {
      return (int)97;
    }
  }
  {}
  if ((_6540 == std::string ("biMaxIterations")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6540 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6540 == std::string ("logIncludeSummary")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6540 == std::string ("logCutSecondOpt")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6540 == std::string ("logAnaPro")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6540 == std::string ("logResponse")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6540 == std::string ("logLocalInfo")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6540 == std::string ("logBi")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6540 == std::string ("logBiFreq")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6540 == std::string ("biCleanOptimizer")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6540 == std::string ("intpntMaxNumRefinementSteps")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6540 == std::string ("intpntStartingPoint")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6540 == std::string ("intpntDiffStep")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6540 == std::string ("intpntScaling")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6540 == std::string ("intpntSolveForm")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6540 == std::string ("logIntpnt")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6540 == std::string ("intpntMaxIterations")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6540 == std::string ("intpntOffColTrh")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6540 == std::string ("intpntOrderMethod")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6540 == std::string ("intpntOrderGpNumSeeds")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6540 == std::string ("intpntBasis")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6540 == std::string ("biIgnoreMaxIter")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6540 == std::string ("biIgnoreNumError")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6540 == std::string ("intpntMaxNumCor")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6540 == std::string ("presolveUse")))
  {
    {
      return (int)108;
    }
  }
  {}
  if ((_6540 == std::string ("presolveLevel")))
  {
    {
      return (int)102;
    }
  }
  {}
  if ((_6540 == std::string ("logPresolve")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6540 == std::string ("presolveLindepUse")))
  {
    {
      return (int)105;
    }
  }
  {}
  if ((_6540 == std::string ("presolveMaxNumPass")))
  {
    {
      return (int)106;
    }
  }
  {}
  if ((_6540 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      return (int)101;
    }
  }
  {}
  if ((_6540 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      return (int)100;
    }
  }
  {}
  if ((_6540 == std::string ("presolveMaxNumReductions")))
  {
    {
      return (int)107;
    }
  }
  {}
  if ((_6540 == std::string ("simStabilityPriority")))
  {
    {
      return (int)145;
    }
  }
  {}
  if ((_6540 == std::string ("simPrimalCrash")))
  {
    {
      return (int)134;
    }
  }
  {}
  if ((_6540 == std::string ("logSim")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6540 == std::string ("logSimMinor")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6540 == std::string ("logSimFreq")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6540 == std::string ("simPrimalRestrictSelection")))
  {
    {
      return (int)136;
    }
  }
  {}
  if ((_6540 == std::string ("simPrimalSelection")))
  {
    {
      return (int)137;
    }
  }
  {}
  if ((_6540 == std::string ("simDualRestrictSelection")))
  {
    {
      return (int)126;
    }
  }
  {}
  if ((_6540 == std::string ("simDualSelection")))
  {
    {
      return (int)127;
    }
  }
  {}
  if ((_6540 == std::string ("simMaxIterations")))
  {
    {
      return (int)131;
    }
  }
  {}
  if ((_6540 == std::string ("simHotstartLu")))
  {
    {
      return (int)130;
    }
  }
  {}
  if ((_6540 == std::string ("simRefactorFreq")))
  {
    {
      return (int)138;
    }
  }
  {}
  if ((_6540 == std::string ("simSeed")))
  {
    {
      return (int)143;
    }
  }
  {}
  if ((_6540 == std::string ("mioMode")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6540 == std::string ("logMio")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6540 == std::string ("logMioFreq")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6540 == std::string ("mioMaxNumRelaxs")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6540 == std::string ("mioMaxNumBranches")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6540 == std::string ("mioMaxNumRootCutRounds")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6540 == std::string ("mioMaxNumSolutions")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6540 == std::string ("mioNodeSelection")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6540 == std::string ("mioHeuristicLevel")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6540 == std::string ("mioProbingLevel")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6540 == std::string ("mioCutSelectionLevel")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6540 == std::string ("mioVbDetectionLevel")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6540 == std::string ("mioBranchDir")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6540 == std::string ("mioRootOptimizer")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6540 == std::string ("mioNodeOptimizer")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6540 == std::string ("mioPerspectiveReformulate")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6540 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6540 == std::string ("mioSeed")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6540 == std::string ("mioConicOuterApproximation")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6540 == std::string ("readKeepFreeCon")))
  {
    {
      return (int)112;
    }
  }
  {}
  if ((_6540 == std::string ("readMpsFormat")))
  {
    {
      return (int)115;
    }
  }
  {}
  if ((_6540 == std::string ("writeMpsFormat")))
  {
    {
      return (int)170;
    }
  }
  {}
  if ((_6540 == std::string ("readMpsWidth")))
  {
    {
      return (int)116;
    }
  }
  {}
  if ((_6540 == std::string ("readDebug")))
  {
    {
      return (int)111;
    }
  }
  {}
  if ((_6540 == std::string ("readLpQuotedNames")))
  {
    {
      return (int)114;
    }
  }
  {}
  if ((_6540 == std::string ("writeDataParam")))
  {
    {
      return (int)157;
    }
  }
  {}
  if ((_6540 == std::string ("writeFreeCon")))
  {
    {
      return (int)158;
    }
  }
  {}
  if ((_6540 == std::string ("writeGenericNames")))
  {
    {
      return (int)159;
    }
  }
  {}
  if ((_6540 == std::string ("writeGenericNamesIo")))
  {
    {
      return (int)160;
    }
  }
  {}
  if ((_6540 == std::string ("writeCompression")))
  {
    {
      return (int)156;
    }
  }
  {}
  if ((_6540 == std::string ("writeMpsInt")))
  {
    {
      return (int)171;
    }
  }
  {}
  if ((_6540 == std::string ("writeLpStrictFormat")))
  {
    {
      return (int)168;
    }
  }
  {}
  if ((_6540 == std::string ("writeLpQuotedNames")))
  {
    {
      return (int)167;
    }
  }
  {}
  if ((_6540 == std::string ("writeLpLineWidth")))
  {
    {
      return (int)166;
    }
  }
  {}
  if ((_6540 == std::string ("writeLpTermsPerLine")))
  {
    {
      return (int)169;
    }
  }
  {}
  if ((_6540 == std::string ("writeLpFullObj")))
  {
    {
      return (int)165;
    }
  }
  {}
  if ((_6540 == std::string ("writePrecision")))
  {
    {
      return (int)172;
    }
  }
  {}
  if ((_6540 == std::string ("writeSolIgnoreInvalidNames")))
  {
    {
      return (int)176;
    }
  }
  {}
  if ((_6540 == std::string ("writeSolHead")))
  {
    {
      return (int)175;
    }
  }
  {}
  if ((_6540 == std::string ("writeSolConstraints")))
  {
    {
      return (int)174;
    }
  }
  {}
  if ((_6540 == std::string ("writeSolVariables")))
  {
    {
      return (int)177;
    }
  }
  {}
  if ((_6540 == std::string ("writeSolBarvariables")))
  {
    {
      return (int)173;
    }
  }
  {}
  if ((_6540 == std::string ("writeBasHead")))
  {
    {
      return (int)154;
    }
  }
  {}
  if ((_6540 == std::string ("writeBasConstraints")))
  {
    {
      return (int)153;
    }
  }
  {}
  if ((_6540 == std::string ("writeBasVariables")))
  {
    {
      return (int)155;
    }
  }
  {}
  if ((_6540 == std::string ("writeIntHead")))
  {
    {
      return (int)163;
    }
  }
  {}
  if ((_6540 == std::string ("writeIntConstraints")))
  {
    {
      return (int)162;
    }
  }
  {}
  if ((_6540 == std::string ("writeIntVariables")))
  {
    {
      return (int)164;
    }
  }
  {}
  if ((_6540 == std::string ("solReadNameWidth")))
  {
    {
      return (int)149;
    }
  }
  {}
  if ((_6540 == std::string ("solReadWidth")))
  {
    {
      return (int)150;
    }
  }
  {}
  if ((_6540 == std::string ("infeasReportAuto")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6540 == std::string ("infeasReportLevel")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6540 == std::string ("infeasGenericNames")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6540 == std::string ("logInfeasAna")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6540 == std::string ("licenseWait")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6540 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6540 == std::string ("licensePauseTime")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6540 == std::string ("licenseDebug")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6540 == std::string ("solFilterKeepBasic")))
  {
    {
      return (int)147;
    }
  }
  {}
  if ((_6540 == std::string ("solFilterKeepRanged")))
  {
    {
      return (int)148;
    }
  }
  {}
  if ((_6540 == std::string ("log")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6540 == std::string ("logExpand")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6540 == std::string ("logFile")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6540 == std::string ("logOrder")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6540 == std::string ("logSensitivity")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6540 == std::string ("logSensitivityOpt")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6540 == std::string ("readTaskIgnoreParam")))
  {
    {
      return (int)117;
    }
  }
  {}
  if ((_6540 == std::string ("writeTaskIncSol")))
  {
    {
      return (int)178;
    }
  }
  {}
  if ((_6540 == std::string ("paramReadCaseName")))
  {
    {
      return (int)98;
    }
  }
  {}
  if ((_6540 == std::string ("paramReadIgnError")))
  {
    {
      return (int)99;
    }
  }
  {}
  if ((_6540 == std::string ("solutionCallback")))
  {
    {
      return (int)151;
    }
  }
  {}
  if ((_6540 == std::string ("simScaling")))
  {
    {
      return (int)141;
    }
  }
  {}
  if ((_6540 == std::string ("simScalingMethod")))
  {
    {
      return (int)142;
    }
  }
  {}
  if ((_6540 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      return (int)135;
    }
  }
  {}
  if ((_6540 == std::string ("simDualPhaseoneMethod")))
  {
    {
      return (int)125;
    }
  }
  {}
  if ((_6540 == std::string ("simMaxNumSetbacks")))
  {
    {
      return (int)132;
    }
  }
  {}
  if ((_6540 == std::string ("simHotstart")))
  {
    {
      return (int)129;
    }
  }
  {}
  if ((_6540 == std::string ("simBasisFactorUse")))
  {
    {
      return (int)122;
    }
  }
  {}
  if ((_6540 == std::string ("simDegen")))
  {
    {
      return (int)123;
    }
  }
  {}
  if ((_6540 == std::string ("simReformulation")))
  {
    {
      return (int)139;
    }
  }
  {}
  if ((_6540 == std::string ("simExploitDupvec")))
  {
    {
      return (int)128;
    }
  }
  {}
  if ((_6540 == std::string ("simSaveLu")))
  {
    {
      return (int)140;
    }
  }
  {}
  if ((_6540 == std::string ("simNonSingular")))
  {
    {
      return (int)133;
    }
  }
  {}
  if ((_6540 == std::string ("simDualCrash")))
  {
    {
      return (int)124;
    }
  }
  {}
  if ((_6540 == std::string ("logStorage")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6540 == std::string ("infeasPreferPrimal")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6540 == std::string ("readLpDropNewVarsInBou")))
  {
    {
      return (int)113;
    }
  }
  {}
  if ((_6540 == std::string ("opfWriteLineLength")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6540 == std::string ("opfWriteHints")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6540 == std::string ("opfWriteParameters")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6540 == std::string ("opfWriteProblem")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6540 == std::string ("opfWriteHeader")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6540 == std::string ("opfWriteSolutions")))
  {
    {
      return (int)96;
    }
  }
  {}
  if ((_6540 == std::string ("opfWriteSolBas")))
  {
    {
      return (int)93;
    }
  }
  {}
  if ((_6540 == std::string ("opfWriteSolItg")))
  {
    {
      return (int)94;
    }
  }
  {}
  if ((_6540 == std::string ("opfWriteSolItr")))
  {
    {
      return (int)95;
    }
  }
  {}
  if ((_6540 == std::string ("ptfWriteTransform")))
  {
    {
      return (int)110;
    }
  }
  {}
  if ((_6540 == std::string ("primalRepairOptimizer")))
  {
    {
      return (int)109;
    }
  }
  {}
  if ((_6540 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6540 == std::string ("mioCutCmir")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6540 == std::string ("mioCutClique")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6540 == std::string ("mioCutImpliedBound")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6540 == std::string ("mioCutKnapsackCover")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6540 == std::string ("mioCutGmi")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6540 == std::string ("sensitivityType")))
  {
    {
      return (int)121;
    }
  }
  {}
  if ((_6540 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      return (int)104;
    }
  }
  {}
  if ((_6540 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      return (int)103;
    }
  }
  {}
  if ((_6540 == std::string ("sensitivityAll")))
  {
    {
      return (int)119;
    }
  }
  {}
  if ((_6540 == std::string ("logFeasRepair")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6540 == std::string ("cacheLicense")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6540 == std::string ("intpntRegularizationUse")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6540 == std::string ("simSolveForm")))
  {
    {
      return (int)144;
    }
  }
  {}
  if ((_6540 == std::string ("simSwitchOptimizer")))
  {
    {
      return (int)146;
    }
  }
  {}
  if ((_6540 == std::string ("writeIgnoreIncompatibleItems")))
  {
    {
      return (int)161;
    }
  }
  {}
  if ((_6540 == std::string ("checkConvexity")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6540 == std::string ("logCheckConvexity")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6540 == std::string ("autoSortABeforeOpt")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6540 == std::string ("sensitivityOptimizer")))
  {
    {
      return (int)120;
    }
  }
  {}
  if ((_6540 == std::string ("writeXmlMode")))
  {
    {
      return (int)179;
    }
  }
  {}
  if ((_6540 == std::string ("anaSolBasis")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6540 == std::string ("anaSolPrintViolated")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6540 == std::string ("basisSolveUsePlusOne")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6540 == std::string ("compressStatfile")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6540 == std::string ("mioRinsMaxNodes")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6540 == std::string ("mioFeaspumpLevel")))
  {
    {
      return (int)69;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_iomode_value(const std::string & _6541){
  if ((_6541 == std::string ("read")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6541 == std::string ("write")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6541 == std::string ("readwrite")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_internal_iinf_value(const std::string & _6542){
  if ((_6542 == std::string ("versionMajor")))
  {
    {
      return (int)95;
    }
  }
  {}
  if ((_6542 == std::string ("versionMinor")))
  {
    {
      return (int)96;
    }
  }
  {}
  if ((_6542 == std::string ("versionRevision")))
  {
    {
      return (int)97;
    }
  }
  {}
  if ((_6542 == std::string ("presolveLindepWork")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6542 == std::string ("presolveLindepPivots")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6542 == std::string ("presolveLindepSkipped")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6542 == std::string ("presolveOutofspace")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6542 == std::string ("presolveBadPrecision")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6542 == std::string ("optObjectiveSense")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6542 == std::string ("optimizer")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6542 == std::string ("intpntFirRefIter")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6542 == std::string ("intpntNumRefSteps")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6542 == std::string ("intpntFactorDim")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6542 == std::string ("intpntFactorSchurNumSingular")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6542 == std::string ("intpntFactorNumDenseA")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6542 == std::string ("intpntFactorNumDenseADup")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6542 == std::string ("intpntFactorNumDenseW")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6542 == std::string ("intpntNumcon")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6542 == std::string ("intpntNumvar")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6542 == std::string ("intpntNumbarvar")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6542 == std::string ("intpntNumblo")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6542 == std::string ("intpntNumbup")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6542 == std::string ("intpntNumbfr")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6542 == std::string ("intpntNumbfx")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6542 == std::string ("intpntNumcone")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6542 == std::string ("intpntNumconevar")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6542 == std::string ("intpntNumbndcone")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6542 == std::string ("intpntNumrqcones")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6542 == std::string ("intpntNumqcones")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6542 == std::string ("intpntNumpexpcones")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6542 == std::string ("intpntNumppowcones")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6542 == std::string ("intpntMinconedim")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6542 == std::string ("intpntMaxconedim")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6542 == std::string ("intpntMaxbarvardim")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6542 == std::string ("presolveNumcon")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6542 == std::string ("presolveNumcfr")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6542 == std::string ("presolveNumcfx")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6542 == std::string ("presolveNumclo")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6542 == std::string ("presolveNumcup")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6542 == std::string ("presolveNumcra")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6542 == std::string ("presolveNumcnl")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6542 == std::string ("presolveNumvar")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6542 == std::string ("presolveNumvfr")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6542 == std::string ("presolveNumvfx")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6542 == std::string ("presolveNumvlo")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6542 == std::string ("presolveNumvup")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6542 == std::string ("presolveNumvra")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6542 == std::string ("presolveNumvnl")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6542 == std::string ("presolveNumnza")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6542 == std::string ("presolveFnumcon")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6542 == std::string ("presolveFnumcfr")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6542 == std::string ("presolveFnumcfx")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6542 == std::string ("presolveFnumclo")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6542 == std::string ("presolveFnumcup")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6542 == std::string ("presolveFnumcra")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6542 == std::string ("presolveFnumcnl")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6542 == std::string ("presolveFnumvar")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6542 == std::string ("presolveFnumvfr")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6542 == std::string ("presolveFnumvfx")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6542 == std::string ("presolveFnumvlo")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6542 == std::string ("presolveFnumvup")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6542 == std::string ("presolveFnumvra")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6542 == std::string ("presolveFnumvnl")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6542 == std::string ("presolveFnumnza")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6542 == std::string ("presolveNumElimns")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6542 == std::string ("presolveEliNumTries")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6542 == std::string ("presolveEliNumFreedCon")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6542 == std::string ("presolveEliNumFreedConTotal")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6542 == std::string ("presolveLindepNumTries")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6542 == std::string ("presolveLindepNum")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6542 == std::string ("presolveForceConNum")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6542 == std::string ("presolveForceConNumVar")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6542 == std::string ("presolveForceVarNum")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6542 == std::string ("presolveForceVarNumCon")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6542 == std::string ("presolvePivOnConNum")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6542 == std::string ("presolveNumDouBlocks")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6542 == std::string ("presolveNumSimplifiedDouBlocks")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6542 == std::string ("presolveSizeSimplifiedDouBlocks")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6542 == std::string ("presolveNumQuadConeOrthoTrans")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6542 == std::string ("intpntFactorNum")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6542 == std::string ("intpntFactorNumSolve")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6542 == std::string ("simPrimalHotstartNumBasics")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6542 == std::string ("simPrimalHotstartBasisRank")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6542 == std::string ("simDualHotstartNumBasics")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6542 == std::string ("simDualHotstartBasisRank")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6542 == std::string ("intpntGpOrderEmployed")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6542 == std::string ("numLuFactorizations")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6542 == std::string ("simPrimalTrust")))
  {
    {
      return (int)94;
    }
  }
  {}
  if ((_6542 == std::string ("simDualTrust")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6542 == std::string ("simPrimalNumSetbacks")))
  {
    {
      return (int)93;
    }
  }
  {}
  if ((_6542 == std::string ("simDualNumSetbacks")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6542 == std::string ("simNumDupvec")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6542 == std::string ("simNumPrimalBoundswaps")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6542 == std::string ("simNumDualBoundswaps")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6542 == std::string ("simNumDualIntegerPivots")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6542 == std::string ("biPrimalInfo")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6542 == std::string ("biDualInfo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6542 == std::string ("presolveLindepNumTruncTries")))
  {
    {
      return (int)57;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_internal_dinf_value(const std::string & _6543){
  if ((_6543 == std::string ("sensitivityPrimalTime")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6543 == std::string ("sensitivityDualTime")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6543 == std::string ("intpntGfeas")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6543 == std::string ("intpntMu")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6543 == std::string ("intpntInitIterTime")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorTime")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6543 == std::string ("intpntInitSearchTime")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFormSearchTime")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6543 == std::string ("intpntUpdateTime")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorSetupTime")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorSchurTime")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorHatSchurTime")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorHatSchurPushTime")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorHatSchurPullTime")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorBarSchurTime")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorBarSchurDeTabTime")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorBarSchurSpTabTime")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorSparseLTime")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorSparseLUpdateLastTime")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorSparseLFactorLastTime")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorDenseLTime")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorDenseTime")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorDenseDotaTime")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorDenseDotaSolveTime")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorDenseDotatdotaTime")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorDenseDotlInitTime")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorDenseDotlFactorTime")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6543 == std::string ("intpntIterNonCorrectorFlops")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6543 == std::string ("intpntIterOneCorrectorFlops")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6543 == std::string ("intpntSolveTime")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6543 == std::string ("intpntIterRefTime")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6543 == std::string ("intpntSolveSparseLTime")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6543 == std::string ("intpntSolveDenseLTime")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorSetupFlops")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorSetupHatSchurFlops")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorSchurFlops")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorHatSchurFlops")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorHatSchurPushFlops")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorHatSchurPullFlops")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorBarSchurFlops")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorSparseLFlops")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorMlOrderSparseLFlops")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorGpOrderSparseLFlops")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorSparseLUpdateLastFlops")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorSparseLFactorLastFlops")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorDenseLFlops")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorDenseFlops")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorDenseDotaFlops")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorDenseDotatdotaFlops")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorDenseDotlFactor_initFlops")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorDenseDotlFactorFlops")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorDenseDotl11FactorFlops")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorDenseDotl21FactorFlops")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorDenseDotl22FactorFlops")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6543 == std::string ("presolveAcoltTime")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6543 == std::string ("presolveSetupTime")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6543 == std::string ("presolveCheckproTime")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6543 == std::string ("presolveDupconTime")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6543 == std::string ("presolveDupvarTime")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6543 == std::string ("presolveFinalTime")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6543 == std::string ("presolveSubDomvarTime")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6543 == std::string ("presolveSubRelaxTime")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6543 == std::string ("primalSimplexInftime")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6543 == std::string ("dualSimplexInftime")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6543 == std::string ("intpntGpOrderSavedFlops")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorSetupDetectDenseTime")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorSetupMlOrderTime")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6543 == std::string ("intpntFactorSetupGpOrderTime")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6543 == std::string ("biCrashTime")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6543 == std::string ("biCrashLuTime")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6543 == std::string ("biFactorTime")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6543 == std::string ("biFactorWork")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6543 == std::string ("biPrimalDone")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6543 == std::string ("biDualDone")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6543 == std::string ("simPrimalObj")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6543 == std::string ("simPrimalFeas")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6543 == std::string ("simDualObj")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6543 == std::string ("simDualFeas")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6543 == std::string ("biPrimalObj")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6543 == std::string ("biDualObj")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6543 == std::string ("biPrimalFeas")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6543 == std::string ("biDualFeas")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6543 == std::string ("intpntPurifyTime")))
  {
    {
      return (int)63;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_inftype_value(const std::string & _6544){
  if ((_6544 == std::string ("douType")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6544 == std::string ("intType")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6544 == std::string ("lintType")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_iinfitem_value(const std::string & _6545){
  if ((_6545 == std::string ("anaProNumCon")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6545 == std::string ("anaProNumConLo")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6545 == std::string ("anaProNumConUp")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6545 == std::string ("anaProNumConRa")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6545 == std::string ("anaProNumConEq")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6545 == std::string ("anaProNumConFr")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6545 == std::string ("anaProNumVar")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6545 == std::string ("anaProNumVarLo")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6545 == std::string ("anaProNumVarUp")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6545 == std::string ("anaProNumVarRa")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6545 == std::string ("anaProNumVarEq")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6545 == std::string ("anaProNumVarFr")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6545 == std::string ("anaProNumVarCont")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6545 == std::string ("anaProNumVarBin")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6545 == std::string ("anaProNumVarInt")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6545 == std::string ("optimizeResponse")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6545 == std::string ("intpntIter")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6545 == std::string ("intpntFactorDimDense")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6545 == std::string ("intpntSolveDual")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6545 == std::string ("mioNodeDepth")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumvar")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumbin")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumint")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumcont")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumcon")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumcone")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumqcones")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumrqcones")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumpexpcones")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumdexpcones")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumppowcones")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumdpowcones")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumconevar")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumbinconevar")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumintconevar")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumcontconevar")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6545 == std::string ("mioPresolvedNumvar")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6545 == std::string ("mioPresolvedNumbin")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6545 == std::string ("mioPresolvedNumint")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6545 == std::string ("mioPresolvedNumcont")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6545 == std::string ("mioPresolvedNumcon")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6545 == std::string ("mioPresolvedNumcone")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6545 == std::string ("mioPresolvedNumqcones")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6545 == std::string ("mioPresolvedNumrqcones")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6545 == std::string ("mioPresolvedNumpexpcones")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6545 == std::string ("mioPresolvedNumdexpcones")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6545 == std::string ("mioPresolvedNumppowcones")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6545 == std::string ("mioPresolvedNumdpowcones")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6545 == std::string ("mioPresolvedNumconevar")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6545 == std::string ("mioPresolvedNumbinconevar")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6545 == std::string ("mioPresolvedNumintconevar")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6545 == std::string ("mioPresolvedNumcontconevar")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6545 == std::string ("mioCliqueTableSize")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6545 == std::string ("mioConstructSolution")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumIntSolutions")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6545 == std::string ("mioObjBoundDefined")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumActiveNodes")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumRelax")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumBranch")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6545 == std::string ("mioTotalNumCuts")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumCmirCuts")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumCliqueCuts")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumImpliedBoundCuts")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumKnapsackCoverCuts")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumGomoryCuts")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6545 == std::string ("mioNumRepeatedPresolve")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6545 == std::string ("mioUserObjCut")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6545 == std::string ("mioRelgapSatisfied")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6545 == std::string ("mioAbsgapSatisfied")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6545 == std::string ("rdProtype")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6545 == std::string ("rdNumcon")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6545 == std::string ("rdNumvar")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6545 == std::string ("rdNumbarvar")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6545 == std::string ("rdNumintvar")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6545 == std::string ("rdNumq")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6545 == std::string ("simDualDegIter")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6545 == std::string ("simDualInfIter")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6545 == std::string ("simDualHotstartLu")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6545 == std::string ("simPrimalIter")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6545 == std::string ("simDualIter")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6545 == std::string ("intpntNumThreads")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6545 == std::string ("simPrimalInfIter")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6545 == std::string ("simPrimalDegIter")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6545 == std::string ("simPrimalHotstart")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6545 == std::string ("simPrimalHotstartLu")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6545 == std::string ("simDualHotstart")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6545 == std::string ("solItrProsta")))
  {
    {
      return (int)98;
    }
  }
  {}
  if ((_6545 == std::string ("solItrSolsta")))
  {
    {
      return (int)99;
    }
  }
  {}
  if ((_6545 == std::string ("solBasProsta")))
  {
    {
      return (int)94;
    }
  }
  {}
  if ((_6545 == std::string ("solBasSolsta")))
  {
    {
      return (int)95;
    }
  }
  {}
  if ((_6545 == std::string ("solItgProsta")))
  {
    {
      return (int)96;
    }
  }
  {}
  if ((_6545 == std::string ("solItgSolsta")))
  {
    {
      return (int)97;
    }
  }
  {}
  if ((_6545 == std::string ("simNumcon")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6545 == std::string ("simNumvar")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6545 == std::string ("optNumcon")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6545 == std::string ("optNumvar")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6545 == std::string ("stoNumARealloc")))
  {
    {
      return (int)100;
    }
  }
  {}
  if ((_6545 == std::string ("rdNumcone")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6545 == std::string ("simSolveDual")))
  {
    {
      return (int)93;
    }
  }
  {}
  if ((_6545 == std::string ("purifyPrimalSuccess")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6545 == std::string ("purifyDualSuccess")))
  {
    {
      return (int)72;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_internal_liinf_value(const std::string & _6546){
  if ((_6546 == std::string ("intpntLenbarvar")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6546 == std::string ("intpntFactorNumNzBefore")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6546 == std::string ("intpntFactorNumNzAfter")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6546 == std::string ("intpntFactorMlOrderSparseLNz")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6546 == std::string ("intpntFactorGpOrderSparseLNz")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6546 == std::string ("presolveStackSize")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6546 == std::string ("intpntFactorVNz")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6546 == std::string ("intpntFactorUpdatedVNz")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_liinfitem_value(const std::string & _6547){
  if ((_6547 == std::string ("mioAnz")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6547 == std::string ("mioPresolvedAnz")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6547 == std::string ("mioSimplexIter")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6547 == std::string ("mioIntpntIter")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6547 == std::string ("biPrimalIter")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6547 == std::string ("biDualIter")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6547 == std::string ("biCleanPrimalIter")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6547 == std::string ("biCleanDualIter")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6547 == std::string ("biCleanPrimalDegIter")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6547 == std::string ("biCleanDualDegIter")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6547 == std::string ("intpntFactorNumNz")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6547 == std::string ("rdNumanz")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6547 == std::string ("rdNumqnz")))
  {
    {
      return (int)12;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_dparam_value(const std::string & _6548){
  if ((_6548 == std::string ("dataTolCjLarge")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6548 == std::string ("dataTolCHuge")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6548 == std::string ("dataTolAijLarge")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6548 == std::string ("dataTolAijHuge")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6548 == std::string ("dataSymMatTol")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6548 == std::string ("dataSymMatTolLarge")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6548 == std::string ("dataSymMatTolHuge")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6548 == std::string ("dataTolBoundInf")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6548 == std::string ("dataTolBoundWrn")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6548 == std::string ("dataTolQij")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6548 == std::string ("dataTolX")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6548 == std::string ("semidefiniteTolApprox")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6548 == std::string ("optimizerMaxTime")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6548 == std::string ("lowerObjCut")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6548 == std::string ("upperObjCut")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6548 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6548 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6548 == std::string ("intpntTolRelGap")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6548 == std::string ("intpntTolStepSize")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6548 == std::string ("simLuTolRelPiv")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6548 == std::string ("intpntTolRelStep")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6548 == std::string ("intpntTolPath")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6548 == std::string ("intpntTolPfeas")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6548 == std::string ("intpntTolDfeas")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6548 == std::string ("intpntTolMuRed")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6548 == std::string ("intpntTolInfeas")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6548 == std::string ("intpntCoTolRelGap")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6548 == std::string ("intpntCoTolPfeas")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6548 == std::string ("intpntCoTolDfeas")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6548 == std::string ("intpntCoTolMuRed")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6548 == std::string ("intpntCoTolNearRel")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6548 == std::string ("intpntCoTolInfeas")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6548 == std::string ("intpntQoTolRelGap")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6548 == std::string ("intpntQoTolPfeas")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6548 == std::string ("intpntQoTolDfeas")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6548 == std::string ("intpntQoTolMuRed")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6548 == std::string ("intpntQoTolNearRel")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6548 == std::string ("intpntQoTolInfeas")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6548 == std::string ("intpntTolPsafe")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6548 == std::string ("intpntTolDsafe")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6548 == std::string ("mioMaxTime")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6548 == std::string ("mioRelGapConst")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6548 == std::string ("mioTolRelGap")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6548 == std::string ("mioTolAbsGap")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6548 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6548 == std::string ("basisTolX")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6548 == std::string ("basisTolS")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6548 == std::string ("basisRelTolS")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6548 == std::string ("presolveTolX")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6548 == std::string ("presolveTolS")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6548 == std::string ("presolveTolAij")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6548 == std::string ("presolveTolAbsLindep")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6548 == std::string ("presolveTolRelLindep")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6548 == std::string ("simplexAbsTolPiv")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6548 == std::string ("mioTolFeas")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6548 == std::string ("anaSolInfeasTol")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6548 == std::string ("checkConvexityRelTol")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6548 == std::string ("qcqoReformulateRelDropTol")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6548 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      return (int)45;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_feature_value(const std::string & _6549){
  if ((_6549 == std::string ("pts")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6549 == std::string ("pton")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_dinfitem_value(const std::string & _6550){
  if ((_6550 == std::string ("biTime")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6550 == std::string ("biPrimalTime")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6550 == std::string ("biDualTime")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6550 == std::string ("biCleanTime")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6550 == std::string ("biCleanPrimalTime")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6550 == std::string ("biCleanDualTime")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6550 == std::string ("intpntTime")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6550 == std::string ("intpntOrderTime")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6550 == std::string ("intpntPrimalObj")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6550 == std::string ("intpntDualObj")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6550 == std::string ("intpntPrimalFeas")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6550 == std::string ("intpntDualFeas")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6550 == std::string ("intpntOptStatus")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6550 == std::string ("simTime")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6550 == std::string ("simPrimalTime")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6550 == std::string ("simDualTime")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6550 == std::string ("simObj")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6550 == std::string ("simFeas")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6550 == std::string ("mioTime")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6550 == std::string ("mioRootPresolveTime")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6550 == std::string ("mioRootOptimizerTime")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6550 == std::string ("toConicTime")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6550 == std::string ("mioConstructSolutionObj")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6550 == std::string ("mioObjInt")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6550 == std::string ("mioObjBound")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6550 == std::string ("mioObjRelGap")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6550 == std::string ("mioObjAbsGap")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6550 == std::string ("mioUserObjCut")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6550 == std::string ("mioCmirSeparationTime")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6550 == std::string ("mioCliqueSeparationTime")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6550 == std::string ("mioKnapsackCoverSeparationTime")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6550 == std::string ("mioGmiSeparationTime")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6550 == std::string ("mioImpliedBoundTime")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6550 == std::string ("mioRootCutgenTime")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6550 == std::string ("mioProbingTime")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6550 == std::string ("optimizerTime")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6550 == std::string ("presolveTime")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6550 == std::string ("mioDualBoundAfterPresolve")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6550 == std::string ("presolveEliTime")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6550 == std::string ("presolveLindepTime")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6550 == std::string ("rdTime")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6550 == std::string ("solItrPrimalObj")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6550 == std::string ("solItrPviolcon")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6550 == std::string ("solItrPviolvar")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6550 == std::string ("solItrPviolbarvar")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6550 == std::string ("solItrPviolcones")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6550 == std::string ("solItrDualObj")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6550 == std::string ("solItrDviolcon")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6550 == std::string ("solItrDviolvar")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6550 == std::string ("solItrDviolbarvar")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6550 == std::string ("solItrDviolcones")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6550 == std::string ("solItrNrmXc")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6550 == std::string ("solItrNrmXx")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6550 == std::string ("solItrNrmBarx")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6550 == std::string ("solItrNrmY")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6550 == std::string ("solItrNrmSlc")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6550 == std::string ("solItrNrmSuc")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6550 == std::string ("solItrNrmSlx")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6550 == std::string ("solItrNrmSux")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6550 == std::string ("solItrNrmSnx")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6550 == std::string ("solItrNrmBars")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6550 == std::string ("solBasPrimalObj")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6550 == std::string ("solBasPviolcon")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6550 == std::string ("solBasPviolvar")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6550 == std::string ("solBasDualObj")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6550 == std::string ("solBasDviolcon")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6550 == std::string ("solBasDviolvar")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6550 == std::string ("solBasNrmXc")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6550 == std::string ("solBasNrmXx")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6550 == std::string ("solBasNrmBarx")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6550 == std::string ("solBasNrmY")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6550 == std::string ("solBasNrmSlc")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6550 == std::string ("solBasNrmSuc")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6550 == std::string ("solBasNrmSlx")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6550 == std::string ("solBasNrmSux")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6550 == std::string ("solItgPrimalObj")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6550 == std::string ("solItgPviolcon")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6550 == std::string ("solItgPviolvar")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6550 == std::string ("solItgPviolbarvar")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6550 == std::string ("solItgPviolcones")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6550 == std::string ("solItgPviolitg")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6550 == std::string ("solItgNrmXc")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6550 == std::string ("solItgNrmXx")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6550 == std::string ("solItgNrmBarx")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6550 == std::string ("intpntFactorNumFlops")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6550 == std::string ("qcqoReformulateTime")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6550 == std::string ("qcqoReformulateMaxPerturbation")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6550 == std::string ("qcqoReformulateWorstCholeskyDiagScaling")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6550 == std::string ("qcqoReformulateWorstCholeskyColumnScaling")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6550 == std::string ("primalRepairPenaltyObj")))
  {
    {
      return (int)35;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_dataformat_value(const std::string & _6551){
  if ((_6551 == std::string ("extension")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6551 == std::string ("mps")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6551 == std::string ("lp")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6551 == std::string ("op")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6551 == std::string ("freeMps")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6551 == std::string ("task")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6551 == std::string ("ptf")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6551 == std::string ("cb")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6551 == std::string ("jsonTask")))
  {
    {
      return (int)8;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_symmattype_value(const std::string & _6552){
  if ((_6552 == std::string ("sparse")))
  {
    {
      return (int)0;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_scopr_value(const std::string & _6553){
  if ((_6553 == std::string ("ent")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6553 == std::string ("exp")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6553 == std::string ("log")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6553 == std::string ("pow")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6553 == std::string ("sqrt")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_nametype_value(const std::string & _6554){
  if ((_6554 == std::string ("gen")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6554 == std::string ("mps")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6554 == std::string ("lp")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_conetype_value(const std::string & _6555){
  if ((_6555 == std::string ("quad")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6555 == std::string ("rquad")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6555 == std::string ("pexp")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6555 == std::string ("dexp")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6555 == std::string ("ppow")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6555 == std::string ("dpow")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6555 == std::string ("zero")))
  {
    {
      return (int)6;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_compresstype_value(const std::string & _6556){
  if ((_6556 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6556 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6556 == std::string ("gzip")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6556 == std::string ("zstd")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_checkconvexitytype_value(const std::string & _6557){
  if ((_6557 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6557 == std::string ("simple")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6557 == std::string ("full")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_callbackcode_value(const std::string & _6558){
  if ((_6558 == std::string ("beginRootCutgen")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6558 == std::string ("imRootCutgen")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6558 == std::string ("endRootCutgen")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6558 == std::string ("beginOptimizer")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6558 == std::string ("endOptimizer")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6558 == std::string ("beginPresolve")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6558 == std::string ("updatePresolve")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6558 == std::string ("imPresolve")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6558 == std::string ("endPresolve")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6558 == std::string ("beginIntpnt")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6558 == std::string ("intpnt")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6558 == std::string ("imIntpnt")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6558 == std::string ("endIntpnt")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6558 == std::string ("beginConic")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6558 == std::string ("conic")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6558 == std::string ("imConic")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6558 == std::string ("endConic")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6558 == std::string ("primalSimplex")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6558 == std::string ("dualSimplex")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6558 == std::string ("beginBi")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6558 == std::string ("imBi")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6558 == std::string ("endBi")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6558 == std::string ("beginPrimalBi")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6558 == std::string ("imPrimalBi")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6558 == std::string ("updatePrimalBi")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6558 == std::string ("endPrimalBi")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6558 == std::string ("beginDualBi")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6558 == std::string ("imDualBi")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6558 == std::string ("updateDualBi")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6558 == std::string ("endDualBi")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6558 == std::string ("beginSimplexBi")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6558 == std::string ("imSimplexBi")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6558 == std::string ("beginPrimalSimplexBi")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6558 == std::string ("updatePrimalSimplexBi")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6558 == std::string ("endPrimalSimplexBi")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6558 == std::string ("beginDualSimplexBi")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6558 == std::string ("updateDualSimplexBi")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6558 == std::string ("endDualSimplexBi")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6558 == std::string ("endSimplexBi")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6558 == std::string ("beginMio")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6558 == std::string ("imMio")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6558 == std::string ("newIntMio")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6558 == std::string ("endMio")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6558 == std::string ("beginSimplex")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6558 == std::string ("beginDualSimplex")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6558 == std::string ("imDualSimplex")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6558 == std::string ("updateDualSimplex")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6558 == std::string ("endDualSimplex")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6558 == std::string ("beginPrimalSimplex")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6558 == std::string ("imPrimalSimplex")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6558 == std::string ("updatePrimalSimplex")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6558 == std::string ("endPrimalSimplex")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6558 == std::string ("endSimplex")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6558 == std::string ("beginInfeasAna")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6558 == std::string ("endInfeasAna")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6558 == std::string ("imPrimalSensivity")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6558 == std::string ("imDualSensivity")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6558 == std::string ("imMioIntpnt")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6558 == std::string ("imMioPrimalSimplex")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6558 == std::string ("imMioDualSimplex")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6558 == std::string ("beginPrimalSetupBi")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6558 == std::string ("endPrimalSetupBi")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6558 == std::string ("beginDualSetupBi")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6558 == std::string ("endDualSetupBi")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6558 == std::string ("beginPrimalSensitivity")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6558 == std::string ("endPrimalSensitivity")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6558 == std::string ("beginDualSensitivity")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6558 == std::string ("endDualSensitivity")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6558 == std::string ("beginLicenseWait")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6558 == std::string ("endLicenseWait")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6558 == std::string ("imLicenseWait")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6558 == std::string ("beginQcqoReformulate")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6558 == std::string ("endQcqoReformulate")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6558 == std::string ("imQoReformulate")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6558 == std::string ("beginToConic")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6558 == std::string ("endToConic")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6558 == std::string ("beginFullConvexityCheck")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6558 == std::string ("endFullConvexityCheck")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6558 == std::string ("imFullConvexityCheck")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6558 == std::string ("beginPrimalRepair")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6558 == std::string ("endPrimalRepair")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6558 == std::string ("beginRead")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6558 == std::string ("imRead")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6558 == std::string ("endRead")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6558 == std::string ("beginWrite")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6558 == std::string ("endWrite")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6558 == std::string ("readOpfSection")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6558 == std::string ("imLu")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6558 == std::string ("imOrder")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6558 == std::string ("imSimplex")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6558 == std::string ("readOpf")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6558 == std::string ("writeOpf")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6558 == std::string ("solvingRemote")))
  {
    {
      return (int)84;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_purify_value(const std::string & _6559){
  if ((_6559 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6559 == std::string ("primal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6559 == std::string ("dual")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6559 == std::string ("primalDual")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6559 == std::string ("auto")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_intpnthotstart_value(const std::string & _6560){
  if ((_6560 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6560 == std::string ("primal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6560 == std::string ("dual")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6560 == std::string ("primalDual")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simhotstart_value(const std::string & _6561){
  if ((_6561 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6561 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6561 == std::string ("statusKeys")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simdupvec_value(const std::string & _6562){
  if ((_6562 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6562 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6562 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simreform_value(const std::string & _6563){
  if ((_6563 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6563 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6563 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6563 == std::string ("aggressive")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_uplo_value(const std::string & _6564){
  if ((_6564 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6564 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_transpose_value(const std::string & _6565){
  if ((_6565 == std::string ("no")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6565 == std::string ("yes")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simdegen_value(const std::string & _6566){
  if ((_6566 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6566 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6566 == std::string ("aggressive")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6566 == std::string ("moderate")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6566 == std::string ("minimum")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_mark_value(const std::string & _6567){
  if ((_6567 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6567 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_boundkey_value(const std::string & _6568){
  if ((_6568 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6568 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6568 == std::string ("fx")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6568 == std::string ("fr")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6568 == std::string ("ra")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_basindtype_value(const std::string & _6569){
  if ((_6569 == std::string ("never")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6569 == std::string ("always")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6569 == std::string ("noError")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6569 == std::string ("ifFeasible")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6569 == std::string ("reservered")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_language_value(const std::string & _6570){
  if ((_6570 == std::string ("eng")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6570 == std::string ("dan")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
void mosek::fusion::p_Parameters::destroy(){}void mosek::fusion::Parameters::destroy() { mosek::fusion::p_Parameters::_get_impl(this)->destroy(); }