#ifndef __FUSION_P_H__
#define __FUSION_P_H__
#include "monty.h"
#include "mosektask_p.h"
#include "list"
#include "vector"
#include "unordered_map"
#include "fusion.h"
namespace mosek
{
namespace fusion
{
// mosek.fusion.BaseModel from file 'src/fusion/cxx/BaseModel_p.h'
// namespace mosek::fusion
struct p_BaseModel
{
  p_BaseModel(BaseModel * _pubthis);

  void _initialize( monty::rc_ptr<BaseModel> m);
  void _initialize( const std::string & name,
                    const std::string & licpath);

  virtual ~p_BaseModel() { /* std::cout << "~p_BaseModel()" << std::endl;*/  }

  static p_BaseModel * _get_impl(Model * _inst) { return _inst->_impl; }

  //----------------------

  bool synched;
  std::string taskname;

  monty::rc_ptr<SolutionStruct> sol_itr;
  monty::rc_ptr<SolutionStruct> sol_itg;
  monty::rc_ptr<SolutionStruct> sol_bas;

  //---------------------

  std::unique_ptr<Task> task;

  //---------------------
  void task_setLogHandler (const msghandler_t & handler);
  void task_setDataCallbackHandler (const datacbhandler_t & handler);
  void task_setCallbackHandler (const cbhandler_t & handler);

  int task_append_barvar(int size, int num);

  void task_var_name   (int index, const std::string & name);
  void task_con_name   (int index, const std::string & name);
  void task_cone_name  (int index, const std::string & name);
  void task_barvar_name(int index, const std::string & name);
  void task_objectivename(         const std::string & name);

  void task_format_var_names(const std::shared_ptr<monty::ndarray<int,1>> subj, const std::string & format,const std::shared_ptr<monty::ndarray<int,1>> dims, const std::shared_ptr<monty::ndarray<long long,1>> sp);
  void task_format_con_names(const std::shared_ptr<monty::ndarray<int,1>> subi, const std::string & format,const std::shared_ptr<monty::ndarray<int,1>> dims, const std::shared_ptr<monty::ndarray<long long,1>> sp);
  void task_format_cone_names(const std::shared_ptr<monty::ndarray<int,1>> subk, const std::string & format,const std::shared_ptr<monty::ndarray<int,1>> dims, const std::shared_ptr<monty::ndarray<long long,1>> sp);

  void task_break_solve();

  //--------------------------

  int task_numvar();
  int task_numcon();
  int task_numcone();
  int task_numbarvar();

  //--------------------------

  void task_put_param(const std::string & name, const std::string & value);
  void task_put_param(const std::string & name, int    value);
  void task_put_param(const std::string & name, double value);
  
  double    task_get_dinf (const std::string & name);
  int       task_get_iinf (const std::string & name);
  long long task_get_liinf(const std::string & name);
  
  //--------------------------

  void task_con_putboundlist_fr(const std::shared_ptr<monty::ndarray<int,1>> idxs);
  void task_con_putboundlist_lo(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_con_putboundlist_up(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_con_putboundlist_fx(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_con_putboundlist_ra(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & lb , 
                                const std::shared_ptr<monty::ndarray<double,1>> & ub );

  void task_var_putboundlist_fr(const std::shared_ptr<monty::ndarray<int,1>> idxs);
  void task_var_putboundlist_lo(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_var_putboundlist_up(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_var_putboundlist_fx(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_var_putboundlist_ra(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & lb , 
                                const std::shared_ptr<monty::ndarray<double,1>> & ub );
  
  void task_var_putintlist(const std::shared_ptr<monty::ndarray<int,1>> & idxs);
  void task_var_putcontlist(const std::shared_ptr<monty::ndarray<int,1>> & idxs); 
 
  //--------------------------

  void task_putbararowlist(const std::shared_ptr<monty::ndarray<int,1>>       subi,
                           const std::shared_ptr<monty::ndarray<long long,1>> ptr,
                           const std::shared_ptr<monty::ndarray<int,1>>       subj,
                           const std::shared_ptr<monty::ndarray<long long,1>> matidx);

  void task_putbaraijlist(const std::shared_ptr<monty::ndarray<int,1>> subi,
                          const std::shared_ptr<monty::ndarray<int,1>> subj,
                          std::shared_ptr<monty::ndarray<long long,1>> matidx);
  
  void task_putbarc(const std::shared_ptr<monty::ndarray<int,1>> subj,
                    const std::shared_ptr<monty::ndarray<int,1>> subl,
                    const std::shared_ptr<monty::ndarray<int,1>> subk,
                    const std::shared_ptr<monty::ndarray<double,1>> val);
  
  std::shared_ptr<monty::ndarray<long long,1>> task_appendsymmatlist (const std::shared_ptr<monty::ndarray<int,1>>       & dim, 
                                                                      const std::shared_ptr<monty::ndarray<long long,1>> & nz, 
                                                                      const std::shared_ptr<monty::ndarray<int,1>>       & subk, 
                                                                      const std::shared_ptr<monty::ndarray<int,1>>       & subl, 
                                                                      const std::shared_ptr<monty::ndarray<double,1>>    & val);
  int  task_barvar_dim(int j);
  void task_putbaraij (int i, int j, int k);
  void task_putbaraij (int i, int j, const std::shared_ptr<monty::ndarray<int,1>> & k);
  void task_putbarcj  (int j, int k);
  void task_putbarcj  (int j,        const std::shared_ptr<monty::ndarray<int,1>> & k);
  int  task_barvardim (int index);

  int task_append_var(int num);
  int task_append_con(int num);

  void task_append_zerocones (int numcone);
  void task_clear_cones   ( const std::shared_ptr<monty::ndarray<int,1>> & idxs );
  void task_put_zerocones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_quadcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_rquadcones( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_pexpcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_ppowcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs, const std::shared_ptr<monty::ndarray<double,1>> & alpha );
  void task_put_dexpcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_dpowcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs, const std::shared_ptr<monty::ndarray<double,1>> & alpha );

  void task_putarowlist(
    const std::shared_ptr<monty::ndarray<int,1>>       & idxs, 
    const std::shared_ptr<monty::ndarray<long long,1>> & ptrb, 
    const std::shared_ptr<monty::ndarray<int,1>>       & subj, 
    const std::shared_ptr<monty::ndarray<double,1>>    & cof);
  void task_putaijlist(
    const std::shared_ptr<monty::ndarray<int,1>>       & subi, 
    const std::shared_ptr<monty::ndarray<int,1>>       & subj, 
    const std::shared_ptr<monty::ndarray<double,1>>    & cof, 
    long long                           num);

  void task_setnumvar(int num);
  void task_cleanup(int oldnum, int oldnumcon, int oldnumcone, int oldnumbarvar);
  void task_solve();

  void task_putobjective( 
    bool                             maximize,
    const std::shared_ptr<monty::ndarray<int,1>>    & subj    ,
    const std::shared_ptr<monty::ndarray<double,1>> & cof     ,
    double                           cfix    );

  void task_putclist(   
    const std::shared_ptr<monty::ndarray<int,1>>    & subj,
    const std::shared_ptr<monty::ndarray<double,1>> & cof);


  void task_putobjectivename(const std::string & name);

  void task_write(const std::string & filename);
  void task_dump (const std::string & filename);

  MSKtask_t task_get();
  MSKtask_t __mosek_2fusion_2BaseModel__task_get();
  
  void dispose();

  void task_putxx_slice(SolutionType which, int first, int last, std::shared_ptr<monty::ndarray<double,1>> & xx);

  static void env_syeig (int n, std::shared_ptr<monty::ndarray<double,1>> & a, std::shared_ptr<monty::ndarray<double,1>> & w);
  static void env_potrf (int n, std::shared_ptr<monty::ndarray<double,1>> & a);                        
  static void env_syevd (int n, std::shared_ptr<monty::ndarray<double,1>> & a, std::shared_ptr<monty::ndarray<double,1>> & w);

  static void env_putlicensecode(std::shared_ptr<monty::ndarray<int,1>> code);
  static void env_putlicensepath(const std::string &licfile);
  static void env_putlicensewait(int wait);

  static std::string env_getversion();

  void convertSolutionStatus(MSKsoltypee soltype, p_SolutionStruct * sol, MSKsolstae status, MSKprostae prosta);


};

// End of file 'src/fusion/cxx/BaseModel_p.h'
struct p_Model : public ::mosek::fusion::p_BaseModel
{
Model * _pubthis;
static mosek::fusion::p_Model* _get_impl(mosek::fusion::Model * _inst){ return static_cast< mosek::fusion::p_Model* >(mosek::fusion::p_BaseModel::_get_impl(_inst)); }
static mosek::fusion::p_Model * _get_impl(mosek::fusion::Model::t _inst) { return _get_impl(_inst.get()); }
p_Model(Model * _pubthis);
virtual ~p_Model() { /* std::cout << "~p_Model" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::WorkStack > xs{};monty::rc_ptr< ::mosek::fusion::WorkStack > ws{};monty::rc_ptr< ::mosek::fusion::WorkStack > rs{};monty::rc_ptr< ::mosek::fusion::Utils::StringIntMap > con_map{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > > cons{};std::shared_ptr< monty::ndarray< int,1 > > natconmap_type{};std::shared_ptr< monty::ndarray< double,1 > > natconmap_ub{};std::shared_ptr< monty::ndarray< double,1 > > natconmap_lb{};std::shared_ptr< monty::ndarray< double,1 > > natconmap_efix{};std::shared_ptr< monty::ndarray< int,1 > > natconmap_idx{};std::shared_ptr< monty::ndarray< long long,1 > > natconmap_slackidx{};std::shared_ptr< monty::ndarray< int,1 > > natconmap_blockid{};monty::rc_ptr< ::mosek::fusion::LinkedBlocks > natconmap{};std::shared_ptr< monty::ndarray< bool,1 > > initsol_xx_flag{};std::shared_ptr< monty::ndarray< double,1 > > initsol_xx{};monty::rc_ptr< ::mosek::fusion::Utils::StringIntMap > var_map{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > barvars{};std::shared_ptr< monty::ndarray< int,1 > > natbarvarmap_ptr{};std::shared_ptr< monty::ndarray< int,1 > > natbarvarmap_num{};int natbarvarmap_nblock{};std::shared_ptr< monty::ndarray< int,1 > > natbarvar_dim{};std::shared_ptr< monty::ndarray< long long,1 > > natbarvar_ptr{};int natbarvar_numbarvarelm{};std::shared_ptr< monty::ndarray< int,1 > > natbarvar_j{};std::shared_ptr< monty::ndarray< int,1 > > natbarvar_i{};std::shared_ptr< monty::ndarray< int,1 > > natbarvar_idx{};std::shared_ptr< monty::ndarray< int,1 > > natvarmap_type{};std::shared_ptr< monty::ndarray< int,1 > > natconemap_dim{};monty::rc_ptr< ::mosek::fusion::LinkedBlocks > natconemap{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > vars{};int bfixidx{};std::shared_ptr< monty::ndarray< int,1 > > natvarmap_idx{};std::shared_ptr< monty::ndarray< int,1 > > natvarmap_blockid{};monty::rc_ptr< ::mosek::fusion::LinkedBlocks > natvarmap{};mosek::fusion::SolutionType solutionptr{};mosek::fusion::AccSolutionStatus acceptable_sol{};std::string model_name{};virtual void destroy();
static Model::t _new_Model(monty::rc_ptr< ::mosek::fusion::Model > _464);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _464);
static Model::t _new_Model(const std::string &  _469);
void _initialize(const std::string &  _469);
static Model::t _new_Model();
void _initialize();
virtual monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > __mosek_2fusion_2Model__formstConstr(monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _472,std::shared_ptr< monty::ndarray< int,1 > > _473,std::shared_ptr< monty::ndarray< int,1 > > _474) ;
virtual void connames(std::shared_ptr< monty::ndarray< int,1 > > _475,const std::string &  _476,std::shared_ptr< monty::ndarray< int,1 > > _477,std::shared_ptr< monty::ndarray< long long,1 > > _478) ;
virtual void varnames(std::shared_ptr< monty::ndarray< int,1 > > _479,const std::string &  _480,std::shared_ptr< monty::ndarray< int,1 > > _481,std::shared_ptr< monty::ndarray< long long,1 > > _482) ;
virtual void varname(int _483,const std::string &  _484) ;
virtual void natbarvarmap_get(int _485,std::shared_ptr< monty::ndarray< int,1 > > _486) ;
virtual void natbarvar_get(int _490,std::shared_ptr< monty::ndarray< long long,1 > > _491) ;
virtual int natbarvarmap_alloc(int _498,int _499) ;
virtual int natvarmap_alloc(int _517) ;
virtual int natconmap_alloc(int _527) ;
virtual int natconemap_alloc(int _537) ;
virtual void make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _540) ;
virtual void make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _546) ;
static  void putlicensewait(bool _552);
static  void putlicensepath(const std::string &  _553);
static  void putlicensecode(std::shared_ptr< monty::ndarray< int,1 > > _554);
virtual /* override */ void dispose() ;
virtual void nativeVarToStr(int _557,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _558) ;
virtual MSKtask_t __mosek_2fusion_2Model__getTask() ;
virtual void getConstraintValues(bool _559,std::shared_ptr< monty::ndarray< int,1 > > _560,std::shared_ptr< monty::ndarray< double,1 > > _561,int _562) ;
virtual void getVariableDuals(bool _570,std::shared_ptr< monty::ndarray< long long,1 > > _571,std::shared_ptr< monty::ndarray< double,1 > > _572,int _573) ;
virtual void getVariableValues(bool _579,std::shared_ptr< monty::ndarray< long long,1 > > _580,std::shared_ptr< monty::ndarray< double,1 > > _581,int _582) ;
virtual void setVariableValues(bool _588,std::shared_ptr< monty::ndarray< long long,1 > > _589,std::shared_ptr< monty::ndarray< double,1 > > _590) ;
virtual void flushNames() ;
virtual void writeTask(const std::string &  _600) ;
virtual long long getSolverLIntInfo(const std::string &  _601) ;
virtual int getSolverIntInfo(const std::string &  _602) ;
virtual double getSolverDoubleInfo(const std::string &  _603) ;
virtual void setCallbackHandler(mosek::cbhandler_t  _604) ;
virtual void setDataCallbackHandler(mosek::datacbhandler_t  _605) ;
virtual void setLogHandler(mosek::msghandler_t  _606) ;
virtual void setSolverParam(const std::string &  _607,double _608) ;
virtual void setSolverParam(const std::string &  _609,int _610) ;
virtual void setSolverParam(const std::string &  _611,const std::string &  _612) ;
virtual void breakSolver() ;
virtual void solve() ;
virtual void flushSolutions() ;
virtual void flush_initsol(mosek::fusion::SolutionType _613) ;
virtual mosek::fusion::SolutionStatus getDualSolutionStatus() ;
virtual mosek::fusion::ProblemStatus getProblemStatus() ;
virtual mosek::fusion::SolutionStatus getPrimalSolutionStatus() ;
virtual double dualObjValue() ;
virtual double primalObjValue() ;
virtual monty::rc_ptr< ::mosek::fusion::SolutionStruct > __mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _620,bool _621,bool _622) ;
virtual monty::rc_ptr< ::mosek::fusion::SolutionStruct > __mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _628,bool _629) ;
virtual void setSolution_xx(std::shared_ptr< monty::ndarray< int,1 > > _630,std::shared_ptr< monty::ndarray< double,1 > > _631) ;
virtual void ensure_initsol_xx() ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_bars(mosek::fusion::SolutionType _638) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_barx(mosek::fusion::SolutionType _639) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_y(mosek::fusion::SolutionType _640) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_xc(mosek::fusion::SolutionType _641) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_snx(mosek::fusion::SolutionType _642) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_suc(mosek::fusion::SolutionType _643) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_slc(mosek::fusion::SolutionType _644) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_sux(mosek::fusion::SolutionType _645) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_slx(mosek::fusion::SolutionType _646) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_yx(mosek::fusion::SolutionType _647) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_xx(mosek::fusion::SolutionType _648) ;
virtual void selectedSolution(mosek::fusion::SolutionType _649) ;
virtual mosek::fusion::AccSolutionStatus getAcceptedSolutionStatus() ;
virtual void acceptedSolutionStatus(mosek::fusion::AccSolutionStatus _650) ;
virtual mosek::fusion::ProblemStatus getProblemStatus(mosek::fusion::SolutionType _651) ;
virtual mosek::fusion::SolutionStatus getDualSolutionStatus(mosek::fusion::SolutionType _653) ;
virtual mosek::fusion::SolutionStatus getPrimalSolutionStatus(mosek::fusion::SolutionType _654) ;
virtual mosek::fusion::SolutionStatus getSolutionStatus(mosek::fusion::SolutionType _655,bool _656) ;
virtual void update(std::shared_ptr< monty::ndarray< int,1 > > _659,monty::rc_ptr< ::mosek::fusion::Expression > _660) ;
virtual void update(std::shared_ptr< monty::ndarray< int,1 > > _693,monty::rc_ptr< ::mosek::fusion::Expression > _694,std::shared_ptr< monty::ndarray< int,1 > > _695,bool _696) ;
virtual void updateObjective(monty::rc_ptr< ::mosek::fusion::Expression > _726,monty::rc_ptr< ::mosek::fusion::Variable > _727) ;
virtual void objective_(const std::string &  _761,mosek::fusion::ObjectiveSense _762,monty::rc_ptr< ::mosek::fusion::Expression > _763) ;
virtual void objective(double _792) ;
virtual void objective(mosek::fusion::ObjectiveSense _793,double _794) ;
virtual void objective(mosek::fusion::ObjectiveSense _795,monty::rc_ptr< ::mosek::fusion::Expression > _796) ;
virtual void objective(const std::string &  _797,double _798) ;
virtual void objective(const std::string &  _799,mosek::fusion::ObjectiveSense _800,double _801) ;
virtual void objective(const std::string &  _802,mosek::fusion::ObjectiveSense _803,monty::rc_ptr< ::mosek::fusion::Expression > _804) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _805,monty::rc_ptr< ::mosek::fusion::ConeDomain > _806) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _807,monty::rc_ptr< ::mosek::fusion::Expression > _808,monty::rc_ptr< ::mosek::fusion::ConeDomain > _809) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _810,monty::rc_ptr< ::mosek::fusion::RangeDomain > _811) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _812,monty::rc_ptr< ::mosek::fusion::Expression > _813,monty::rc_ptr< ::mosek::fusion::RangeDomain > _814) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _815,monty::rc_ptr< ::mosek::fusion::LinearDomain > _816) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _817,monty::rc_ptr< ::mosek::fusion::Expression > _818,monty::rc_ptr< ::mosek::fusion::LinearDomain > _819) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _820,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _821) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _822,monty::rc_ptr< ::mosek::fusion::Expression > _823,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _824) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _825,monty::rc_ptr< ::mosek::fusion::PSDDomain > _826) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _827,monty::rc_ptr< ::mosek::fusion::Expression > _828,monty::rc_ptr< ::mosek::fusion::PSDDomain > _829) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _830) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _831,int _832,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _833) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _834,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _835) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _836,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _837) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _838,int _839,int _840,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _841) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _842,int _843,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _844) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _845,std::shared_ptr< monty::ndarray< int,1 > > _846,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _847) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _848) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _849,int _850,monty::rc_ptr< ::mosek::fusion::PSDDomain > _851) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _852,monty::rc_ptr< ::mosek::fusion::PSDDomain > _853) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _854,monty::rc_ptr< ::mosek::fusion::PSDDomain > _855) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _856,int _857,int _858,monty::rc_ptr< ::mosek::fusion::PSDDomain > _859) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _860,int _861,monty::rc_ptr< ::mosek::fusion::PSDDomain > _862) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _863,std::shared_ptr< monty::ndarray< int,1 > > _864,monty::rc_ptr< ::mosek::fusion::PSDDomain > _865) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _866) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _867) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _868) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _869,monty::rc_ptr< ::mosek::fusion::ConeDomain > _870) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _871,monty::rc_ptr< ::mosek::fusion::RangeDomain > _872) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _873,monty::rc_ptr< ::mosek::fusion::LinearDomain > _874) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _875) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _876,monty::rc_ptr< ::mosek::fusion::ConeDomain > _877) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _878,monty::rc_ptr< ::mosek::fusion::RangeDomain > _879) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _880,monty::rc_ptr< ::mosek::fusion::LinearDomain > _881) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _882) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _883,monty::rc_ptr< ::mosek::fusion::ConeDomain > _884) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _885,monty::rc_ptr< ::mosek::fusion::RangeDomain > _886) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _887,monty::rc_ptr< ::mosek::fusion::LinearDomain > _888) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _889,std::shared_ptr< monty::ndarray< int,1 > > _890,monty::rc_ptr< ::mosek::fusion::ConeDomain > _891) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _892,std::shared_ptr< monty::ndarray< int,1 > > _893,monty::rc_ptr< ::mosek::fusion::RangeDomain > _894) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _895,std::shared_ptr< monty::ndarray< int,1 > > _896,monty::rc_ptr< ::mosek::fusion::LinearDomain > _897) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _898,std::shared_ptr< monty::ndarray< int,1 > > _899) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _900,int _901,monty::rc_ptr< ::mosek::fusion::ConeDomain > _902) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _903,int _904,monty::rc_ptr< ::mosek::fusion::RangeDomain > _905) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _906,int _907,monty::rc_ptr< ::mosek::fusion::LinearDomain > _908) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _909,int _910) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _911) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__ranged_variable(const std::string &  _912,std::shared_ptr< monty::ndarray< int,1 > > _913,monty::rc_ptr< ::mosek::fusion::RangeDomain > _914) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable_(const std::string &  _935,std::shared_ptr< monty::ndarray< int,1 > > _936,monty::rc_ptr< ::mosek::fusion::ConeDomain > _937) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable_(const std::string &  _965,std::shared_ptr< monty::ndarray< int,1 > > _966,monty::rc_ptr< ::mosek::fusion::LinearDomain > _967) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable_(const std::string &  _1009,std::shared_ptr< monty::ndarray< int,1 > > _1010,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1011) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricVariable > __mosek_2fusion_2Model__variable_(const std::string &  _1033,std::shared_ptr< monty::ndarray< int,1 > > _1034,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1035) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1050,monty::rc_ptr< ::mosek::fusion::Expression > _1051,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1052) ;
virtual void update_bfix(std::shared_ptr< monty::ndarray< int,1 > > _1092,std::shared_ptr< monty::ndarray< double,1 > > _1093) ;
virtual void putarows(std::shared_ptr< monty::ndarray< int,1 > > _1095,monty::rc_ptr< ::mosek::fusion::WorkStack > _1096,int _1097,int _1098,int _1099,int _1100,int _1101) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1138,monty::rc_ptr< ::mosek::fusion::Expression > _1139,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1140) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1207,monty::rc_ptr< ::mosek::fusion::Expression > _1208,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1209) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1261,monty::rc_ptr< ::mosek::fusion::Expression > _1262,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1263) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1313,monty::rc_ptr< ::mosek::fusion::Expression > _1314,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1315) ;
static  std::string getVersion();
virtual bool hasConstraint(const std::string &  _1363) ;
virtual bool hasVariable(const std::string &  _1364) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__getConstraint(int _1365) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__getConstraint(const std::string &  _1366) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__getVariable(int _1367) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__getVariable(const std::string &  _1368) ;
virtual std::string getName() ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2Model__clone() ;
}; // struct Model;

// mosek.fusion.Debug from file 'src/fusion/cxx/Debug_p.h'
// namespace mosek::fusion
struct p_Debug
{
  Debug * _pubthis;

  p_Debug(Debug * _pubthis) : _pubthis(_pubthis) {}

  static Debug::t o ()                 { return monty::rc_ptr<Debug>(new Debug()); }
  Debug::t p (const std::string & val) { std::cout << val; return Debug::t(_pubthis); }
  Debug::t p (      int val)           { std::cout << val; return Debug::t(_pubthis); }
  Debug::t p (long long val)           { std::cout << val; return Debug::t(_pubthis); }
  Debug::t p (   double val)           { std::cout << val; return Debug::t(_pubthis); }
  Debug::t p (     bool val)           { std::cout << val; return Debug::t(_pubthis); }
  Debug::t lf()                        { std::cout << std::endl; return Debug::t(_pubthis); }

  static p_Debug * _get_impl(Debug * _inst) { return _inst->ptr; }

  template<typename T>
  Debug::t p(const std::shared_ptr<monty::ndarray<T,1>> & val)
  {
    if (val->size() > 0)
    {
      std::cout << (*val)[0];
      for (int i = 1; i < val->size(); ++i)
        std::cout << "," << (*val)[i];
    }
    return Debug::t(_pubthis);
  }

  Debug::t __mosek_2fusion_2Debug__p (const std::string & val) { std::cout << val; return Debug::t(_pubthis); }

  template<class C>
  Debug::t __mosek_2fusion_2Debug__p (C val) { std::cout << val; return Debug::t(_pubthis); }
  Debug::t __mosek_2fusion_2Debug__lf()      { std::cout << std::endl; return Debug::t(_pubthis); }
  
};
// End of file 'src/fusion/cxx/Debug_p.h'
struct p_Sort
{
Sort * _pubthis;
static mosek::fusion::p_Sort* _get_impl(mosek::fusion::Sort * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Sort * _get_impl(mosek::fusion::Sort::t _inst) { return _get_impl(_inst.get()); }
p_Sort(Sort * _pubthis);
virtual ~p_Sort() { /* std::cout << "~p_Sort" << std::endl;*/ };
virtual void destroy();
static  void argTransposeSort(std::shared_ptr< monty::ndarray< long long,1 > > _151,std::shared_ptr< monty::ndarray< long long,1 > > _152,int _153,int _154,int _155,std::shared_ptr< monty::ndarray< long long,1 > > _156);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _164,std::shared_ptr< monty::ndarray< long long,1 > > _165);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _166,std::shared_ptr< monty::ndarray< int,1 > > _167);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _168,std::shared_ptr< monty::ndarray< long long,1 > > _169,std::shared_ptr< monty::ndarray< long long,1 > > _170);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _171,std::shared_ptr< monty::ndarray< int,1 > > _172,std::shared_ptr< monty::ndarray< int,1 > > _173);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _174,std::shared_ptr< monty::ndarray< long long,1 > > _175,long long _176,long long _177);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _178,std::shared_ptr< monty::ndarray< int,1 > > _179,long long _180,long long _181);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _182,std::shared_ptr< monty::ndarray< long long,1 > > _183,std::shared_ptr< monty::ndarray< long long,1 > > _184,long long _185,long long _186);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _187,std::shared_ptr< monty::ndarray< int,1 > > _188,std::shared_ptr< monty::ndarray< int,1 > > _189,long long _190,long long _191);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _192,std::shared_ptr< monty::ndarray< long long,1 > > _193,long long _194,long long _195,bool _196);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _199,std::shared_ptr< monty::ndarray< int,1 > > _200,long long _201,long long _202,bool _203);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _206,std::shared_ptr< monty::ndarray< long long,1 > > _207,std::shared_ptr< monty::ndarray< long long,1 > > _208,long long _209,long long _210,bool _211);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _214,std::shared_ptr< monty::ndarray< int,1 > > _215,std::shared_ptr< monty::ndarray< int,1 > > _216,long long _217,long long _218,bool _219);
static  void argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _222,std::shared_ptr< monty::ndarray< long long,1 > > _223,long long _224,long long _225,long long _226,long long _227);
static  void argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _228,std::shared_ptr< monty::ndarray< int,1 > > _229,long long _230,long long _231,int _232,int _233);
static  void getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _234,std::shared_ptr< monty::ndarray< long long,1 > > _235,std::shared_ptr< monty::ndarray< long long,1 > > _236,long long _237,long long _238,std::shared_ptr< monty::ndarray< long long,1 > > _239);
static  void getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _242,std::shared_ptr< monty::ndarray< int,1 > > _243,std::shared_ptr< monty::ndarray< int,1 > > _244,long long _245,long long _246,std::shared_ptr< monty::ndarray< int,1 > > _247);
static  bool issorted(std::shared_ptr< monty::ndarray< long long,1 > > _250,std::shared_ptr< monty::ndarray< long long,1 > > _251,long long _252,long long _253,bool _254);
static  bool issorted(std::shared_ptr< monty::ndarray< long long,1 > > _256,std::shared_ptr< monty::ndarray< int,1 > > _257,long long _258,long long _259,bool _260);
static  bool issorted(std::shared_ptr< monty::ndarray< long long,1 > > _262,std::shared_ptr< monty::ndarray< long long,1 > > _263,std::shared_ptr< monty::ndarray< long long,1 > > _264,long long _265,long long _266,bool _267);
static  bool issorted(std::shared_ptr< monty::ndarray< long long,1 > > _269,std::shared_ptr< monty::ndarray< int,1 > > _270,std::shared_ptr< monty::ndarray< int,1 > > _271,long long _272,long long _273,bool _274);
}; // struct Sort;

struct p_IndexCounter
{
IndexCounter * _pubthis;
static mosek::fusion::p_IndexCounter* _get_impl(mosek::fusion::IndexCounter * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_IndexCounter * _get_impl(mosek::fusion::IndexCounter::t _inst) { return _get_impl(_inst.get()); }
p_IndexCounter(IndexCounter * _pubthis);
virtual ~p_IndexCounter() { /* std::cout << "~p_IndexCounter" << std::endl;*/ };
long long start{};std::shared_ptr< monty::ndarray< int,1 > > dims{};std::shared_ptr< monty::ndarray< long long,1 > > strides{};std::shared_ptr< monty::ndarray< long long,1 > > st{};std::shared_ptr< monty::ndarray< int,1 > > ii{};int n{};virtual void destroy();
static IndexCounter::t _new_IndexCounter(std::shared_ptr< monty::ndarray< int,1 > > _276);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _276);
static IndexCounter::t _new_IndexCounter(long long _278,std::shared_ptr< monty::ndarray< int,1 > > _279,std::shared_ptr< monty::ndarray< int,1 > > _280);
void _initialize(long long _278,std::shared_ptr< monty::ndarray< int,1 > > _279,std::shared_ptr< monty::ndarray< int,1 > > _280);
static IndexCounter::t _new_IndexCounter(long long _283,std::shared_ptr< monty::ndarray< int,1 > > _284,std::shared_ptr< monty::ndarray< long long,1 > > _285);
void _initialize(long long _283,std::shared_ptr< monty::ndarray< int,1 > > _284,std::shared_ptr< monty::ndarray< long long,1 > > _285);
virtual bool atEnd() ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getIndex() ;
virtual long long next() ;
virtual long long get() ;
virtual void inc() ;
virtual void reset() ;
}; // struct IndexCounter;

struct p_CommonTools
{
CommonTools * _pubthis;
static mosek::fusion::p_CommonTools* _get_impl(mosek::fusion::CommonTools * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_CommonTools * _get_impl(mosek::fusion::CommonTools::t _inst) { return _get_impl(_inst.get()); }
p_CommonTools(CommonTools * _pubthis);
virtual ~p_CommonTools() { /* std::cout << "~p_CommonTools" << std::endl;*/ };
virtual void destroy();
static  std::shared_ptr< monty::ndarray< long long,1 > > resize(std::shared_ptr< monty::ndarray< long long,1 > > _291,int _292);
static  std::shared_ptr< monty::ndarray< int,1 > > resize(std::shared_ptr< monty::ndarray< int,1 > > _294,int _295);
static  std::shared_ptr< monty::ndarray< double,1 > > resize(std::shared_ptr< monty::ndarray< double,1 > > _297,int _298);
static  int binarySearch(std::shared_ptr< monty::ndarray< int,1 > > _300,int _301);
static  int binarySearch(std::shared_ptr< monty::ndarray< long long,1 > > _305,long long _306);
static  int binarySearchR(std::shared_ptr< monty::ndarray< long long,1 > > _308,long long _309);
static  int binarySearchL(std::shared_ptr< monty::ndarray< long long,1 > > _313,long long _314);
static  void ndIncr(std::shared_ptr< monty::ndarray< int,1 > > _318,std::shared_ptr< monty::ndarray< int,1 > > _319,std::shared_ptr< monty::ndarray< int,1 > > _320);
static  void transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _322,std::shared_ptr< monty::ndarray< int,1 > > _323,std::shared_ptr< monty::ndarray< double,1 > > _324,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _325,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _326,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _327,long long _328,int _329,int _330);
static  void transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _343,std::shared_ptr< monty::ndarray< int,1 > > _344,std::shared_ptr< monty::ndarray< double,1 > > _345,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _346,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _347,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _348,long long _349,int _350,int _351);
static  void tripletSort(std::shared_ptr< monty::ndarray< int,1 > > _364,std::shared_ptr< monty::ndarray< int,1 > > _365,std::shared_ptr< monty::ndarray< double,1 > > _366,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _367,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _368,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _369,long long _370,int _371,int _372);
static  void argMSort(std::shared_ptr< monty::ndarray< int,1 > > _398,std::shared_ptr< monty::ndarray< int,1 > > _399);
static  void mergeInto(std::shared_ptr< monty::ndarray< int,1 > > _404,std::shared_ptr< monty::ndarray< int,1 > > _405,std::shared_ptr< monty::ndarray< int,1 > > _406,int _407,int _408,int _409);
static  void argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _415,std::shared_ptr< monty::ndarray< long long,1 > > _416,std::shared_ptr< monty::ndarray< long long,1 > > _417,long long _418,long long _419);
static  void argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _420,std::shared_ptr< monty::ndarray< int,1 > > _421,std::shared_ptr< monty::ndarray< int,1 > > _422,long long _423,long long _424);
}; // struct CommonTools;

struct p_SolutionStruct
{
SolutionStruct * _pubthis;
static mosek::fusion::p_SolutionStruct* _get_impl(mosek::fusion::SolutionStruct * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_SolutionStruct * _get_impl(mosek::fusion::SolutionStruct::t _inst) { return _get_impl(_inst.get()); }
p_SolutionStruct(SolutionStruct * _pubthis);
virtual ~p_SolutionStruct() { /* std::cout << "~p_SolutionStruct" << std::endl;*/ };
std::shared_ptr< monty::ndarray< double,1 > > yx{};std::shared_ptr< monty::ndarray< double,1 > > snx{};std::shared_ptr< monty::ndarray< double,1 > > sux{};std::shared_ptr< monty::ndarray< double,1 > > slx{};std::shared_ptr< monty::ndarray< double,1 > > bars{};std::shared_ptr< monty::ndarray< double,1 > > barx{};std::shared_ptr< monty::ndarray< double,1 > > y{};std::shared_ptr< monty::ndarray< double,1 > > suc{};std::shared_ptr< monty::ndarray< double,1 > > slc{};std::shared_ptr< monty::ndarray< double,1 > > xx{};std::shared_ptr< monty::ndarray< double,1 > > xc{};double dobj{};double pobj{};mosek::fusion::ProblemStatus probstatus{};mosek::fusion::SolutionStatus dstatus{};mosek::fusion::SolutionStatus pstatus{};int sol_numbarvar{};int sol_numcone{};int sol_numvar{};int sol_numcon{};virtual void destroy();
static SolutionStruct::t _new_SolutionStruct(int _425,int _426,int _427,int _428);
void _initialize(int _425,int _426,int _427,int _428);
static SolutionStruct::t _new_SolutionStruct(monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429);
void _initialize(monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429);
virtual monty::rc_ptr< ::mosek::fusion::SolutionStruct > __mosek_2fusion_2SolutionStruct__clone() ;
virtual void resize(int _430,int _431,int _432,int _433) ;
virtual bool isDualAcceptable(mosek::fusion::AccSolutionStatus _453) ;
virtual bool isPrimalAcceptable(mosek::fusion::AccSolutionStatus _454) ;
virtual bool isAcceptable(mosek::fusion::SolutionStatus _455,mosek::fusion::AccSolutionStatus _456) ;
}; // struct SolutionStruct;

struct p_ConNZStruct
{
ConNZStruct * _pubthis;
static mosek::fusion::p_ConNZStruct* _get_impl(mosek::fusion::ConNZStruct * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_ConNZStruct * _get_impl(mosek::fusion::ConNZStruct::t _inst) { return _get_impl(_inst.get()); }
p_ConNZStruct(ConNZStruct * _pubthis);
virtual ~p_ConNZStruct() { /* std::cout << "~p_ConNZStruct" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > barmidx{};std::shared_ptr< monty::ndarray< int,1 > > barsubj{};std::shared_ptr< monty::ndarray< int,1 > > barsubi{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};std::shared_ptr< monty::ndarray< double,1 > > cof{};std::shared_ptr< monty::ndarray< int,1 > > subj{};std::shared_ptr< monty::ndarray< long long,1 > > ptrb{};virtual void destroy();
static ConNZStruct::t _new_ConNZStruct(std::shared_ptr< monty::ndarray< long long,1 > > _457,std::shared_ptr< monty::ndarray< int,1 > > _458,std::shared_ptr< monty::ndarray< double,1 > > _459,std::shared_ptr< monty::ndarray< double,1 > > _460,std::shared_ptr< monty::ndarray< int,1 > > _461,std::shared_ptr< monty::ndarray< int,1 > > _462,std::shared_ptr< monty::ndarray< int,1 > > _463);
void _initialize(std::shared_ptr< monty::ndarray< long long,1 > > _457,std::shared_ptr< monty::ndarray< int,1 > > _458,std::shared_ptr< monty::ndarray< double,1 > > _459,std::shared_ptr< monty::ndarray< double,1 > > _460,std::shared_ptr< monty::ndarray< int,1 > > _461,std::shared_ptr< monty::ndarray< int,1 > > _462,std::shared_ptr< monty::ndarray< int,1 > > _463);
}; // struct ConNZStruct;

struct p_BaseVariable : public /*implements*/ virtual ::mosek::fusion::Variable
{
BaseVariable * _pubthis;
static mosek::fusion::p_BaseVariable* _get_impl(mosek::fusion::BaseVariable * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_BaseVariable * _get_impl(mosek::fusion::BaseVariable::t _inst) { return _get_impl(_inst.get()); }
p_BaseVariable(BaseVariable * _pubthis);
virtual ~p_BaseVariable() { /* std::cout << "~p_BaseVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};monty::rc_ptr< ::mosek::fusion::Model > model{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static BaseVariable::t _new_BaseVariable(monty::rc_ptr< ::mosek::fusion::BaseVariable > _1610,monty::rc_ptr< ::mosek::fusion::Model > _1611);
void _initialize(monty::rc_ptr< ::mosek::fusion::BaseVariable > _1610,monty::rc_ptr< ::mosek::fusion::Model > _1611);
static BaseVariable::t _new_BaseVariable(monty::rc_ptr< ::mosek::fusion::Model > _1612,std::shared_ptr< monty::ndarray< int,1 > > _1613,std::shared_ptr< monty::ndarray< long long,1 > > _1614,std::shared_ptr< monty::ndarray< long long,1 > > _1615);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1612,std::shared_ptr< monty::ndarray< int,1 > > _1613,std::shared_ptr< monty::ndarray< long long,1 > > _1614,std::shared_ptr< monty::ndarray< long long,1 > > _1615);
virtual /* override */ std::string toString() ;
virtual monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2BaseVariable__eval() ;
virtual monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2Expression__eval() { return __mosek_2fusion_2BaseVariable__eval(); }
virtual void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _1618,monty::rc_ptr< ::mosek::fusion::WorkStack > _1619,monty::rc_ptr< ::mosek::fusion::WorkStack > _1620) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__reshape(int _1640,int _1641,int _1642) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__reshape(int _1640,int _1641,int _1642) { return __mosek_2fusion_2BaseVariable__reshape(_1640,_1641,_1642); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__reshape(int _1643,int _1644) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__reshape(int _1643,int _1644) { return __mosek_2fusion_2BaseVariable__reshape(_1643,_1644); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__reshape(int _1645) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__reshape(int _1645) { return __mosek_2fusion_2BaseVariable__reshape(_1645); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1646) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1646) { return __mosek_2fusion_2BaseVariable__reshape(_1646); }
virtual void setLevel(std::shared_ptr< monty::ndarray< double,1 > > _1650) ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2BaseVariable__getModel() ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2Variable__getModel() { return __mosek_2fusion_2BaseVariable__getModel(); }
virtual int getND() ;
virtual int getDim(int _1653) ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getShape() ;
virtual long long getSize() ;
virtual std::shared_ptr< monty::ndarray< double,1 > > dual() ;
virtual std::shared_ptr< monty::ndarray< double,1 > > level() ;
virtual void makeContinuous() ;
virtual void makeInteger() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__transpose() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__transpose() { return __mosek_2fusion_2BaseVariable__transpose(); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(int _1674,int _1675,int _1676) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(int _1674,int _1675,int _1676) { return __mosek_2fusion_2BaseVariable__index(_1674,_1675,_1676); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(int _1677,int _1678) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(int _1677,int _1678) { return __mosek_2fusion_2BaseVariable__index(_1677,_1678); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1679) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1679) { return __mosek_2fusion_2BaseVariable__index(_1679); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(int _1682) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(int _1682) { return __mosek_2fusion_2BaseVariable__index(_1682); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1683,std::shared_ptr< monty::ndarray< int,1 > > _1684,std::shared_ptr< monty::ndarray< int,1 > > _1685) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1683,std::shared_ptr< monty::ndarray< int,1 > > _1684,std::shared_ptr< monty::ndarray< int,1 > > _1685) { return __mosek_2fusion_2BaseVariable__pick(_1683,_1684,_1685); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1688,std::shared_ptr< monty::ndarray< int,1 > > _1689) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1688,std::shared_ptr< monty::ndarray< int,1 > > _1689) { return __mosek_2fusion_2BaseVariable__pick(_1688,_1689); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1692) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1692) { return __mosek_2fusion_2BaseVariable__pick(_1692); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1714) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1714) { return __mosek_2fusion_2BaseVariable__pick(_1714); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__antidiag(int _1725) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__antidiag(int _1725) { return __mosek_2fusion_2BaseVariable__antidiag(_1725); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__antidiag() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__antidiag() { return __mosek_2fusion_2BaseVariable__antidiag(); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__diag(int _1726) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__diag(int _1726) { return __mosek_2fusion_2BaseVariable__diag(_1726); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__diag() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__diag() { return __mosek_2fusion_2BaseVariable__diag(); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > > _1727,std::shared_ptr< monty::ndarray< int,1 > > _1728,int _1729) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1750,std::shared_ptr< monty::ndarray< int,1 > > _1751) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1750,std::shared_ptr< monty::ndarray< int,1 > > _1751) { return __mosek_2fusion_2BaseVariable__slice(_1750,_1751); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(int _1785,int _1786) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__slice(int _1785,int _1786) { return __mosek_2fusion_2BaseVariable__slice(_1785,_1786); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseVariable__asExpr() ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Variable__asExpr() { return __mosek_2fusion_2BaseVariable__asExpr(); }
virtual int inst(int _1795,std::shared_ptr< monty::ndarray< long long,1 > > _1796,int _1797,std::shared_ptr< monty::ndarray< long long,1 > > _1798) ;
virtual int numInst() ;
virtual void inst(int _1803,std::shared_ptr< monty::ndarray< long long,1 > > _1804) ;
virtual void set_values(std::shared_ptr< monty::ndarray< double,1 > > _1811,bool _1812) ;
virtual void dual_lu(int _1817,std::shared_ptr< monty::ndarray< double,1 > > _1818,bool _1819) ;
virtual void values(int _1822,std::shared_ptr< monty::ndarray< double,1 > > _1823,bool _1824) ;
virtual void make_continuous() ;
virtual void make_integer() ;
}; // struct BaseVariable;

struct p_SliceVariable : public ::mosek::fusion::p_BaseVariable
{
SliceVariable * _pubthis;
static mosek::fusion::p_SliceVariable* _get_impl(mosek::fusion::SliceVariable * _inst){ return static_cast< mosek::fusion::p_SliceVariable* >(mosek::fusion::p_BaseVariable::_get_impl(_inst)); }
static mosek::fusion::p_SliceVariable * _get_impl(mosek::fusion::SliceVariable::t _inst) { return _get_impl(_inst.get()); }
p_SliceVariable(SliceVariable * _pubthis);
virtual ~p_SliceVariable() { /* std::cout << "~p_SliceVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};virtual void destroy();
static SliceVariable::t _new_SliceVariable(monty::rc_ptr< ::mosek::fusion::Model > _1370,std::shared_ptr< monty::ndarray< int,1 > > _1371,std::shared_ptr< monty::ndarray< long long,1 > > _1372,std::shared_ptr< monty::ndarray< long long,1 > > _1373);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1370,std::shared_ptr< monty::ndarray< int,1 > > _1371,std::shared_ptr< monty::ndarray< long long,1 > > _1372,std::shared_ptr< monty::ndarray< long long,1 > > _1373);
}; // struct SliceVariable;

struct p_ModelVariable : public ::mosek::fusion::p_BaseVariable
{
ModelVariable * _pubthis;
static mosek::fusion::p_ModelVariable* _get_impl(mosek::fusion::ModelVariable * _inst){ return static_cast< mosek::fusion::p_ModelVariable* >(mosek::fusion::p_BaseVariable::_get_impl(_inst)); }
static mosek::fusion::p_ModelVariable * _get_impl(mosek::fusion::ModelVariable::t _inst) { return _get_impl(_inst.get()); }
p_ModelVariable(ModelVariable * _pubthis);
virtual ~p_ModelVariable() { /* std::cout << "~p_ModelVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< int,1 > > shape{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};long long varid{};std::string name{};virtual void destroy();
static ModelVariable::t _new_ModelVariable(monty::rc_ptr< ::mosek::fusion::ModelVariable > _1573,monty::rc_ptr< ::mosek::fusion::Model > _1574);
void _initialize(monty::rc_ptr< ::mosek::fusion::ModelVariable > _1573,monty::rc_ptr< ::mosek::fusion::Model > _1574);
static ModelVariable::t _new_ModelVariable(monty::rc_ptr< ::mosek::fusion::Model > _1575,const std::string &  _1576,std::shared_ptr< monty::ndarray< int,1 > > _1577,long long _1578,std::shared_ptr< monty::ndarray< long long,1 > > _1579,std::shared_ptr< monty::ndarray< long long,1 > > _1580);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1575,const std::string &  _1576,std::shared_ptr< monty::ndarray< int,1 > > _1577,long long _1578,std::shared_ptr< monty::ndarray< long long,1 > > _1579,std::shared_ptr< monty::ndarray< long long,1 > > _1580);
virtual void flushNames() { throw monty::AbstractClassError("Call to abstract method"); }
virtual void elementName(long long _1581,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1582) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1583) { throw monty::AbstractClassError("Call to abstract method"); }
}; // struct ModelVariable;

struct p_SymRangedVariable : public ::mosek::fusion::p_ModelVariable, public /*implements*/ virtual ::mosek::fusion::SymmetricVariable
{
SymRangedVariable * _pubthis;
static mosek::fusion::p_SymRangedVariable* _get_impl(mosek::fusion::SymRangedVariable * _inst){ return static_cast< mosek::fusion::p_SymRangedVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_SymRangedVariable * _get_impl(mosek::fusion::SymRangedVariable::t _inst) { return _get_impl(_inst.get()); }
p_SymRangedVariable(SymRangedVariable * _pubthis);
virtual ~p_SymRangedVariable() { /* std::cout << "~p_SymRangedVariable" << std::endl;*/ };
int dim{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};virtual void destroy();
static SymRangedVariable::t _new_SymRangedVariable(monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1374,monty::rc_ptr< ::mosek::fusion::Model > _1375);
void _initialize(monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1374,monty::rc_ptr< ::mosek::fusion::Model > _1375);
static SymRangedVariable::t _new_SymRangedVariable(monty::rc_ptr< ::mosek::fusion::Model > _1376,const std::string &  _1377,long long _1378,int _1379,std::shared_ptr< monty::ndarray< long long,1 > > _1380,std::shared_ptr< monty::ndarray< int,1 > > _1381);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1376,const std::string &  _1377,long long _1378,int _1379,std::shared_ptr< monty::ndarray< long long,1 > > _1380,std::shared_ptr< monty::ndarray< int,1 > > _1381);
virtual void dual_u(int _1382,std::shared_ptr< monty::ndarray< double,1 > > _1383) ;
virtual void dual_l(int _1384,std::shared_ptr< monty::ndarray< double,1 > > _1385) ;
virtual /* override */ void flushNames() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2SymRangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1389) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1389) { return __mosek_2fusion_2SymRangedVariable__clone(_1389); }
static  std::shared_ptr< monty::ndarray< long long,1 > > mirror_idxs(int _1390,std::shared_ptr< monty::ndarray< long long,1 > > _1391,std::shared_ptr< monty::ndarray< int,1 > > _1392);
static  std::shared_ptr< monty::ndarray< long long,1 > > mirror_sp(int _1408,std::shared_ptr< monty::ndarray< long long,1 > > _1409);
}; // struct SymRangedVariable;

struct p_RangedVariable : public ::mosek::fusion::p_ModelVariable
{
RangedVariable * _pubthis;
static mosek::fusion::p_RangedVariable* _get_impl(mosek::fusion::RangedVariable * _inst){ return static_cast< mosek::fusion::p_RangedVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_RangedVariable * _get_impl(mosek::fusion::RangedVariable::t _inst) { return _get_impl(_inst.get()); }
p_RangedVariable(RangedVariable * _pubthis);
virtual ~p_RangedVariable() { /* std::cout << "~p_RangedVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};bool names_flushed{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};virtual void destroy();
static RangedVariable::t _new_RangedVariable(monty::rc_ptr< ::mosek::fusion::RangedVariable > _1420,monty::rc_ptr< ::mosek::fusion::Model > _1421);
void _initialize(monty::rc_ptr< ::mosek::fusion::RangedVariable > _1420,monty::rc_ptr< ::mosek::fusion::Model > _1421);
static RangedVariable::t _new_RangedVariable(monty::rc_ptr< ::mosek::fusion::Model > _1422,const std::string &  _1423,long long _1424,std::shared_ptr< monty::ndarray< int,1 > > _1425,std::shared_ptr< monty::ndarray< long long,1 > > _1426,std::shared_ptr< monty::ndarray< int,1 > > _1427);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1422,const std::string &  _1423,long long _1424,std::shared_ptr< monty::ndarray< int,1 > > _1425,std::shared_ptr< monty::ndarray< long long,1 > > _1426,std::shared_ptr< monty::ndarray< int,1 > > _1427);
virtual monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > __mosek_2fusion_2RangedVariable__elementDesc(long long _1428,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1429) ;
virtual /* override */ void flushNames() ;
virtual void dual_u(int _1433,std::shared_ptr< monty::ndarray< double,1 > > _1434) ;
virtual void dual_l(int _1435,std::shared_ptr< monty::ndarray< double,1 > > _1436) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2RangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1437) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1437) { return __mosek_2fusion_2RangedVariable__clone(_1437); }
static  std::shared_ptr< monty::ndarray< long long,1 > > globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1438);
}; // struct RangedVariable;

struct p_LinearPSDVariable : public ::mosek::fusion::p_ModelVariable
{
LinearPSDVariable * _pubthis;
static mosek::fusion::p_LinearPSDVariable* _get_impl(mosek::fusion::LinearPSDVariable * _inst){ return static_cast< mosek::fusion::p_LinearPSDVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_LinearPSDVariable * _get_impl(mosek::fusion::LinearPSDVariable::t _inst) { return _get_impl(_inst.get()); }
p_LinearPSDVariable(LinearPSDVariable * _pubthis);
virtual ~p_LinearPSDVariable() { /* std::cout << "~p_LinearPSDVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};int varid{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};int conedim{};virtual void destroy();
static LinearPSDVariable::t _new_LinearPSDVariable(monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1441,monty::rc_ptr< ::mosek::fusion::Model > _1442);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1441,monty::rc_ptr< ::mosek::fusion::Model > _1442);
static LinearPSDVariable::t _new_LinearPSDVariable(monty::rc_ptr< ::mosek::fusion::Model > _1443,const std::string &  _1444,int _1445,std::shared_ptr< monty::ndarray< int,1 > > _1446,int _1447,std::shared_ptr< monty::ndarray< long long,1 > > _1448);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1443,const std::string &  _1444,int _1445,std::shared_ptr< monty::ndarray< int,1 > > _1446,int _1447,std::shared_ptr< monty::ndarray< long long,1 > > _1448);
virtual /* override */ void flushNames() ;
virtual /* override */ std::string toString() ;
virtual void make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _1451) ;
virtual void make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _1452) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2LinearPSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1453) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1453) { return __mosek_2fusion_2LinearPSDVariable__clone(_1453); }
static  std::shared_ptr< monty::ndarray< long long,1 > > globalNativeIndexes(std::shared_ptr< monty::ndarray< long long,1 > > _1454);
}; // struct LinearPSDVariable;

struct p_PSDVariable : public ::mosek::fusion::p_ModelVariable, public /*implements*/ virtual ::mosek::fusion::SymmetricVariable
{
PSDVariable * _pubthis;
static mosek::fusion::p_PSDVariable* _get_impl(mosek::fusion::PSDVariable * _inst){ return static_cast< mosek::fusion::p_PSDVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_PSDVariable * _get_impl(mosek::fusion::PSDVariable::t _inst) { return _get_impl(_inst.get()); }
p_PSDVariable(PSDVariable * _pubthis);
virtual ~p_PSDVariable() { /* std::cout << "~p_PSDVariable" << std::endl;*/ };
int conedim2{};int conedim1{};std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};int varid{};virtual void destroy();
static PSDVariable::t _new_PSDVariable(monty::rc_ptr< ::mosek::fusion::PSDVariable > _1456,monty::rc_ptr< ::mosek::fusion::Model > _1457);
void _initialize(monty::rc_ptr< ::mosek::fusion::PSDVariable > _1456,monty::rc_ptr< ::mosek::fusion::Model > _1457);
static PSDVariable::t _new_PSDVariable(monty::rc_ptr< ::mosek::fusion::Model > _1458,const std::string &  _1459,int _1460,std::shared_ptr< monty::ndarray< int,1 > > _1461,int _1462,int _1463,std::shared_ptr< monty::ndarray< long long,1 > > _1464);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1458,const std::string &  _1459,int _1460,std::shared_ptr< monty::ndarray< int,1 > > _1461,int _1462,int _1463,std::shared_ptr< monty::ndarray< long long,1 > > _1464);
virtual /* override */ void flushNames() ;
virtual /* override */ std::string toString() ;
virtual monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > __mosek_2fusion_2PSDVariable__elementDesc(long long _1467,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1468) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2PSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1469) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1469) { return __mosek_2fusion_2PSDVariable__clone(_1469); }
static  std::shared_ptr< monty::ndarray< long long,1 > > fullnativeidxs(std::shared_ptr< monty::ndarray< int,1 > > _1470,int _1471,int _1472,std::shared_ptr< monty::ndarray< long long,1 > > _1473);
}; // struct PSDVariable;

struct p_SymLinearVariable : public ::mosek::fusion::p_ModelVariable, public /*implements*/ virtual ::mosek::fusion::SymmetricVariable
{
SymLinearVariable * _pubthis;
static mosek::fusion::p_SymLinearVariable* _get_impl(mosek::fusion::SymLinearVariable * _inst){ return static_cast< mosek::fusion::p_SymLinearVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_SymLinearVariable * _get_impl(mosek::fusion::SymLinearVariable::t _inst) { return _get_impl(_inst.get()); }
p_SymLinearVariable(SymLinearVariable * _pubthis);
virtual ~p_SymLinearVariable() { /* std::cout << "~p_SymLinearVariable" << std::endl;*/ };
int dim{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};virtual void destroy();
static SymLinearVariable::t _new_SymLinearVariable(monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1498,monty::rc_ptr< ::mosek::fusion::Model > _1499);
void _initialize(monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1498,monty::rc_ptr< ::mosek::fusion::Model > _1499);
static SymLinearVariable::t _new_SymLinearVariable(monty::rc_ptr< ::mosek::fusion::Model > _1500,const std::string &  _1501,long long _1502,int _1503,std::shared_ptr< monty::ndarray< long long,1 > > _1504,std::shared_ptr< monty::ndarray< int,1 > > _1505);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1500,const std::string &  _1501,long long _1502,int _1503,std::shared_ptr< monty::ndarray< long long,1 > > _1504,std::shared_ptr< monty::ndarray< int,1 > > _1505);
virtual /* override */ void flushNames() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2SymLinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1509) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1509) { return __mosek_2fusion_2SymLinearVariable__clone(_1509); }
static  std::shared_ptr< monty::ndarray< long long,1 > > mirror_idxs(int _1510,std::shared_ptr< monty::ndarray< long long,1 > > _1511,std::shared_ptr< monty::ndarray< int,1 > > _1512);
static  std::shared_ptr< monty::ndarray< long long,1 > > mirror_sp(int _1528,std::shared_ptr< monty::ndarray< long long,1 > > _1529);
}; // struct SymLinearVariable;

struct p_LinearVariable : public ::mosek::fusion::p_ModelVariable
{
LinearVariable * _pubthis;
static mosek::fusion::p_LinearVariable* _get_impl(mosek::fusion::LinearVariable * _inst){ return static_cast< mosek::fusion::p_LinearVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_LinearVariable * _get_impl(mosek::fusion::LinearVariable::t _inst) { return _get_impl(_inst.get()); }
p_LinearVariable(LinearVariable * _pubthis);
virtual ~p_LinearVariable() { /* std::cout << "~p_LinearVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};virtual void destroy();
static LinearVariable::t _new_LinearVariable(monty::rc_ptr< ::mosek::fusion::LinearVariable > _1540,monty::rc_ptr< ::mosek::fusion::Model > _1541);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearVariable > _1540,monty::rc_ptr< ::mosek::fusion::Model > _1541);
static LinearVariable::t _new_LinearVariable(monty::rc_ptr< ::mosek::fusion::Model > _1542,const std::string &  _1543,long long _1544,std::shared_ptr< monty::ndarray< int,1 > > _1545,std::shared_ptr< monty::ndarray< long long,1 > > _1546,std::shared_ptr< monty::ndarray< int,1 > > _1547);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1542,const std::string &  _1543,long long _1544,std::shared_ptr< monty::ndarray< int,1 > > _1545,std::shared_ptr< monty::ndarray< long long,1 > > _1546,std::shared_ptr< monty::ndarray< int,1 > > _1547);
virtual /* override */ std::string toString() ;
virtual /* override */ void flushNames() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2LinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1553) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1553) { return __mosek_2fusion_2LinearVariable__clone(_1553); }
static  std::shared_ptr< monty::ndarray< long long,1 > > globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1554);
}; // struct LinearVariable;

struct p_ConicVariable : public ::mosek::fusion::p_ModelVariable
{
ConicVariable * _pubthis;
static mosek::fusion::p_ConicVariable* _get_impl(mosek::fusion::ConicVariable * _inst){ return static_cast< mosek::fusion::p_ConicVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_ConicVariable * _get_impl(mosek::fusion::ConicVariable::t _inst) { return _get_impl(_inst.get()); }
p_ConicVariable(ConicVariable * _pubthis);
virtual ~p_ConicVariable() { /* std::cout << "~p_ConicVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};bool names_flushed{};int varid{};virtual void destroy();
static ConicVariable::t _new_ConicVariable(monty::rc_ptr< ::mosek::fusion::ConicVariable > _1557,monty::rc_ptr< ::mosek::fusion::Model > _1558);
void _initialize(monty::rc_ptr< ::mosek::fusion::ConicVariable > _1557,monty::rc_ptr< ::mosek::fusion::Model > _1558);
static ConicVariable::t _new_ConicVariable(monty::rc_ptr< ::mosek::fusion::Model > _1559,const std::string &  _1560,int _1561,std::shared_ptr< monty::ndarray< int,1 > > _1562,std::shared_ptr< monty::ndarray< int,1 > > _1563);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1559,const std::string &  _1560,int _1561,std::shared_ptr< monty::ndarray< int,1 > > _1562,std::shared_ptr< monty::ndarray< int,1 > > _1563);
virtual /* override */ std::string toString() ;
virtual /* override */ void flushNames() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ConicVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1569) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1569) { return __mosek_2fusion_2ConicVariable__clone(_1569); }
static  std::shared_ptr< monty::ndarray< long long,1 > > globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1570);
}; // struct ConicVariable;

struct p_NilVariable : public ::mosek::fusion::p_BaseVariable, public /*implements*/ virtual ::mosek::fusion::SymmetricVariable
{
NilVariable * _pubthis;
static mosek::fusion::p_NilVariable* _get_impl(mosek::fusion::NilVariable * _inst){ return static_cast< mosek::fusion::p_NilVariable* >(mosek::fusion::p_BaseVariable::_get_impl(_inst)); }
static mosek::fusion::p_NilVariable * _get_impl(mosek::fusion::NilVariable::t _inst) { return _get_impl(_inst.get()); }
p_NilVariable(NilVariable * _pubthis);
virtual ~p_NilVariable() { /* std::cout << "~p_NilVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static NilVariable::t _new_NilVariable(std::shared_ptr< monty::ndarray< int,1 > > _1584);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _1584);
static NilVariable::t _new_NilVariable();
void _initialize();
virtual void flushNames() ;
virtual monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > __mosek_2fusion_2NilVariable__elementDesc(long long _1586,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1587) ;
virtual void elementName(long long _1588,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1589) ;
virtual /* override */ int numInst() ;
virtual int inst(int _1590,std::shared_ptr< monty::ndarray< long long,1 > > _1591,std::shared_ptr< monty::ndarray< long long,1 > > _1592) ;
virtual /* override */ void inst(int _1593,std::shared_ptr< monty::ndarray< long long,1 > > _1594) ;
virtual /* override */ void set_values(std::shared_ptr< monty::ndarray< double,1 > > _1595,bool _1596) ;
virtual /* override */ void values(int _1597,std::shared_ptr< monty::ndarray< double,1 > > _1598,bool _1599) ;
virtual /* override */ void make_continuous() ;
virtual /* override */ void make_integer() ;
virtual /* override */ std::string toString() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2NilVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1600) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1600) { return __mosek_2fusion_2NilVariable__index(_1600); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1600) { return __mosek_2fusion_2NilVariable__index(_1600); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2NilVariable__index(int _1602) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(int _1602) { return __mosek_2fusion_2NilVariable__index(_1602); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(int _1602) { return __mosek_2fusion_2NilVariable__index(_1602); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2NilVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1604,std::shared_ptr< monty::ndarray< int,1 > > _1605) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1604,std::shared_ptr< monty::ndarray< int,1 > > _1605) { return __mosek_2fusion_2NilVariable__slice(_1604,_1605); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1604,std::shared_ptr< monty::ndarray< int,1 > > _1605) { return __mosek_2fusion_2NilVariable__slice(_1604,_1605); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2NilVariable__slice(int _1608,int _1609) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(int _1608,int _1609) { return __mosek_2fusion_2NilVariable__slice(_1608,_1609); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__slice(int _1608,int _1609) { return __mosek_2fusion_2NilVariable__slice(_1608,_1609); }
}; // struct NilVariable;

struct p_Var
{
Var * _pubthis;
static mosek::fusion::p_Var* _get_impl(mosek::fusion::Var * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Var * _get_impl(mosek::fusion::Var::t _inst) { return _get_impl(_inst.get()); }
p_Var(Var * _pubthis);
virtual ~p_Var() { /* std::cout << "~p_Var" << std::endl;*/ };
virtual void destroy();
static  monty::rc_ptr< ::mosek::fusion::Variable > empty(std::shared_ptr< monty::ndarray< int,1 > > _1866);
static  monty::rc_ptr< ::mosek::fusion::Variable > compress(monty::rc_ptr< ::mosek::fusion::Variable > _1868);
static  monty::rc_ptr< ::mosek::fusion::Variable > reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1876,int _1877);
static  monty::rc_ptr< ::mosek::fusion::Variable > reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1878,int _1879,int _1880);
static  monty::rc_ptr< ::mosek::fusion::Variable > flatten(monty::rc_ptr< ::mosek::fusion::Variable > _1881);
static  monty::rc_ptr< ::mosek::fusion::Variable > reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1882,std::shared_ptr< monty::ndarray< int,1 > > _1883);
static  monty::rc_ptr< ::mosek::fusion::Variable > index_permute_(monty::rc_ptr< ::mosek::fusion::Variable > _1884,std::shared_ptr< monty::ndarray< int,1 > > _1885);
static  monty::rc_ptr< ::mosek::fusion::Variable > hrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1914,int _1915);
static  monty::rc_ptr< ::mosek::fusion::Variable > vrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1916,int _1917);
static  monty::rc_ptr< ::mosek::fusion::Variable > repeat(monty::rc_ptr< ::mosek::fusion::Variable > _1918,int _1919);
static  monty::rc_ptr< ::mosek::fusion::Variable > repeat(monty::rc_ptr< ::mosek::fusion::Variable > _1920,int _1921,int _1922);
static  monty::rc_ptr< ::mosek::fusion::Variable > drepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1923,int _1924,int _1925);
static  monty::rc_ptr< ::mosek::fusion::Variable > stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _1989);
static  monty::rc_ptr< ::mosek::fusion::Variable > vstack(monty::rc_ptr< ::mosek::fusion::Variable > _1991,monty::rc_ptr< ::mosek::fusion::Variable > _1992,monty::rc_ptr< ::mosek::fusion::Variable > _1993);
static  monty::rc_ptr< ::mosek::fusion::Variable > vstack(monty::rc_ptr< ::mosek::fusion::Variable > _1994,monty::rc_ptr< ::mosek::fusion::Variable > _1995);
static  monty::rc_ptr< ::mosek::fusion::Variable > vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1996);
static  monty::rc_ptr< ::mosek::fusion::Variable > hstack(monty::rc_ptr< ::mosek::fusion::Variable > _1997,monty::rc_ptr< ::mosek::fusion::Variable > _1998,monty::rc_ptr< ::mosek::fusion::Variable > _1999);
static  monty::rc_ptr< ::mosek::fusion::Variable > hstack(monty::rc_ptr< ::mosek::fusion::Variable > _2000,monty::rc_ptr< ::mosek::fusion::Variable > _2001);
static  monty::rc_ptr< ::mosek::fusion::Variable > hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2002);
static  monty::rc_ptr< ::mosek::fusion::Variable > stack(monty::rc_ptr< ::mosek::fusion::Variable > _2003,monty::rc_ptr< ::mosek::fusion::Variable > _2004,monty::rc_ptr< ::mosek::fusion::Variable > _2005,int _2006);
static  monty::rc_ptr< ::mosek::fusion::Variable > stack(monty::rc_ptr< ::mosek::fusion::Variable > _2007,monty::rc_ptr< ::mosek::fusion::Variable > _2008,int _2009);
static  monty::rc_ptr< ::mosek::fusion::Variable > stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2010,int _2011);
static  monty::rc_ptr< ::mosek::fusion::Variable > promote(monty::rc_ptr< ::mosek::fusion::Variable > _2014,int _2015);
static  monty::rc_ptr< ::mosek::fusion::Variable > dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2020,int _2021);
}; // struct Var;

struct p_ConstraintCache
{
ConstraintCache * _pubthis;
static mosek::fusion::p_ConstraintCache* _get_impl(mosek::fusion::ConstraintCache * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_ConstraintCache * _get_impl(mosek::fusion::ConstraintCache::t _inst) { return _get_impl(_inst.get()); }
p_ConstraintCache(ConstraintCache * _pubthis);
virtual ~p_ConstraintCache() { /* std::cout << "~p_ConstraintCache" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > barmatidx{};std::shared_ptr< monty::ndarray< int,1 > > barsubj{};std::shared_ptr< monty::ndarray< int,1 > > barsubi{};long long nbarnz{};long long nunordered{};std::shared_ptr< monty::ndarray< int,1 > > buffer_subi{};std::shared_ptr< monty::ndarray< int,1 > > buffer_subj{};std::shared_ptr< monty::ndarray< double,1 > > buffer_cof{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};std::shared_ptr< monty::ndarray< double,1 > > cof{};std::shared_ptr< monty::ndarray< int,1 > > subi{};std::shared_ptr< monty::ndarray< int,1 > > subj{};long long nnz{};int nrows{};virtual void destroy();
static ConstraintCache::t _new_ConstraintCache(monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2144);
void _initialize(monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2144);
static ConstraintCache::t _new_ConstraintCache(std::shared_ptr< monty::ndarray< long long,1 > > _2145,std::shared_ptr< monty::ndarray< double,1 > > _2146,std::shared_ptr< monty::ndarray< int,1 > > _2147,std::shared_ptr< monty::ndarray< double,1 > > _2148,std::shared_ptr< monty::ndarray< int,1 > > _2149,std::shared_ptr< monty::ndarray< int,1 > > _2150,std::shared_ptr< monty::ndarray< int,1 > > _2151);
void _initialize(std::shared_ptr< monty::ndarray< long long,1 > > _2145,std::shared_ptr< monty::ndarray< double,1 > > _2146,std::shared_ptr< monty::ndarray< int,1 > > _2147,std::shared_ptr< monty::ndarray< double,1 > > _2148,std::shared_ptr< monty::ndarray< int,1 > > _2149,std::shared_ptr< monty::ndarray< int,1 > > _2150,std::shared_ptr< monty::ndarray< int,1 > > _2151);
virtual void unchecked_add_fx(std::shared_ptr< monty::ndarray< double,1 > > _2154) ;
virtual long long order_barentries() ;
virtual void add_bar(std::shared_ptr< monty::ndarray< int,1 > > _2164,std::shared_ptr< monty::ndarray< int,1 > > _2165,std::shared_ptr< monty::ndarray< int,1 > > _2166) ;
virtual void unchecked_add_l(std::shared_ptr< monty::ndarray< long long,1 > > _2172,std::shared_ptr< monty::ndarray< int,1 > > _2173,std::shared_ptr< monty::ndarray< double,1 > > _2174,std::shared_ptr< monty::ndarray< double,1 > > _2175) ;
virtual void add(std::shared_ptr< monty::ndarray< long long,1 > > _2184,std::shared_ptr< monty::ndarray< int,1 > > _2185,std::shared_ptr< monty::ndarray< double,1 > > _2186,std::shared_ptr< monty::ndarray< double,1 > > _2187) ;
virtual long long flush(std::shared_ptr< monty::ndarray< int,1 > > _2188,std::shared_ptr< monty::ndarray< int,1 > > _2189,std::shared_ptr< monty::ndarray< double,1 > > _2190,std::shared_ptr< monty::ndarray< double,1 > > _2191) ;
virtual long long numUnsorted() ;
virtual monty::rc_ptr< ::mosek::fusion::ConstraintCache > __mosek_2fusion_2ConstraintCache__clone() ;
}; // struct ConstraintCache;

struct p_Constraint
{
Constraint * _pubthis;
static mosek::fusion::p_Constraint* _get_impl(mosek::fusion::Constraint * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Constraint * _get_impl(mosek::fusion::Constraint::t _inst) { return _get_impl(_inst.get()); }
p_Constraint(Constraint * _pubthis);
virtual ~p_Constraint() { /* std::cout << "~p_Constraint" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};std::shared_ptr< monty::ndarray< int,1 > > shape{};monty::rc_ptr< ::mosek::fusion::Model > model{};virtual void destroy();
static Constraint::t _new_Constraint(monty::rc_ptr< ::mosek::fusion::Constraint > _2265,monty::rc_ptr< ::mosek::fusion::Model > _2266);
void _initialize(monty::rc_ptr< ::mosek::fusion::Constraint > _2265,monty::rc_ptr< ::mosek::fusion::Model > _2266);
static Constraint::t _new_Constraint(monty::rc_ptr< ::mosek::fusion::Model > _2267,std::shared_ptr< monty::ndarray< int,1 > > _2268,std::shared_ptr< monty::ndarray< int,1 > > _2269);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2267,std::shared_ptr< monty::ndarray< int,1 > > _2268,std::shared_ptr< monty::ndarray< int,1 > > _2269);
virtual /* override */ std::string toString() ;
virtual void toStringArray(std::shared_ptr< monty::ndarray< long long,1 > > _2270,long long _2271,std::shared_ptr< monty::ndarray< std::string,1 > > _2272) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > dual() ;
virtual std::shared_ptr< monty::ndarray< double,1 > > level() ;
virtual void values(bool _2275,int _2276,std::shared_ptr< monty::ndarray< double,1 > > _2277) ;
virtual void update(std::shared_ptr< monty::ndarray< double,1 > > _2278) ;
virtual void update(monty::rc_ptr< ::mosek::fusion::Expression > _2279) ;
virtual void update(monty::rc_ptr< ::mosek::fusion::Expression > _2283,monty::rc_ptr< ::mosek::fusion::Variable > _2284,bool _2285) ;
virtual void update(monty::rc_ptr< ::mosek::fusion::Expression > _2304,monty::rc_ptr< ::mosek::fusion::Variable > _2305) ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2Constraint__get_model() ;
virtual int get_nd() ;
virtual long long size() ;
static  monty::rc_ptr< ::mosek::fusion::Constraint > stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2308,int _2309);
static  monty::rc_ptr< ::mosek::fusion::Constraint > stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2310,monty::rc_ptr< ::mosek::fusion::Constraint > _2311,monty::rc_ptr< ::mosek::fusion::Constraint > _2312,int _2313);
static  monty::rc_ptr< ::mosek::fusion::Constraint > stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2314,monty::rc_ptr< ::mosek::fusion::Constraint > _2315,int _2316);
static  monty::rc_ptr< ::mosek::fusion::Constraint > hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2317);
static  monty::rc_ptr< ::mosek::fusion::Constraint > vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2318);
static  monty::rc_ptr< ::mosek::fusion::Constraint > hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2319,monty::rc_ptr< ::mosek::fusion::Constraint > _2320,monty::rc_ptr< ::mosek::fusion::Constraint > _2321);
static  monty::rc_ptr< ::mosek::fusion::Constraint > vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2322,monty::rc_ptr< ::mosek::fusion::Constraint > _2323,monty::rc_ptr< ::mosek::fusion::Constraint > _2324);
static  monty::rc_ptr< ::mosek::fusion::Constraint > hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2325,monty::rc_ptr< ::mosek::fusion::Constraint > _2326);
static  monty::rc_ptr< ::mosek::fusion::Constraint > vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2327,monty::rc_ptr< ::mosek::fusion::Constraint > _2328);
static  monty::rc_ptr< ::mosek::fusion::Constraint > dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2329,int _2330);
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2381) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__index(int _2388) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2389,std::shared_ptr< monty::ndarray< int,1 > > _2390) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__slice(int _2409,int _2410) ;
virtual int getND() ;
virtual int getSize() ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2Constraint__getModel() ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getShape() ;
}; // struct Constraint;

struct p_SliceConstraint : public ::mosek::fusion::p_Constraint
{
SliceConstraint * _pubthis;
static mosek::fusion::p_SliceConstraint* _get_impl(mosek::fusion::SliceConstraint * _inst){ return static_cast< mosek::fusion::p_SliceConstraint* >(mosek::fusion::p_Constraint::_get_impl(_inst)); }
static mosek::fusion::p_SliceConstraint * _get_impl(mosek::fusion::SliceConstraint::t _inst) { return _get_impl(_inst.get()); }
p_SliceConstraint(SliceConstraint * _pubthis);
virtual ~p_SliceConstraint() { /* std::cout << "~p_SliceConstraint" << std::endl;*/ };
virtual void destroy();
static SliceConstraint::t _new_SliceConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2214,std::shared_ptr< monty::ndarray< int,1 > > _2215,std::shared_ptr< monty::ndarray< int,1 > > _2216);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2214,std::shared_ptr< monty::ndarray< int,1 > > _2215,std::shared_ptr< monty::ndarray< int,1 > > _2216);
virtual /* override */ std::string toString() ;
}; // struct SliceConstraint;

struct p_ModelConstraint : public ::mosek::fusion::p_Constraint
{
ModelConstraint * _pubthis;
static mosek::fusion::p_ModelConstraint* _get_impl(mosek::fusion::ModelConstraint * _inst){ return static_cast< mosek::fusion::p_ModelConstraint* >(mosek::fusion::p_Constraint::_get_impl(_inst)); }
static mosek::fusion::p_ModelConstraint * _get_impl(mosek::fusion::ModelConstraint::t _inst) { return _get_impl(_inst.get()); }
p_ModelConstraint(ModelConstraint * _pubthis);
virtual ~p_ModelConstraint() { /* std::cout << "~p_ModelConstraint" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};virtual void destroy();
static ModelConstraint::t _new_ModelConstraint(monty::rc_ptr< ::mosek::fusion::ModelConstraint > _2254,monty::rc_ptr< ::mosek::fusion::Model > _2255);
void _initialize(monty::rc_ptr< ::mosek::fusion::ModelConstraint > _2254,monty::rc_ptr< ::mosek::fusion::Model > _2255);
static ModelConstraint::t _new_ModelConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2256,const std::string &  _2257,std::shared_ptr< monty::ndarray< int,1 > > _2258,std::shared_ptr< monty::ndarray< int,1 > > _2259);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2256,const std::string &  _2257,std::shared_ptr< monty::ndarray< int,1 > > _2258,std::shared_ptr< monty::ndarray< int,1 > > _2259);
virtual /* override */ std::string toString() ;
virtual void flushNames() ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2264) { throw monty::AbstractClassError("Call to abstract method"); }
}; // struct ModelConstraint;

struct p_LinearPSDConstraint : public ::mosek::fusion::p_ModelConstraint
{
LinearPSDConstraint * _pubthis;
static mosek::fusion::p_LinearPSDConstraint* _get_impl(mosek::fusion::LinearPSDConstraint * _inst){ return static_cast< mosek::fusion::p_LinearPSDConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_LinearPSDConstraint * _get_impl(mosek::fusion::LinearPSDConstraint::t _inst) { return _get_impl(_inst.get()); }
p_LinearPSDConstraint(LinearPSDConstraint * _pubthis);
virtual ~p_LinearPSDConstraint() { /* std::cout << "~p_LinearPSDConstraint" << std::endl;*/ };
int conedim{};std::shared_ptr< monty::ndarray< int,1 > > shape{};int conid{};std::shared_ptr< monty::ndarray< long long,1 > > slackidxs{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};virtual void destroy();
static LinearPSDConstraint::t _new_LinearPSDConstraint(monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2090,monty::rc_ptr< ::mosek::fusion::Model > _2091);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2090,monty::rc_ptr< ::mosek::fusion::Model > _2091);
static LinearPSDConstraint::t _new_LinearPSDConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2092,const std::string &  _2093,int _2094,std::shared_ptr< monty::ndarray< int,1 > > _2095,int _2096,std::shared_ptr< monty::ndarray< int,1 > > _2097,std::shared_ptr< monty::ndarray< long long,1 > > _2098);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2092,const std::string &  _2093,int _2094,std::shared_ptr< monty::ndarray< int,1 > > _2095,int _2096,std::shared_ptr< monty::ndarray< int,1 > > _2097,std::shared_ptr< monty::ndarray< long long,1 > > _2098);
virtual void domainToString(long long _2099,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2100) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2LinearPSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2104) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2104) { return __mosek_2fusion_2LinearPSDConstraint__clone(_2104); }
}; // struct LinearPSDConstraint;

struct p_PSDConstraint : public ::mosek::fusion::p_ModelConstraint
{
PSDConstraint * _pubthis;
static mosek::fusion::p_PSDConstraint* _get_impl(mosek::fusion::PSDConstraint * _inst){ return static_cast< mosek::fusion::p_PSDConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_PSDConstraint * _get_impl(mosek::fusion::PSDConstraint::t _inst) { return _get_impl(_inst.get()); }
p_PSDConstraint(PSDConstraint * _pubthis);
virtual ~p_PSDConstraint() { /* std::cout << "~p_PSDConstraint" << std::endl;*/ };
bool names_flushed{};int conedim1{};int conedim0{};std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};std::shared_ptr< monty::ndarray< long long,1 > > slackidxs{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};int conid{};virtual void destroy();
static PSDConstraint::t _new_PSDConstraint(monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2105,monty::rc_ptr< ::mosek::fusion::Model > _2106);
void _initialize(monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2105,monty::rc_ptr< ::mosek::fusion::Model > _2106);
static PSDConstraint::t _new_PSDConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2107,const std::string &  _2108,int _2109,std::shared_ptr< monty::ndarray< int,1 > > _2110,int _2111,int _2112,std::shared_ptr< monty::ndarray< long long,1 > > _2113,std::shared_ptr< monty::ndarray< int,1 > > _2114);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2107,const std::string &  _2108,int _2109,std::shared_ptr< monty::ndarray< int,1 > > _2110,int _2111,int _2112,std::shared_ptr< monty::ndarray< long long,1 > > _2113,std::shared_ptr< monty::ndarray< int,1 > > _2114);
virtual /* override */ std::string toString() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2PSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2115) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2115) { return __mosek_2fusion_2PSDConstraint__clone(_2115); }
static  std::shared_ptr< monty::ndarray< int,1 > > computenidxs(std::shared_ptr< monty::ndarray< int,1 > > _2116,int _2117,int _2118,std::shared_ptr< monty::ndarray< int,1 > > _2119);
}; // struct PSDConstraint;

struct p_RangedConstraint : public ::mosek::fusion::p_ModelConstraint
{
RangedConstraint * _pubthis;
static mosek::fusion::p_RangedConstraint* _get_impl(mosek::fusion::RangedConstraint * _inst){ return static_cast< mosek::fusion::p_RangedConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_RangedConstraint * _get_impl(mosek::fusion::RangedConstraint::t _inst) { return _get_impl(_inst.get()); }
p_RangedConstraint(RangedConstraint * _pubthis);
virtual ~p_RangedConstraint() { /* std::cout << "~p_RangedConstraint" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static RangedConstraint::t _new_RangedConstraint(monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2218,monty::rc_ptr< ::mosek::fusion::Model > _2219);
void _initialize(monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2218,monty::rc_ptr< ::mosek::fusion::Model > _2219);
static RangedConstraint::t _new_RangedConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2220,const std::string &  _2221,std::shared_ptr< monty::ndarray< int,1 > > _2222,std::shared_ptr< monty::ndarray< int,1 > > _2223);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2220,const std::string &  _2221,std::shared_ptr< monty::ndarray< int,1 > > _2222,std::shared_ptr< monty::ndarray< int,1 > > _2223);
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2RangedConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2224) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2224) { return __mosek_2fusion_2RangedConstraint__clone(_2224); }
}; // struct RangedConstraint;

struct p_ConicConstraint : public ::mosek::fusion::p_ModelConstraint
{
ConicConstraint * _pubthis;
static mosek::fusion::p_ConicConstraint* _get_impl(mosek::fusion::ConicConstraint * _inst){ return static_cast< mosek::fusion::p_ConicConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_ConicConstraint * _get_impl(mosek::fusion::ConicConstraint::t _inst) { return _get_impl(_inst.get()); }
p_ConicConstraint(ConicConstraint * _pubthis);
virtual ~p_ConicConstraint() { /* std::cout << "~p_ConicConstraint" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > nativeslack{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};std::shared_ptr< monty::ndarray< int,1 > > shape{};monty::rc_ptr< ::mosek::fusion::ConeDomain > dom{};int conid{};virtual void destroy();
static ConicConstraint::t _new_ConicConstraint(monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2225,monty::rc_ptr< ::mosek::fusion::Model > _2226);
void _initialize(monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2225,monty::rc_ptr< ::mosek::fusion::Model > _2226);
static ConicConstraint::t _new_ConicConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2227,const std::string &  _2228,monty::rc_ptr< ::mosek::fusion::ConeDomain > _2229,std::shared_ptr< monty::ndarray< int,1 > > _2230,int _2231,std::shared_ptr< monty::ndarray< int,1 > > _2232,std::shared_ptr< monty::ndarray< int,1 > > _2233);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2227,const std::string &  _2228,monty::rc_ptr< ::mosek::fusion::ConeDomain > _2229,std::shared_ptr< monty::ndarray< int,1 > > _2230,int _2231,std::shared_ptr< monty::ndarray< int,1 > > _2232,std::shared_ptr< monty::ndarray< int,1 > > _2233);
virtual /* override */ void flushNames() ;
virtual /* override */ std::string toString() ;
virtual void domainToString(long long _2240,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2241) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ConicConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2242) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2242) { return __mosek_2fusion_2ConicConstraint__clone(_2242); }
}; // struct ConicConstraint;

struct p_LinearConstraint : public ::mosek::fusion::p_ModelConstraint
{
LinearConstraint * _pubthis;
static mosek::fusion::p_LinearConstraint* _get_impl(mosek::fusion::LinearConstraint * _inst){ return static_cast< mosek::fusion::p_LinearConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_LinearConstraint * _get_impl(mosek::fusion::LinearConstraint::t _inst) { return _get_impl(_inst.get()); }
p_LinearConstraint(LinearConstraint * _pubthis);
virtual ~p_LinearConstraint() { /* std::cout << "~p_LinearConstraint" << std::endl;*/ };
std::string name{};int conid{};virtual void destroy();
static LinearConstraint::t _new_LinearConstraint(monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2243,monty::rc_ptr< ::mosek::fusion::Model > _2244);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2243,monty::rc_ptr< ::mosek::fusion::Model > _2244);
static LinearConstraint::t _new_LinearConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2245,const std::string &  _2246,int _2247,std::shared_ptr< monty::ndarray< int,1 > > _2248,std::shared_ptr< monty::ndarray< int,1 > > _2249);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2245,const std::string &  _2246,int _2247,std::shared_ptr< monty::ndarray< int,1 > > _2248,std::shared_ptr< monty::ndarray< int,1 > > _2249);
virtual /* override */ std::string toString() ;
virtual void domainToString(long long _2251,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2252) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2LinearConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2253) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2253) { return __mosek_2fusion_2LinearConstraint__clone(_2253); }
}; // struct LinearConstraint;

struct p_Set
{
Set * _pubthis;
static mosek::fusion::p_Set* _get_impl(mosek::fusion::Set * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Set * _get_impl(mosek::fusion::Set::t _inst) { return _get_impl(_inst.get()); }
p_Set(Set * _pubthis);
virtual ~p_Set() { /* std::cout << "~p_Set" << std::endl;*/ };
virtual void destroy();
static  long long size(std::shared_ptr< monty::ndarray< int,1 > > _2415);
static  bool match(std::shared_ptr< monty::ndarray< int,1 > > _2418,std::shared_ptr< monty::ndarray< int,1 > > _2419);
static  long long linearidx(std::shared_ptr< monty::ndarray< int,1 > > _2421,std::shared_ptr< monty::ndarray< int,1 > > _2422);
static  std::shared_ptr< monty::ndarray< int,1 > > idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2425,long long _2426);
static  void idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2428,long long _2429,std::shared_ptr< monty::ndarray< int,1 > > _2430);
static  std::string indexToString(std::shared_ptr< monty::ndarray< int,1 > > _2434,long long _2435);
static  std::string keyToString(std::shared_ptr< monty::ndarray< int,1 > > _2442);
static  void indexToKey(std::shared_ptr< monty::ndarray< int,1 > > _2445,long long _2446,std::shared_ptr< monty::ndarray< int,1 > > _2447);
static  std::shared_ptr< monty::ndarray< long long,1 > > strides(std::shared_ptr< monty::ndarray< int,1 > > _2451);
static  std::shared_ptr< monty::ndarray< int,1 > > make(std::shared_ptr< monty::ndarray< int,1 > > _2455,std::shared_ptr< monty::ndarray< int,1 > > _2456);
static  std::shared_ptr< monty::ndarray< int,1 > > make(std::shared_ptr< monty::ndarray< int,1 > > _2460);
static  std::shared_ptr< monty::ndarray< int,1 > > make(int _2462,int _2463,int _2464);
static  std::shared_ptr< monty::ndarray< int,1 > > make(int _2465,int _2466);
static  std::shared_ptr< monty::ndarray< int,1 > > make(int _2467);
static  std::shared_ptr< monty::ndarray< int,1 > > scalar();
static  std::shared_ptr< monty::ndarray< int,1 > > make(std::shared_ptr< monty::ndarray< std::string,1 > > _2468);
}; // struct Set;

struct p_ConeDomain
{
ConeDomain * _pubthis;
static mosek::fusion::p_ConeDomain* _get_impl(mosek::fusion::ConeDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_ConeDomain * _get_impl(mosek::fusion::ConeDomain::t _inst) { return _get_impl(_inst.get()); }
p_ConeDomain(ConeDomain * _pubthis);
virtual ~p_ConeDomain() { /* std::cout << "~p_ConeDomain" << std::endl;*/ };
double alpha{};std::shared_ptr< monty::ndarray< int,1 > > shape{};bool int_flag{};bool axisset{};int axisidx{};mosek::fusion::QConeKey key{};virtual void destroy();
static ConeDomain::t _new_ConeDomain(mosek::fusion::QConeKey _2469,double _2470,std::shared_ptr< monty::ndarray< int,1 > > _2471);
void _initialize(mosek::fusion::QConeKey _2469,double _2470,std::shared_ptr< monty::ndarray< int,1 > > _2471);
static ConeDomain::t _new_ConeDomain(mosek::fusion::QConeKey _2472,std::shared_ptr< monty::ndarray< int,1 > > _2473);
void _initialize(mosek::fusion::QConeKey _2472,std::shared_ptr< monty::ndarray< int,1 > > _2473);
virtual bool match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2474) ;
virtual monty::rc_ptr< ::mosek::fusion::ConeDomain > __mosek_2fusion_2ConeDomain__integral() ;
virtual bool axisIsSet() ;
virtual int getAxis() ;
virtual monty::rc_ptr< ::mosek::fusion::ConeDomain > __mosek_2fusion_2ConeDomain__axis(int _2475) ;
}; // struct ConeDomain;

struct p_LinPSDDomain
{
LinPSDDomain * _pubthis;
static mosek::fusion::p_LinPSDDomain* _get_impl(mosek::fusion::LinPSDDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_LinPSDDomain * _get_impl(mosek::fusion::LinPSDDomain::t _inst) { return _get_impl(_inst.get()); }
p_LinPSDDomain(LinPSDDomain * _pubthis);
virtual ~p_LinPSDDomain() { /* std::cout << "~p_LinPSDDomain" << std::endl;*/ };
int conedim{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static LinPSDDomain::t _new_LinPSDDomain(std::shared_ptr< monty::ndarray< int,1 > > _2476,int _2477);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2476,int _2477);
static LinPSDDomain::t _new_LinPSDDomain(std::shared_ptr< monty::ndarray< int,1 > > _2478);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2478);
static LinPSDDomain::t _new_LinPSDDomain();
void _initialize();
}; // struct LinPSDDomain;

struct p_PSDDomain
{
PSDDomain * _pubthis;
static mosek::fusion::p_PSDDomain* _get_impl(mosek::fusion::PSDDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_PSDDomain * _get_impl(mosek::fusion::PSDDomain::t _inst) { return _get_impl(_inst.get()); }
p_PSDDomain(PSDDomain * _pubthis);
virtual ~p_PSDDomain() { /* std::cout << "~p_PSDDomain" << std::endl;*/ };
bool axisIsSet{};int conedim2{};int conedim1{};mosek::fusion::PSDKey key{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static PSDDomain::t _new_PSDDomain(mosek::fusion::PSDKey _2479,std::shared_ptr< monty::ndarray< int,1 > > _2480,int _2481,int _2482);
void _initialize(mosek::fusion::PSDKey _2479,std::shared_ptr< monty::ndarray< int,1 > > _2480,int _2481,int _2482);
static PSDDomain::t _new_PSDDomain(mosek::fusion::PSDKey _2484,std::shared_ptr< monty::ndarray< int,1 > > _2485);
void _initialize(mosek::fusion::PSDKey _2484,std::shared_ptr< monty::ndarray< int,1 > > _2485);
static PSDDomain::t _new_PSDDomain(mosek::fusion::PSDKey _2486);
void _initialize(mosek::fusion::PSDKey _2486);
virtual monty::rc_ptr< ::mosek::fusion::PSDDomain > __mosek_2fusion_2PSDDomain__axis(int _2487,int _2488) ;
}; // struct PSDDomain;

struct p_RangeDomain
{
RangeDomain * _pubthis;
static mosek::fusion::p_RangeDomain* _get_impl(mosek::fusion::RangeDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_RangeDomain * _get_impl(mosek::fusion::RangeDomain::t _inst) { return _get_impl(_inst.get()); }
p_RangeDomain(RangeDomain * _pubthis);
virtual ~p_RangeDomain() { /* std::cout << "~p_RangeDomain" << std::endl;*/ };
bool cardinal_flag{};bool scalable{};std::shared_ptr< monty::ndarray< double,1 > > ub{};std::shared_ptr< monty::ndarray< double,1 > > lb{};std::shared_ptr< monty::ndarray< int,2 > > sparsity{};bool empty{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static RangeDomain::t _new_RangeDomain(bool _2490,std::shared_ptr< monty::ndarray< double,1 > > _2491,std::shared_ptr< monty::ndarray< double,1 > > _2492,std::shared_ptr< monty::ndarray< int,1 > > _2493);
void _initialize(bool _2490,std::shared_ptr< monty::ndarray< double,1 > > _2491,std::shared_ptr< monty::ndarray< double,1 > > _2492,std::shared_ptr< monty::ndarray< int,1 > > _2493);
static RangeDomain::t _new_RangeDomain(bool _2494,std::shared_ptr< monty::ndarray< double,1 > > _2495,std::shared_ptr< monty::ndarray< double,1 > > _2496,std::shared_ptr< monty::ndarray< int,1 > > _2497,std::shared_ptr< monty::ndarray< int,2 > > _2498);
void _initialize(bool _2494,std::shared_ptr< monty::ndarray< double,1 > > _2495,std::shared_ptr< monty::ndarray< double,1 > > _2496,std::shared_ptr< monty::ndarray< int,1 > > _2497,std::shared_ptr< monty::ndarray< int,2 > > _2498);
static RangeDomain::t _new_RangeDomain(bool _2499,std::shared_ptr< monty::ndarray< double,1 > > _2500,std::shared_ptr< monty::ndarray< double,1 > > _2501,std::shared_ptr< monty::ndarray< int,1 > > _2502,std::shared_ptr< monty::ndarray< int,2 > > _2503,int _2504);
void _initialize(bool _2499,std::shared_ptr< monty::ndarray< double,1 > > _2500,std::shared_ptr< monty::ndarray< double,1 > > _2501,std::shared_ptr< monty::ndarray< int,1 > > _2502,std::shared_ptr< monty::ndarray< int,2 > > _2503,int _2504);
static RangeDomain::t _new_RangeDomain(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2505);
void _initialize(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2505);
virtual monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > __mosek_2fusion_2RangeDomain__symmetric() ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2506) ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2509) ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__sparse() ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__integral() ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2511) ;
virtual bool match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2512) ;
}; // struct RangeDomain;

struct p_SymmetricRangeDomain : public ::mosek::fusion::p_RangeDomain
{
SymmetricRangeDomain * _pubthis;
static mosek::fusion::p_SymmetricRangeDomain* _get_impl(mosek::fusion::SymmetricRangeDomain * _inst){ return static_cast< mosek::fusion::p_SymmetricRangeDomain* >(mosek::fusion::p_RangeDomain::_get_impl(_inst)); }
static mosek::fusion::p_SymmetricRangeDomain * _get_impl(mosek::fusion::SymmetricRangeDomain::t _inst) { return _get_impl(_inst.get()); }
p_SymmetricRangeDomain(SymmetricRangeDomain * _pubthis);
virtual ~p_SymmetricRangeDomain() { /* std::cout << "~p_SymmetricRangeDomain" << std::endl;*/ };
int dim{};virtual void destroy();
static SymmetricRangeDomain::t _new_SymmetricRangeDomain(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2489);
void _initialize(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2489);
}; // struct SymmetricRangeDomain;

struct p_SymmetricLinearDomain
{
SymmetricLinearDomain * _pubthis;
static mosek::fusion::p_SymmetricLinearDomain* _get_impl(mosek::fusion::SymmetricLinearDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_SymmetricLinearDomain * _get_impl(mosek::fusion::SymmetricLinearDomain::t _inst) { return _get_impl(_inst.get()); }
p_SymmetricLinearDomain(SymmetricLinearDomain * _pubthis);
virtual ~p_SymmetricLinearDomain() { /* std::cout << "~p_SymmetricLinearDomain" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,2 > > sparsity{};bool cardinal_flag{};mosek::fusion::RelationKey key{};std::shared_ptr< monty::ndarray< int,1 > > shape{};monty::rc_ptr< ::mosek::fusion::LinearDomain > dom{};int dim{};virtual void destroy();
static SymmetricLinearDomain::t _new_SymmetricLinearDomain(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2514);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2514);
virtual monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2515) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2518) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > __mosek_2fusion_2SymmetricLinearDomain__integral() ;
virtual bool match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2520) ;
}; // struct SymmetricLinearDomain;

struct p_LinearDomain
{
LinearDomain * _pubthis;
static mosek::fusion::p_LinearDomain* _get_impl(mosek::fusion::LinearDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_LinearDomain * _get_impl(mosek::fusion::LinearDomain::t _inst) { return _get_impl(_inst.get()); }
p_LinearDomain(LinearDomain * _pubthis);
virtual ~p_LinearDomain() { /* std::cout << "~p_LinearDomain" << std::endl;*/ };
bool empty{};bool scalable{};std::shared_ptr< monty::ndarray< int,2 > > sparsity{};bool cardinal_flag{};mosek::fusion::RelationKey key{};std::shared_ptr< monty::ndarray< double,1 > > bnd{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static LinearDomain::t _new_LinearDomain(mosek::fusion::RelationKey _2522,bool _2523,std::shared_ptr< monty::ndarray< double,1 > > _2524,std::shared_ptr< monty::ndarray< int,1 > > _2525);
void _initialize(mosek::fusion::RelationKey _2522,bool _2523,std::shared_ptr< monty::ndarray< double,1 > > _2524,std::shared_ptr< monty::ndarray< int,1 > > _2525);
static LinearDomain::t _new_LinearDomain(mosek::fusion::RelationKey _2526,bool _2527,std::shared_ptr< monty::ndarray< double,1 > > _2528,std::shared_ptr< monty::ndarray< int,1 > > _2529,std::shared_ptr< monty::ndarray< int,2 > > _2530,int _2531);
void _initialize(mosek::fusion::RelationKey _2526,bool _2527,std::shared_ptr< monty::ndarray< double,1 > > _2528,std::shared_ptr< monty::ndarray< int,1 > > _2529,std::shared_ptr< monty::ndarray< int,2 > > _2530,int _2531);
static LinearDomain::t _new_LinearDomain(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2532);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2532);
virtual monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > __mosek_2fusion_2LinearDomain__symmetric() ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2533) ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2536) ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__sparse() ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__integral() ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2538) ;
virtual bool match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2539) ;
}; // struct LinearDomain;

struct p_Domain
{
Domain * _pubthis;
static mosek::fusion::p_Domain* _get_impl(mosek::fusion::Domain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Domain * _get_impl(mosek::fusion::Domain::t _inst) { return _get_impl(_inst.get()); }
p_Domain(Domain * _pubthis);
virtual ~p_Domain() { /* std::cout << "~p_Domain" << std::endl;*/ };
virtual void destroy();
static  long long dimsize(std::shared_ptr< monty::ndarray< int,1 > > _2541);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > mkLinearDomain(mosek::fusion::RelationKey _2544,monty::rc_ptr< ::mosek::fusion::Matrix > _2545);
static  long long prod(std::shared_ptr< monty::ndarray< int,1 > > _2551);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(bool _2554,std::shared_ptr< monty::ndarray< double,1 > > _2555,std::shared_ptr< monty::ndarray< double,1 > > _2556,std::shared_ptr< monty::ndarray< int,2 > > _2557,std::shared_ptr< monty::ndarray< int,1 > > _2558);
static  monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > symmetric(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2560);
static  monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > symmetric(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2561);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2562,std::shared_ptr< monty::ndarray< int,2 > > _2563);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2564,std::shared_ptr< monty::ndarray< int,1 > > _2565);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2566,std::shared_ptr< monty::ndarray< int,2 > > _2567);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2568,std::shared_ptr< monty::ndarray< int,1 > > _2569);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > integral(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2570);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > integral(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2571);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > integral(monty::rc_ptr< ::mosek::fusion::ConeDomain > _2572);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > axis(monty::rc_ptr< ::mosek::fusion::ConeDomain > _2573,int _2574);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDPowerCone(double _2575,std::shared_ptr< monty::ndarray< int,1 > > _2576);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDPowerCone(double _2578,int _2579);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDPowerCone(double _2580);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPPowerCone(double _2581,std::shared_ptr< monty::ndarray< int,1 > > _2582);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPPowerCone(double _2584,int _2585);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPPowerCone(double _2586);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDExpCone(std::shared_ptr< monty::ndarray< int,1 > > _2587);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDExpCone(int _2589);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDExpCone();
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPExpCone(std::shared_ptr< monty::ndarray< int,1 > > _2590);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPExpCone(int _2592);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPExpCone();
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inRotatedQCone(std::shared_ptr< monty::ndarray< int,1 > > _2593);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inRotatedQCone(int _2595,int _2596);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inRotatedQCone(int _2597);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inRotatedQCone();
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inQCone(std::shared_ptr< monty::ndarray< int,1 > > _2598);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inQCone(int _2600,int _2601);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inQCone(int _2602);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inQCone();
static  monty::rc_ptr< ::mosek::fusion::LinPSDDomain > isLinPSD(int _2603,int _2604);
static  monty::rc_ptr< ::mosek::fusion::LinPSDDomain > isLinPSD(int _2605);
static  monty::rc_ptr< ::mosek::fusion::LinPSDDomain > isLinPSD();
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > isTrilPSD(int _2606,int _2607);
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > isTrilPSD(int _2608);
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > isTrilPSD();
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > inPSDCone(int _2609,int _2610);
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > inPSDCone(int _2611);
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > inPSDCone();
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > binary();
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > binary(std::shared_ptr< monty::ndarray< int,1 > > _2612);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > binary(int _2613,int _2614);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > binary(int _2615);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(std::shared_ptr< monty::ndarray< double,1 > > _2616,std::shared_ptr< monty::ndarray< double,1 > > _2617,std::shared_ptr< monty::ndarray< int,1 > > _2618);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(std::shared_ptr< monty::ndarray< double,1 > > _2619,double _2620,std::shared_ptr< monty::ndarray< int,1 > > _2621);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(double _2623,std::shared_ptr< monty::ndarray< double,1 > > _2624,std::shared_ptr< monty::ndarray< int,1 > > _2625);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(double _2627,double _2628,std::shared_ptr< monty::ndarray< int,1 > > _2629);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(std::shared_ptr< monty::ndarray< double,1 > > _2630,std::shared_ptr< monty::ndarray< double,1 > > _2631);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(std::shared_ptr< monty::ndarray< double,1 > > _2632,double _2633);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(double _2635,std::shared_ptr< monty::ndarray< double,1 > > _2636);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(double _2638,double _2639);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(monty::rc_ptr< ::mosek::fusion::Matrix > _2640);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _2641,std::shared_ptr< monty::ndarray< int,1 > > _2642);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(std::shared_ptr< monty::ndarray< double,2 > > _2643);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _2646);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(double _2647,std::shared_ptr< monty::ndarray< int,1 > > _2648);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(double _2650,int _2651,int _2652);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(double _2654,int _2655);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(double _2657);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(monty::rc_ptr< ::mosek::fusion::Matrix > _2658);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(std::shared_ptr< monty::ndarray< double,1 > > _2659,std::shared_ptr< monty::ndarray< int,1 > > _2660);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(std::shared_ptr< monty::ndarray< double,2 > > _2661);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(std::shared_ptr< monty::ndarray< double,1 > > _2664);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(double _2665,std::shared_ptr< monty::ndarray< int,1 > > _2666);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(double _2667,int _2668,int _2669);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(double _2670,int _2671);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(double _2672);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(monty::rc_ptr< ::mosek::fusion::Matrix > _2673);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _2674,std::shared_ptr< monty::ndarray< int,1 > > _2675);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(std::shared_ptr< monty::ndarray< double,2 > > _2676);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _2679);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(double _2680,std::shared_ptr< monty::ndarray< int,1 > > _2681);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(double _2682,int _2683,int _2684);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(double _2685,int _2686);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(double _2687);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > unbounded(std::shared_ptr< monty::ndarray< int,1 > > _2688);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > unbounded(int _2690,int _2691);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > unbounded(int _2692);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > unbounded();
}; // struct Domain;

struct p_BaseExpression : public /*implements*/ virtual ::mosek::fusion::Expression
{
BaseExpression * _pubthis;
static mosek::fusion::p_BaseExpression* _get_impl(mosek::fusion::BaseExpression * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_BaseExpression * _get_impl(mosek::fusion::BaseExpression::t _inst) { return _get_impl(_inst.get()); }
p_BaseExpression(BaseExpression * _pubthis);
virtual ~p_BaseExpression() { /* std::cout << "~p_BaseExpression" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static BaseExpression::t _new_BaseExpression(std::shared_ptr< monty::ndarray< int,1 > > _4868);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _4868);
virtual /* override */ std::string toString() ;
virtual monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2BaseExpression__eval() ;
virtual monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2Expression__eval() { return __mosek_2fusion_2BaseExpression__eval(); }
static  void storeexpr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4884,std::shared_ptr< monty::ndarray< int,1 > > _4885,std::shared_ptr< monty::ndarray< int,1 > > _4886,std::shared_ptr< monty::ndarray< long long,1 > > _4887,std::shared_ptr< monty::ndarray< long long,1 > > _4888,std::shared_ptr< monty::ndarray< double,1 > > _4889,std::shared_ptr< monty::ndarray< double,1 > > _4890);
virtual void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4901,monty::rc_ptr< ::mosek::fusion::WorkStack > _4902,monty::rc_ptr< ::mosek::fusion::WorkStack > _4903) { throw monty::AbstractClassError("Call to abstract method"); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4904) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4904) { return __mosek_2fusion_2BaseExpression__pick(_4904); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4905) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4905) { return __mosek_2fusion_2BaseExpression__pick(_4905); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__index(std::shared_ptr< monty::ndarray< int,1 > > _4908) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__index(std::shared_ptr< monty::ndarray< int,1 > > _4908) { return __mosek_2fusion_2BaseExpression__index(_4908); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__index(int _4911) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__index(int _4911) { return __mosek_2fusion_2BaseExpression__index(_4911); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4913,std::shared_ptr< monty::ndarray< int,1 > > _4914) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4913,std::shared_ptr< monty::ndarray< int,1 > > _4914) { return __mosek_2fusion_2BaseExpression__slice(_4913,_4914); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__slice(int _4915,int _4916) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__slice(int _4915,int _4916) { return __mosek_2fusion_2BaseExpression__slice(_4915,_4916); }
virtual long long getSize() ;
virtual int getND() ;
virtual int getDim(int _4917) ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getShape() ;
}; // struct BaseExpression;

struct p_ExprConst : public ::mosek::fusion::p_BaseExpression
{
ExprConst * _pubthis;
static mosek::fusion::p_ExprConst* _get_impl(mosek::fusion::ExprConst * _inst){ return static_cast< mosek::fusion::p_ExprConst* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprConst * _get_impl(mosek::fusion::ExprConst::t _inst) { return _get_impl(_inst.get()); }
p_ExprConst(ExprConst * _pubthis);
virtual ~p_ExprConst() { /* std::cout << "~p_ExprConst" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};virtual void destroy();
static ExprConst::t _new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > > _2693,std::shared_ptr< monty::ndarray< long long,1 > > _2694,std::shared_ptr< monty::ndarray< double,1 > > _2695);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2693,std::shared_ptr< monty::ndarray< long long,1 > > _2694,std::shared_ptr< monty::ndarray< double,1 > > _2695);
static ExprConst::t _new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > > _2696,std::shared_ptr< monty::ndarray< long long,1 > > _2697,double _2698);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2696,std::shared_ptr< monty::ndarray< long long,1 > > _2697,double _2698);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2701,monty::rc_ptr< ::mosek::fusion::WorkStack > _2702,monty::rc_ptr< ::mosek::fusion::WorkStack > _2703) ;
static  void validate(std::shared_ptr< monty::ndarray< int,1 > > _2717,std::shared_ptr< monty::ndarray< double,1 > > _2718,std::shared_ptr< monty::ndarray< long long,1 > > _2719);
virtual /* override */ std::string toString() ;
}; // struct ExprConst;

struct p_ExprPick : public ::mosek::fusion::p_BaseExpression
{
ExprPick * _pubthis;
static mosek::fusion::p_ExprPick* _get_impl(mosek::fusion::ExprPick * _inst){ return static_cast< mosek::fusion::p_ExprPick* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprPick * _get_impl(mosek::fusion::ExprPick::t _inst) { return _get_impl(_inst.get()); }
p_ExprPick(ExprPick * _pubthis);
virtual ~p_ExprPick() { /* std::cout << "~p_ExprPick" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > idxs{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprPick::t _new_ExprPick(monty::rc_ptr< ::mosek::fusion::Expression > _2723,std::shared_ptr< monty::ndarray< int,2 > > _2724);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _2723,std::shared_ptr< monty::ndarray< int,2 > > _2724);
static ExprPick::t _new_ExprPick(monty::rc_ptr< ::mosek::fusion::Expression > _2736,std::shared_ptr< monty::ndarray< long long,1 > > _2737);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _2736,std::shared_ptr< monty::ndarray< long long,1 > > _2737);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2742,monty::rc_ptr< ::mosek::fusion::WorkStack > _2743,monty::rc_ptr< ::mosek::fusion::WorkStack > _2744) ;
virtual /* override */ std::string toString() ;
}; // struct ExprPick;

struct p_ExprSlice : public ::mosek::fusion::p_BaseExpression
{
ExprSlice * _pubthis;
static mosek::fusion::p_ExprSlice* _get_impl(mosek::fusion::ExprSlice * _inst){ return static_cast< mosek::fusion::p_ExprSlice* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprSlice * _get_impl(mosek::fusion::ExprSlice::t _inst) { return _get_impl(_inst.get()); }
p_ExprSlice(ExprSlice * _pubthis);
virtual ~p_ExprSlice() { /* std::cout << "~p_ExprSlice" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > last{};std::shared_ptr< monty::ndarray< int,1 > > first{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprSlice::t _new_ExprSlice(monty::rc_ptr< ::mosek::fusion::Expression > _2796,std::shared_ptr< monty::ndarray< int,1 > > _2797,std::shared_ptr< monty::ndarray< int,1 > > _2798);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _2796,std::shared_ptr< monty::ndarray< int,1 > > _2797,std::shared_ptr< monty::ndarray< int,1 > > _2798);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2799,monty::rc_ptr< ::mosek::fusion::WorkStack > _2800,monty::rc_ptr< ::mosek::fusion::WorkStack > _2801) ;
static  std::shared_ptr< monty::ndarray< int,1 > > makeShape(std::shared_ptr< monty::ndarray< int,1 > > _2855,std::shared_ptr< monty::ndarray< int,1 > > _2856,std::shared_ptr< monty::ndarray< int,1 > > _2857);
virtual /* override */ std::string toString() ;
}; // struct ExprSlice;

struct p_ExprPermuteDims : public ::mosek::fusion::p_BaseExpression
{
ExprPermuteDims * _pubthis;
static mosek::fusion::p_ExprPermuteDims* _get_impl(mosek::fusion::ExprPermuteDims * _inst){ return static_cast< mosek::fusion::p_ExprPermuteDims* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprPermuteDims * _get_impl(mosek::fusion::ExprPermuteDims::t _inst) { return _get_impl(_inst.get()); }
p_ExprPermuteDims(ExprPermuteDims * _pubthis);
virtual ~p_ExprPermuteDims() { /* std::cout << "~p_ExprPermuteDims" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > dperm{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprPermuteDims::t _new_ExprPermuteDims(std::shared_ptr< monty::ndarray< int,1 > > _2862,monty::rc_ptr< ::mosek::fusion::Expression > _2863);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2862,monty::rc_ptr< ::mosek::fusion::Expression > _2863);
static ExprPermuteDims::t _new_ExprPermuteDims(std::shared_ptr< monty::ndarray< int,1 > > _2869,monty::rc_ptr< ::mosek::fusion::Expression > _2870,int _2871);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2869,monty::rc_ptr< ::mosek::fusion::Expression > _2870,int _2871);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2872,monty::rc_ptr< ::mosek::fusion::WorkStack > _2873,monty::rc_ptr< ::mosek::fusion::WorkStack > _2874) ;
static  std::shared_ptr< monty::ndarray< int,1 > > computeshape(std::shared_ptr< monty::ndarray< int,1 > > _2926,std::shared_ptr< monty::ndarray< int,1 > > _2927);
}; // struct ExprPermuteDims;

struct p_ExprTranspose : public ::mosek::fusion::p_BaseExpression
{
ExprTranspose * _pubthis;
static mosek::fusion::p_ExprTranspose* _get_impl(mosek::fusion::ExprTranspose * _inst){ return static_cast< mosek::fusion::p_ExprTranspose* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprTranspose * _get_impl(mosek::fusion::ExprTranspose::t _inst) { return _get_impl(_inst.get()); }
p_ExprTranspose(ExprTranspose * _pubthis);
virtual ~p_ExprTranspose() { /* std::cout << "~p_ExprTranspose" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprTranspose::t _new_ExprTranspose(monty::rc_ptr< ::mosek::fusion::Expression > _2929);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _2929);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2930,monty::rc_ptr< ::mosek::fusion::WorkStack > _2931,monty::rc_ptr< ::mosek::fusion::WorkStack > _2932) ;
virtual /* override */ std::string toString() ;
static  std::shared_ptr< monty::ndarray< int,1 > > transposeShape(std::shared_ptr< monty::ndarray< int,1 > > _2976);
}; // struct ExprTranspose;

struct p_ExprStack : public ::mosek::fusion::p_BaseExpression
{
ExprStack * _pubthis;
static mosek::fusion::p_ExprStack* _get_impl(mosek::fusion::ExprStack * _inst){ return static_cast< mosek::fusion::p_ExprStack* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprStack * _get_impl(mosek::fusion::ExprStack::t _inst) { return _get_impl(_inst.get()); }
p_ExprStack(ExprStack * _pubthis);
virtual ~p_ExprStack() { /* std::cout << "~p_ExprStack" << std::endl;*/ };
int dim{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > exprs{};virtual void destroy();
static ExprStack::t _new_ExprStack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2977,int _2978);
void _initialize(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2977,int _2978);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2980,monty::rc_ptr< ::mosek::fusion::WorkStack > _2981,monty::rc_ptr< ::mosek::fusion::WorkStack > _2982) ;
static  std::shared_ptr< monty::ndarray< int,1 > > getshape(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _3130,int _3131);
virtual /* override */ std::string toString() ;
}; // struct ExprStack;

struct p_ExprInner : public ::mosek::fusion::p_BaseExpression
{
ExprInner * _pubthis;
static mosek::fusion::p_ExprInner* _get_impl(mosek::fusion::ExprInner * _inst){ return static_cast< mosek::fusion::p_ExprInner* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprInner * _get_impl(mosek::fusion::ExprInner::t _inst) { return _get_impl(_inst.get()); }
p_ExprInner(ExprInner * _pubthis);
virtual ~p_ExprInner() { /* std::cout << "~p_ExprInner" << std::endl;*/ };
std::shared_ptr< monty::ndarray< double,1 > > vcof{};std::shared_ptr< monty::ndarray< long long,1 > > vsub{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprInner::t _new_ExprInner(monty::rc_ptr< ::mosek::fusion::Expression > _3145,std::shared_ptr< monty::ndarray< long long,1 > > _3146,std::shared_ptr< monty::ndarray< double,1 > > _3147);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _3145,std::shared_ptr< monty::ndarray< long long,1 > > _3146,std::shared_ptr< monty::ndarray< double,1 > > _3147);
static ExprInner::t _new_ExprInner(monty::rc_ptr< ::mosek::fusion::Expression > _3153,std::shared_ptr< monty::ndarray< double,1 > > _3154);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _3153,std::shared_ptr< monty::ndarray< double,1 > > _3154);
static ExprInner::t _new_ExprInner(monty::rc_ptr< ::mosek::fusion::Expression > _3156,std::shared_ptr< monty::ndarray< int,2 > > _3157,std::shared_ptr< monty::ndarray< double,1 > > _3158);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _3156,std::shared_ptr< monty::ndarray< int,2 > > _3157,std::shared_ptr< monty::ndarray< double,1 > > _3158);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3159,monty::rc_ptr< ::mosek::fusion::WorkStack > _3160,monty::rc_ptr< ::mosek::fusion::WorkStack > _3161) ;
static  std::shared_ptr< monty::ndarray< long long,1 > > range(int _3197);
static  std::shared_ptr< monty::ndarray< long long,1 > > convert(std::shared_ptr< monty::ndarray< int,1 > > _3199,std::shared_ptr< monty::ndarray< int,2 > > _3200);
virtual /* override */ std::string toString() ;
}; // struct ExprInner;

struct p_ExprMulDiagRight : public ::mosek::fusion::p_BaseExpression
{
ExprMulDiagRight * _pubthis;
static mosek::fusion::p_ExprMulDiagRight* _get_impl(mosek::fusion::ExprMulDiagRight * _inst){ return static_cast< mosek::fusion::p_ExprMulDiagRight* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulDiagRight * _get_impl(mosek::fusion::ExprMulDiagRight::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulDiagRight(ExprMulDiagRight * _pubthis);
virtual ~p_ExprMulDiagRight() { /* std::cout << "~p_ExprMulDiagRight" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprMulDiagRight::t _new_ExprMulDiagRight(int _3207,int _3208,std::shared_ptr< monty::ndarray< int,1 > > _3209,std::shared_ptr< monty::ndarray< int,1 > > _3210,std::shared_ptr< monty::ndarray< double,1 > > _3211,monty::rc_ptr< ::mosek::fusion::Expression > _3212,int _3213);
void _initialize(int _3207,int _3208,std::shared_ptr< monty::ndarray< int,1 > > _3209,std::shared_ptr< monty::ndarray< int,1 > > _3210,std::shared_ptr< monty::ndarray< double,1 > > _3211,monty::rc_ptr< ::mosek::fusion::Expression > _3212,int _3213);
static ExprMulDiagRight::t _new_ExprMulDiagRight(int _3214,int _3215,std::shared_ptr< monty::ndarray< int,1 > > _3216,std::shared_ptr< monty::ndarray< int,1 > > _3217,std::shared_ptr< monty::ndarray< double,1 > > _3218,monty::rc_ptr< ::mosek::fusion::Expression > _3219);
void _initialize(int _3214,int _3215,std::shared_ptr< monty::ndarray< int,1 > > _3216,std::shared_ptr< monty::ndarray< int,1 > > _3217,std::shared_ptr< monty::ndarray< double,1 > > _3218,monty::rc_ptr< ::mosek::fusion::Expression > _3219);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3220,monty::rc_ptr< ::mosek::fusion::WorkStack > _3221,monty::rc_ptr< ::mosek::fusion::WorkStack > _3222) ;
static  int validate(int _3314,int _3315,std::shared_ptr< monty::ndarray< int,1 > > _3316,std::shared_ptr< monty::ndarray< int,1 > > _3317,std::shared_ptr< monty::ndarray< double,1 > > _3318,monty::rc_ptr< ::mosek::fusion::Expression > _3319);
virtual /* override */ std::string toString() ;
}; // struct ExprMulDiagRight;

struct p_ExprMulDiagLeft : public ::mosek::fusion::p_BaseExpression
{
ExprMulDiagLeft * _pubthis;
static mosek::fusion::p_ExprMulDiagLeft* _get_impl(mosek::fusion::ExprMulDiagLeft * _inst){ return static_cast< mosek::fusion::p_ExprMulDiagLeft* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulDiagLeft * _get_impl(mosek::fusion::ExprMulDiagLeft::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulDiagLeft(ExprMulDiagLeft * _pubthis);
virtual ~p_ExprMulDiagLeft() { /* std::cout << "~p_ExprMulDiagLeft" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprMulDiagLeft::t _new_ExprMulDiagLeft(int _3328,int _3329,std::shared_ptr< monty::ndarray< int,1 > > _3330,std::shared_ptr< monty::ndarray< int,1 > > _3331,std::shared_ptr< monty::ndarray< double,1 > > _3332,monty::rc_ptr< ::mosek::fusion::Expression > _3333,int _3334);
void _initialize(int _3328,int _3329,std::shared_ptr< monty::ndarray< int,1 > > _3330,std::shared_ptr< monty::ndarray< int,1 > > _3331,std::shared_ptr< monty::ndarray< double,1 > > _3332,monty::rc_ptr< ::mosek::fusion::Expression > _3333,int _3334);
static ExprMulDiagLeft::t _new_ExprMulDiagLeft(int _3335,int _3336,std::shared_ptr< monty::ndarray< int,1 > > _3337,std::shared_ptr< monty::ndarray< int,1 > > _3338,std::shared_ptr< monty::ndarray< double,1 > > _3339,monty::rc_ptr< ::mosek::fusion::Expression > _3340);
void _initialize(int _3335,int _3336,std::shared_ptr< monty::ndarray< int,1 > > _3337,std::shared_ptr< monty::ndarray< int,1 > > _3338,std::shared_ptr< monty::ndarray< double,1 > > _3339,monty::rc_ptr< ::mosek::fusion::Expression > _3340);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3341,monty::rc_ptr< ::mosek::fusion::WorkStack > _3342,monty::rc_ptr< ::mosek::fusion::WorkStack > _3343) ;
static  int validate(int _3428,int _3429,std::shared_ptr< monty::ndarray< int,1 > > _3430,std::shared_ptr< monty::ndarray< int,1 > > _3431,std::shared_ptr< monty::ndarray< double,1 > > _3432,monty::rc_ptr< ::mosek::fusion::Expression > _3433);
virtual /* override */ std::string toString() ;
}; // struct ExprMulDiagLeft;

struct p_ExprMulElement : public ::mosek::fusion::p_BaseExpression
{
ExprMulElement * _pubthis;
static mosek::fusion::p_ExprMulElement* _get_impl(mosek::fusion::ExprMulElement * _inst){ return static_cast< mosek::fusion::p_ExprMulElement* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulElement * _get_impl(mosek::fusion::ExprMulElement::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulElement(ExprMulElement * _pubthis);
virtual ~p_ExprMulElement() { /* std::cout << "~p_ExprMulElement" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< long long,1 > > msp{};std::shared_ptr< monty::ndarray< double,1 > > mcof{};virtual void destroy();
static ExprMulElement::t _new_ExprMulElement(std::shared_ptr< monty::ndarray< double,1 > > _3442,std::shared_ptr< monty::ndarray< long long,1 > > _3443,monty::rc_ptr< ::mosek::fusion::Expression > _3444);
void _initialize(std::shared_ptr< monty::ndarray< double,1 > > _3442,std::shared_ptr< monty::ndarray< long long,1 > > _3443,monty::rc_ptr< ::mosek::fusion::Expression > _3444);
static ExprMulElement::t _new_ExprMulElement(std::shared_ptr< monty::ndarray< double,1 > > _3451,std::shared_ptr< monty::ndarray< long long,1 > > _3452,monty::rc_ptr< ::mosek::fusion::Expression > _3453,int _3454);
void _initialize(std::shared_ptr< monty::ndarray< double,1 > > _3451,std::shared_ptr< monty::ndarray< long long,1 > > _3452,monty::rc_ptr< ::mosek::fusion::Expression > _3453,int _3454);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3455,monty::rc_ptr< ::mosek::fusion::WorkStack > _3456,monty::rc_ptr< ::mosek::fusion::WorkStack > _3457) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulElement;

struct p_ExprMulScalarConst : public ::mosek::fusion::p_BaseExpression
{
ExprMulScalarConst * _pubthis;
static mosek::fusion::p_ExprMulScalarConst* _get_impl(mosek::fusion::ExprMulScalarConst * _inst){ return static_cast< mosek::fusion::p_ExprMulScalarConst* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulScalarConst * _get_impl(mosek::fusion::ExprMulScalarConst::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulScalarConst(ExprMulScalarConst * _pubthis);
virtual ~p_ExprMulScalarConst() { /* std::cout << "~p_ExprMulScalarConst" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};double c{};virtual void destroy();
static ExprMulScalarConst::t _new_ExprMulScalarConst(double _3504,monty::rc_ptr< ::mosek::fusion::Expression > _3505);
void _initialize(double _3504,monty::rc_ptr< ::mosek::fusion::Expression > _3505);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3506,monty::rc_ptr< ::mosek::fusion::WorkStack > _3507,monty::rc_ptr< ::mosek::fusion::WorkStack > _3508) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulScalarConst;

struct p_ExprScalarMul : public ::mosek::fusion::p_BaseExpression
{
ExprScalarMul * _pubthis;
static mosek::fusion::p_ExprScalarMul* _get_impl(mosek::fusion::ExprScalarMul * _inst){ return static_cast< mosek::fusion::p_ExprScalarMul* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprScalarMul * _get_impl(mosek::fusion::ExprScalarMul::t _inst) { return _get_impl(_inst.get()); }
p_ExprScalarMul(ExprScalarMul * _pubthis);
virtual ~p_ExprScalarMul() { /* std::cout << "~p_ExprScalarMul" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprScalarMul::t _new_ExprScalarMul(int _3516,int _3517,std::shared_ptr< monty::ndarray< int,1 > > _3518,std::shared_ptr< monty::ndarray< int,1 > > _3519,std::shared_ptr< monty::ndarray< double,1 > > _3520,monty::rc_ptr< ::mosek::fusion::Expression > _3521,int _3522);
void _initialize(int _3516,int _3517,std::shared_ptr< monty::ndarray< int,1 > > _3518,std::shared_ptr< monty::ndarray< int,1 > > _3519,std::shared_ptr< monty::ndarray< double,1 > > _3520,monty::rc_ptr< ::mosek::fusion::Expression > _3521,int _3522);
static ExprScalarMul::t _new_ExprScalarMul(int _3523,int _3524,std::shared_ptr< monty::ndarray< int,1 > > _3525,std::shared_ptr< monty::ndarray< int,1 > > _3526,std::shared_ptr< monty::ndarray< double,1 > > _3527,monty::rc_ptr< ::mosek::fusion::Expression > _3528);
void _initialize(int _3523,int _3524,std::shared_ptr< monty::ndarray< int,1 > > _3525,std::shared_ptr< monty::ndarray< int,1 > > _3526,std::shared_ptr< monty::ndarray< double,1 > > _3527,monty::rc_ptr< ::mosek::fusion::Expression > _3528);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3529,monty::rc_ptr< ::mosek::fusion::WorkStack > _3530,monty::rc_ptr< ::mosek::fusion::WorkStack > _3531) ;
static  int validate(int _3556,int _3557,std::shared_ptr< monty::ndarray< int,1 > > _3558,std::shared_ptr< monty::ndarray< int,1 > > _3559,std::shared_ptr< monty::ndarray< double,1 > > _3560,monty::rc_ptr< ::mosek::fusion::Expression > _3561);
virtual /* override */ std::string toString() ;
}; // struct ExprScalarMul;

struct p_ExprMulRight : public ::mosek::fusion::p_BaseExpression
{
ExprMulRight * _pubthis;
static mosek::fusion::p_ExprMulRight* _get_impl(mosek::fusion::ExprMulRight * _inst){ return static_cast< mosek::fusion::p_ExprMulRight* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulRight * _get_impl(mosek::fusion::ExprMulRight::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulRight(ExprMulRight * _pubthis);
virtual ~p_ExprMulRight() { /* std::cout << "~p_ExprMulRight" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprMulRight::t _new_ExprMulRight(int _3568,int _3569,std::shared_ptr< monty::ndarray< int,1 > > _3570,std::shared_ptr< monty::ndarray< int,1 > > _3571,std::shared_ptr< monty::ndarray< double,1 > > _3572,monty::rc_ptr< ::mosek::fusion::Expression > _3573,int _3574);
void _initialize(int _3568,int _3569,std::shared_ptr< monty::ndarray< int,1 > > _3570,std::shared_ptr< monty::ndarray< int,1 > > _3571,std::shared_ptr< monty::ndarray< double,1 > > _3572,monty::rc_ptr< ::mosek::fusion::Expression > _3573,int _3574);
static ExprMulRight::t _new_ExprMulRight(int _3575,int _3576,std::shared_ptr< monty::ndarray< int,1 > > _3577,std::shared_ptr< monty::ndarray< int,1 > > _3578,std::shared_ptr< monty::ndarray< double,1 > > _3579,monty::rc_ptr< ::mosek::fusion::Expression > _3580);
void _initialize(int _3575,int _3576,std::shared_ptr< monty::ndarray< int,1 > > _3577,std::shared_ptr< monty::ndarray< int,1 > > _3578,std::shared_ptr< monty::ndarray< double,1 > > _3579,monty::rc_ptr< ::mosek::fusion::Expression > _3580);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3581,monty::rc_ptr< ::mosek::fusion::WorkStack > _3582,monty::rc_ptr< ::mosek::fusion::WorkStack > _3583) ;
static  std::shared_ptr< monty::ndarray< int,1 > > computeshape(int _3733,std::shared_ptr< monty::ndarray< int,1 > > _3734);
static  int validate(int _3735,int _3736,std::shared_ptr< monty::ndarray< int,1 > > _3737,std::shared_ptr< monty::ndarray< int,1 > > _3738,std::shared_ptr< monty::ndarray< double,1 > > _3739,monty::rc_ptr< ::mosek::fusion::Expression > _3740);
virtual /* override */ std::string toString() ;
}; // struct ExprMulRight;

struct p_ExprMulLeft : public ::mosek::fusion::p_BaseExpression
{
ExprMulLeft * _pubthis;
static mosek::fusion::p_ExprMulLeft* _get_impl(mosek::fusion::ExprMulLeft * _inst){ return static_cast< mosek::fusion::p_ExprMulLeft* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulLeft * _get_impl(mosek::fusion::ExprMulLeft::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulLeft(ExprMulLeft * _pubthis);
virtual ~p_ExprMulLeft() { /* std::cout << "~p_ExprMulLeft" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprMulLeft::t _new_ExprMulLeft(int _3749,int _3750,std::shared_ptr< monty::ndarray< int,1 > > _3751,std::shared_ptr< monty::ndarray< int,1 > > _3752,std::shared_ptr< monty::ndarray< double,1 > > _3753,monty::rc_ptr< ::mosek::fusion::Expression > _3754,int _3755);
void _initialize(int _3749,int _3750,std::shared_ptr< monty::ndarray< int,1 > > _3751,std::shared_ptr< monty::ndarray< int,1 > > _3752,std::shared_ptr< monty::ndarray< double,1 > > _3753,monty::rc_ptr< ::mosek::fusion::Expression > _3754,int _3755);
static ExprMulLeft::t _new_ExprMulLeft(int _3756,int _3757,std::shared_ptr< monty::ndarray< int,1 > > _3758,std::shared_ptr< monty::ndarray< int,1 > > _3759,std::shared_ptr< monty::ndarray< double,1 > > _3760,monty::rc_ptr< ::mosek::fusion::Expression > _3761);
void _initialize(int _3756,int _3757,std::shared_ptr< monty::ndarray< int,1 > > _3758,std::shared_ptr< monty::ndarray< int,1 > > _3759,std::shared_ptr< monty::ndarray< double,1 > > _3760,monty::rc_ptr< ::mosek::fusion::Expression > _3761);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3762,monty::rc_ptr< ::mosek::fusion::WorkStack > _3763,monty::rc_ptr< ::mosek::fusion::WorkStack > _3764) ;
static  std::shared_ptr< monty::ndarray< int,1 > > computeshape(int _3862,int _3863,std::shared_ptr< monty::ndarray< int,1 > > _3864);
static  int validate(int _3865,int _3866,std::shared_ptr< monty::ndarray< int,1 > > _3867,std::shared_ptr< monty::ndarray< int,1 > > _3868,std::shared_ptr< monty::ndarray< double,1 > > _3869,monty::rc_ptr< ::mosek::fusion::Expression > _3870);
virtual /* override */ std::string toString() ;
}; // struct ExprMulLeft;

struct p_ExprMulVar : public ::mosek::fusion::p_BaseExpression
{
ExprMulVar * _pubthis;
static mosek::fusion::p_ExprMulVar* _get_impl(mosek::fusion::ExprMulVar * _inst){ return static_cast< mosek::fusion::p_ExprMulVar* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulVar * _get_impl(mosek::fusion::ExprMulVar::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulVar(ExprMulVar * _pubthis);
virtual ~p_ExprMulVar() { /* std::cout << "~p_ExprMulVar" << std::endl;*/ };
bool left{};monty::rc_ptr< ::mosek::fusion::Variable > x{};std::shared_ptr< monty::ndarray< double,1 > > mcof{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdimj{};int mdimi{};virtual void destroy();
static ExprMulVar::t _new_ExprMulVar(bool _3878,int _3879,int _3880,std::shared_ptr< monty::ndarray< int,1 > > _3881,std::shared_ptr< monty::ndarray< int,1 > > _3882,std::shared_ptr< monty::ndarray< double,1 > > _3883,monty::rc_ptr< ::mosek::fusion::Variable > _3884);
void _initialize(bool _3878,int _3879,int _3880,std::shared_ptr< monty::ndarray< int,1 > > _3881,std::shared_ptr< monty::ndarray< int,1 > > _3882,std::shared_ptr< monty::ndarray< double,1 > > _3883,monty::rc_ptr< ::mosek::fusion::Variable > _3884);
static ExprMulVar::t _new_ExprMulVar(bool _3887,int _3888,int _3889,std::shared_ptr< monty::ndarray< int,1 > > _3890,std::shared_ptr< monty::ndarray< int,1 > > _3891,std::shared_ptr< monty::ndarray< double,1 > > _3892,monty::rc_ptr< ::mosek::fusion::Variable > _3893,int _3894);
void _initialize(bool _3887,int _3888,int _3889,std::shared_ptr< monty::ndarray< int,1 > > _3890,std::shared_ptr< monty::ndarray< int,1 > > _3891,std::shared_ptr< monty::ndarray< double,1 > > _3892,monty::rc_ptr< ::mosek::fusion::Variable > _3893,int _3894);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3895,monty::rc_ptr< ::mosek::fusion::WorkStack > _3896,monty::rc_ptr< ::mosek::fusion::WorkStack > _3897) ;
virtual void eval_right(monty::rc_ptr< ::mosek::fusion::WorkStack > _3898,monty::rc_ptr< ::mosek::fusion::WorkStack > _3899,monty::rc_ptr< ::mosek::fusion::WorkStack > _3900) ;
virtual void eval_left(monty::rc_ptr< ::mosek::fusion::WorkStack > _4006,monty::rc_ptr< ::mosek::fusion::WorkStack > _4007,monty::rc_ptr< ::mosek::fusion::WorkStack > _4008) ;
virtual void validate(int _4083,int _4084,std::shared_ptr< monty::ndarray< int,1 > > _4085,std::shared_ptr< monty::ndarray< int,1 > > _4086,std::shared_ptr< monty::ndarray< double,1 > > _4087) ;
static  std::shared_ptr< monty::ndarray< int,1 > > resshape(int _4091,int _4092,std::shared_ptr< monty::ndarray< int,1 > > _4093,bool _4094);
virtual /* override */ std::string toString() ;
}; // struct ExprMulVar;

struct p_ExprMulScalarVar : public ::mosek::fusion::p_BaseExpression
{
ExprMulScalarVar * _pubthis;
static mosek::fusion::p_ExprMulScalarVar* _get_impl(mosek::fusion::ExprMulScalarVar * _inst){ return static_cast< mosek::fusion::p_ExprMulScalarVar* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulScalarVar * _get_impl(mosek::fusion::ExprMulScalarVar::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulScalarVar(ExprMulScalarVar * _pubthis);
virtual ~p_ExprMulScalarVar() { /* std::cout << "~p_ExprMulScalarVar" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Variable > x{};std::shared_ptr< monty::ndarray< double,1 > > mcof{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdimj{};int mdimi{};virtual void destroy();
static ExprMulScalarVar::t _new_ExprMulScalarVar(int _4095,int _4096,std::shared_ptr< monty::ndarray< int,1 > > _4097,std::shared_ptr< monty::ndarray< int,1 > > _4098,std::shared_ptr< monty::ndarray< double,1 > > _4099,monty::rc_ptr< ::mosek::fusion::Variable > _4100);
void _initialize(int _4095,int _4096,std::shared_ptr< monty::ndarray< int,1 > > _4097,std::shared_ptr< monty::ndarray< int,1 > > _4098,std::shared_ptr< monty::ndarray< double,1 > > _4099,monty::rc_ptr< ::mosek::fusion::Variable > _4100);
static ExprMulScalarVar::t _new_ExprMulScalarVar(int _4105,int _4106,std::shared_ptr< monty::ndarray< int,1 > > _4107,std::shared_ptr< monty::ndarray< int,1 > > _4108,std::shared_ptr< monty::ndarray< double,1 > > _4109,monty::rc_ptr< ::mosek::fusion::Variable > _4110,int _4111);
void _initialize(int _4105,int _4106,std::shared_ptr< monty::ndarray< int,1 > > _4107,std::shared_ptr< monty::ndarray< int,1 > > _4108,std::shared_ptr< monty::ndarray< double,1 > > _4109,monty::rc_ptr< ::mosek::fusion::Variable > _4110,int _4111);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4112,monty::rc_ptr< ::mosek::fusion::WorkStack > _4113,monty::rc_ptr< ::mosek::fusion::WorkStack > _4114) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulScalarVar;

struct p_ExprMulVarScalarConst : public ::mosek::fusion::p_BaseExpression
{
ExprMulVarScalarConst * _pubthis;
static mosek::fusion::p_ExprMulVarScalarConst* _get_impl(mosek::fusion::ExprMulVarScalarConst * _inst){ return static_cast< mosek::fusion::p_ExprMulVarScalarConst* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulVarScalarConst * _get_impl(mosek::fusion::ExprMulVarScalarConst::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulVarScalarConst(ExprMulVarScalarConst * _pubthis);
virtual ~p_ExprMulVarScalarConst() { /* std::cout << "~p_ExprMulVarScalarConst" << std::endl;*/ };
double c{};monty::rc_ptr< ::mosek::fusion::Variable > x{};virtual void destroy();
static ExprMulVarScalarConst::t _new_ExprMulVarScalarConst(monty::rc_ptr< ::mosek::fusion::Variable > _4133,double _4134);
void _initialize(monty::rc_ptr< ::mosek::fusion::Variable > _4133,double _4134);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4135,monty::rc_ptr< ::mosek::fusion::WorkStack > _4136,monty::rc_ptr< ::mosek::fusion::WorkStack > _4137) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulVarScalarConst;

struct p_ExprAdd : public ::mosek::fusion::p_BaseExpression
{
ExprAdd * _pubthis;
static mosek::fusion::p_ExprAdd* _get_impl(mosek::fusion::ExprAdd * _inst){ return static_cast< mosek::fusion::p_ExprAdd* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprAdd * _get_impl(mosek::fusion::ExprAdd::t _inst) { return _get_impl(_inst.get()); }
p_ExprAdd(ExprAdd * _pubthis);
virtual ~p_ExprAdd() { /* std::cout << "~p_ExprAdd" << std::endl;*/ };
double m2{};double m1{};monty::rc_ptr< ::mosek::fusion::Expression > e2{};monty::rc_ptr< ::mosek::fusion::Expression > e1{};virtual void destroy();
static ExprAdd::t _new_ExprAdd(monty::rc_ptr< ::mosek::fusion::Expression > _4155,monty::rc_ptr< ::mosek::fusion::Expression > _4156,double _4157,double _4158);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4155,monty::rc_ptr< ::mosek::fusion::Expression > _4156,double _4157,double _4158);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4160,monty::rc_ptr< ::mosek::fusion::WorkStack > _4161,monty::rc_ptr< ::mosek::fusion::WorkStack > _4162) ;
virtual /* override */ std::string toString() ;
}; // struct ExprAdd;

struct p_ExprWSum : public ::mosek::fusion::p_BaseExpression
{
ExprWSum * _pubthis;
static mosek::fusion::p_ExprWSum* _get_impl(mosek::fusion::ExprWSum * _inst){ return static_cast< mosek::fusion::p_ExprWSum* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprWSum * _get_impl(mosek::fusion::ExprWSum::t _inst) { return _get_impl(_inst.get()); }
p_ExprWSum(ExprWSum * _pubthis);
virtual ~p_ExprWSum() { /* std::cout << "~p_ExprWSum" << std::endl;*/ };
std::shared_ptr< monty::ndarray< double,1 > > w{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > es{};virtual void destroy();
static ExprWSum::t _new_ExprWSum(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4272,std::shared_ptr< monty::ndarray< double,1 > > _4273);
void _initialize(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4272,std::shared_ptr< monty::ndarray< double,1 > > _4273);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4280,monty::rc_ptr< ::mosek::fusion::WorkStack > _4281,monty::rc_ptr< ::mosek::fusion::WorkStack > _4282) ;
virtual /* override */ std::string toString() ;
}; // struct ExprWSum;

struct p_ExprSumReduce : public ::mosek::fusion::p_BaseExpression
{
ExprSumReduce * _pubthis;
static mosek::fusion::p_ExprSumReduce* _get_impl(mosek::fusion::ExprSumReduce * _inst){ return static_cast< mosek::fusion::p_ExprSumReduce* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprSumReduce * _get_impl(mosek::fusion::ExprSumReduce::t _inst) { return _get_impl(_inst.get()); }
p_ExprSumReduce(ExprSumReduce * _pubthis);
virtual ~p_ExprSumReduce() { /* std::cout << "~p_ExprSumReduce" << std::endl;*/ };
int dim{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprSumReduce::t _new_ExprSumReduce(int _4349,monty::rc_ptr< ::mosek::fusion::Expression > _4350);
void _initialize(int _4349,monty::rc_ptr< ::mosek::fusion::Expression > _4350);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4352,monty::rc_ptr< ::mosek::fusion::WorkStack > _4353,monty::rc_ptr< ::mosek::fusion::WorkStack > _4354) ;
static  std::shared_ptr< monty::ndarray< int,1 > > computeShape(int _4458,std::shared_ptr< monty::ndarray< int,1 > > _4459);
virtual /* override */ std::string toString() ;
}; // struct ExprSumReduce;

struct p_ExprDenseTril : public ::mosek::fusion::p_BaseExpression
{
ExprDenseTril * _pubthis;
static mosek::fusion::p_ExprDenseTril* _get_impl(mosek::fusion::ExprDenseTril * _inst){ return static_cast< mosek::fusion::p_ExprDenseTril* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprDenseTril * _get_impl(mosek::fusion::ExprDenseTril::t _inst) { return _get_impl(_inst.get()); }
p_ExprDenseTril(ExprDenseTril * _pubthis);
virtual ~p_ExprDenseTril() { /* std::cout << "~p_ExprDenseTril" << std::endl;*/ };
int dim1{};int dim0{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprDenseTril::t _new_ExprDenseTril(int _4463,int _4464,monty::rc_ptr< ::mosek::fusion::Expression > _4465,int _4466);
void _initialize(int _4463,int _4464,monty::rc_ptr< ::mosek::fusion::Expression > _4465,int _4466);
static ExprDenseTril::t _new_ExprDenseTril(int _4467,int _4468,monty::rc_ptr< ::mosek::fusion::Expression > _4469);
void _initialize(int _4467,int _4468,monty::rc_ptr< ::mosek::fusion::Expression > _4469);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4471,monty::rc_ptr< ::mosek::fusion::WorkStack > _4472,monty::rc_ptr< ::mosek::fusion::WorkStack > _4473) ;
}; // struct ExprDenseTril;

struct p_ExprDense : public ::mosek::fusion::p_BaseExpression
{
ExprDense * _pubthis;
static mosek::fusion::p_ExprDense* _get_impl(mosek::fusion::ExprDense * _inst){ return static_cast< mosek::fusion::p_ExprDense* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprDense * _get_impl(mosek::fusion::ExprDense::t _inst) { return _get_impl(_inst.get()); }
p_ExprDense(ExprDense * _pubthis);
virtual ~p_ExprDense() { /* std::cout << "~p_ExprDense" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprDense::t _new_ExprDense(monty::rc_ptr< ::mosek::fusion::Expression > _4546);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4546);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4547,monty::rc_ptr< ::mosek::fusion::WorkStack > _4548,monty::rc_ptr< ::mosek::fusion::WorkStack > _4549) ;
virtual /* override */ std::string toString() ;
}; // struct ExprDense;

struct p_ExprSymmetrize : public ::mosek::fusion::p_BaseExpression
{
ExprSymmetrize * _pubthis;
static mosek::fusion::p_ExprSymmetrize* _get_impl(mosek::fusion::ExprSymmetrize * _inst){ return static_cast< mosek::fusion::p_ExprSymmetrize* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprSymmetrize * _get_impl(mosek::fusion::ExprSymmetrize::t _inst) { return _get_impl(_inst.get()); }
p_ExprSymmetrize(ExprSymmetrize * _pubthis);
virtual ~p_ExprSymmetrize() { /* std::cout << "~p_ExprSymmetrize" << std::endl;*/ };
int dim1{};int dim0{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprSymmetrize::t _new_ExprSymmetrize(int _4572,int _4573,monty::rc_ptr< ::mosek::fusion::Expression > _4574,int _4575);
void _initialize(int _4572,int _4573,monty::rc_ptr< ::mosek::fusion::Expression > _4574,int _4575);
static ExprSymmetrize::t _new_ExprSymmetrize(int _4576,int _4577,monty::rc_ptr< ::mosek::fusion::Expression > _4578);
void _initialize(int _4576,int _4577,monty::rc_ptr< ::mosek::fusion::Expression > _4578);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4580,monty::rc_ptr< ::mosek::fusion::WorkStack > _4581,monty::rc_ptr< ::mosek::fusion::WorkStack > _4582) ;
}; // struct ExprSymmetrize;

struct p_ExprCompress : public ::mosek::fusion::p_BaseExpression
{
ExprCompress * _pubthis;
static mosek::fusion::p_ExprCompress* _get_impl(mosek::fusion::ExprCompress * _inst){ return static_cast< mosek::fusion::p_ExprCompress* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprCompress * _get_impl(mosek::fusion::ExprCompress::t _inst) { return _get_impl(_inst.get()); }
p_ExprCompress(ExprCompress * _pubthis);
virtual ~p_ExprCompress() { /* std::cout << "~p_ExprCompress" << std::endl;*/ };
double eps{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprCompress::t _new_ExprCompress(monty::rc_ptr< ::mosek::fusion::Expression > _4681);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4681);
static ExprCompress::t _new_ExprCompress(monty::rc_ptr< ::mosek::fusion::Expression > _4682,double _4683);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4682,double _4683);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4684,monty::rc_ptr< ::mosek::fusion::WorkStack > _4685,monty::rc_ptr< ::mosek::fusion::WorkStack > _4686) ;
static  void arg_sort(monty::rc_ptr< ::mosek::fusion::WorkStack > _4752,monty::rc_ptr< ::mosek::fusion::WorkStack > _4753,int _4754,int _4755,int _4756,int _4757,int _4758);
static  void merge_sort(int _4794,int _4795,int _4796,int _4797,int _4798,int _4799,std::shared_ptr< monty::ndarray< int,1 > > _4800,std::shared_ptr< monty::ndarray< long long,1 > > _4801);
virtual /* override */ std::string toString() ;
}; // struct ExprCompress;

struct p_ExprCondense : public ::mosek::fusion::p_BaseExpression
{
ExprCondense * _pubthis;
static mosek::fusion::p_ExprCondense* _get_impl(mosek::fusion::ExprCondense * _inst){ return static_cast< mosek::fusion::p_ExprCondense* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprCondense * _get_impl(mosek::fusion::ExprCondense::t _inst) { return _get_impl(_inst.get()); }
p_ExprCondense(ExprCondense * _pubthis);
virtual ~p_ExprCondense() { /* std::cout << "~p_ExprCondense" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprCondense::t _new_ExprCondense(monty::rc_ptr< ::mosek::fusion::Expression > _4824);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4824);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4825,monty::rc_ptr< ::mosek::fusion::WorkStack > _4826,monty::rc_ptr< ::mosek::fusion::WorkStack > _4827) ;
}; // struct ExprCondense;

struct p_ExprFromVar : public ::mosek::fusion::p_BaseExpression
{
ExprFromVar * _pubthis;
static mosek::fusion::p_ExprFromVar* _get_impl(mosek::fusion::ExprFromVar * _inst){ return static_cast< mosek::fusion::p_ExprFromVar* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprFromVar * _get_impl(mosek::fusion::ExprFromVar::t _inst) { return _get_impl(_inst.get()); }
p_ExprFromVar(ExprFromVar * _pubthis);
virtual ~p_ExprFromVar() { /* std::cout << "~p_ExprFromVar" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Variable > x{};virtual void destroy();
static ExprFromVar::t _new_ExprFromVar(monty::rc_ptr< ::mosek::fusion::Variable > _4834);
void _initialize(monty::rc_ptr< ::mosek::fusion::Variable > _4834);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4835,monty::rc_ptr< ::mosek::fusion::WorkStack > _4836,monty::rc_ptr< ::mosek::fusion::WorkStack > _4837) ;
virtual /* override */ std::string toString() ;
}; // struct ExprFromVar;

struct p_ExprReshape : public ::mosek::fusion::p_BaseExpression
{
ExprReshape * _pubthis;
static mosek::fusion::p_ExprReshape* _get_impl(mosek::fusion::ExprReshape * _inst){ return static_cast< mosek::fusion::p_ExprReshape* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprReshape * _get_impl(mosek::fusion::ExprReshape::t _inst) { return _get_impl(_inst.get()); }
p_ExprReshape(ExprReshape * _pubthis);
virtual ~p_ExprReshape() { /* std::cout << "~p_ExprReshape" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > e{};virtual void destroy();
static ExprReshape::t _new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > > _4855,monty::rc_ptr< ::mosek::fusion::Expression > _4856);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _4855,monty::rc_ptr< ::mosek::fusion::Expression > _4856);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4858,monty::rc_ptr< ::mosek::fusion::WorkStack > _4859,monty::rc_ptr< ::mosek::fusion::WorkStack > _4860) ;
virtual /* override */ std::string toString() ;
}; // struct ExprReshape;

struct p_Expr : public ::mosek::fusion::p_BaseExpression
{
Expr * _pubthis;
static mosek::fusion::p_Expr* _get_impl(mosek::fusion::Expr * _inst){ return static_cast< mosek::fusion::p_Expr* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_Expr * _get_impl(mosek::fusion::Expr::t _inst) { return _get_impl(_inst.get()); }
p_Expr(Expr * _pubthis);
virtual ~p_Expr() { /* std::cout << "~p_Expr" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > inst{};std::shared_ptr< monty::ndarray< double,1 > > cof_v{};std::shared_ptr< monty::ndarray< long long,1 > > subj{};std::shared_ptr< monty::ndarray< long long,1 > > ptrb{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static Expr::t _new_Expr(std::shared_ptr< monty::ndarray< long long,1 > > _4992,std::shared_ptr< monty::ndarray< long long,1 > > _4993,std::shared_ptr< monty::ndarray< double,1 > > _4994,std::shared_ptr< monty::ndarray< double,1 > > _4995,std::shared_ptr< monty::ndarray< int,1 > > _4996,std::shared_ptr< monty::ndarray< long long,1 > > _4997);
void _initialize(std::shared_ptr< monty::ndarray< long long,1 > > _4992,std::shared_ptr< monty::ndarray< long long,1 > > _4993,std::shared_ptr< monty::ndarray< double,1 > > _4994,std::shared_ptr< monty::ndarray< double,1 > > _4995,std::shared_ptr< monty::ndarray< int,1 > > _4996,std::shared_ptr< monty::ndarray< long long,1 > > _4997);
static Expr::t _new_Expr(std::shared_ptr< monty::ndarray< long long,1 > > _5008,std::shared_ptr< monty::ndarray< long long,1 > > _5009,std::shared_ptr< monty::ndarray< double,1 > > _5010,std::shared_ptr< monty::ndarray< double,1 > > _5011,std::shared_ptr< monty::ndarray< int,1 > > _5012,std::shared_ptr< monty::ndarray< long long,1 > > _5013,int _5014);
void _initialize(std::shared_ptr< monty::ndarray< long long,1 > > _5008,std::shared_ptr< monty::ndarray< long long,1 > > _5009,std::shared_ptr< monty::ndarray< double,1 > > _5010,std::shared_ptr< monty::ndarray< double,1 > > _5011,std::shared_ptr< monty::ndarray< int,1 > > _5012,std::shared_ptr< monty::ndarray< long long,1 > > _5013,int _5014);
static Expr::t _new_Expr(monty::rc_ptr< ::mosek::fusion::Expression > _5015);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _5015);
virtual long long prod(std::shared_ptr< monty::ndarray< int,1 > > _5040) ;
static  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > varstack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _5043);
static  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > varstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5046,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5047);
static  monty::rc_ptr< ::mosek::fusion::Expression > condense(monty::rc_ptr< ::mosek::fusion::Expression > _5051);
static  monty::rc_ptr< ::mosek::fusion::Expression > flatten(monty::rc_ptr< ::mosek::fusion::Expression > _5052);
static  monty::rc_ptr< ::mosek::fusion::Expression > reshape(monty::rc_ptr< ::mosek::fusion::Expression > _5053,int _5054,int _5055);
static  monty::rc_ptr< ::mosek::fusion::Expression > reshape(monty::rc_ptr< ::mosek::fusion::Expression > _5056,int _5057);
static  monty::rc_ptr< ::mosek::fusion::Expression > reshape(monty::rc_ptr< ::mosek::fusion::Expression > _5058,std::shared_ptr< monty::ndarray< int,1 > > _5059);
virtual long long size() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2Expr__eval() ;
virtual monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2BaseExpression__eval() { return __mosek_2fusion_2Expr__eval(); }
static  monty::rc_ptr< ::mosek::fusion::Expression > zeros(std::shared_ptr< monty::ndarray< int,1 > > _5062);
static  monty::rc_ptr< ::mosek::fusion::Expression > zeros(int _5063);
static  monty::rc_ptr< ::mosek::fusion::Expression > ones();
static  monty::rc_ptr< ::mosek::fusion::Expression > ones(std::shared_ptr< monty::ndarray< int,1 > > _5064,std::shared_ptr< monty::ndarray< int,2 > > _5065);
static  monty::rc_ptr< ::mosek::fusion::Expression > ones(std::shared_ptr< monty::ndarray< int,1 > > _5066);
static  monty::rc_ptr< ::mosek::fusion::Expression > ones(int _5067);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5068);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(monty::rc_ptr< ::mosek::fusion::Matrix > _5069);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(double _5078);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5079,std::shared_ptr< monty::ndarray< int,2 > > _5080,double _5081);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5089,std::shared_ptr< monty::ndarray< int,2 > > _5090,std::shared_ptr< monty::ndarray< double,1 > > _5091);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5099,double _5100);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(int _5101,double _5102);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< double,2 > > _5104);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< double,1 > > _5107);
virtual long long numNonzeros() ;
static  monty::rc_ptr< ::mosek::fusion::Expression > sum(monty::rc_ptr< ::mosek::fusion::Expression > _5108,int _5109);
static  monty::rc_ptr< ::mosek::fusion::Expression > sum(monty::rc_ptr< ::mosek::fusion::Expression > _5110);
static  monty::rc_ptr< ::mosek::fusion::Expression > neg(monty::rc_ptr< ::mosek::fusion::Expression > _5111);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(bool _5112,monty::rc_ptr< ::mosek::fusion::Matrix > _5113,monty::rc_ptr< ::mosek::fusion::Expression > _5114);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _5121,monty::rc_ptr< ::mosek::fusion::Matrix > _5122);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _5123,monty::rc_ptr< ::mosek::fusion::Variable > _5124);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _5125,monty::rc_ptr< ::mosek::fusion::Matrix > _5126);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _5127,monty::rc_ptr< ::mosek::fusion::Expression > _5128);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _5129,std::shared_ptr< monty::ndarray< double,2 > > _5130);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _5137,std::shared_ptr< monty::ndarray< double,2 > > _5138);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _5145,monty::rc_ptr< ::mosek::fusion::Variable > _5146);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _5153,monty::rc_ptr< ::mosek::fusion::Expression > _5154);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm_(monty::rc_ptr< ::mosek::fusion::Matrix > _5161,monty::rc_ptr< ::mosek::fusion::Expression > _5162);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm_(std::shared_ptr< monty::ndarray< double,1 > > _5171,monty::rc_ptr< ::mosek::fusion::Expression > _5172);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm_(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5174,monty::rc_ptr< ::mosek::fusion::Expression > _5175);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Expression > _5178,double _5179);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(double _5180,monty::rc_ptr< ::mosek::fusion::Expression > _5181);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Expression > _5182,std::shared_ptr< monty::ndarray< double,1 > > _5183);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(std::shared_ptr< monty::ndarray< double,1 > > _5184,monty::rc_ptr< ::mosek::fusion::Expression > _5185);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Expression > _5186,std::shared_ptr< monty::ndarray< double,2 > > _5187);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(std::shared_ptr< monty::ndarray< double,2 > > _5188,monty::rc_ptr< ::mosek::fusion::Expression > _5189);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Expression > _5190,monty::rc_ptr< ::mosek::fusion::Matrix > _5191);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Matrix > _5192,monty::rc_ptr< ::mosek::fusion::Expression > _5193);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(bool _5194,std::shared_ptr< monty::ndarray< double,1 > > _5195,monty::rc_ptr< ::mosek::fusion::Expression > _5196);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(bool _5211,std::shared_ptr< monty::ndarray< double,2 > > _5212,monty::rc_ptr< ::mosek::fusion::Expression > _5213);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(bool _5228,monty::rc_ptr< ::mosek::fusion::Matrix > _5229,monty::rc_ptr< ::mosek::fusion::Expression > _5230);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Variable > _5239,monty::rc_ptr< ::mosek::fusion::Matrix > _5240);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Matrix > _5246,monty::rc_ptr< ::mosek::fusion::Variable > _5247);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(bool _5253,int _5254,int _5255,std::shared_ptr< monty::ndarray< int,1 > > _5256,std::shared_ptr< monty::ndarray< int,1 > > _5257,std::shared_ptr< monty::ndarray< double,1 > > _5258,monty::rc_ptr< ::mosek::fusion::Variable > _5259);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Expression > _5261,monty::rc_ptr< ::mosek::fusion::Matrix > _5262);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Expression > _5270,std::shared_ptr< monty::ndarray< double,2 > > _5271);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Expression > _5275,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5276);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Expression > _5277,std::shared_ptr< monty::ndarray< double,1 > > _5278);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Matrix > _5283,monty::rc_ptr< ::mosek::fusion::Expression > _5284);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5285,monty::rc_ptr< ::mosek::fusion::Expression > _5286);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(std::shared_ptr< monty::ndarray< double,2 > > _5287,monty::rc_ptr< ::mosek::fusion::Expression > _5288);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(std::shared_ptr< monty::ndarray< double,1 > > _5289,monty::rc_ptr< ::mosek::fusion::Expression > _5290);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(std::shared_ptr< monty::ndarray< double,1 > > _5291,monty::rc_ptr< ::mosek::fusion::Expression > _5292);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(monty::rc_ptr< ::mosek::fusion::Expression > _5296,std::shared_ptr< monty::ndarray< double,1 > > _5297);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(monty::rc_ptr< ::mosek::fusion::Matrix > _5300,monty::rc_ptr< ::mosek::fusion::Variable > _5301);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(monty::rc_ptr< ::mosek::fusion::Variable > _5308,monty::rc_ptr< ::mosek::fusion::Matrix > _5309);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(std::shared_ptr< monty::ndarray< double,1 > > _5316,monty::rc_ptr< ::mosek::fusion::Variable > _5317);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(monty::rc_ptr< ::mosek::fusion::Variable > _5319,std::shared_ptr< monty::ndarray< double,1 > > _5320);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer_(int _5322,std::shared_ptr< monty::ndarray< long long,1 > > _5323,std::shared_ptr< monty::ndarray< long long,1 > > _5324,std::shared_ptr< monty::ndarray< double,1 > > _5325,std::shared_ptr< monty::ndarray< double,1 > > _5326,std::shared_ptr< monty::ndarray< long long,1 > > _5327,std::shared_ptr< monty::ndarray< double,1 > > _5328,std::shared_ptr< monty::ndarray< int,1 > > _5329,int _5330,bool _5331);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer_(monty::rc_ptr< ::mosek::fusion::Variable > _5361,int _5362,std::shared_ptr< monty::ndarray< double,1 > > _5363,std::shared_ptr< monty::ndarray< int,1 > > _5364,int _5365,bool _5366);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >,1 > > _5383);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _5389,double _5390,double _5391);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _5392,double _5393,monty::rc_ptr< ::mosek::fusion::Expression > _5394);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _5395,monty::rc_ptr< ::mosek::fusion::Expression > _5396,double _5397);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _5398,monty::rc_ptr< ::mosek::fusion::Expression > _5399,monty::rc_ptr< ::mosek::fusion::Expression > _5400);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5401,double _5402,double _5403);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5404,double _5405,monty::rc_ptr< ::mosek::fusion::Expression > _5406);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5407,monty::rc_ptr< ::mosek::fusion::Expression > _5408,double _5409);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5410,monty::rc_ptr< ::mosek::fusion::Expression > _5411,monty::rc_ptr< ::mosek::fusion::Expression > _5412);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _5413,monty::rc_ptr< ::mosek::fusion::Expression > _5414);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5415,double _5416);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5417,monty::rc_ptr< ::mosek::fusion::Expression > _5418);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5419);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5421,monty::rc_ptr< ::mosek::fusion::Expression > _5422,monty::rc_ptr< ::mosek::fusion::Expression > _5423);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5424,monty::rc_ptr< ::mosek::fusion::Expression > _5425,double _5426);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5427,double _5428,monty::rc_ptr< ::mosek::fusion::Expression > _5429);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5430,double _5431,double _5432);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(double _5433,monty::rc_ptr< ::mosek::fusion::Expression > _5434,monty::rc_ptr< ::mosek::fusion::Expression > _5435);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(double _5436,monty::rc_ptr< ::mosek::fusion::Expression > _5437,double _5438);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(double _5439,double _5440,monty::rc_ptr< ::mosek::fusion::Expression > _5441);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(double _5442,monty::rc_ptr< ::mosek::fusion::Expression > _5443);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5444,double _5445);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5446,monty::rc_ptr< ::mosek::fusion::Expression > _5447);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5448);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5450,monty::rc_ptr< ::mosek::fusion::Expression > _5451,monty::rc_ptr< ::mosek::fusion::Expression > _5452,monty::rc_ptr< ::mosek::fusion::Expression > _5453);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5454,monty::rc_ptr< ::mosek::fusion::Expression > _5455,monty::rc_ptr< ::mosek::fusion::Expression > _5456,double _5457);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5458,monty::rc_ptr< ::mosek::fusion::Expression > _5459,double _5460,monty::rc_ptr< ::mosek::fusion::Expression > _5461);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5462,monty::rc_ptr< ::mosek::fusion::Expression > _5463,double _5464,double _5465);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5466,double _5467,monty::rc_ptr< ::mosek::fusion::Expression > _5468,monty::rc_ptr< ::mosek::fusion::Expression > _5469);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5470,double _5471,monty::rc_ptr< ::mosek::fusion::Expression > _5472,double _5473);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5474,double _5475,double _5476,monty::rc_ptr< ::mosek::fusion::Expression > _5477);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5478,double _5479,monty::rc_ptr< ::mosek::fusion::Expression > _5480);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5481,monty::rc_ptr< ::mosek::fusion::Expression > _5482,double _5483);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5484,monty::rc_ptr< ::mosek::fusion::Expression > _5485,monty::rc_ptr< ::mosek::fusion::Expression > _5486);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5487,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5488);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5489,int _5490);
static  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > promote(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5491,int _5492);
static  monty::rc_ptr< ::mosek::fusion::Expression > repeat(monty::rc_ptr< ::mosek::fusion::Expression > _5505,int _5506,int _5507);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5509);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5511);
static  monty::rc_ptr< ::mosek::fusion::Expression > add_(monty::rc_ptr< ::mosek::fusion::Expression > _5544,double _5545,monty::rc_ptr< ::mosek::fusion::Expression > _5546,double _5547);
static  monty::rc_ptr< ::mosek::fusion::Expression > transpose(monty::rc_ptr< ::mosek::fusion::Expression > _5558);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Matrix > _5559,monty::rc_ptr< ::mosek::fusion::Expression > _5560);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5561,monty::rc_ptr< ::mosek::fusion::Expression > _5562);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(std::shared_ptr< monty::ndarray< double,2 > > _5563,monty::rc_ptr< ::mosek::fusion::Expression > _5564);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(std::shared_ptr< monty::ndarray< double,1 > > _5565,monty::rc_ptr< ::mosek::fusion::Expression > _5566);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5567,monty::rc_ptr< ::mosek::fusion::Matrix > _5568);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5569,std::shared_ptr< monty::ndarray< double,2 > > _5570);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5571,std::shared_ptr< monty::ndarray< double,1 > > _5572);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5573,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5574);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5575,monty::rc_ptr< ::mosek::fusion::Expression > _5576);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5577,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5578);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Matrix > _5579,monty::rc_ptr< ::mosek::fusion::Expression > _5580);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5581,monty::rc_ptr< ::mosek::fusion::Matrix > _5582);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(double _5583,monty::rc_ptr< ::mosek::fusion::Expression > _5584);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5585,double _5586);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(std::shared_ptr< monty::ndarray< double,2 > > _5587,monty::rc_ptr< ::mosek::fusion::Expression > _5588);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(std::shared_ptr< monty::ndarray< double,1 > > _5589,monty::rc_ptr< ::mosek::fusion::Expression > _5590);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5591,std::shared_ptr< monty::ndarray< double,2 > > _5592);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5593,std::shared_ptr< monty::ndarray< double,1 > > _5594);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5595,monty::rc_ptr< ::mosek::fusion::Expression > _5596);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5597,monty::rc_ptr< ::mosek::fusion::Expression > _5598);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5599,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5600);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Matrix > _5601,monty::rc_ptr< ::mosek::fusion::Expression > _5602);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5603,monty::rc_ptr< ::mosek::fusion::Matrix > _5604);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(double _5605,monty::rc_ptr< ::mosek::fusion::Expression > _5606);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5607,double _5608);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(std::shared_ptr< monty::ndarray< double,2 > > _5609,monty::rc_ptr< ::mosek::fusion::Expression > _5610);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(std::shared_ptr< monty::ndarray< double,1 > > _5611,monty::rc_ptr< ::mosek::fusion::Expression > _5612);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5613,std::shared_ptr< monty::ndarray< double,2 > > _5614);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5615,std::shared_ptr< monty::ndarray< double,1 > > _5616);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5617,monty::rc_ptr< ::mosek::fusion::Expression > _5618);
virtual /* override */ int getND() ;
virtual /* override */ std::shared_ptr< monty::ndarray< int,1 > > getShape() ;
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5619,monty::rc_ptr< ::mosek::fusion::WorkStack > _5620,monty::rc_ptr< ::mosek::fusion::WorkStack > _5621) ;
static  void validateData(std::shared_ptr< monty::ndarray< long long,1 > > _5623,std::shared_ptr< monty::ndarray< long long,1 > > _5624,std::shared_ptr< monty::ndarray< double,1 > > _5625,std::shared_ptr< monty::ndarray< double,1 > > _5626,std::shared_ptr< monty::ndarray< int,1 > > _5627,std::shared_ptr< monty::ndarray< long long,1 > > _5628);
static  monty::rc_ptr< ::mosek::fusion::Model > extractModel(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5641);
}; // struct Expr;

struct p_WorkStack
{
WorkStack * _pubthis;
static mosek::fusion::p_WorkStack* _get_impl(mosek::fusion::WorkStack * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_WorkStack * _get_impl(mosek::fusion::WorkStack::t _inst) { return _get_impl(_inst.get()); }
p_WorkStack(WorkStack * _pubthis);
virtual ~p_WorkStack() { /* std::cout << "~p_WorkStack" << std::endl;*/ };
int cof_base{};int bfix_base{};int nidxs_base{};int sp_base{};int shape_base{};int ptr_base{};bool hassp{};int nelem{};int nnz{};int nd{};int pf64{};int pi64{};int pi32{};std::shared_ptr< monty::ndarray< double,1 > > f64{};std::shared_ptr< monty::ndarray< long long,1 > > i64{};std::shared_ptr< monty::ndarray< int,1 > > i32{};virtual void destroy();
static WorkStack::t _new_WorkStack();
void _initialize();
virtual bool peek_hassp() ;
virtual int peek_nnz() ;
virtual int peek_nelem() ;
virtual int peek_dim(int _4918) ;
virtual int peek_nd() ;
virtual void alloc_expr(int _4919,int _4920,int _4921,bool _4922) ;
virtual void move_expr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4923) ;
virtual void peek_expr() ;
virtual void pop_expr() ;
virtual void ensure_sparsity() ;
virtual void clear() ;
virtual int allocf64(int _4938) ;
virtual int alloci64(int _4940) ;
virtual int alloci32(int _4942) ;
virtual void pushf64(double _4944) ;
virtual void pushi64(long long _4945) ;
virtual void pushi32(int _4946) ;
virtual void ensuref64(int _4947) ;
virtual void ensurei64(int _4950) ;
virtual void ensurei32(int _4953) ;
virtual int popf64(int _4956) ;
virtual int popi64(int _4957) ;
virtual int popi32(int _4958) ;
virtual void popf64(int _4959,std::shared_ptr< monty::ndarray< double,1 > > _4960,int _4961) ;
virtual void popi64(int _4962,std::shared_ptr< monty::ndarray< long long,1 > > _4963,int _4964) ;
virtual void popi32(int _4965,std::shared_ptr< monty::ndarray< int,1 > > _4966,int _4967) ;
virtual double popf64() ;
virtual long long popi64() ;
virtual int popi32() ;
virtual double peekf64() ;
virtual long long peeki64() ;
virtual int peeki32() ;
virtual double peekf64(int _4968) ;
virtual long long peeki64(int _4969) ;
virtual int peeki32(int _4970) ;
}; // struct WorkStack;

struct p_SymmetricExpr
{
SymmetricExpr * _pubthis;
static mosek::fusion::p_SymmetricExpr* _get_impl(mosek::fusion::SymmetricExpr * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_SymmetricExpr * _get_impl(mosek::fusion::SymmetricExpr::t _inst) { return _get_impl(_inst.get()); }
p_SymmetricExpr(SymmetricExpr * _pubthis);
virtual ~p_SymmetricExpr() { /* std::cout << "~p_SymmetricExpr" << std::endl;*/ };
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > xs{};monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > b{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > Ms{};int n{};virtual void destroy();
static SymmetricExpr::t _new_SymmetricExpr(int _4971,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4972,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4973,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4974);
void _initialize(int _4971,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4972,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4973,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4974);
static  monty::rc_ptr< ::mosek::fusion::SymmetricExpr > add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4975,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4976);
static  monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mul(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4977,double _4978);
static  monty::rc_ptr< ::mosek::fusion::SymmetricExpr > add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4980,monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4981);
virtual /* override */ std::string toString() ;
}; // struct SymmetricExpr;

struct p_FlatExpr
{
FlatExpr * _pubthis;
static mosek::fusion::p_FlatExpr* _get_impl(mosek::fusion::FlatExpr * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_FlatExpr * _get_impl(mosek::fusion::FlatExpr::t _inst) { return _get_impl(_inst.get()); }
p_FlatExpr(FlatExpr * _pubthis);
virtual ~p_FlatExpr() { /* std::cout << "~p_FlatExpr" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > inst{};std::shared_ptr< monty::ndarray< int,1 > > shape{};long long nnz{};std::shared_ptr< monty::ndarray< double,1 > > cof{};std::shared_ptr< monty::ndarray< long long,1 > > subj{};std::shared_ptr< monty::ndarray< long long,1 > > ptrb{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};virtual void destroy();
static FlatExpr::t _new_FlatExpr(monty::rc_ptr< ::mosek::fusion::FlatExpr > _5654);
void _initialize(monty::rc_ptr< ::mosek::fusion::FlatExpr > _5654);
static FlatExpr::t _new_FlatExpr(std::shared_ptr< monty::ndarray< double,1 > > _5655,std::shared_ptr< monty::ndarray< long long,1 > > _5656,std::shared_ptr< monty::ndarray< long long,1 > > _5657,std::shared_ptr< monty::ndarray< double,1 > > _5658,std::shared_ptr< monty::ndarray< int,1 > > _5659,std::shared_ptr< monty::ndarray< long long,1 > > _5660);
void _initialize(std::shared_ptr< monty::ndarray< double,1 > > _5655,std::shared_ptr< monty::ndarray< long long,1 > > _5656,std::shared_ptr< monty::ndarray< long long,1 > > _5657,std::shared_ptr< monty::ndarray< double,1 > > _5658,std::shared_ptr< monty::ndarray< int,1 > > _5659,std::shared_ptr< monty::ndarray< long long,1 > > _5660);
virtual /* override */ std::string toString() ;
virtual int size() ;
}; // struct FlatExpr;

struct p_SymmetricMatrix
{
SymmetricMatrix * _pubthis;
static mosek::fusion::p_SymmetricMatrix* _get_impl(mosek::fusion::SymmetricMatrix * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_SymmetricMatrix * _get_impl(mosek::fusion::SymmetricMatrix::t _inst) { return _get_impl(_inst.get()); }
p_SymmetricMatrix(SymmetricMatrix * _pubthis);
virtual ~p_SymmetricMatrix() { /* std::cout << "~p_SymmetricMatrix" << std::endl;*/ };
int nnz{};double scale{};std::shared_ptr< monty::ndarray< double,1 > > vval{};std::shared_ptr< monty::ndarray< int,1 > > vsubj{};std::shared_ptr< monty::ndarray< int,1 > > vsubi{};std::shared_ptr< monty::ndarray< double,1 > > uval{};std::shared_ptr< monty::ndarray< int,1 > > usubj{};std::shared_ptr< monty::ndarray< int,1 > > usubi{};int d1{};int d0{};virtual void destroy();
static SymmetricMatrix::t _new_SymmetricMatrix(int _5662,int _5663,std::shared_ptr< monty::ndarray< int,1 > > _5664,std::shared_ptr< monty::ndarray< int,1 > > _5665,std::shared_ptr< monty::ndarray< double,1 > > _5666,std::shared_ptr< monty::ndarray< int,1 > > _5667,std::shared_ptr< monty::ndarray< int,1 > > _5668,std::shared_ptr< monty::ndarray< double,1 > > _5669,double _5670);
void _initialize(int _5662,int _5663,std::shared_ptr< monty::ndarray< int,1 > > _5664,std::shared_ptr< monty::ndarray< int,1 > > _5665,std::shared_ptr< monty::ndarray< double,1 > > _5666,std::shared_ptr< monty::ndarray< int,1 > > _5667,std::shared_ptr< monty::ndarray< int,1 > > _5668,std::shared_ptr< monty::ndarray< double,1 > > _5669,double _5670);
static  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > rankOne(int _5671,std::shared_ptr< monty::ndarray< int,1 > > _5672,std::shared_ptr< monty::ndarray< double,1 > > _5673);
static  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > rankOne(std::shared_ptr< monty::ndarray< double,1 > > _5681);
static  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > antiDiag(std::shared_ptr< monty::ndarray< double,1 > > _5689);
static  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > diag(std::shared_ptr< monty::ndarray< double,1 > > _5696);
virtual monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > __mosek_2fusion_2SymmetricMatrix__add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5702) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > __mosek_2fusion_2SymmetricMatrix__sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5722) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > __mosek_2fusion_2SymmetricMatrix__mul(double _5723) ;
virtual int getdim() ;
}; // struct SymmetricMatrix;

struct p_NDSparseArray
{
NDSparseArray * _pubthis;
static mosek::fusion::p_NDSparseArray* _get_impl(mosek::fusion::NDSparseArray * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_NDSparseArray * _get_impl(mosek::fusion::NDSparseArray::t _inst) { return _get_impl(_inst.get()); }
p_NDSparseArray(NDSparseArray * _pubthis);
virtual ~p_NDSparseArray() { /* std::cout << "~p_NDSparseArray" << std::endl;*/ };
std::shared_ptr< monty::ndarray< double,1 > > cof{};std::shared_ptr< monty::ndarray< long long,1 > > inst{};std::shared_ptr< monty::ndarray< int,1 > > dims{};long long size{};virtual void destroy();
static NDSparseArray::t _new_NDSparseArray(std::shared_ptr< monty::ndarray< int,1 > > _5724,std::shared_ptr< monty::ndarray< int,2 > > _5725,std::shared_ptr< monty::ndarray< double,1 > > _5726);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _5724,std::shared_ptr< monty::ndarray< int,2 > > _5725,std::shared_ptr< monty::ndarray< double,1 > > _5726);
static NDSparseArray::t _new_NDSparseArray(std::shared_ptr< monty::ndarray< int,1 > > _5747,std::shared_ptr< monty::ndarray< long long,1 > > _5748,std::shared_ptr< monty::ndarray< double,1 > > _5749);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _5747,std::shared_ptr< monty::ndarray< long long,1 > > _5748,std::shared_ptr< monty::ndarray< double,1 > > _5749);
static NDSparseArray::t _new_NDSparseArray(monty::rc_ptr< ::mosek::fusion::Matrix > _5764);
void _initialize(monty::rc_ptr< ::mosek::fusion::Matrix > _5764);
static  monty::rc_ptr< ::mosek::fusion::NDSparseArray > make(monty::rc_ptr< ::mosek::fusion::Matrix > _5772);
static  monty::rc_ptr< ::mosek::fusion::NDSparseArray > make(std::shared_ptr< monty::ndarray< int,1 > > _5773,std::shared_ptr< monty::ndarray< long long,1 > > _5774,std::shared_ptr< monty::ndarray< double,1 > > _5775);
static  monty::rc_ptr< ::mosek::fusion::NDSparseArray > make(std::shared_ptr< monty::ndarray< int,1 > > _5776,std::shared_ptr< monty::ndarray< int,2 > > _5777,std::shared_ptr< monty::ndarray< double,1 > > _5778);
}; // struct NDSparseArray;

struct p_Matrix
{
Matrix * _pubthis;
static mosek::fusion::p_Matrix* _get_impl(mosek::fusion::Matrix * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Matrix * _get_impl(mosek::fusion::Matrix::t _inst) { return _get_impl(_inst.get()); }
p_Matrix(Matrix * _pubthis);
virtual ~p_Matrix() { /* std::cout << "~p_Matrix" << std::endl;*/ };
int dimj{};int dimi{};virtual void destroy();
static Matrix::t _new_Matrix(int _5848,int _5849);
void _initialize(int _5848,int _5849);
virtual /* override */ std::string toString() ;
virtual void switchDims() ;
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(int _5851,monty::rc_ptr< ::mosek::fusion::Matrix > _5852);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5854);
static  monty::rc_ptr< ::mosek::fusion::Matrix > antidiag(int _5872,double _5873,int _5874);
static  monty::rc_ptr< ::mosek::fusion::Matrix > antidiag(int _5875,double _5876);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(int _5877,double _5878,int _5879);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(int _5880,double _5881);
static  monty::rc_ptr< ::mosek::fusion::Matrix > antidiag(std::shared_ptr< monty::ndarray< double,1 > > _5882,int _5883);
static  monty::rc_ptr< ::mosek::fusion::Matrix > antidiag(std::shared_ptr< monty::ndarray< double,1 > > _5893);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(std::shared_ptr< monty::ndarray< double,1 > > _5894,int _5895);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(std::shared_ptr< monty::ndarray< double,1 > > _5903);
static  monty::rc_ptr< ::mosek::fusion::Matrix > ones(int _5904,int _5905);
static  monty::rc_ptr< ::mosek::fusion::Matrix > eye(int _5906);
static  monty::rc_ptr< ::mosek::fusion::Matrix > dense(monty::rc_ptr< ::mosek::fusion::Matrix > _5908);
static  monty::rc_ptr< ::mosek::fusion::Matrix > dense(int _5909,int _5910,double _5911);
static  monty::rc_ptr< ::mosek::fusion::Matrix > dense(int _5912,int _5913,std::shared_ptr< monty::ndarray< double,1 > > _5914);
static  monty::rc_ptr< ::mosek::fusion::Matrix > dense(std::shared_ptr< monty::ndarray< double,2 > > _5915);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(monty::rc_ptr< ::mosek::fusion::Matrix > _5916);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >,1 > > _5920);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(std::shared_ptr< monty::ndarray< double,2 > > _5951);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(int _5961,int _5962);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(int _5963,int _5964,std::shared_ptr< monty::ndarray< int,1 > > _5965,std::shared_ptr< monty::ndarray< int,1 > > _5966,double _5967);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(std::shared_ptr< monty::ndarray< int,1 > > _5969,std::shared_ptr< monty::ndarray< int,1 > > _5970,double _5971);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(std::shared_ptr< monty::ndarray< int,1 > > _5976,std::shared_ptr< monty::ndarray< int,1 > > _5977,std::shared_ptr< monty::ndarray< double,1 > > _5978);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(int _5983,int _5984,std::shared_ptr< monty::ndarray< int,1 > > _5985,std::shared_ptr< monty::ndarray< int,1 > > _5986,std::shared_ptr< monty::ndarray< double,1 > > _5987);
virtual double get(int _5992,int _5993) { throw monty::AbstractClassError("Call to abstract method"); }
virtual bool isSparse() { throw monty::AbstractClassError("Call to abstract method"); }
virtual std::shared_ptr< monty::ndarray< double,1 > > getDataAsArray() { throw monty::AbstractClassError("Call to abstract method"); }
virtual void getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5994,std::shared_ptr< monty::ndarray< int,1 > > _5995,std::shared_ptr< monty::ndarray< double,1 > > _5996) { throw monty::AbstractClassError("Call to abstract method"); }
virtual monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2Matrix__transpose() { throw monty::AbstractClassError("Call to abstract method"); }
virtual long long numNonzeros() { throw monty::AbstractClassError("Call to abstract method"); }
virtual int numColumns() ;
virtual int numRows() ;
}; // struct Matrix;

struct p_DenseMatrix : public ::mosek::fusion::p_Matrix
{
DenseMatrix * _pubthis;
static mosek::fusion::p_DenseMatrix* _get_impl(mosek::fusion::DenseMatrix * _inst){ return static_cast< mosek::fusion::p_DenseMatrix* >(mosek::fusion::p_Matrix::_get_impl(_inst)); }
static mosek::fusion::p_DenseMatrix * _get_impl(mosek::fusion::DenseMatrix::t _inst) { return _get_impl(_inst.get()); }
p_DenseMatrix(DenseMatrix * _pubthis);
virtual ~p_DenseMatrix() { /* std::cout << "~p_DenseMatrix" << std::endl;*/ };
long long nnz{};std::shared_ptr< monty::ndarray< double,1 > > data{};virtual void destroy();
static DenseMatrix::t _new_DenseMatrix(int _5779,int _5780,std::shared_ptr< monty::ndarray< double,1 > > _5781);
void _initialize(int _5779,int _5780,std::shared_ptr< monty::ndarray< double,1 > > _5781);
static DenseMatrix::t _new_DenseMatrix(monty::rc_ptr< ::mosek::fusion::Matrix > _5782);
void _initialize(monty::rc_ptr< ::mosek::fusion::Matrix > _5782);
static DenseMatrix::t _new_DenseMatrix(std::shared_ptr< monty::ndarray< double,2 > > _5787);
void _initialize(std::shared_ptr< monty::ndarray< double,2 > > _5787);
static DenseMatrix::t _new_DenseMatrix(int _5790,int _5791,double _5792);
void _initialize(int _5790,int _5791,double _5792);
virtual /* override */ std::string toString() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2DenseMatrix__transpose() ;
virtual monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2DenseMatrix__transpose(); }
virtual /* override */ bool isSparse() ;
virtual /* override */ std::shared_ptr< monty::ndarray< double,1 > > getDataAsArray() ;
virtual /* override */ void getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5805,std::shared_ptr< monty::ndarray< int,1 > > _5806,std::shared_ptr< monty::ndarray< double,1 > > _5807) ;
virtual /* override */ double get(int _5811,int _5812) ;
virtual /* override */ long long numNonzeros() ;
}; // struct DenseMatrix;

struct p_SparseMatrix : public ::mosek::fusion::p_Matrix
{
SparseMatrix * _pubthis;
static mosek::fusion::p_SparseMatrix* _get_impl(mosek::fusion::SparseMatrix * _inst){ return static_cast< mosek::fusion::p_SparseMatrix* >(mosek::fusion::p_Matrix::_get_impl(_inst)); }
static mosek::fusion::p_SparseMatrix * _get_impl(mosek::fusion::SparseMatrix::t _inst) { return _get_impl(_inst.get()); }
p_SparseMatrix(SparseMatrix * _pubthis);
virtual ~p_SparseMatrix() { /* std::cout << "~p_SparseMatrix" << std::endl;*/ };
long long nnz{};std::shared_ptr< monty::ndarray< double,1 > > val{};std::shared_ptr< monty::ndarray< int,1 > > subj{};std::shared_ptr< monty::ndarray< int,1 > > subi{};virtual void destroy();
static SparseMatrix::t _new_SparseMatrix(int _5813,int _5814,std::shared_ptr< monty::ndarray< int,1 > > _5815,std::shared_ptr< monty::ndarray< int,1 > > _5816,std::shared_ptr< monty::ndarray< double,1 > > _5817,long long _5818);
void _initialize(int _5813,int _5814,std::shared_ptr< monty::ndarray< int,1 > > _5815,std::shared_ptr< monty::ndarray< int,1 > > _5816,std::shared_ptr< monty::ndarray< double,1 > > _5817,long long _5818);
static SparseMatrix::t _new_SparseMatrix(int _5824,int _5825,std::shared_ptr< monty::ndarray< int,1 > > _5826,std::shared_ptr< monty::ndarray< int,1 > > _5827,std::shared_ptr< monty::ndarray< double,1 > > _5828);
void _initialize(int _5824,int _5825,std::shared_ptr< monty::ndarray< int,1 > > _5826,std::shared_ptr< monty::ndarray< int,1 > > _5827,std::shared_ptr< monty::ndarray< double,1 > > _5828);
virtual std::shared_ptr< monty::ndarray< long long,1 > > formPtrb() ;
virtual /* override */ std::string toString() ;
virtual /* override */ long long numNonzeros() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2SparseMatrix__transpose() ;
virtual monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2SparseMatrix__transpose(); }
virtual /* override */ bool isSparse() ;
virtual /* override */ std::shared_ptr< monty::ndarray< double,1 > > getDataAsArray() ;
virtual /* override */ void getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5840,std::shared_ptr< monty::ndarray< int,1 > > _5841,std::shared_ptr< monty::ndarray< double,1 > > _5842) ;
virtual /* override */ double get(int _5843,int _5844) ;
}; // struct SparseMatrix;

struct p_LinkedBlocks
{
LinkedBlocks * _pubthis;
static mosek::fusion::p_LinkedBlocks* _get_impl(mosek::fusion::LinkedBlocks * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_LinkedBlocks * _get_impl(mosek::fusion::LinkedBlocks::t _inst) { return _get_impl(_inst.get()); }
p_LinkedBlocks(LinkedBlocks * _pubthis);
virtual ~p_LinkedBlocks() { /* std::cout << "~p_LinkedBlocks" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > bfirst{};std::shared_ptr< monty::ndarray< int,1 > > bsize{};monty::rc_ptr< ::mosek::fusion::LinkedInts > blocks{};monty::rc_ptr< ::mosek::fusion::LinkedInts > ints{};virtual void destroy();
static LinkedBlocks::t _new_LinkedBlocks();
void _initialize();
static LinkedBlocks::t _new_LinkedBlocks(int _6020);
void _initialize(int _6020);
static LinkedBlocks::t _new_LinkedBlocks(monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _6021);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _6021);
virtual void free(int _6022) ;
virtual int alloc(int _6024) ;
virtual int maxidx(int _6029) ;
virtual void get(int _6030,std::shared_ptr< monty::ndarray< int,1 > > _6031,int _6032) ;
virtual int numblocks() ;
virtual int blocksize(int _6033) ;
virtual int capacity() ;
virtual bool validate() ;
}; // struct LinkedBlocks;

struct p_LinkedInts
{
LinkedInts * _pubthis;
static mosek::fusion::p_LinkedInts* _get_impl(mosek::fusion::LinkedInts * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_LinkedInts * _get_impl(mosek::fusion::LinkedInts::t _inst) { return _get_impl(_inst.get()); }
p_LinkedInts(LinkedInts * _pubthis);
virtual ~p_LinkedInts() { /* std::cout << "~p_LinkedInts" << std::endl;*/ };
int nfree{};int last_free{};int first_free{};int first_used{};std::shared_ptr< monty::ndarray< int,1 > > prev{};std::shared_ptr< monty::ndarray< int,1 > > next{};virtual void destroy();
static LinkedInts::t _new_LinkedInts(int _6034);
void _initialize(int _6034);
static LinkedInts::t _new_LinkedInts();
void _initialize();
static LinkedInts::t _new_LinkedInts(monty::rc_ptr< ::mosek::fusion::LinkedInts > _6037);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinkedInts > _6037);
virtual void free(int _6038,int _6039) ;
virtual int alloc() ;
virtual int alloc(int _6045) ;
virtual void alloc(int _6046,std::shared_ptr< monty::ndarray< int,1 > > _6047,int _6048) ;
virtual void get(int _6051,int _6052,std::shared_ptr< monty::ndarray< int,1 > > _6053,int _6054) ;
virtual int maxidx(int _6057,int _6058) ;
virtual int allocblock(int _6062) ;
virtual void recap(int _6068) ;
virtual int capacity() ;
virtual bool validate() ;
}; // struct LinkedInts;

struct p_Parameters
{
Parameters * _pubthis;
static mosek::fusion::p_Parameters* _get_impl(mosek::fusion::Parameters * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Parameters * _get_impl(mosek::fusion::Parameters::t _inst) { return _get_impl(_inst.get()); }
p_Parameters(Parameters * _pubthis);
virtual ~p_Parameters() { /* std::cout << "~p_Parameters" << std::endl;*/ };
virtual void destroy();
static  void setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6077,const std::string &  _6078,double _6079);
static  void setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6173,const std::string &  _6174,int _6175);
static  void setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6269,const std::string &  _6270,const std::string &  _6271);
static  int string_to_variabletype_value(const std::string &  _6509);
static  int string_to_value_value(const std::string &  _6510);
static  int string_to_streamtype_value(const std::string &  _6511);
static  int string_to_startpointtype_value(const std::string &  _6512);
static  int string_to_stakey_value(const std::string &  _6513);
static  int string_to_sparam_value(const std::string &  _6514);
static  int string_to_solveform_value(const std::string &  _6515);
static  int string_to_soltype_value(const std::string &  _6516);
static  int string_to_solsta_value(const std::string &  _6517);
static  int string_to_solitem_value(const std::string &  _6518);
static  int string_to_simseltype_value(const std::string &  _6519);
static  int string_to_sensitivitytype_value(const std::string &  _6520);
static  int string_to_scalingmethod_value(const std::string &  _6521);
static  int string_to_scalingtype_value(const std::string &  _6522);
static  int string_to_rescodetype_value(const std::string &  _6523);
static  int string_to_rescode_value(const std::string &  _6524);
static  int string_to_xmlwriteroutputtype_value(const std::string &  _6525);
static  int string_to_prosta_value(const std::string &  _6526);
static  int string_to_problemtype_value(const std::string &  _6527);
static  int string_to_problemitem_value(const std::string &  _6528);
static  int string_to_parametertype_value(const std::string &  _6529);
static  int string_to_presolvemode_value(const std::string &  _6530);
static  int string_to_orderingtype_value(const std::string &  _6531);
static  int string_to_optimizertype_value(const std::string &  _6532);
static  int string_to_onoffkey_value(const std::string &  _6533);
static  int string_to_objsense_value(const std::string &  _6534);
static  int string_to_mpsformat_value(const std::string &  _6535);
static  int string_to_mionodeseltype_value(const std::string &  _6536);
static  int string_to_miomode_value(const std::string &  _6537);
static  int string_to_miocontsoltype_value(const std::string &  _6538);
static  int string_to_branchdir_value(const std::string &  _6539);
static  int string_to_iparam_value(const std::string &  _6540);
static  int string_to_iomode_value(const std::string &  _6541);
static  int string_to_internal_iinf_value(const std::string &  _6542);
static  int string_to_internal_dinf_value(const std::string &  _6543);
static  int string_to_inftype_value(const std::string &  _6544);
static  int string_to_iinfitem_value(const std::string &  _6545);
static  int string_to_internal_liinf_value(const std::string &  _6546);
static  int string_to_liinfitem_value(const std::string &  _6547);
static  int string_to_dparam_value(const std::string &  _6548);
static  int string_to_feature_value(const std::string &  _6549);
static  int string_to_dinfitem_value(const std::string &  _6550);
static  int string_to_dataformat_value(const std::string &  _6551);
static  int string_to_symmattype_value(const std::string &  _6552);
static  int string_to_scopr_value(const std::string &  _6553);
static  int string_to_nametype_value(const std::string &  _6554);
static  int string_to_conetype_value(const std::string &  _6555);
static  int string_to_compresstype_value(const std::string &  _6556);
static  int string_to_checkconvexitytype_value(const std::string &  _6557);
static  int string_to_callbackcode_value(const std::string &  _6558);
static  int string_to_purify_value(const std::string &  _6559);
static  int string_to_intpnthotstart_value(const std::string &  _6560);
static  int string_to_simhotstart_value(const std::string &  _6561);
static  int string_to_simdupvec_value(const std::string &  _6562);
static  int string_to_simreform_value(const std::string &  _6563);
static  int string_to_uplo_value(const std::string &  _6564);
static  int string_to_transpose_value(const std::string &  _6565);
static  int string_to_simdegen_value(const std::string &  _6566);
static  int string_to_mark_value(const std::string &  _6567);
static  int string_to_boundkey_value(const std::string &  _6568);
static  int string_to_basindtype_value(const std::string &  _6569);
static  int string_to_language_value(const std::string &  _6570);
}; // struct Parameters;

}
}
namespace mosek
{
namespace fusion
{
namespace Utils
{
// mosek.fusion.Utils.IntMap from file 'src/fusion/cxx/IntMap_p.h'
struct p_IntMap 
{
  IntMap * _pubself;

  static p_IntMap * _get_impl(IntMap * _inst) { return _inst->_impl.get(); }

  p_IntMap(IntMap * _pubself) : _pubself(_pubself) {}

  static IntMap::t _new_IntMap() { return new IntMap(); }

  ::std::unordered_map<long long,int> m;

  bool hasItem (long long key) { return m.find(key) != m.end(); }
  int  getItem (long long key) { return m.find(key)->second; } // will probably throw something or crash of no such key
  void setItem (long long key, int val) { m[key] = val; }

  std::shared_ptr<monty::ndarray<long long,1>> keys()
  { 
    size_t size = m.size();
    auto res = std::shared_ptr<monty::ndarray<long long,1>>(new monty::ndarray<long long,1>(monty::shape((int)size)));

    ptrdiff_t i = 0;
    for (auto it = m.begin(); it != m.end(); ++it)
      (*res)[i++] = it->first;

    return res;    
  }

  std::shared_ptr<monty::ndarray<int,1>> values()
  {
    size_t size = m.size();
    auto res = std::shared_ptr<monty::ndarray<int,1>>(new monty::ndarray<int,1>(monty::shape((int)size)));

    ptrdiff_t i = 0;
    for (auto it = m.begin(); it != m.end(); ++it)
      (*res)[i++] = it->second;

    return res;
  }

  IntMap::t clone();
  IntMap::t __mosek_2fusion_2Utils_2IntMap__clone();
};



struct p_StringIntMap
{
  StringIntMap * _pubself;

  static p_StringIntMap * _get_impl(StringIntMap * _inst) { return _inst->_impl.get(); }

  p_StringIntMap(StringIntMap * _pubself) : _pubself(_pubself) {}

  static StringIntMap::t _new_StringIntMap() { return new StringIntMap(); }

  ::std::unordered_map<std::string,int> m;

  bool hasItem (const std::string & key) { return m.find(key) != m.end(); }
  int  getItem (const std::string & key) { return m.find(key)->second; } // will probably throw something or crash of no such key
  void setItem (const std::string & key, int val) { m[key] = val; }

  std::shared_ptr<monty::ndarray<std::string,1>> keys()
  {
    size_t size = m.size();
    auto res = std::shared_ptr<monty::ndarray<std::string,1>>(new monty::ndarray<std::string,1>(monty::shape((int)size)));

    ptrdiff_t i = 0;
    for (auto it = m.begin(); it != m.end(); ++it)
      (*res)[i++] = it->first;

    return res;
  }

  std::shared_ptr<monty::ndarray<int,1>> values()
  {
    size_t size = m.size();
    auto res = std::shared_ptr<monty::ndarray<int,1>>(new monty::ndarray<int,1>(monty::shape((int)size)));

    ptrdiff_t i = 0;
    for (auto it = m.begin(); it != m.end(); ++it)
      (*res)[i++] = it->second;

    return res;
  }

  StringIntMap::t clone();
  StringIntMap::t __mosek_2fusion_2Utils_2StringIntMap__clone();
};
// End of file 'src/fusion/cxx/IntMap_p.h'
// mosek.fusion.Utils.StringBuffer from file 'src/fusion/cxx/StringBuffer_p.h'
// namespace mosek::fusion::Utils
struct p_StringBuffer
{
  StringBuffer * _pubthis; 
  std::stringstream ss;

  p_StringBuffer(StringBuffer * _pubthis) : _pubthis(_pubthis) {}

  static p_StringBuffer * _get_impl(StringBuffer::t ptr) { return ptr->_impl.get(); }
  static p_StringBuffer * _get_impl(StringBuffer * ptr) { return ptr->_impl.get(); }

  static StringBuffer::t _new_StringBuffer() { return new StringBuffer(); }

  StringBuffer::t clear ();
  
  StringBuffer::t a (const monty::ndarray<std::string,1> & val);
  StringBuffer::t a (const monty::ndarray<int,1> & val);
  StringBuffer::t a (const monty::ndarray<long long,1> & val);
  StringBuffer::t a (const monty::ndarray<double,1> & val);
  

  StringBuffer::t a (const int & val);
  StringBuffer::t a (const long long & val);
  StringBuffer::t a (const double & val);
  StringBuffer::t a (const bool & val);
  StringBuffer::t a (const std::string & val);

  StringBuffer::t lf ();
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__clear ();

  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const monty::ndarray<std::string,1> & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const monty::ndarray<int,1> & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const monty::ndarray<long long,1> & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const monty::ndarray<double,1> & val);

  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const int & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const long long & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const double & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const bool & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const std::string & val);

  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__lf ();

  std::string toString () const;
};
// End of file 'src/fusion/cxx/StringBuffer_p.h'
}
}
}
#endif
